@@ -16,26 +16,27 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
 #ifdef PRECOMP
 #	include "xmule-headers.h"
-#else
-#	include "AddFileThread.h"
-#	include "KnownFile.h"
-#	include "opcodes.h"
-#	include "otherfunctions.h"
-#	include "types.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
 #endif
 
+#include "AddFileThread.h"                  // Needed for Module's Prototype(s) - audited 4 Nov 2004
+
+#include "KnownFile.h"                      // Needed for CKnownFile - audited 4 Nov 2004
+#include "opcodes.h"                        // Needed for ID_XMULEDLG - audited 4 Nov 2004
+#include "otherfunctions.h"                 // Needed for nstrdup - audited 4 Nov 2004
+#include "xmule.h"                          // Needed for theApp - audited 4 Nov 2004
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg - audited 4 Nov 2004
+
+#include <wx/event.h>                       // Needed for wxCommandEvent
+
 struct UnknownFile_Struct
 {
     char *name;
     char *directory;
     CPartFile *owner;
-}
-
-;
+};
 
 wxMutex CAddFileThread::m_lockWaitingForHashList;
 
@@ -89,7 +90,7 @@ wxThread::ExitCode CAddFileThread::Entry()
         {
             m_lockWaitingForHashList.Unlock();
             wxCommandEvent evt(wxEVT_COMMAND_MENU_SELECTED, TM_HASHTHREADFINISHED);
-            wxPostEvent(theApp.xmuledlg, evt);
+            wxPostEvent(wxWindow::FindWindowById(ID_XMULEDLG), evt);
             return 0;
         }
         if (m_sWaitingForHashList.IsEmpty())
