@@ -3,7 +3,7 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,20 +14,20 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifndef ADDFRIEND_H
-#define ADDFRIEND_H
+#define ADDFRIEND_H 1
+
+#include "resource.h"                       // Needed for IDD_ADDFRIEND IDS_ERR_NOVALIDFRIENDINFO - audited 4 Nov 2004
 
 #include <wx/dialog.h>                      // Needed for wxDialog
 
-class CAddFriend : public wxDialog
+class CAddFriend: public wxDialog
 {
-    DECLARE_DYNAMIC_CLASS(CAddFriend)
-
 public:
     CAddFriend() {};
 
@@ -35,10 +35,12 @@ public:
     void Localize();
     virtual ~CAddFriend();
     virtual bool OnInitDialog();
+    // Dialog Data
+    enum { IDD = IDD_ADDFRIEND };
 
 private:
+    DECLARE_DYNAMIC_CLASS(CAddFriend)
     DECLARE_EVENT_TABLE()
-
     void OnAddBtn(wxCommandEvent& evt);
     void OnCloseBtn(wxCommandEvent& evt);
 };
