@@ -20,40 +20,43 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "ClientList.h"
-#include "config.h"                         // Needed for PACKAGE_VERSION
-#	include "DownloadQueue.h"
-#	include "Friend.h"
-#	include "FriendList.h"
-#	include "IPFilter.h"
-#	include "KnownFile.h"
-#	include "ListenSocket.h"
-#include "NewSockets.h"                     // Needed for NewSocket_SendPacketOP
-#	include "opcodes.h"
-#	include "otherfunctions.h"
-#include "packets.h"                        // CTag
-#include "Preferences.h"                    // CPreferences::GetUserHash
-#	include "SearchList.h"
-#include "ServerSocket.h"                   // CServerConnect
-#	include "ServerWnd.h"
-#	include "SharedFileList.h"
-#	include "TransferWnd.h"
-#	include "UploadQueue.h"
-#	include "updownclient.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
-#include "xmuleIPV4Address.h"               // xmuleIPV4Address
+    #include "xmule-headers.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include "updownclient.h"                   // Needed for Module's Prototype(s) - audited 5 Nov 2004
+
+#include "ClientCredits.h"                  // Needed for CClientCredits - audited 5 Nov 2004
+#include "ClientList.h"                     // Needed for CClientList - audited 5 Nov 2004
+#include "config.h"                         // Needed for PACKAGE_VERSION - audited 5 Nov 2004
+#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl - audited 5 Nov 2004
+#include "DownloadQueue.h"                  // Needed for CDownloadQueue - audited 5 Nov 2004
+#include "Friend.h"                         // Needed for CFriend - audited 5 Nov 2004
+#include "FriendList.h"                     // Needed for CFriendList - audited 5 Nov 2004
+#include "IPFilter.h"                       // Needed for CIPFilter - audited 5 Nov 2004
+#include "ListenSocket.h"                   // Needed for CClientReqSocket - audited 5 Nov 2004
+#include "NewSockets.h"                     // Needed for NewSocket_SendPacketOP - audited 5 Nov 2004
+#include "otherstructs.h"                   // Needed for Requested_Blocks_Struct - audited 5 Nov 2004
+#include "packets.h"                        // Needed for CTag - audited 5 Nov 2004
+#include "PartFile.h"                       // Needed for CPartFile - audited 5 Nov 2004
+#include "Preferences.h"                    // Needed for CPreferences::GetUserHash
+#include "SafeFile.h"                       // Needed for CSafeMemFile - audited 5 Nov 2004
+#include "server.h"                         // Needed for CServer - audited 5 Nov 2004
+#include "ServerListCtrl.h"                 // Needed for CServerListCtrl - audited 5 Nov 2004
+#include "sockets.h"                        // Needed for CServerConnect - audited 5 Nov 2004
+#include "ServerWnd.h"                      // Needed for CServerWnd - audited 5 Nov 2004
+#include "TransferWnd.h"                    // Needed for CTransferWnd - audited 5 Nov 2004
+#include "UploadQueue.h"                    // Needed for CUploadQueue - audited 5 Nov 2004
+#include "xmule.h"                          // Needed for theApp - audited 4 Nov 2004
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg - audited 5 Nov 2004
+#include "xmuleIPV4Address.h"               // Needed for xmuleIPV4Address - audited 5 Nov 2004
+
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <wx/hashmap.h>
+#include <wx/socket.h>                      // Needed for wxIPV4address
 
 // some client testing variables
 static wxString crash_name = "[Invalid User Name]";
@@ -70,16 +73,16 @@ CUpDownClient::CUpDownClient(CClientReqSocket *sender)
     Init();
 }
 
-CUpDownClient::CUpDownClient(uint16 in_port, uint32 in_userid, uint32 in_serverip, uint16 in_serverport, CPartFile *in_reqfile)
+CUpDownClient::CUpDownClient(uint16_t in_port, uint32_t in_userid, uint32_t in_serverip, uint16_t in_serverport, CPartFile *in_reqfile)
 {
     SpecialPerson = false;
     socket = 0;
     Init();
     m_nUserID = in_userid;
     m_nUserPort = in_port;
-    sourcesslot = m_nUserID % SOURCESSLOTS;
+    sourcesslot = 0;
     if (!HasLowID())
-    sprintf(m_szFullUserIP, "%i.%i.%i.%i", (uint8) m_nUserID, (uint8)(m_nUserID >> 8), (uint8)(m_nUserID >> 16), (uint8)(m_nUserID >> 24));
+    sprintf(m_szFullUserIP, "%i.%i.%i.%i", (uint8_t) m_nUserID, (uint8_t)(m_nUserID >> 8), (uint8_t)(m_nUserID >> 16), (uint8_t)(m_nUserID >> 24));
     m_dwServerIP = in_serverip;
     m_nServerPort = in_serverport;
     reqfile = in_reqfile;
@@ -251,7 +254,7 @@ CUpDownClient::~CUpDownClient()
         }
         delete pending;
     }
-    if (m_iRate > 0 || m_strComment.GetLength() > 0)
+    if (m_iRate > 0 || m_strComment.length() > 0)
     {
         m_iRate = 0;
         m_strComment = "";
@@ -260,13 +263,13 @@ CUpDownClient::~CUpDownClient()
     m_PendingBlocks_list.RemoveAll();
     m_AvarageUDR_list.RemoveAll();
     m_AvarageDDR_list.RemoveAll();
-//    SetUploadFileID(NULL);
+    SetUploadFileID(NULL);
 }
 
-bool CUpDownClient::ProcessHelloPacket(char *pachPacket, uint32 nSize)
+bool CUpDownClient::ProcessHelloPacket(char *pachPacket, uint32_t nSize)
 {
     CSafeMemFile data((BYTE *) pachPacket, nSize);
-    uint8 hashsize;
+    uint8_t hashsize;
     if (1 == data.Read( &hashsize, 1))
     {
         return ProcessHelloTypePacket( &data);
@@ -277,7 +280,7 @@ bool CUpDownClient::ProcessHelloPacket(char *pachPacket, uint32 nSize)
     }
 }
 
-bool CUpDownClient::ProcessHelloAnswer(char *pachPacket, uint32 nSize)
+bool CUpDownClient::ProcessHelloAnswer(char *pachPacket, uint32_t nSize)
 {
     CSafeMemFile data((BYTE *) pachPacket, nSize);
     return ProcessHelloTypePacket( &data);
@@ -290,7 +293,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
     DWORD dwEmuleTags = 0;
     if (data->Read( &m_achUserHash, 16) == 16)
     {
-        uint32 nUserID;
+        uint32_t nUserID;
         if (data->Read( &nUserID, 4) == 4)
         {
             //fsch2010:if (!m_nUserID || nUserID < 16777216)
@@ -298,14 +301,14 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
             // hmm clientport is sent twice - why?:
             if (data->Read( &m_nUserPort, 2) == 2)
             {
-                uint32 tagcount;
+                uint32_t tagcount;
                 if (data->Read( &tagcount, 4) == 4)
                 {
                     // TODO: Check if we get everything needed!
  /* It seems that various Mules and Donkeys send tagcount 2, Old MLDonkey sends
  tagcount 3, new mldonkeys 4. There are also some clients
     sending tagcount 5 and 7, what are those? */
-                    for (uint32 i = 0 ; i < tagcount ; i++)
+                    for (uint32_t i = 0 ; i < tagcount ; i++)
                     {
                         CTag *temptag = new CTag(data);
                         if (temptag->tag->tagname && !strcmp(temptag->tag->tagname, "pr"))
@@ -324,7 +327,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
                                     if (m_pszUsername)
                                     {
                                         bOldUser = true;
-                                        oldusername.Format("%s", m_pszUsername);
+                                        oldusername.Printf("%s", m_pszUsername);
                                         delete[] m_pszUsername;
                                         m_pszUsername = NULL;
                                     }
@@ -340,13 +343,13 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
                                     if ((bOldUser && (oldusername.CmpNoCase(m_pszUsername) != 0))
                                     && !thief)
                                     {
-                                        uint64 id = getUID();
+                                        uint64_t id = getUID();
 
                                         leechertype = 0;
                                         if (theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end())
                                         theApp.listensocket->offensecounter[id]++;
                                         else
-                                        theApp.listensocket->offensecounter[id] = (uint32) 1;
+                                        theApp.listensocket->offensecounter[id] = (uint32_t) 1;
                                         theApp.listensocket->offensecounter[0]++;
                                     }
                                 }
@@ -368,7 +371,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
                                     }
                                     else if(temptag->tag->type == 3)
                                     {
-                                        m_strModVersion.Format("%ModID=%u", temptag->tag->intvalue);
+                                        m_strModVersion.Printf("%ModID=%u", temptag->tag->intvalue);
                                     }
                                     else
                                     {
@@ -443,13 +446,13 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
                     {
                         if (data->Read( &m_nServerPort, 2) == 2)
                         {
-                            // Hybrid now has an extra uint32.. What is it for?
+                            // Hybrid now has an extra uint32_t.. What is it for?
                             // Also, many clients seem to send an extra 6? These are not eDonkeys or Hybrids..
                             if (data->GetLength() - data->GetPosition() == 4)
                             {
-                                uint32 test;
+                                uint32_t test;
                                 data->Read( &test, 4);
-                                if (test == (uint32) "KDLM")
+                                if (test == (uint32_t) "KDLM")
                                 {
                                     m_bIsML = true;
                                 }
@@ -499,7 +502,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
                     {
                         m_nUserID = m_dwUserIP;
                     }
-                    uchar key[16];
+                    unsigned char key[16];
                     md4cpy(key, m_achUserHash);
                     credits = theApp.clientcredits->GetCredit(key);
                     if ((m_Friend = theApp.friendlist->LinkFriend(key, m_dwUserIP, m_nUserPort)) != NULL)
@@ -508,7 +511,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
                         m_Friend->m_dwHasHash = 1;
                         for (int i = 0 ; i < 16 ; i++)
                         m_Friend->m_abyUserhash[i] = GetUserHash() [i];
-                        m_Friend->m_strName.Format("%s", m_pszUsername);
+                        m_Friend->m_strName.Printf("%s", m_pszUsername);
                         m_Friend->m_dwLastUsedIP = m_dwUserIP;
                         m_Friend->m_nLastUsedPort = m_nUserPort;
                         theApp.friendlist->RefreshFriend(m_Friend);
@@ -518,7 +521,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
                     if (!thief)
                     {
                         // Stolen Hash detection [BlackRat]
-                        uint64 id = getUID();
+                        uint64_t id = getUID();
                         if (theApp.serverconnect->GetClientID() != m_nUserID &&memcmp(m_achUserHash, theApp.glob_prefs->GetUserHash(), 16) == 0)
                         {
                             // This is a hasl stealer !
@@ -528,15 +531,15 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
                             if (theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end())
                             theApp.listensocket->offensecounter[id]++;
                             else
-                            theApp.listensocket->offensecounter[id] = (uint32) 1;
+                            theApp.listensocket->offensecounter[id] = (uint32_t) 1;
                         }
                         // Detection id change [BlackRat]
  /*
  There is still something to do here
  Actually, due to problems with HashMap, everybody here is consider as id stealers...
     */
-                        uint64 lasthash;
-                        uint64 thishash = 0;
+                        uint64_t lasthash;
+                        uint64_t thishash = 0;
                         for (int i = 0 ; i < 8 ; i++)
                         thishash += GetUserHash() [i] << (i *8) ^ GetUserHash() [i + 8] << (i *8);
                         if ((theApp.listensocket->hashbase.find(id) != theApp.listensocket->hashbase.end()) &&
@@ -547,7 +550,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
                             if (theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end())
                             theApp.listensocket->offensecounter[id]++;
                             else
-                            theApp.listensocket->offensecounter[id] = (uint32) 1;
+                            theApp.listensocket->offensecounter[id] = (uint32_t) 1;
                             theApp.listensocket->offensecounter[0]++;
                         }
                         theApp.listensocket->hashbase[id] = thishash;
@@ -606,10 +609,10 @@ void CUpDownClient::SendHelloPacket()
             return;
         }
         CMemFile *data = new CMemFile();
-        uint8 hashsize = 16;
+        uint8_t hashsize = 16;
         data->Write( &hashsize, 1);
         SendHelloTypePacket(data);
-        NewSocket_SendPacketOPdata(2, OP_HELLO, data, (wxUint32) this, 0);
+        NewSocket_SendPacketOPdata(2, OP_HELLO, data, (uint32_t) this, 0);
         delete data;
         //faz:m_bHelloAnswerPending = true;
     }
@@ -620,12 +623,12 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer)
     if (socket)
     {
         CMemFile *data = new CMemFile();
-        uint8 version = CURRENT_VERSION_SHORT;
+        uint8_t version = CURRENT_VERSION_SHORT;
         data->Write( &version, 1);
-        uint8 protversion = EMULE_PROTOCOL;
+        uint8_t protversion = EMULE_PROTOCOL;
         data->Write( &protversion, 1);
-//        uint32 tagcount = 7;
-        uint32 tagcount = 8;
+//        uint32_t tagcount = 7;
+        uint32_t tagcount = 8;
 
 /*        if (!newprefs01_opt[3])
         {
@@ -637,7 +640,7 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer)
         tag.WriteTagToFile(data);
         CTag tag2(ET_UDPVER, 3);
         tag2.WriteTagToFile(data);
-        CTag tag3(ET_UDPPORT, static_cast<uint16>(theApp.dynprefs->Get<long>("tcp-port")));
+        CTag tag3(ET_UDPPORT, static_cast<uint16_t>(theApp.dynprefs->Get<long>("tcp-port")));
         tag3.WriteTagToFile(data);
         CTag tag4(ET_SOURCEEXCHANGE, 2);
         tag4.WriteTagToFile(data);
@@ -645,7 +648,7 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer)
         tag5.WriteTagToFile(data);
         CTag tag6(ET_EXTENDEDREQUEST, 2);
         tag6.WriteTagToFile(data);
-        uint32 dwTagValue = (theApp.clientcredits->CryptoAvailable() ? 3: 0);
+        uint32_t dwTagValue = (theApp.clientcredits->CryptoAvailable() ? 3: 0);
         CTag tag7(ET_FEATURES, dwTagValue);
         tag7.WriteTagToFile(data);
 
@@ -660,20 +663,20 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer)
 
         if (!bAnswer)
         {
-            NewSocket_SendPacketOP(2, OP_EMULEINFO, packet, (wxUint32) this, 1);
+            NewSocket_SendPacketOP(2, OP_EMULEINFO, packet, (uint32_t) this, 1);
         }
         else
         {
-            NewSocket_SendPacketOP(2, OP_EMULEINFOANSWER, packet, (wxUint32) this, 1);
+            NewSocket_SendPacketOP(2, OP_EMULEINFOANSWER, packet, (uint32_t) this, 1);
         }
     }
 }
 
-void CUpDownClient::ProcessMuleInfoPacket(char *pachPacket, uint32 nSize)
+void CUpDownClient::ProcessMuleInfoPacket(char *pachPacket, uint32_t nSize)
 {
     CSafeMemFile *data = new CSafeMemFile((BYTE *) pachPacket, nSize);
     //The version number part of this packet will soon be useless since it is only able to go to v.99.
-    //Why the version is a uint8 and why it was not done as a tag like the eDonkey hello packet is not known..
+    //Why the version is a uint8_t and why it was not done as a tag like the eDonkey hello packet is not known..
     //Therefore, sooner or later, we are going to have to switch over to using the eDonkey hello packet to
     //set the version.
     //No sense making a third value sent for versions..
@@ -684,7 +687,7 @@ void CUpDownClient::ProcessMuleInfoPacket(char *pachPacket, uint32 nSize)
         {
             m_byEmuleVersion = 0x22;
         }
-        uint8 protversion;
+        uint8_t protversion;
         if (data->Read( &protversion, 1) == 1)
         {
             //implicitly supported options by older clients
@@ -703,7 +706,7 @@ void CUpDownClient::ProcessMuleInfoPacket(char *pachPacket, uint32 nSize)
                 // MLdonkey currently does not support shared directories:
                 if (m_byEmuleVersion >= 0x28 && !m_bIsML) m_bSharedDirectories = true;
                 m_bEmuleProtocol = true;
-                uint32 tagcount;
+                uint32_t tagcount;
                 if (data->Read( &tagcount, 4) == 4)
                 {
                     for (unsigned int i = 0 ; i < tagcount ; i++)
@@ -791,7 +794,7 @@ void CUpDownClient::SendHelloAnswer()
     SendHelloTypePacket(data);
     if (socket)
     {
-        NewSocket_SendPacketOPdata(2, OP_HELLOANSWER, data, (wxUint32) this, 0);
+        NewSocket_SendPacketOPdata(2, OP_HELLOANSWER, data, (uint32_t) this, 0);
     }
     delete data;
 }
@@ -808,11 +811,11 @@ printf("\n");
 */
 
     data->Write(theApp.glob_prefs->GetUserHash(), 16);
-    uint32 clientid = theApp.serverconnect->GetClientID();
+    uint32_t clientid = theApp.serverconnect->GetClientID();
     data->Write( &clientid, 4);
-    uint16 nPort = static_cast<uint16>(theApp.dynprefs->Get<long>("tcp-port"));
+    uint16_t nPort = static_cast<uint16_t>(theApp.dynprefs->Get<long>("tcp-port"));
     data->Write( &nPort, 2);
-    uint32 tagcount = 5;
+    uint32_t tagcount = 5;
     data->Write( &tagcount, 4);
     ////////START adding by sivka [xrmb: -HashThief Protection-]
     //to change from 1 to 5 -->theApp.glob_prefs->IsHashThiefProtectionEnabled()):
@@ -874,13 +877,13 @@ printf("\n");
     ////////STOP adding by sivka [xrmb: -HashThief Protection-]
     CTag tagVersion(CT_VERSION, EDONKEYVERSION);
     tagVersion.WriteTagToFile(data);
-    CTag tagUDPports(CT_EMULE_UDPPORTS, static_cast<uint32>(theApp.dynprefs->Get<long>("udp-port")));
+    CTag tagUDPports(CT_EMULE_UDPPORTS, static_cast<uint32_t>(theApp.dynprefs->Get<long>("udp-port")));
     tagUDPports.WriteTagToFile(data);
-    wxUint32 uUdpVer;
-    const wxUint32 uDataCompVer = 1;
-    const wxUint32 uSupportSecIdent = theApp.clientcredits->CryptoAvailable() ? 3: 0;
-    const wxUint32 uSourceExchangeVer = 2;
-    wxUint32 uExtendedRequestsVer;
+    uint32_t uUdpVer;
+    const uint32_t uDataCompVer = 1;
+    const uint32_t uSupportSecIdent = theApp.clientcredits->CryptoAvailable() ? 3: 0;
+    const uint32_t uSourceExchangeVer = 2;
+    uint32_t uExtendedRequestsVer;
 /*    if (newprefs02_opt[1])
     {
         uUdpVer = 4;
@@ -891,13 +894,13 @@ printf("\n");
         uUdpVer = 3;
         uExtendedRequestsVer = 0;
 //    }
-    const wxUint32 uAcceptCommentVer = 1;
+    const uint32_t uAcceptCommentVer = 1;
     CTag tagMiscOptions(CT_EMULE_MISCOPTIONS1,
     (uUdpVer << 4 *6) | (uDataCompVer << 4 *5) | (uSupportSecIdent << 4 *4) | (uSourceExchangeVer << 4 *3) |
     (uExtendedRequestsVer << 4 *2) | (uAcceptCommentVer << 4));
     tagMiscOptions.WriteTagToFile(data);
 
-    uint32 dwIP;
+    uint32_t dwIP;
 /*  
     10     0000001 0001001 010     0000001 base 2
     client maj v   minor v release revision
@@ -922,7 +925,7 @@ printf("\n");
     data->Write( &nPort, 2);
 }
 
-void CUpDownClient::ProcessMuleCommentPacket(char *pachPacket, uint32 nSize)
+void CUpDownClient::ProcessMuleCommentPacket(char *pachPacket, uint32_t nSize)
 {
     if (reqfile)
     {
@@ -947,14 +950,14 @@ void CUpDownClient::ProcessMuleCommentPacket(char *pachPacket, uint32 nSize)
                             char *desc = new char[length + 1];
                             memset(desc, 0, length + 1);
                             length == data.Read(desc, length);
-                            m_strComment.Format("%s", desc);
+                            m_strComment.Printf("%s", desc);
                             reqfile->SetHasComment(true);
                             delete[] desc;
-    if (0/*theApp.glob_prefs->GetCommentFilter() .GetLength() >0*/
-                            )
+#if 0
+                            if (0/*theApp.glob_prefs->GetCommentFilter() .GetLength() >0*/)
                             {
-                                CString resToken;
-                                CString strlink = theApp.glob_prefs->GetCommentFilter();
+                                wxString resToken;
+                                wxString strlink = theApp.glob_prefs->GetCommentFilter();
                                 strlink.MakeLower();
 
                                 ///resToken= strlink.Tokenize("|",curPos);
@@ -971,6 +974,7 @@ void CUpDownClient::ProcessMuleCommentPacket(char *pachPacket, uint32 nSize)
                                     ///resToken= strlink.Tokenize("|",curPos);
                                 }
                             }
+#endif
                         }
                     }
                 }
@@ -1201,18 +1205,18 @@ void CUpDownClient::ConnectionEstablished()
         if (theApp.uploadqueue->IsDownloading(this))
         {
             SetUploadState(US_UPLOADING);
-            NewSocket_SendPacketOPdata(2, OP_ACCEPTUPLOADREQ, NULL, (wxUint32) this, 0);
+            NewSocket_SendPacketOPdata(2, OP_ACCEPTUPLOADREQ, NULL, (uint32_t) this, 0);
         }
     }
     if (m_iFileListRequested == 1)
     {
         if (m_bSharedDirectories)
         {
-            NewSocket_SendPacketOPdata(2, OP_ASKSHAREDDIRS, NULL, (wxUint32) this, 0);
+            NewSocket_SendPacketOPdata(2, OP_ASKSHAREDDIRS, NULL, (uint32_t) this, 0);
         }
         else
         {
-            NewSocket_SendPacketOPdata(2, OP_ASKSHAREDFILES, NULL, (wxUint32) this, 0);
+            NewSocket_SendPacketOPdata(2, OP_ASKSHAREDFILES, NULL, (uint32_t) this, 0);
         }
     }
 }
@@ -1331,9 +1335,9 @@ void CUpDownClient::ReGetClientSoft()
         }
         else
         {
-            wxUint32 nClientMajVersion = (m_nClientVersion >> 17) & 0x7f;
-            wxUint32 nClientMinVersion = (m_nClientVersion >> 10) & 0x7f;
-            wxUint32 nClientUpVersion  = (m_nClientVersion >>  7) & 0x07;
+            uint32_t nClientMajVersion = (m_nClientVersion >> 17) & 0x7f;
+            uint32_t nClientMinVersion = (m_nClientVersion >> 10) & 0x7f;
+            uint32_t nClientUpVersion  = (m_nClientVersion >>  7) & 0x07;
             m_nClientVersion = form_version(nClientMajVersion, nClientMinVersion, nClientUpVersion);
             
             if (m_clientSoft == SO_EMULE)
@@ -1382,7 +1386,7 @@ void CUpDownClient::RequestSharedFileList()
     (void) TryToConnect(true);
 }
 
-void CUpDownClient::ProcessSharedFileList(char *pachPacket, uint32 nSize)
+void CUpDownClient::ProcessSharedFileList(char *pachPacket, uint32_t nSize)
 {
     if (m_iFileListRequested > 0)
     {
@@ -1420,7 +1424,7 @@ void CUpDownClient::Destroy()
     socket->Destroy();
 }
 
-void CUpDownClient::SetUserHash(uchar *m_achTempUserHash)
+void CUpDownClient::SetUserHash(unsigned char *m_achTempUserHash)
 {
     if (m_achTempUserHash == NULL)
     {
@@ -1441,13 +1445,13 @@ void CUpDownClient::SendPublicKeyPacket()
             Packet *packet = new Packet(OP_PUBLICKEY, theApp.clientcredits->GetPubKeyLen() + 1, OP_EMULEPROT);
             memcpy(packet->pBuffer + 1, theApp.clientcredits->GetPublicKey(), theApp.clientcredits->GetPubKeyLen());
             packet->pBuffer[0] = theApp.clientcredits->GetPubKeyLen();
-            NewSocket_SendPacketOP(2, OP_PUBLICKEY, packet, (wxUint32) this, 0);
+            NewSocket_SendPacketOP(2, OP_PUBLICKEY, packet, (uint32_t) this, 0);
             m_SecureIdentState = IS_SIGNATURENEEDED;
         }
     }
 }
 
-void CUpDownClient::ProcessSecIdentStatePacket(unsigned char *pachPacket, wxUint32 nSize)
+void CUpDownClient::ProcessSecIdentStatePacket(unsigned char *pachPacket, uint32_t nSize)
 {
     if (nSize == 5)
     {
@@ -1465,7 +1469,7 @@ void CUpDownClient::ProcessSecIdentStatePacket(unsigned char *pachPacket, wxUint
                 m_SecureIdentState = IS_KEYANDSIGNEEDED;
                 break;
             }
-            uint32 dwRandom;
+            uint32_t dwRandom;
             memcpy( &dwRandom, pachPacket+1, 4);
             credits->m_dwCryptRndChallengeFrom = dwRandom;
         }
@@ -1497,8 +1501,8 @@ void CUpDownClient::SendSignaturePacket()
                     {
                         bUseV2 = true;
                     }
-                    uint8 byChaIPKind = 0;
-                    uint32 ChallengeIP = 0;
+                    uint8_t byChaIPKind = 0;
+                    uint32_t ChallengeIP = 0;
                     if (bUseV2)
                     {
                         if (theApp.serverconnect->GetClientID() == 0 || theApp.serverconnect->IsLowID())
@@ -1514,8 +1518,8 @@ void CUpDownClient::SendSignaturePacket()
                         }
                     }
                     //end v2
-                    uchar achBuffer[250];
-                    uint8 siglen = theApp.clientcredits->CreateSignature(credits, achBuffer, 250, ChallengeIP,byChaIPKind);
+                    unsigned char achBuffer[250];
+                    uint8_t siglen = theApp.clientcredits->CreateSignature(credits, achBuffer, 250, ChallengeIP,byChaIPKind);
                     (void)theApp.clientcredits->VerifyIdent(credits, achBuffer, siglen, GetIP(),byChaIPKind);
                     if (siglen)
                     {
@@ -1526,7 +1530,7 @@ void CUpDownClient::SendSignaturePacket()
                         {
                             packet->pBuffer[1 + siglen] = byChaIPKind;
                         }
-                        NewSocket_SendPacketOP(2, OP_SIGNATURE, packet, (wxUint32) this, 0);
+                        NewSocket_SendPacketOP(2, OP_SIGNATURE, packet, (uint32_t) this, 0);
                         m_SecureIdentState = IS_ALLREQUESTSSEND;
                     }
                 }
@@ -1563,7 +1567,7 @@ void CUpDownClient::ResetFileStatusInfo()
  }
     */
 
-void CUpDownClient::ProcessPublicKeyPacket(uchar *pachPacket, uint32 nSize)
+void CUpDownClient::ProcessPublicKeyPacket(unsigned char *pachPacket, uint32_t nSize)
 {
     //fsch2010removedtheApp.clientlist->AddTrackClient(this);
     /// delete this line later
@@ -1593,7 +1597,7 @@ void CUpDownClient::ProcessPublicKeyPacket(uchar *pachPacket, uint32 nSize)
 void CUpDownClient::SendSecIdentStatePacket()
 {
     // check if we need public key and signature
-    uint8 nValue = 0;
+    uint8_t nValue = 0;
     if (credits)
     {
         if (theApp.clientcredits->CryptoAvailable())
@@ -1610,17 +1614,17 @@ void CUpDownClient::SendSecIdentStatePacket()
         if (nValue)
         {
             // crypt: send random data to sign
-            uint32 dwRandom = rand() + 1;
+            uint32_t dwRandom = rand() + 1;
             credits->m_dwCryptRndChallengeFor = dwRandom;
             Packet *packet = new Packet(OP_SECIDENTSTATE, 5, OP_EMULEPROT);
             packet->pBuffer[0] = nValue;
             memcpy(packet->pBuffer + 1, &dwRandom, sizeof(dwRandom));
-            NewSocket_SendPacketOP(2, OP_SECIDENTSTATE, packet, (wxUint32) this, 0);
+            NewSocket_SendPacketOP(2, OP_SECIDENTSTATE, packet, (uint32_t) this, 0);
         }
     }
 }
 
-void CUpDownClient::ProcessSignaturePacket(uchar *pachPacket, uint32 nSize)
+void CUpDownClient::ProcessSignaturePacket(unsigned char *pachPacket, uint32_t nSize)
 {
     /// delete this line later
     // here we spread the good guys from the bad ones ;)
@@ -1628,7 +1632,7 @@ void CUpDownClient::ProcessSignaturePacket(uchar *pachPacket, uint32 nSize)
     {
         return;
     }
-    uint8 byChaIPKind;
+    uint8_t byChaIPKind;
     if (pachPacket[0] == nSize - 1)
     {
         byChaIPKind = 0;
@@ -1685,7 +1689,7 @@ void CUpDownClient::InfoPacketsReceived()
  AddLogLine(true, GetResString(IDS_ERR_PREVIEWALREADY));
  }
  }
- void CUpDownClient::SendPreviewAnswer(CKnownFile* pForFile, CxImage** imgFrames, uint8 nCount) {
+ void CUpDownClient::SendPreviewAnswer(CKnownFile* pForFile, CxImage** imgFrames, uint8_t nCount) {
  m_bPreviewAnsPending = false;
  CSafeMemFile data(1024);
  if (pForFile) {
@@ -1721,27 +1725,27 @@ void CUpDownClient::InfoPacketsReceived()
  printf("CUpDownClient::SendPreviewAnswer: OP_PREVIEWANSWER size=%ld\n",packet->size);
  SafeSendPacket(packet);//okdeb
  }
- void CUpDownClient::ProcessPreviewReq(char* pachPacket, uint32 nSize) {
+ void CUpDownClient::ProcessPreviewReq(char* pachPacket, uint32_t nSize) {
  if (nSize < 16)
  throw GetResString(IDS_ERR_WRONGPACKAGESIZE);
  if (m_bPreviewAnsPending|| theApp.glob_prefs->ServePreview() ==2|| (theApp.glob_prefs->ServePreview() ==1&& !IsFriend()))
  return;
  m_bPreviewAnsPending = true;
- CKnownFile* previewFile = theApp.sharedfiles->GetFileByID((uchar*) pachPacket);
+ CKnownFile* previewFile = theApp.sharedfiles->GetFileByID((unsigned char*) pachPacket);
  if (previewFile == NULL) {
  SendPreviewAnswer(NULL, NULL, 0);
  } else {
  previewFile->GrabImage(4,0,true,450,this);
  }
  }
- void CUpDownClient::ProcessPreviewAnswer(char* pachPacket, uint32 nSize) {
+ void CUpDownClient::ProcessPreviewAnswer(char* pachPacket, uint32_t nSize) {
  if (!m_bPreviewReqPending)
  return;
  m_bPreviewReqPending = false;
  CSafeMemFile data((BYTE*) pachPacket,nSize);
- uchar Hash[16];
+ unsigned char Hash[16];
  data.Read(Hash,16);
- uint8 nCount;
+ uint8_t nCount;
  data.Read(&nCount,1);
  if (nCount == 0) {
  // to res table -later
@@ -1777,7 +1781,7 @@ bool CUpDownClient::SafeSendPacket(Packet *packet)
     {
         if (socket->IsConnected())
         {
-            NewSocket_SendPacket(4, packet, (wxUint32) this, 0);
+            NewSocket_SendPacket(4, packet, (uint32_t) this, 0);
         }
         else
         {
