@@ -22,15 +22,14 @@
 
 // something that looks like the MFC CMemFile
 
-#include "wintypes.h"
-#include "CFile.h"
+#include "CFile.h"                          // CFile - audited 5 Nov 2004
 
 class CMemFile : public CFile {
 public:  
 	CMemFile(unsigned int growBytes=1024);
-	CMemFile(BYTE* buffer,unsigned int bufferSize,unsigned int growBytes=0);
-	void Attach(BYTE* buffer,unsigned int buffserSize,unsigned int growBytes=0);
-	BYTE* Detach();
+	CMemFile(unsigned char* buffer,unsigned int bufferSize,unsigned int growBytes=0);
+	void Attach(unsigned char* buffer,unsigned int buffserSize,unsigned int growBytes=0);
+	unsigned char* Detach();
 	virtual ~CMemFile();
 	virtual unsigned long GetPosition() {return fPosition;};
 	virtual bool GetStatus(unsigned long none) const {return 1;};
@@ -52,7 +51,7 @@ private:
 	unsigned long fBufferSize;
 	unsigned long fFileSize;
 	int deleteBuffer;
-	BYTE* fBuffer;
+	unsigned char* fBuffer;
 };
 
 #endif
