@@ -23,22 +23,22 @@
     #include "xmule-headers.h"
 #endif
 
-#include "CatDialog.h"                      // Needed for this Interface's Prototype
+#include "CatDialog.h"                      // Needed for Module's Prototype(s) - audited 5 Nov 2004
 
-#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl
-#include "otherfunctions.h"                 // Needed for GetResString
-#include "Preferences.h"                    // CPreferences::GetCategory
-#include "SharedFileList.h"                 // Needed for CSharedFileList
-#include "TransferWnd.h"                    // Needed for CTransferWnd
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for CxmuleDlg
+#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl - audited 5 Nov 2004
+#include "otherfunctions.h"                 // Needed for GetResString - audited 5 Nov 2004
+#include "Preferences.h"                    // CPreferences::GetCategory - audited 5 Nov 2004
+#include "SharedFileList.h"                 // Needed for CSharedFileList - audited 5 Nov 2004
+#include "TransferWnd.h"                    // Needed for CTransferWnd - audited 5 Nov 2004
+#include "xmule.h"                          // Needed for theApp - audited 5 Nov 2004
+#include "xmuleDlg.h"                       // Needed for CxmuleDlg - audited 5 Nov 2004
 
 #include <wx/button.h>                      // Needed for wxButton
 #include <wx/colordlg.h>                    // Needed for wxGetColourFromUser
 #include <wx/combobox.h>                    // Needed for wxComboBox
 #include <wx/dirdlg.h>                      // Needed for wxDirSelector
 #include <wx/textctrl.h>                    // Needed for wxTextCtrl
-
+#include <iostream>
 #if defined(HAVE_XRC)
     #include <wx/xrc/xmlres.h>              // Needed for wxXmlResource
     #define SMARTID(A) (XRCID(#A))
@@ -60,7 +60,7 @@
         IDC_TITLE
     };
 #endif
-
+using namespace std;
 #define GetRValue(rgb) (((rgb)>>16)&0xff)
 #define GetGValue(rgb) (((rgb)>>8)&0xff)
 #define GetBValue(rgb) ((rgb)&0xff)
@@ -97,7 +97,7 @@ CCatDialog::CCatDialog(wxWindow *parent, int index)
     wxTextCtrl* item6 = new wxTextCtrl( item1, IDC_TITLE, _T(""), wxDefaultPosition, wxDefaultSize, 0);
     item4->Add(item6, 0, wxALIGN_CENTER_VERTICAL|wxLEFT|wxRIGHT|wxBOTTOM, 5);
 
-    wxStaticText* item7 = new wxStaticText( item1, wxID_STATIC, _("Comment:"), wxDefaultPosition, wxDefaultSize, 0);
+    wxStaticText* item7 = new wxStaticText( item1, wxID_STATIC, _("Description:"), wxDefaultPosition, wxDefaultSize, 0);
     item2->Add(item7, 0, wxALIGN_LEFT|wxLEFT|wxRIGHT|wxTOP|wxADJUST_MINSIZE, 5);
 
     wxBoxSizer* item8 = new wxBoxSizer(wxHORIZONTAL);
@@ -168,9 +168,9 @@ bool CCatDialog::OnInitDialog()
 
     m_ctlColor = GetDlgItem(IDC_CATCOLOR, wxButton);
 
-    GetDlgItem(IDC_TITLE, wxTextCtrl)->SetValue(wxString(m_myCat->title, *wxConvCurrent));    
-    GetDlgItem(IDC_INCOMING, wxTextCtrl)->SetValue(wxString(m_myCat->incomingpath, *wxConvCurrent));
-    GetDlgItem(IDC_COMMENT, wxTextCtrl)->SetValue(wxString(m_myCat->comment, *wxConvCurrent));
+    GetDlgItem(IDC_TITLE, wxTextCtrl)->SetValue(m_myCat->title);
+    GetDlgItem(IDC_INCOMING, wxTextCtrl)->SetValue(m_myCat->incomingpath);
+    GetDlgItem(IDC_COMMENT, wxTextCtrl)->SetValue(m_myCat->comment);
     newcolor = m_myCat->color;
 
     m_prio->Append(GetResString(IDS_DONTCHANGE));
@@ -197,19 +197,19 @@ void CCatDialog::OnBnClickedBrowse(wxCommandEvent &evt)
 
 void CCatDialog::OnBnClickedOk(wxCommandEvent &evt)
 {
-    CString oldpath = CString(m_myCat->incomingpath);
+    wxString oldpath = m_myCat->incomingpath;
 
     if (GetDlgItem(IDC_TITLE, wxTextCtrl)->GetValue().Length() > 0)
     {
-        strncpy(m_myCat->title, GetDlgItem(IDC_TITLE, wxTextCtrl)->GetValue(), 64);
+        m_myCat->title = GetDlgItem(IDC_TITLE, wxTextCtrl)->GetValue();
     }
 
     if (GetDlgItem(IDC_INCOMING, wxTextCtrl)->GetValue().Length() > 1)
     {
-        strncpy(m_myCat->incomingpath, GetDlgItem(IDC_INCOMING, wxTextCtrl)->GetValue(), MAX_PATH);
+        m_myCat->incomingpath = GetDlgItem(IDC_INCOMING, wxTextCtrl)->GetValue();
     }
 
-    strncpy(m_myCat->comment, GetDlgItem(IDC_COMMENT, wxTextCtrl)->GetValue(), 255);
+    m_myCat->comment = GetDlgItem(IDC_COMMENT, wxTextCtrl)->GetValue();
     MakeFoldername(m_myCat->incomingpath);
 
     if (!::wxDirExists(m_myCat->incomingpath))
@@ -217,13 +217,14 @@ void CCatDialog::OnBnClickedOk(wxCommandEvent &evt)
         wxMkdir(m_myCat->incomingpath, 0777);
     }
 
-    if (CString(m_myCat->incomingpath).CmpNoCase(oldpath) != 0)
+    if (m_myCat->incomingpath.CmpNoCase(oldpath) != 0)
     {
         theApp.sharedfiles->AddFilesFromDirectory(m_myCat->incomingpath);
         theApp.sharedfiles->Reload();
     }
     
     m_myCat->color = newcolor;
+    cout << "cat color: " << std::hex << newcolor << endl;
     m_myCat->prio = m_prio->GetSelection();
     theApp.xmuledlg->transferwnd->downloadlistctrl->Refresh();
     EndModal(0);
