@@ -3,7 +3,7 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -22,26 +22,36 @@
 #ifndef CHATWND_H
 #define CHATWND_H 1
 
-#include <wx/panel.h>                   // Needed for wxPanel
+#include "resource.h"                       // Needed for IDD_CHAT - audited 4 Nov 2004
+
+#include <wx/panel.h>                       // Needed for wxPanel
 
 class CUpDownClient;
 
 class CChatWnd : public wxPanel //CResizableDialog
 {
 public:
-	CChatWnd(wxWindow* pParent = NULL);   // standard constructor
-	virtual ~CChatWnd();
+    CChatWnd(wxWindow* pParent = NULL);   // standard constructor
+    virtual ~CChatWnd();
 
 // Dialog Data
-	enum
-        {
-            IDD_CHAT,
-            IDD = IDD_CHAT
-        };
-	void StartSession(CUpDownClient* client);
-	void Localize();
-	//CChatSelector chatselector;
-protected:
-};
+    enum
+    {
+        IDD = IDD_CHAT
+    };
 
+    void StartSession(CUpDownClient* client);
+    void Localize();
+protected:
+/*
+    virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support	
+    DECLARE_MESSAGE_MAP()
+    virtual bool OnInitDialog(); 
+    afx_msg void OnBnClickedCsend();
+    void	OnShowWindow(bool bShow,UINT nStatus);
+    virtual bool	PreTranslateMessage(MSG* pMsg);
+public:
+    afx_msg void OnBnClickedCclose();
+*/
+};
 #endif
