@@ -20,34 +20,32 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "ClientCredits.h"
-#	include "opcodes.h"
-#include "otherfunctions.h"                 // md4cpy
-#	include "resource.h"
-#	include "SafeFile.h"
-#	include "updownclient.h"
-#	include "wintypes.h"
-#	include "sockets.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
-#	include "NewFunctions.h"
+    #include "xmule-headers.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include "ClientCredits.h"                  // Needed for Module's Prototype(s) - audited 5 Nov 2004
 
-#include <math.h>
-#include <time.h>
+#include "config.h"                         // Needed for HAVE_CRYPTO - audited 5 Nov 2004
+#include "NewFunctions.h"                   // Needed for MAP - audited 5 Nov 2004
+#include "opcodes.h"                        // Needed for CREDITFILE_VERSION - audited 4 Nov 2004
+#include "otherfunctions.h"                 // Needed for md4cpy - audited 4 Nov 2004
+#include "resource.h"                       // Needed for IDS_ERR_CREDITFILEOLD - audited 4 Nov 2004
+#include "sockets.h"                        // Needed for CServerConnect - audited 5 Nov 2004
+#include "wintypes.h"                       // Needed for BYTE - audited 5 Nov 2004
+#include "xmule.h"                          // Needed for theApp - audited 4 Nov 2004
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg - audited 4 Nov 2004
+
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
+
+#include <cmath>
+#include <ctime>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <wx/utils.h>
 #include <wx/file.h>                        // Needed for wxFile
 
-#include "config.h"
-
-#if !HAVE_CRYPTO
+#if !HAVE_CRYPTOPP
     #include "CryptoXMpp.h"
 #else
     #include <cryptopp/config.h>
@@ -58,18 +56,11 @@
     #define CryptoXMpp CryptoPP
 #endif
 
-#ifdef _DEBUG
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
-
-#define new DEBUG_NEW
-#endif
-
 #define		CLIENTS_MET_FILENAME	"clients.met"
 
 MAP * mcc = NULL;
 
-uint32 ldwForIP;
+uint32_t ldwForIP;
 
 using namespace CryptoXMpp;
 
@@ -82,7 +73,7 @@ CClientCredits::CClientCredits(CreditStruct * in_credits)
     m_dwWaitTimeIP = 0;
 }
 
-CClientCredits::CClientCredits(uchar * key)
+CClientCredits::CClientCredits(unsigned char * key)
 {
     m_pCredits = new CreditStruct;
     memset(m_pCredits, 0, sizeof(CreditStruct));
@@ -98,24 +89,24 @@ CClientCredits::~ CClientCredits()
     delete m_pCredits;
 }
 
-void CClientCredits::AddDownloaded(uint32 bytes, uint32 dwForIP)
+void CClientCredits::AddDownloaded(uint32_t bytes, uint32_t dwForIP)
 {
     if ((GetCurrentIdentState(dwForIP) == IS_IDFAILED || GetCurrentIdentState(dwForIP) == IS_IDBADGUY ||
-    GetCurrentIdentState(dwForIP) == IS_IDNEEDED) && theApp. clientcredits->CryptoAvailable())
+    GetCurrentIdentState(dwForIP) == IS_IDNEEDED) && theApp.clientcredits->CryptoAvailable())
     {
         return;
     }
     //encode
-    uint64 current = m_pCredits->nDownloadedHi;
+    uint64_t current = m_pCredits->nDownloadedHi;
     current = (current << 32) + m_pCredits->nDownloadedLo + bytes;
     //recode
-    m_pCredits->nDownloadedLo = (uint32) current;
-    m_pCredits->nDownloadedHi = (uint32)(current >> 32);
+    m_pCredits->nDownloadedLo = (uint32_t) current;
+    m_pCredits->nDownloadedHi = (uint32_t)(current >> 32);
 }
 
-void CClientCredits::ShowCHandPK(uint32 challenge, unsigned char * pk, int length)
+void CClientCredits::ShowCHandPK(uint32_t challenge, unsigned char * pk, int length)
 {
-    printf("    credits=%u  challenge=%u  length=%d  publickey=", (uint32) this, challenge, length);
+    printf("    credits=%u  challenge=%u  length=%d  publickey=", (uint32_t) this, challenge, length);
     for (int i = 0 ; i < length ; i++)
     {
         if (i < 5 || i > length - 6)
@@ -126,36 +117,36 @@ void CClientCredits::ShowCHandPK(uint32 challenge, unsigned char * pk, int lengt
     printf("\n");
 }
 
-void CClientCredits::AddUploaded(uint32 bytes, uint32 dwForIP)
+void CClientCredits::AddUploaded(uint32_t bytes, uint32_t dwForIP)
 {
-    if ((GetCurrentIdentState(dwForIP) == IS_IDFAILED || GetCurrentIdentState(dwForIP) == IS_IDBADGUY || GetCurrentIdentState(dwForIP) == IS_IDNEEDED) && theApp. clientcredits->CryptoAvailable())
+    if ((GetCurrentIdentState(dwForIP) == IS_IDFAILED || GetCurrentIdentState(dwForIP) == IS_IDBADGUY || GetCurrentIdentState(dwForIP) == IS_IDNEEDED) && theApp.clientcredits->CryptoAvailable())
     {
         return;
     }
     else
     {
-        uint64 current = m_pCredits->nUploadedHi;
+        uint64_t current = m_pCredits->nUploadedHi;
         current = (current << 32) + m_pCredits->nUploadedLo + bytes;
-        m_pCredits->nUploadedLo = (uint32) current;
-        m_pCredits->nUploadedHi = (uint32)(current >> 32);
+        m_pCredits->nUploadedLo = (uint32_t) current;
+        m_pCredits->nUploadedHi = (uint32_t)(current >> 32);
     }
 }
 
-uint64 CClientCredits::GetUploadedTotal()
+uint64_t CClientCredits::GetUploadedTotal()
 {
-    return((uint64) m_pCredits->nUploadedHi << 32) + m_pCredits->nUploadedLo;
+    return((uint64_t) m_pCredits->nUploadedHi << 32) + m_pCredits->nUploadedLo;
 }
 
-uint64 CClientCredits::GetDownloadedTotal()
+uint64_t CClientCredits::GetDownloadedTotal()
 {
-    return((uint64) m_pCredits->nDownloadedHi << 32) + m_pCredits->nDownloadedLo;
+    return((uint64_t) m_pCredits->nDownloadedHi << 32) + m_pCredits->nDownloadedLo;
 }
 
-float CClientCredits::GetScoreRatio(wxUint32 dwForIP)
+float CClientCredits::GetScoreRatio(uint32_t dwForIP)
 {
     // Check the client ident status
     if ((GetCurrentIdentState(dwForIP) == IS_IDFAILED || GetCurrentIdentState(dwForIP) == IS_IDNEEDED) &&
-    theApp. clientcredits->CryptoAvailable() == true)
+    theApp.clientcredits->CryptoAvailable() == true)
     {
         // bad guy - no credits for you
         return 1;
@@ -163,7 +154,7 @@ float CClientCredits::GetScoreRatio(wxUint32 dwForIP)
     else
     {
         // Cache value
-        const uint64 downloadTotal = GetDownloadedTotal();
+        const uint64_t downloadTotal = GetDownloadedTotal();
         // Check if this client has any credit (sent >1MB)
         if (downloadTotal < 1000000)
         {
@@ -172,7 +163,7 @@ float CClientCredits::GetScoreRatio(wxUint32 dwForIP)
         else
         {
             // Cache value
-            const uint64 uploadTotal = GetUploadedTotal();
+            const uint64_t uploadTotal = GetUploadedTotal();
             // Factor 1
             float result = (uploadTotal == 0) ?
             10.0f: (float)(2 * downloadTotal) / (float) uploadTotal;
@@ -202,12 +193,12 @@ float CClientCredits::GetScoreRatio(wxUint32 dwForIP)
 // Maella end
 
 // added by sivka [VQB: -ownCredits-]
-float CClientCredits::GetMyScoreRatio(uint32 dwForIP)
+float CClientCredits::GetMyScoreRatio(uint32_t dwForIP)
 {
     // check the client ident status
-    if ((GetCurrentIdentState(dwForIP) == IS_IDFAILED || GetCurrentIdentState(dwForIP) == IS_IDNEEDED) && theApp. clientcredits->CryptoAvailable())
+    if ((GetCurrentIdentState(dwForIP) == IS_IDFAILED || GetCurrentIdentState(dwForIP) == IS_IDNEEDED) && theApp.clientcredits->CryptoAvailable())
     {
-        // bad guy - no credits for... me?
+        // bad guy - no credits for...me?
         return 1;
     }
     if (GetUploadedTotal() < 1000000)
@@ -270,12 +261,12 @@ void CClientCreditsList::LoadList()
     
     if (loadlist.Open(strFileName, wxFile::read))
     {
-        uint8 version;
+        uint8_t version;
         loadlist.Read(&version, 1);
 
         if (version != CREDITFILE_VERSION && version != CREDITFILE_VERSION_29)
         {
-            theApp. xmuledlg->AddLogLine(false, GetResString(IDS_ERR_CREDITFILEOLD));
+            theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_CREDITFILEOLD));
             loadlist.Close();
         }
         else
@@ -283,7 +274,7 @@ void CClientCreditsList::LoadList()
             struct stat loadlistbuf;
             fstat(loadlist.fd(), &loadlistbuf);
             wxString strBakFileName(strFileName + wxT(".BAK"));
-            BOOL bCreateBackup = TRUE;
+            bool bCreateBackup = TRUE;
             wxFile hBakFile;
 
             if (hBakFile.Open(strBakFileName, wxFile::read))
@@ -305,7 +296,7 @@ void CClientCreditsList::LoadList()
 
                 if (!SafeCopyFile(strFileName, strBakFileName))
                 {
-                    printf("info: Could not create backup file '%s'\n", strFileName. c_str());
+                    printf("info: Could not create backup file '%s'\n", strFileName.c_str());
                 }
 
                 if (loadlist.Open(strFileName, wxFile::read))
@@ -314,13 +305,13 @@ void CClientCreditsList::LoadList()
                 }
             }
 
-            uint32 count;
+            uint32_t count;
             loadlist.Read(&count, 4);
-            // TODO: should be prime number... and 20% larger
-            const uint32 dwExpired = time(NULL) - 12960000;
+            // TODO: should be prime number...and 20% larger
+            const uint32_t dwExpired = time(NULL) - 12960000;
             // today - 150 day
-            uint32 cDeleted = 0;
-            for (uint32 i = 0 ; i < count ; i++)
+            uint32_t cDeleted = 0;
+            for (uint32_t i = 0 ; i < count ; i++)
             {
                 CreditStruct * newcstruct = new CreditStruct;
                 memset(newcstruct, 0, sizeof(CreditStruct));
@@ -346,29 +337,39 @@ void CClientCreditsList::LoadList()
     }
     else
     {
-        theApp. xmuledlg->AddLogLine(true, GetResString(IDS_ERR_LOADCREDITFILE));
+        theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_LOADCREDITFILE));
     }
 }
 
+#include <fstream>
+using std::endl;
+using std::ofstream;
+
 void CClientCreditsList::SaveList()
 {
-    FILE * savelist;
     m_nLastSaved =::GetTickCount();
     wxString name(theApp.dynprefs->Get<wxString>("app-directory") + wxString(CLIENTS_MET_FILENAME, *wxConvCurrent));
-    savelist = fopen((const char *) name, "w");
-    if (savelist)
+
+    ofstream savelist;
+
+    savelist.open(name.c_str(), ofstream::out | ofstream::binary);
+
+    if (savelist && (savelist.good() == true))
     {
-        BYTE * pBuffer = new BYTE[MapData_GetCount(mcc) * sizeof(CreditStruct) ];
-        wxUint32 count = 0;
-        CClientCredits * cur_client;
-        MAP * pos;
+        BYTE* pBuffer = new BYTE[MapData_GetCount(mcc) * sizeof(CreditStruct)];
+        uint32_t count = 0;
+        CClientCredits* cur_client;
+        MAP* pos;
         pos = mcc;
+
         do
         {
             pos = MapData_GetNext(pos);
+
             if (pos)
             {
-                cur_client = (CClientCredits *) MapData_GetIt(pos);
+                cur_client = static_cast<CClientCredits *>(MapData_GetIt(pos));
+
                 if (cur_client)
                 {
                     if (cur_client->GetUploadedTotal() || cur_client->GetDownloadedTotal())
@@ -381,17 +382,20 @@ void CClientCreditsList::SaveList()
             }
         }
         while (pos);
+
         wxUint8 version = CREDITFILE_VERSION;
-        (void) fwrite( & version, 1, 1, savelist);
-        (void) fwrite( & count, sizeof(count), 1, savelist);
-        (void) fwrite(pBuffer, sizeof(CreditStruct), count, savelist);
-        (void) fflush(savelist);
-        (void) fclose(savelist);
+
+        savelist.write(reinterpret_cast<char *>(&version), 1);
+        savelist.write(reinterpret_cast<char *>(&count), sizeof(count));
+        savelist.write(reinterpret_cast<char *>(pBuffer), sizeof(CreditStruct) * count);
+        savelist.flush();
+        savelist.close();
+
         delete[] pBuffer;
     }
 }
 
-CClientCredits * CClientCreditsList::GetCredit(uchar * key)
+CClientCredits * CClientCreditsList::GetCredit(unsigned char * key)
 {
     CClientCredits * result;
     MAP * pos;
@@ -437,7 +441,7 @@ void CClientCredits::InitalizeIdent()
     m_dwIdentIP = 0;
 }
 
-void CClientCredits::Verified(uint32 dwForIP)
+void CClientCredits::Verified(uint32_t dwForIP)
 {
     m_dwIdentIP = dwForIP;
     // client was verified, copy the keyto store him if not done already
@@ -458,7 +462,7 @@ void CClientCredits::Verified(uint32 dwForIP)
     IdentState = IS_IDENTIFIED;
 }
 
-bool CClientCredits::SetSecureIdent(uchar * pachIdent, uint8 nIdentLen)
+bool CClientCredits::SetSecureIdent(unsigned char * pachIdent, uint8_t nIdentLen)
 {
     // verified Public key cannot change, use only if there is not public key yet
     if (MAXPUBKEYSIZE < nIdentLen || m_pCredits->nKeySize != 0)
@@ -474,7 +478,7 @@ bool CClientCredits::SetSecureIdent(uchar * pachIdent, uint8 nIdentLen)
     }
 }
 
-EIdentState CClientCredits::GetCurrentIdentState(uint32 dwForIP)
+EIdentState CClientCredits::GetCurrentIdentState(uint32_t dwForIP)
 {
     if (ldwForIP != dwForIP)
     {
@@ -539,9 +543,9 @@ void CClientCreditsList::InitalizeCrypting()
         // calculate and store public key
         RSASSA_PKCS1v15_SHA_Verifier pubkey(*m_pSignkey);
         ArraySink asink(m_abyMyPublicKey, 80);
-        pubkey. DEREncode(asink);
-        m_nMyPublicKeyLen = asink. TotalPutLength();
-        asink. MessageEnd();
+        pubkey.DEREncode(asink);
+        m_nMyPublicKeyLen = asink.TotalPutLength();
+        asink.MessageEnd();
         printf("PublicKey: keylen=%u\n", m_nMyPublicKeyLen);
         for (int i = 0 ; i < m_nMyPublicKeyLen ; i++)
         {
@@ -558,13 +562,13 @@ void CClientCreditsList::CreateKeyPair()
 {
     AutoSeededRandomPool rng;
     InvertibleRSAFunction privkey;
-    privkey. Initialize(rng, 384);
+    privkey.Initialize(rng, 384);
     Base64Encoder privkeysink(new FileSink(wxString(theApp.dynprefs->Get<wxString>("app-directory") + wxT("cryptkey.dat"))));
-    privkey. DEREncode(privkeysink);
-    privkeysink. MessageEnd();
+    privkey.DEREncode(privkeysink);
+    privkeysink.MessageEnd();
 }
 
-uint8 CClientCreditsList::CreateSignature(CClientCredits * pTarget, uchar * pachOutput, uint8 nMaxSize, uint32 ChallengeIP, uint8 byChaIPKind)
+uint8_t CClientCreditsList::CreateSignature(CClientCredits * pTarget, unsigned char * pachOutput, uint8_t nMaxSize, uint32_t ChallengeIP, uint8_t byChaIPKind)
 {
     RSASSA_PKCS1v15_SHA_Signer * sigkey = NULL;
     StringSource ss_Pubkey((byte *) pTarget->GetSecureIdent(), pTarget->GetSecIDKeyLen(), true, 0);
@@ -574,35 +578,35 @@ uint8 CClientCreditsList::CreateSignature(CClientCredits * pTarget, uchar * pach
     SecByteBlock sbbSignature(sigkey->SignatureLength());
     AutoSeededRandomPool rng;
     byte abyBuffer[MAXPUBKEYSIZE + 9];
-    uint32 keylen = pTarget->GetSecIDKeyLen();
+    uint32_t keylen = pTarget->GetSecIDKeyLen();
     memcpy(abyBuffer, pTarget->GetSecureIdent(), keylen);
     // 4 additional bytes random data send from this client
-    uint32 challenge = pTarget->m_dwCryptRndChallengeFrom;
+    uint32_t challenge = pTarget->m_dwCryptRndChallengeFrom;
     memcpy(abyBuffer + keylen, & challenge, 4);
-    uint16 ChIpLen = 4;
+    uint16_t ChIpLen = 4;
     if (byChaIPKind != 0)
     {
         memcpy(abyBuffer + keylen + 4, & ChallengeIP, 4);
         memcpy(abyBuffer + keylen + 4 + 4, & byChaIPKind, 1);
         ChIpLen += 5;
     }
-    for (unsigned int i = 0 ; i < sbbSignature. size() ; i++)
+    for (unsigned int i = 0 ; i < sbbSignature.size() ; i++)
     {
         sbbSignature.begin() [i] = 0;
     }
-    sigkey->SignMessage(rng, abyBuffer, keylen + ChIpLen, sbbSignature. begin());
-    if (nMaxSize > sbbSignature. size())
+    sigkey->SignMessage(rng, abyBuffer, keylen + ChIpLen, sbbSignature.begin());
+    if (nMaxSize > sbbSignature.size())
     {
-        nMaxSize = sbbSignature. size();
+        nMaxSize = sbbSignature.size();
     }
     for (int i = 0 ; i < nMaxSize ; i++)
     {
-        pachOutput[i] = ((unsigned char *) sbbSignature. begin()) [i];
+        pachOutput[i] = ((unsigned char *) sbbSignature.begin()) [i];
     }
-    return(uint8) nMaxSize;
+    return(uint8_t) nMaxSize;
 }
 
-bool CClientCreditsList::VerifyIdent(CClientCredits * pTarget, uchar * pachSignature, uint8 nInputSize, uint32 dwForIP, uint8 byChaIPKind)
+bool CClientCreditsList::VerifyIdent(CClientCredits * pTarget, unsigned char * pachSignature, uint8_t nInputSize, uint32_t dwForIP, uint8_t byChaIPKind)
 {
     bool bResult;
     StringSource ss_Pubkey((byte *) pTarget->GetSecureIdent(), pTarget->GetSecIDKeyLen(), true, 0);
@@ -610,27 +614,27 @@ bool CClientCreditsList::VerifyIdent(CClientCredits * pTarget, uchar * pachSigna
     // 4 additional bytes random data send from this client +5 bytes v2
     byte abyBuffer[MAXPUBKEYSIZE + 9];
     memcpy(abyBuffer, m_abyMyPublicKey, m_nMyPublicKeyLen);
-    uint32 challenge = pTarget->m_dwCryptRndChallengeFor;
+    uint32_t challenge = pTarget->m_dwCryptRndChallengeFor;
     memcpy(abyBuffer + m_nMyPublicKeyLen, & challenge, 4);
     // v2 security improvments (not supported by 29b, not used as default by 29c)
-    uint8 nChIpSize = 0;
+    uint8_t nChIpSize = 0;
     if (byChaIPKind != 0)
     {
         nChIpSize = 5;
-        uint32 ChallengeIP = 0;
+        uint32_t ChallengeIP = 0;
         switch (byChaIPKind)
         {
         case CRYPT_CIP_LOCALCLIENT:
             ChallengeIP = dwForIP;
             break;
         case CRYPT_CIP_REMOTECLIENT:
-            if ((theApp. serverconnect->GetClientID() == 0) || theApp. serverconnect->IsLowID())
+            if ((theApp.serverconnect->GetClientID() == 0) || theApp.serverconnect->IsLowID())
             {
-                ChallengeIP = theApp. serverconnect->GetLocalIP();
+                ChallengeIP = theApp.serverconnect->GetLocalIP();
             }
             else
             {
-                ChallengeIP = theApp. serverconnect->GetClientID();
+                ChallengeIP = theApp.serverconnect->GetClientID();
             }
             break;
             // maybe not supported in future versions:
@@ -642,7 +646,7 @@ bool CClientCreditsList::VerifyIdent(CClientCredits * pTarget, uchar * pachSigna
         memcpy(abyBuffer + m_nMyPublicKeyLen + 4 + 4, & byChaIPKind, 1);
     }
     //v2 end
-    bResult = pubkey. VerifyMessage(abyBuffer, m_nMyPublicKeyLen + 4 + nChIpSize, pachSignature, nInputSize);
+    bResult = pubkey.VerifyMessage(abyBuffer, m_nMyPublicKeyLen + 4 + nChIpSize, pachSignature, nInputSize);
     if (!bResult)
     {
         if (pTarget->IdentState == IS_IDNEEDED)
@@ -660,7 +664,7 @@ bool CClientCreditsList::CryptoAvailable()
     return(m_nMyPublicKeyLen > 0 && m_pSignkey != 0 && theApp.dynprefs->Get<bool>("secure-ident"));
 }
 
-uint32 CClientCredits::GetSecureWaitStartTime(uint32 dwForIP)
+uint32_t CClientCredits::GetSecureWaitStartTime(uint32_t dwForIP)
 {
     if (m_dwUnSecureWaitTime == 0 || m_dwSecureWaitTime == 0)
     SetSecWaitStartTime(dwForIP);
@@ -683,7 +687,6 @@ uint32 CClientCredits::GetSecureWaitStartTime(uint32 dwForIP)
             {
                 // bad boy
                 // this can also happen if the client has not identified himself yet, but will do later - so maybe he is not a bad boy :) .
-                CString buffer2, buffer;
                 m_dwUnSecureWaitTime =::GetTickCount();
                 m_dwWaitTimeIP = dwForIP;
                 return m_dwUnSecureWaitTime;
@@ -697,7 +700,7 @@ uint32 CClientCredits::GetSecureWaitStartTime(uint32 dwForIP)
     }
 }
 
-void CClientCredits::SetSecWaitStartTime(uint32 dwForIP)
+void CClientCredits::SetSecWaitStartTime(uint32_t dwForIP)
 {
     m_dwUnSecureWaitTime =::GetTickCount() - 1;
     m_dwSecureWaitTime =::GetTickCount() - 1;
