@@ -23,22 +23,22 @@
 //
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "ClientUDPSocket.h"
-#	include "DownloadQueue.h"
-#include "NewSockets.h"                     // Needed for NewSocket_SendPacketOP
-#	include "opcodes.h"
-#include "packets.h"                        // Packet
-#include "Preferences.h"                    // CPreferences::GetQueueSize
-#	include "SharedFileList.h"
-#	include "UploadQueue.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
-#include "xmuleIPV4Address.h"               // xmuleIPV4Address
+    #include "xmule-headers.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include "ClientUDPSocket.h"                // Needed for Module's Protype(s) - audited 6 Nov 2004
+
+#include "DownloadQueue.h"                  // Needed for CDownloadQueue - audited 5 Nov 2004
+#include "NewSockets.h"                     // Needed for NewSocket_SendPacketOP - audited 5 Nov 2004
+#include "opcodes.h"                        // Needed for OP_EMULEPROT - audited 4 Nov 2004
+#include "packets.h"                        // Needed for Packet - audited 5 Nov 2004
+#include "SharedFileList.h"                 // Needed for CSharedFileList - audited 5 Nov 2004
+#include "updownclient.h"                   // Needed for CUpDownClient - audited 5 Nov 2004
+#include "UploadQueue.h"                    // Needed for CUploadQueue - audited 5 Nov 2004
+#include "xmule.h"                          // Needed for theApp - audited 4 Nov 2004
+#include "xmuleIPV4Address.h"               // Needed for xmuleIPV4Address - audited 5 Nov 2004
+
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <arpa/inet.h>
 #include <errno.h>
@@ -107,7 +107,7 @@ void CClientUDPSocket::OnReceive(int nErrorCode)
     }
 }
 
-bool CClientUDPSocket::ProcessPacket(unsigned char *packet, int16 size, wxUint8 opcode, wxUint32 hostip, uint16 port)
+bool CClientUDPSocket::ProcessPacket(unsigned char *packet, int16_t size, wxUint8 opcode, wxUint32 hostip, uint16_t port)
 {
 printf("====> CClientUDPSocket::ProcessPacket opcode=0x%02x size=%u\n",opcode,size);
     switch (opcode)
@@ -119,7 +119,7 @@ printf("====> CClientUDPSocket::ProcessPacket opcode=0x%02x size=%u\n",opcode,si
             {
                 break;
             }
-            CKnownFile *reqfile = theApp.sharedfiles->GetFileByID((uchar *) packet);
+            CKnownFile *reqfile = theApp.sharedfiles->GetFileByID((unsigned char *) packet);
             if (!reqfile)
             {
                 Packet *response = new Packet(OP_FILENOTFOUND, 0, OP_EMULEPROT);
@@ -136,7 +136,7 @@ printf("====> CClientUDPSocket::ProcessPacket opcode=0x%02x size=%u\n",opcode,si
             }
             else
             {
-                if (((uint32) theApp.uploadqueue->GetWaitingUserCount() + 50) > theApp.glob_prefs->GetQueueSize())
+                if (((uint32_t) theApp.uploadqueue->GetWaitingUserCount() + 50) > theApp.dynprefs->Get<long>("upload-queue-size"))
                 {
                     Packet *response = new Packet(OP_QUEUEFULL, 0, OP_EMULEPROT);
                     NewSocket_SendPacketOP(1, OP_QUEUEFULL, response, hostip, port);
@@ -165,7 +165,7 @@ printf("====> CClientUDPSocket::ProcessPacket opcode=0x%02x size=%u\n",opcode,si
                 {
                     break;
                 }
-                uint16 nRank;
+                uint16_t nRank;
                 memcpy( &nRank, packet, 2);
                 sender->SetRemoteQueueFull(false);
                 sender->UDPReaskACK(nRank);
@@ -227,7 +227,7 @@ void CClientUDPSocket::OnSend(int nErrorCode)
     failed_packets.RemoveAll();
 }
 
-bool CClientUDPSocket::SendTo(char *lpBuf, int nBufLen, uint32 dwIP, uint16 nPort)
+bool CClientUDPSocket::SendTo(char *lpBuf, int nBufLen, uint32_t dwIP, uint16_t nPort)
 {
     if (Ok())
     {
@@ -248,7 +248,7 @@ bool CClientUDPSocket::SendTo(char *lpBuf, int nBufLen, uint32 dwIP, uint16 nPor
 
     if (Error())
     {
-        uint32 error = LastError();
+        uint32_t error = LastError();
         if (error == wxSOCKET_WOULDBLOCK)
         {
             m_bWouldBlock = true;
@@ -262,7 +262,7 @@ bool CClientUDPSocket::SendTo(char *lpBuf, int nBufLen, uint32 dwIP, uint16 nPor
     return true;
 }
 
-bool CClientUDPSocket::SendPacket(Packet *packet, uint32 dwIP, uint16 nPort)
+bool CClientUDPSocket::SendPacket(Packet *packet, uint32_t dwIP, uint16_t nPort)
 {
 //printf("CClientUDPSocket::SendPacket opcode=0x%02x size=%u\n",packet->opcode,packet->size);
     UDPPack *newpending = new UDPPack;
