@@ -113,12 +113,12 @@ void CCommentDialog::OnBnClickedApply(wxCommandEvent &evt)
 {
     wxString SValue;
     SValue = GetDlgItem(IDC_CMT_TEXT, wxTextCtrl)->GetValue();
-    m_file->SetFileComment(CString(SValue));
-    m_file->SetFileRate((int8) ratebox->GetSelection());
+    m_file->SetFileComment(wxString(SValue));
+    m_file->SetFileRate((int8_t) ratebox->GetSelection());
     EndModal(0);
 }
 
-BOOL CCommentDialog::OnInitDialog()
+bool CCommentDialog::OnInitDialog()
 {
     Localize();
     GetDlgItem(IDC_CMT_TEXT, wxTextCtrl)->SetValue(m_file->GetFileComment());
