@@ -20,37 +20,40 @@
 #ifndef COMMENTDLGLIST_H
 #define COMMENTDLGLIST_H
 
-#include "resource.h"                       // Needed for IDS_CD_UNAME
-#include "wintypes.h"                       // Needed for BOOL
+#include <wx/dialog.h>
+#include <wx/listctrl.h>
 
-#include <wx/dialog.h>                      // Needed for wxDialog
+#include "resource.h"
+#include "wintypes.h"
 
 class CPartFile;
-class wxListCtrl;
+
+// CCommentDialogLst dialog 
 
 class CCommentDialogLst : public wxDialog
-{
-public:
-   CCommentDialogLst(wxWindow* pParent,CPartFile* file);
-   virtual ~CCommentDialogLst();
-   void Localize();
-   virtual BOOL OnInitDialog();
+{ 
+  //DECLARE_DYNAMIC(CCommentDialogLst) 
+
+public: 
+   CCommentDialogLst(wxWindow* pParent,CPartFile* file); 
+   virtual ~CCommentDialogLst(); 
+   void Localize(); 
+   virtual bool OnInitDialog(); 
+   //CHyperTextCtrl lstbox; 
    wxListCtrl *pmyListCtrl;
 
-// Dialog Data
-    enum
-    {
-        IDD_COMMENTLST,
-        IDD = IDD_COMMENTLST
-    };
-protected:
+// Dialog Data 
+   enum { IDD = IDD_COMMENTLST }; 
+protected: 
+   //virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support 
+   //DECLARE_MESSAGE_MAP() 
    DECLARE_EVENT_TABLE()
-public:
-   void OnBnClickedApply(wxCommandEvent& evt);
-   void OnBnClickedRefresh(wxCommandEvent& evt);
-private:
-   void CompleteList();
-   CPartFile* m_file;
+public: 
+   void OnBnClickedApply(wxCommandEvent& evt); 
+   void OnBnClickedRefresh(wxCommandEvent& evt); 
+private: 
+   void CompleteList(); 
+   CPartFile* m_file; 
 };
 
 #endif
