@@ -3,51 +3,52 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#include "DownloadQueue.h"
+
+#	include "ClientList.h"
+#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl - audited 5 Nov 2004
+#include "packets.h"                        // Packet
+#	include "PartFile.h"
+#include "SearchDlg.h"                      // CSearchDlg::ExecuteLinkED2K
+#	include "SearchList.h"
+#include "server.h"                         // CServer
+#include "ServerList.h"                     // Need for CServerList - audited 5 Nov 2004
+#include "ServerSocket.h"                   // CServerConnect
+#include "SharedFileList.h"
+#include "sockets.h"                        // Needed for CServerConnect - audited 6 Nov 2004
+#	include "SysTray.h"
+#	include "TransferWnd.h"
+#	include "updownclient.h"
+#	include "xmuleDlg.h"
 #endif
 
-#include "DownloadQueue.h"                  // Needed for this Interface's Prototype
+#include "ED2KLink.h"                       // CED2KFileLink
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
-#include "ClientList.h"                     // Needed for CClientList
-#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl
-#include "ED2KLink.h"                       // Needed for HasValidSources
-#include "otherfunctions.h"                 // Needed for GetTickCount
-#include "packets.h"                        // Needed for CTag
-#include "PartFile.h"                       // Needed for CPartFile
-#include "Preferences.h"                    // Needed for CPreferences
-#include "SafeFile.h"                       // Needed for CSafeFile
-#include "SearchList.h"                     // Needed for CSearchFile
-#include "server.h"                         // Needed for CServer
-#include "ServerList.h"                     // Needed for CServerList
-#include "ServerSocket.h"                   // Needed for CServerSocket
-#include "SharedFileList.h"                 // Needed for CSharedFileList
-#include "sockets.h"                        // Needed for CServer
-#include "SysTray.h"                        // Needed for TBN_DLOAD
-#include "TransferWnd.h"                    // Needed for CTransferWnd
-#include "updownclient.h"                   // Needed for CUpDownClient
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for CxmuleDlg
-
-#include <wx/file.h>                        // Needed for wxFile::Exists
-#include <wx/filename.h>                    // Needed for wxFileName
-#include <wx/textfile.h>                    // Needed for wxTextFile
+#include <wx/filename.h>
+#include <wx/listimpl.cpp>
+#include <wx/file.h>
+#include <wx/textfile.h>
+#include <wx/utils.h>
 
 #define		MAX_FILES_PER_UDP_PACKET	31
 #define		MAX_REQUESTS_PER_SERVER		35
@@ -105,7 +106,7 @@ CDownloadQueue::CDownloadQueue(CPreferences *in_prefs, CSharedFileList *in_share
 void CDownloadQueue::UpdateDisplayedInfo(bool force)
 {
     DWORD curTick =::GetTickCount();
-    if (force || curTick - m_lastRefreshedDLDisplay > MINWAIT_BEFORE_DLDISPLAY_WINDOWUPDATE + (uint32)(rand() / (RAND_MAX/1000)))
+    if (force || curTick - m_lastRefreshedDLDisplay > MINWAIT_BEFORE_DLDISPLAY_WINDOWUPDATE + (uint32_t)(rand() / (RAND_MAX/1000)))
     {
         theApp.xmuledlg->transferwnd->downloadlistctrl->UpdateItem(this);
         m_lastRefreshedDLDisplay = curTick;
@@ -114,12 +115,12 @@ void CDownloadQueue::UpdateDisplayedInfo(bool force)
 
 void CDownloadQueue::AddPartFilesToShare()
 {
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if (cur_file->GetStatus(true) == PS_READY)
         {
-            sharedfilelist->SafeAddKFile(1,cur_file, true);
+            sharedfilelist->SafeAddKFile(cur_file, true);
             printf("Sharing %s\n", cur_file->GetFullName());
         }
     }
@@ -134,11 +135,11 @@ void CDownloadQueue::CompDownDatarateOverhead()
     }
     m_nDownDatarateOverhead = 0;
     m_nDownDataRateMSOverhead = 0;
-    for (POSITION pos = m_AvarageDDRO_list.GetHeadPosition(); pos != 0; m_AvarageDDRO_list.GetNext(pos))
+    for (POSITION pos = m_AvarageDDRO_list.GetHeadPosition() ; pos != 0 ; m_AvarageDDRO_list.GetNext(pos))
     m_nDownDatarateOverhead += m_AvarageDDRO_list.GetAt(pos);
     if (m_AvarageDDRO_list.GetCount() > 10)
     {
-        m_nDownDatarateOverhead = 10 * m_nDownDatarateOverhead / m_AvarageDDRO_list.GetCount();
+        m_nDownDatarateOverhead = 10 *m_nDownDatarateOverhead/m_AvarageDDRO_list.GetCount();
     }
     else
     {
@@ -152,7 +153,7 @@ void CDownloadQueue::Init()
         int count0 = 0;;
     do
     {
-        wxString searchPath(app_prefs->GetTempDir());
+        wxString searchPath(theApp.dynprefs->Get<wxString>("temp-directory"));
         int count = 0;
         switch (count0)
         {
@@ -170,14 +171,14 @@ void CDownloadQueue::Init()
             wxFileName myFileName(fileName);
             printf("Loading %s... ", myFileName.GetFullName() .GetData());
             CPartFile *toadd = new CPartFile();
-            if (toadd->LoadPartFile(app_prefs->GetTempDir(), (char *) myFileName.GetFullName() .GetData()))
+            if (toadd->LoadPartFile(const_cast<char *>(theApp.dynprefs->Get<wxString>("temp-directory").c_str()), (char *) myFileName.GetFullName() .GetData()))
             {
                 count++;
                 printf("Done.\n");
                 filelist.AddTail(toadd);
                 if (toadd->GetStatus(true) == PS_READY)
                 {
-                    sharedfilelist->SafeAddKFile(1,toadd);
+                    sharedfilelist->SafeAddKFile(toadd);
                 }
                 theApp.xmuledlg->transferwnd->downloadlistctrl->AddFile(toadd);
             }
@@ -205,10 +206,10 @@ CDownloadQueue::~CDownloadQueue()
 {
     //	if (!theApp.xmuledlg->m_app_state== APP_STATE_SHUTINGDOWN )
     //		SavePartFiles(true);	// changed by InterCeptor
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
-        filelist.GetAt(pos)->m_hpartfile->Flush(); // Flush before close app [Tarod]
-        filelist.GetAt(pos)->SavePartFile();
+        //filelist.GetAt(pos)->m_hpartfile.Flush() ; // Flush before close app [Tarod]
+        //filelist.GetAt(pos)->SavePartFile();
         delete filelist.GetAt(pos);
     }
 }
@@ -218,9 +219,9 @@ CDownloadQueue::~CDownloadQueue()
 
 )
 {
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
-        filelist.GetAt(pos)->m_hpartfile->Flush();
+        filelist.GetAt(pos)->m_hpartfile.Flush();
         filelist.GetAt(pos)->SavePartFile();
         if (del)
         delete filelist.GetAt(pos);
@@ -241,7 +242,7 @@ void CDownloadQueue::AddSearchToDownload(CSearchFile *toadd)
     AddDownload(newfile);
 }
 
-void CDownloadQueue::AddSearchToDownload(CString link)
+void CDownloadQueue::AddSearchToDownload(wxString link)
 {
     // Bodo: Why here not, but in
     // Bodo: void CDownloadQueue::AddSearchToDownload(CSearchFile* toadd)?
@@ -259,30 +260,47 @@ void CDownloadQueue::AddSearchToDownload(CString link)
 
 void CDownloadQueue::StartNextFile()
 {
-    if (!theApp.glob_prefs->StartNextFile())
-    return;
-    CPartFile *pfile = NULL;
+    if (theApp.dynprefs->Get<bool>("start-next-file") == false)
+    {
+        return;
+    }
+
+    CPartFile* pfile = NULL;
+
     for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
-        CPartFile *cur_file = filelist.GetAt(pos);
+        CPartFile* cur_file = filelist.GetAt(pos);
+
         if (cur_file->GetStatus() == PS_PAUSED)
         {
             if (!pfile)
             {
                 pfile = cur_file;
-                if (pfile->GetDownPriority() == PR_HIGH) break;
+
+                if (pfile->GetDownPriority() == PR_HIGH)
+                {
+                    break;
+                }
             }
             else
             {
                 if (cur_file->GetDownPriority() > pfile->GetDownPriority())
                 {
                     pfile = cur_file;
-                    if (pfile->GetDownPriority() == PR_HIGH) break;
+
+                    if (pfile->GetDownPriority() == PR_HIGH)
+                    {
+                        break;
+                    }
                 }
             }
         }
     }
-    if (pfile) pfile->ResumeFile();
+
+    if (pfile)
+    {
+        pfile->ResumeFile();
+    }
 }
 
 void CDownloadQueue::AddFileLinkToDownload(CED2KFileLink *pLink)
@@ -308,7 +326,7 @@ void CDownloadQueue::AddFileLinkToDownload(CED2KFileLink *pLink)
         }
         else
         {
-            CPartFile *partfile = GetFileByID((uchar *) pLink->GetHashKey());
+            CPartFile *partfile = GetFileByID((unsigned char *) pLink->GetHashKey());
             if (partfile) partfile->AddClientSources(pLink->SourcesList, 1);
         }
     }
@@ -317,20 +335,22 @@ void CDownloadQueue::AddFileLinkToDownload(CED2KFileLink *pLink)
 void CDownloadQueue::AddDownload(CPartFile *newfile)
 {
     // Barry - Add in paused mode if required
-    if (theApp.glob_prefs->AddNewFilesPaused())
-    newfile->PauseFile();
+    if (theApp.dynprefs->Get<bool>("add-paused") == true)
+    {
+        newfile->PauseFile();
+    }
     filelist.AddTail(newfile);
     SortByPriority();
     theApp.xmuledlg->transferwnd->downloadlistctrl->AddFile(newfile);
     theApp.xmuledlg->AddLogLine(true, GetResString(IDS_NEWDOWNLOAD), newfile->GetFileName());
-    CString msgTemp;
-    msgTemp.Format(GetResString(IDS_NEWDOWNLOAD) + "\n", newfile->GetFileName());
+    wxString msgTemp;
+    msgTemp = GetResString(IDS_NEWDOWNLOAD) + wxT("\n") + newfile->GetFileName();
     theApp.xmuledlg->ShowNotifier(msgTemp, TBN_DLOAD);
 }
 
-bool CDownloadQueue::IsFileExisting(uchar *fileid)
+bool CDownloadQueue::IsFileExisting(unsigned char *fileid)
 {
-    if (CKnownFile *file = sharedfilelist->GetFileByID((uchar *) fileid))
+    if (CKnownFile *file = sharedfilelist->GetFileByID((unsigned char *) fileid))
     {
         if (file->IsPartFile())
         theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADING), file->GetFileName());
@@ -338,7 +358,7 @@ bool CDownloadQueue::IsFileExisting(uchar *fileid)
         theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADED), file->GetFileName());
         return true;
     }
-    else if(file = this->GetFileByID((uchar *) fileid))
+    else if(file = this->GetFileByID((unsigned char *) fileid))
     {
         theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADING), file->GetFileName());
         return true;
@@ -348,11 +368,11 @@ bool CDownloadQueue::IsFileExisting(uchar *fileid)
 
 void CDownloadQueue::Process()
 {
-    uint32 downspeed = 0;
-    if (app_prefs->GetMaxDownload() != UNLIMITED &&datarate > 1500)
+    uint32_t downspeed = 0;
+    if ((theApp.dynprefs->Get<long>("limits-download") != UNLIMITED) && (datarate > 1500))
     {
-        //(uint16)((float)((float)(app_prefs->GetMaxDownload()*1024)/(datarate+1)) * 100);:
-        downspeed = (app_prefs->GetMaxDownload() * 1024 * 100) / (datarate + 1);
+        //(uint16_t)((float)((float)(app_prefs->GetMaxDownload()*1024)/(datarate+1)) * 100);:
+        downspeed = (theApp.dynprefs->Get<long>("limits-download") * 1024 * 100) / (datarate + 1);
         if (downspeed < 50)
         downspeed = 50;
         else if(downspeed > 200)
@@ -361,7 +381,7 @@ void CDownloadQueue::Process()
         //	downspeed = 0xFFF;
     }
     datarate = 0;
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (!cur_file->IsAutoDownPriority() &&cur_file->GetDownPriority() == PR_HIGH))
@@ -369,7 +389,7 @@ void CDownloadQueue::Process()
             datarate += cur_file->Process(downspeed);
         }
     }
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (!cur_file->IsAutoDownPriority() &&cur_file->GetDownPriority() == PR_NORMAL))
@@ -377,7 +397,7 @@ void CDownloadQueue::Process()
             datarate += cur_file->Process(downspeed);
         }
     }
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (cur_file->GetDownPriority() == PR_LOW || cur_file->IsAutoDownPriority()))
@@ -403,7 +423,7 @@ void CDownloadQueue::Process()
     // Check for new links once per second.
     if ((::GetTickCount() - m_nLastED2KLinkCheck) >= 1000)
     {
-        wxString filename = filename.Format("%s/.xMule/ED2KLinks", getenv("HOME"));
+        wxString filename = wxString(getenv("HOME"), *wxConvCurrent) + wxT("/.xMule/ED2KLinks");
         if (wxFile::Exists(filename))
         {
             AddLinksFromFile();
@@ -412,9 +432,9 @@ void CDownloadQueue::Process()
     }
 }
 
-CPartFile *CDownloadQueue::GetFileByID(uchar *filehash)
+CPartFile *CDownloadQueue::GetFileByID(unsigned char *filehash)
 {
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         if (!memcmp(filehash, filelist.GetAt(pos)->GetFileHash(), 16))
         return filelist.GetAt(pos);
@@ -426,7 +446,7 @@ CPartFile *CDownloadQueue::GetFileByIndex(int index)
 {
     //      if (index>=filelist.GetCount()) return 0;
     int count = 0;
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         if (count == index) return filelist.GetAt(pos);
         count++;
@@ -436,7 +456,7 @@ CPartFile *CDownloadQueue::GetFileByIndex(int index)
 
 bool CDownloadQueue::IsPartFile(void *totest)
 {
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     if (totest == filelist.GetAt(pos))
     return true;
     return false;
@@ -459,13 +479,12 @@ void CDownloadQueue::CheckAndAddSource(CPartFile *sender, CUpDownClient *source)
  }
     */
     // uses this only for temp. clients
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
-        for (int sl = 0; sl < SOURCESSLOTS; sl++) if(!cur_file->srclists[sl].IsEmpty())
-        for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition(); pos2 != 0; cur_file->srclists[sl].GetNext(pos2))
+        for (POSITION pos2 = cur_file->srclist.GetHeadPosition() ; pos2 != 0 ; cur_file->srclist.GetNext(pos2))
         {
-            if (cur_file->srclists[sl].GetAt(pos2)->Compare(source))
+            if (cur_file->srclist.GetAt(pos2)->Compare(source))
             {
                 if (cur_file == sender)
                 {
@@ -474,10 +493,10 @@ void CDownloadQueue::CheckAndAddSource(CPartFile *sender, CUpDownClient *source)
                     return;
                 }
                 // set request for this source
-                if (cur_file->srclists[sl].GetAt(pos2)->AddRequestForAnotherFile(sender))
+                if (cur_file->srclist.GetAt(pos2)->AddRequestForAnotherFile(sender))
                 {
                     // add it to uploadlistctrl
-                    theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender, cur_file->srclists[sl].GetAt(pos2), true);
+                    theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender, cur_file->srclist.GetAt(pos2), true);
                     delete source;
                     return;
                 }
@@ -496,7 +515,7 @@ void CDownloadQueue::CheckAndAddSource(CPartFile *sender, CUpDownClient *source)
     source->SetDownloadFile(sender);
     else
     theApp.clientlist->AddClient(source, true);
-    sender->srclists[source->sourcesslot].AddTail(source);
+    sender->srclist.AddTail(source);
     theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender, source, false);
     //theApp.xmuledlg->transferwnd.downloadlistctrl.UpdateItem(this);
     UpdateDisplayedInfo();
@@ -507,11 +526,11 @@ void CDownloadQueue::CheckAndAddKnownSource(CPartFile *sender, CUpDownClient *so
     if (!source->HasLowID() && (source->GetUserID() &0xFF) == 0x7F)
     return;
     // use this for client which are already know (downloading for example)
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
-        for (int sl = 0; sl < SOURCESSLOTS; sl++) if(!cur_file->srclists[sl].IsEmpty())
-        if (cur_file->srclists[sl].Find(source))
+
+        if (cur_file->srclist.Find(source))
         {
             if (cur_file == sender)
             return;
@@ -521,7 +540,7 @@ void CDownloadQueue::CheckAndAddKnownSource(CPartFile *sender, CUpDownClient *so
         }
     }
     source->SetDownloadFile(sender);
-    sender->srclists[source->sourcesslot].AddTail(source);
+    sender->srclist.AddTail(source);
     theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender, source, false);
     UpdateDisplayedInfo();
 }
@@ -529,22 +548,22 @@ void CDownloadQueue::CheckAndAddKnownSource(CPartFile *sender, CUpDownClient *so
 bool CDownloadQueue::RemoveSource(CUpDownClient *toremove, bool updatewindow)
 {
     bool removed = false;
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
-        for (int sl = 0; sl < SOURCESSLOTS; sl++) if(!cur_file->srclists[sl].IsEmpty())
-        for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition(); pos2 != 0; cur_file->srclists[sl].GetNext(pos2))
+
+        for (POSITION pos2 = cur_file->srclist.GetHeadPosition() ; pos2 != 0 ; cur_file->srclist.GetNext(pos2))
         {
-            if (toremove == cur_file->srclists[sl].GetAt(pos2))
+            if (toremove == cur_file->srclist.GetAt(pos2))
             {
-                cur_file->srclists[sl].RemoveAt(pos2);
+                cur_file->srclist.RemoveAt(pos2);
                 cur_file->NewSrcPartsInfo();
                 removed = true;
     /* Razor 1a - Modif by MikaelB */
                 if (!toremove->m_OtherRequests_list.IsEmpty())
                 {
                     POSITION pos3, pos4;
-                    for (pos3 = toremove->m_OtherRequests_list.GetHeadPosition(); (pos4 = pos3) != NULL;)
+                    for (pos3 = toremove->m_OtherRequests_list.GetHeadPosition() ; (pos4 = pos3) != NULL ;)
                     {
                         toremove->m_OtherRequests_list.GetNext(pos3);
                         POSITION pos5 = toremove->m_OtherRequests_list.GetAt(pos4)->A4AFSourcesList.Find(toremove);
@@ -580,7 +599,7 @@ bool CDownloadQueue::RemoveSource(CUpDownClient *toremove, bool updatewindow)
 
 void CDownloadQueue::RemoveFile(CPartFile *toremove)
 {
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         if (toremove == filelist.GetAt(pos))
         {
@@ -593,11 +612,10 @@ void CDownloadQueue::RemoveFile(CPartFile *toremove)
 void CDownloadQueue::DeleteAll()
 {
     POSITION pos;
-    for (pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
-        for (int sl = 0; sl < SOURCESSLOTS; sl++) if(!cur_file->srclists[sl].IsEmpty())
-        cur_file->srclists[sl].RemoveAll();
+        cur_file->srclist.RemoveAll();
         // Barry - Should also remove all requested blocks
         // Don't worry about deleting the blocks, that gets handled
         // when CUpDownClient is deleted in CClientList::DeleteAll()
@@ -708,7 +726,8 @@ bool CDownloadQueue::SendNextUDPPacket()
                 }
             }
         }
-        if (!bSentPacket &&nextfile &&nextfile->GetSourceCount() < theApp.glob_prefs->GetMaxSourcePerFileUDP())
+        // Number of sources to get via UDP...60% of MaxSources.
+        if (!bSentPacket && nextfile && nextfile->GetSourceCount() < (theApp.dynprefs->Get<long>("max-sources") * 0.60))
         {
             dataGlobGetSources.Write(nextfile->GetFileHash(), 16);
             iFiles++;
@@ -723,7 +742,7 @@ bool CDownloadQueue::SendNextUDPPacket()
  /*
  if (filelist.GetCount() >= MAX_REQUESTS_PER_SERVER)
  {
- for (int i = 0; i != MAX_REQUESTS_PER_SERVER; i++)
+ for (int i = 0 ; i != MAX_REQUESTS_PER_SERVER ; i++)
  {
  filelist.AddHead(filelist.RemoveTail());
  }
@@ -754,8 +773,8 @@ void CDownloadQueue::StopUDPRequests()
 void CDownloadQueue::SortByPriority()
 {
     POSITION pos1, pos2;
-    uint16 i = 0;
-    for (pos1 = filelist.GetHeadPosition(); (pos2 = pos1) != NULL;)
+    uint16_t i = 0;
+    for (pos1 = filelist.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
         filelist.GetNext(pos1);
         CPartFile *cur_file = filelist.GetAt(pos2);
@@ -779,7 +798,7 @@ void CDownloadQueue::GetDownloadStats(int results[])
 {
     results[0] = 0;
     results[1] = 0;
-    for (POSITION pos = theApp.downloadqueue->filelist.GetHeadPosition(); pos != 0; theApp.downloadqueue->filelist.GetNext(pos))
+    for (POSITION pos = theApp.downloadqueue->filelist.GetHeadPosition() ; pos != 0 ; theApp.downloadqueue->filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         results[0] += cur_file->GetSourceCount();
@@ -787,17 +806,17 @@ void CDownloadQueue::GetDownloadStats(int results[])
     }
 }
 
-CUpDownClient *CDownloadQueue::GetDownloadClientByIP(uint32 dwIP)
+CUpDownClient *CDownloadQueue::GetDownloadClientByIP(uint32_t dwIP)
 {
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
-        for (int sl = 0; sl < SOURCESSLOTS; sl++) if(!cur_file->srclists[sl].IsEmpty())
-        for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition(); pos2 != 0; cur_file->srclists[sl].GetNext(pos2))
+
+        for (POSITION pos2 = cur_file->srclist.GetHeadPosition() ; pos2 != 0 ; cur_file->srclist.GetNext(pos2))
         {
-            if (dwIP == cur_file->srclists[sl].GetAt(pos2)->GetIP())
+            if (dwIP == cur_file->srclist.GetAt(pos2)->GetIP())
             {
-                return cur_file->srclists[sl].GetAt(pos2);
+                return cur_file->srclist.GetAt(pos2);
             }
         }
     }
@@ -814,33 +833,15 @@ void CDownloadQueue::AddLinksFromFile()
         link = linksfile.GetFirstLine();
         // GetLineCount returns the actual number of lines in file, but line numbering
         // starts from zero. Thus we must loop until i = GetLineCount()-1.
-        for (unsigned int i = 0; i < linksfile.GetLineCount(); i++)
+        for (unsigned int i = 0 ; i < linksfile.GetLineCount() ; i++)
         {
             // Need the links to end with /, otherwise CreateLinkFromUrl crashes us.
             if (link.Right(1) != "/")
             {
                 link += "/";
             }
-            try
-            {
-                CED2KLink *pLink = CED2KLink::CreateLinkFromUrl(link);
-                if (pLink->GetKind() == CED2KLink::kFile)
-                {
-                    // All seems ok, add it to download queue.
-                    AddFileLinkToDownload(pLink->GetFileLink());
-                }
-                else
-                {
-                    throw wxString(_("Bad link."));
-                }
-                delete pLink;
-            }
-            catch(wxString error)
-            {
-                char buffer[200];
-                sprintf(buffer, GetResString(IDS_ERR_INVALIDLINK), error.GetData());
-                theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_LINKERROR), buffer);
-            }
+
+            CSearchDlg::ExecuteLinkED2K(link);
             // We must double-check here where are we, because GetNextLine moves reading head
             // one line below, and we must make sure that line exists. Thus check if we are
             // at least one line away from end before trying to read next line.
@@ -865,7 +866,7 @@ void CDownloadQueue::AddLinksFromFile()
 void CDownloadQueue::RemoveSourceFromPartFile(CPartFile *file, CUpDownClient *client, POSITION position)
 {
     // Remove source at position in sources list of file
-    file->srclists[client->sourcesslot].RemoveAt(position);
+    file->srclist.RemoveAt(position);
     // Update infos of file
     file->NewSrcPartsInfo();
     file->UpdateAvailablePartsCount();
@@ -885,7 +886,7 @@ void CDownloadQueue::RemoveSourceFromPartFile(CPartFile *file, CUpDownClient *cl
         // Some positions
         POSITION position, temp_position;
         // For every position in other requests list of client...
-        for (position = client->m_OtherRequests_list.GetHeadPosition(); (temp_position = position) != NULL;)
+        for (position = client->m_OtherRequests_list.GetHeadPosition() ; (temp_position = position) != NULL ;)
         {
             // Get next position in position
             client->m_OtherRequests_list.GetNext(position);
@@ -918,7 +919,7 @@ void CDownloadQueue::RemoveSourceFromPartFile(CPartFile *file, CUpDownClient *cl
 void CDownloadQueue::DisableAnyA4AFAuto(void)
 {
     // For all position in filelist...
-    for (POSITION position = filelist.GetHeadPosition(); position != NULL; filelist.GetNext(position))
+    for (POSITION position = filelist.GetHeadPosition() ; position != NULL ; filelist.GetNext(position))
     {
         // Get file at position in filelist
         CPartFile *file = (CPartFile *) filelist.GetAt(position);
@@ -933,7 +934,7 @@ void CDownloadQueue::DisableAnyA4AFAuto(void)
 
 void CDownloadQueue::ResetCatParts(int cat)
 {
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if (cur_file->GetCategory() == cat)
@@ -947,9 +948,9 @@ void CDownloadQueue::ResetCatParts(int cat)
     }
 }
 
-void CDownloadQueue::SetCatPrio(int cat, uint8 newprio)
+void CDownloadQueue::SetCatPrio(int cat, uint8_t newprio)
 {
-    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if (cat == 0 || cur_file->GetCategory() == cat)
@@ -985,6 +986,7 @@ void CDownloadQueue::SetCatStatus(int cat, int newstatus)
             {
             case MP_CANCEL:
                 cur_file->DeleteFile();
+                delete cur_file;
                 reset = true;
                 break;
             case MP_PAUSE:
