@@ -22,74 +22,80 @@
 #ifndef DOWNLOADQUEUE_H
 #define DOWNLOADQUEUE_H
 
-//#include "stdafx.h"
-#include "PartFile.h"
-#include "opcodes.h"
-#include "types.h"
-#include "SharedFileList.h"
+#include "mfc.h"                            // Needed for wxString - audited 4 Nov 2004
+#include "resource.h"                       // Needed for IDD_TRANSFER - audited 4 Nov 2004
+#include "wintypes.h"                       // Needed for DWORD - audited 5 Nov 2004
 
+#include <stdint.h>                         // Needed for uint16_t
+
+class CED2KFileLink;
+class CPartFile;
+class CPreferences;
 class CSafeMemFile;
+class CSearchFile;
 class CServer;
+class CSharedFileList;
+class CUpDownClient;
 
 class CDownloadQueue
 {
 	friend class CAddFileThread;
 	friend class CServerSocket;
 public:
-	CDownloadQueue(CPreferences* in_prefs,CSharedFileList* in_sharedfilelist);
+	CDownloadQueue(CPreferences* in_prefs, CSharedFileList* in_sharedfilelist);
 	~CDownloadQueue();
 	void	Process();
 	void	Init();
 	void	AddSearchToDownload(CSearchFile* toadd);
-	void	AddSearchToDownload(CString link);
+	void	AddSearchToDownload(wxString link);
 	void	AddFileLinkToDownload(class CED2KFileLink* pLink);
-	bool	IsFileExisting(uchar* fileid);
+	bool	IsFileExisting(unsigned char* fileid);
 	bool	IsPartFile(void* totest);
-	CPartFile*	GetFileByID(uchar* filehash);
+	CPartFile*	GetFileByID(unsigned char* filehash);
 	CPartFile* GetFileByIndex(int idx);
 	void    CheckAndAddSource(CPartFile* sender,CUpDownClient* source);
 	void    CheckAndAddKnownSource(CPartFile* sender,CUpDownClient* source);
 	bool	RemoveSource(CUpDownClient* toremove, bool updatewindow = true);
 	void	DeleteAll();
 	void	RemoveFile(CPartFile* toremove);
-	uint32	GetDatarate()			{return datarate;}
+	uint32_t	GetDatarate()			{return datarate;}
 	void	SortByPriority();
 	void	StopUDPRequests();
 	CServer*	cur_udpserver;
 	void	GetDownloadStats(int results[]);
 	void	AddPartFilesToShare();
 	void	AddDownload(CPartFile* newfile);
-	CUpDownClient* 	GetDownloadClientByIP(uint32 dwIP);
+	CUpDownClient* 	GetDownloadClientByIP(uint32_t dwIP);
 	void	UpdateDisplayedInfo(bool force=false);
 	void	StartNextFile();
-	void	AddDownDataOverheadSourceExchange(uint32 data)	{ m_nDownDataRateMSOverhead += data;
+	void	AddDownDataOverheadSourceExchange(uint32_t data)	{ m_nDownDataRateMSOverhead += data;
 															  m_nDownDataOverheadSourceExchange += data;
 															  m_nDownDataOverheadSourceExchangePackets++;}
-	void	AddDownDataOverheadFileRequest(uint32 data)		{ m_nDownDataRateMSOverhead += data;
+	void	AddDownDataOverheadFileRequest(uint32_t data)		{ m_nDownDataRateMSOverhead += data;
 															  m_nDownDataOverheadFileRequest += data;
 															  m_nDownDataOverheadFileRequestPackets++;}
-	void	AddDownDataOverheadServer(uint32 data)			{ m_nDownDataRateMSOverhead += data;
+	void	AddDownDataOverheadServer(uint32_t data)			{ m_nDownDataRateMSOverhead += data;
 															  m_nDownDataOverheadServer += data;
 															  m_nDownDataOverheadServerPackets++;}
-	void	AddDownDataOverheadOther(uint32 data)			{ m_nDownDataRateMSOverhead += data;
+	void	AddDownDataOverheadOther(uint32_t data)			{ m_nDownDataRateMSOverhead += data;
 															  m_nDownDataOverheadOther += data;
 															  m_nDownDataOverheadOtherPackets++;}
 	void	AddLinksFromFile();
 	
-	uint32	GetDownDatarateOverhead()			{return m_nDownDatarateOverhead;}
-	uint64	GetDownDataOverheadSourceExchange()		{return m_nDownDataOverheadSourceExchange;}
-	uint64	GetDownDataOverheadFileRequest()		{return m_nDownDataOverheadFileRequest;}
-	uint64	GetDownDataOverheadServer()			{return m_nDownDataOverheadServer;}
-	uint64	GetDownDataOverheadOther()			{return m_nDownDataOverheadOther;}
-	uint64	GetDownDataOverheadSourceExchangePackets()	{return m_nDownDataOverheadSourceExchangePackets;}
-	uint64	GetDownDataOverheadFileRequestPackets()		{return m_nDownDataOverheadFileRequestPackets;}
-	uint64	GetDownDataOverheadServerPackets()		{return m_nDownDataOverheadServerPackets;}
-	uint64	GetDownDataOverheadOtherPackets()		{return m_nDownDataOverheadOtherPackets;}
+	uint32_t	GetDownDatarateOverhead()			{return m_nDownDatarateOverhead;}
+	uint64_t	GetDownDataOverheadSourceExchange()		{return m_nDownDataOverheadSourceExchange;}
+	uint64_t	GetDownDataOverheadFileRequest()		{return m_nDownDataOverheadFileRequest;}
+	uint64_t	GetDownDataOverheadServer()			{return m_nDownDataOverheadServer;}
+	uint64_t	GetDownDataOverheadOther()			{return m_nDownDataOverheadOther;}
+	uint64_t	GetDownDataOverheadSourceExchangePackets()	{return m_nDownDataOverheadSourceExchangePackets;}
+	uint64_t	GetDownDataOverheadFileRequestPackets()		{return m_nDownDataOverheadFileRequestPackets;}
+	uint64_t	GetDownDataOverheadServerPackets()		{return m_nDownDataOverheadServerPackets;}
+	uint64_t	GetDownDataOverheadOtherPackets()		{return m_nDownDataOverheadOtherPackets;}
 	void	CompDownDatarateOverhead();
 	int	GetFileCount()					{return filelist.GetCount();}
 	void	ResetCatParts(int cat);
 	void	SavePartFiles(bool del = false);	// InterCeptor
-	void	SetCatPrio(int cat, uint8 newprio);
+	void	SetCatPrio(int cat, uint8_t newprio);
 	void	SetCatStatus(int cat, int newstatus);
 protected:
 	bool	SendNextUDPPacket();
@@ -99,27 +105,27 @@ private:
 	CTypedPtrList<CPtrList, CPartFile*> filelist;
 	CSharedFileList* sharedfilelist;
 	CPreferences*	 app_prefs;
-	uint16	filesrdy;
-	uint32	datarate;
+	uint16_t	filesrdy;
+	uint32_t	datarate;
 	
 	CPartFile*	lastfile;
-	uint32		lastudpsearchtime;
-	uint32		lastudpstattime;
-	uint32		m_nLastED2KLinkCheck;
-	uint8		udcounter;
-	uint8		m_cRequestsSentToServer;
+	uint32_t		lastudpsearchtime;
+	uint32_t		lastudpstattime;
+	uint32_t		m_nLastED2KLinkCheck;
+	uint8_t		udcounter;
+	uint8_t		m_cRequestsSentToServer;
 	int		m_iSearchedServers;
 
-	uint32		m_nDownDatarateOverhead;
-	uint32		m_nDownDataRateMSOverhead;
-	uint64		m_nDownDataOverheadSourceExchange;
-	uint64		m_nDownDataOverheadSourceExchangePackets;
-	uint64		m_nDownDataOverheadFileRequest;
-	uint64		m_nDownDataOverheadFileRequestPackets;
-	uint64		m_nDownDataOverheadServer;
-	uint64		m_nDownDataOverheadServerPackets;
-	uint64		m_nDownDataOverheadOther;
-	uint64		m_nDownDataOverheadOtherPackets;
+	uint32_t		m_nDownDatarateOverhead;
+	uint32_t		m_nDownDataRateMSOverhead;
+	uint64_t		m_nDownDataOverheadSourceExchange;
+	uint64_t		m_nDownDataOverheadSourceExchangePackets;
+	uint64_t		m_nDownDataOverheadFileRequest;
+	uint64_t		m_nDownDataOverheadFileRequestPackets;
+	uint64_t		m_nDownDataOverheadServer;
+	uint64_t		m_nDownDataOverheadServerPackets;
+	uint64_t		m_nDownDataOverheadOther;
+	uint64_t		m_nDownDataOverheadOtherPackets;
 	CList<int,int>	m_AvarageDDRO_list;
 
     DWORD m_lastRefreshedDLDisplay;
