@@ -18,16 +18,16 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "ED2KLink.h"
+#	include "otherfunctions.h"
+#	include "resource.h"
+#	include "wintypes.h"
+#	include "xmule.h"
 #endif
 
-#include "ED2KLink.h"                       // Needed for this Interface's Prototype
-
-#include "CMemFile.h"                       // Needed for CMemFile
-#include "otherfunctions.h"                 // Needed for GetResString
-#include "resource.h"                       // Needed for IDS_ERR_ILLFORMEDHASH
-
-#include <wx/datetime.h>                    // Needed for wxDateTime
+#include <wx/datetime.h>
 
 #if 1
 namespace
@@ -139,7 +139,7 @@ CED2KServerLink::CED2KServerLink(const TCHAR *ip, const TCHAR *port)
     unsigned long ul = atoi(port);
     if (ul > 0xFFFF)
     throw GetResString(IDS_ERR_BADPORT);
-    m_port = static_cast < uint16 > (ul);
+    m_port = static_cast < uint16_t > (ul);
     m_defaultName = "Server ";
     m_defaultName += ip;
     m_defaultName += ":";
@@ -216,11 +216,11 @@ CED2KFileLink::CED2KFileLink(const TCHAR *name, const TCHAR *size, const TCHAR *
         //COleDateTime expirationDate;
         wxDateTime expirationDate;
         int nYear, nMonth, nDay;
-        uint16 nCount = 0;
-        uint32 dwID;
-        uint16 nPort;
-        uint32 dwServerIP = 0;
-        uint16 nServerPort = 0;
+        uint16_t nCount = 0;
+        uint32_t dwID;
+        uint16_t nPort;
+        uint32_t dwServerIP = 0;
+        uint16_t nServerPort = 0;
         unsigned long ul;
         int nInvalid = 0;
         pCh = strstr(pCh, _T("sources"));
@@ -259,7 +259,7 @@ CED2KFileLink::CED2KFileLink(const TCHAR *name, const TCHAR *size, const TCHAR *
                 // init to 0, we'll fix this at the end.:
                 SourcesList->Write( &nCount, sizeof(nCount));
                 // for each "ip:port" source string until the end
-                // limit to prevent overflow (uint16 due to CPartFile::AddClientSources)
+                // limit to prevent overflow (uint16_t due to CPartFile::AddClientSources)
 #define MAXSHORT 65535
                 while ( *pCh != 0 &&nCount < MAXSHORT)
                 {
@@ -287,7 +287,7 @@ CED2KFileLink::CED2KFileLink(const TCHAR *name, const TCHAR *size, const TCHAR *
                     dwID = inet_addr(pIP);
                     //tcstoul( pPort, 0, 10 );:
                     ul = atoi(pPort);
-                    nPort = static_cast < uint16 > (ul);
+                    nPort = static_cast < uint16_t > (ul);
                     // skip bad ips / ports
                     if (dwID == INADDR_NONE || dwID < 16777216 ||
                     ul > 0xFFFF || ul == 0)
@@ -417,3 +417,62 @@ CED2KLink::CreateLinkFromUrl(const TCHAR *uri)
     }
     return 0;
 }
+
+#if 0
+//static
+CED2KLink *
+CED2KLink::CreateLinkFromUrl(const TCHAR *uri)
+{
+    // Parse pseudo-URI
+    const TCHAR *pChArray[7];
+    if (uri == 0)
+    throw wxString(("null ed2k link"));
+    TCHAR *pNewString = strdup(uri);
+    autoFree liberator(pNewString);
+    TCHAR *pCh = pNewString;
+    const TCHAR *pStart = pCh;
+    int idx = 0;
+    for (idx = 0 ; idx < 7 ; idx++) pChArray[idx] = NULL;
+    idx = 0;
+    while (idx < 7 && ((pCh = strchr(pCh, ('|'))) != 0))
+    {
+        pChArray[idx++] = pStart;
+        *pCh = 0;
+        ++pCh;
+        pStart = pCh;
+    }
+    if ( *pStart != ('/'))
+    {
+        throw wxString((GetResString(IDS_ERR_BADED2KLINK)));
+    }
+    if (idx < 3
+    || pChArray[0] == 0
+    || pChArray[1] == 0
+    || pChArray[2] == 0
+    || pChArray[3] == 0
+    || strcmp(("ed2k://"), pChArray[0]) != 0
+    )
+    {
+        throw GetResString(IDS_ERR_BADED2KLINK);
+    }
+    if (strcmp(("file"), pChArray[1]) == 0 &&idx == 5 &&pChArray[4] != 0)
+    {
+        return new CED2KFileLink(pChArray[2], pChArray[3], pChArray[4]);
+    }
+    else if(strcmp(("serverlist"), pChArray[1]) == 0 &&idx == 3)
+    {
+        return new CED2KServerListLink(pChArray[2]);
+    }
+    else if(strcmp(("server"), pChArray[1]) == 0 &&idx == 4)
+    {
+        return new CED2KServerLink(pChArray[2], pChArray[3]);
+    }
+    else
+    {
+        throw GetResString(IDS_ERR_NOSLLINK);
+    }
+    return 0;
+}
+
+#endif
+
