@@ -3,18 +3,18 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -22,21 +22,22 @@
 // FileDetailDialog.cpp : implementation file
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "CommentDialogLst.h"
+#	include "FileDetailDialog.h"
+#	include "muuli_wdr.h"
+#	include "otherfunctions.h"
+#	include "PartFile.h"
+#	include "updownclient.h"
+#	include "wintypes.h"
+#	include "xmule.h"
 #endif
 
-#include "FileDetailDialog.h"               // Needed for this Interface's Prototype
+#include "wx/xrc/xmlres.h"
 
-#include "CommentDialogLst.h"               // Needed for CCommentDialogLst
-#include "mfc.h"                            // Needed for CString
-#include "muuli_wdr.h"                      // Needed for ID_CLOSEWND
-#include "PartFile.h"                       // Needed for CPartFile
-#include "updownclient.h"                   // Needed for GetClientFilename
-
-#include <wx/listctrl.h>                    // Needed for wxListCtrl
-#include <wx/settings.h>                    // Needed for wxSystemSettings
-#include <wx/textctrl.h>                    // Needed for wxTextCtrl::SetLabel
-#include <wx/xrc/xh_all.h>                  // Needed for XRCID
+#include <wx/settings.h>
+#include <wx/textctrl.h>                    // wxTextCtrl
 
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
 
@@ -49,17 +50,17 @@
 
 //IMPLEMENT_DYNAMIC(CFileDetailDialog, CDialog)
 BEGIN_EVENT_TABLE(CFileDetailDialog, wxDialog)
-    EVT_BUTTON(ID_CLOSEWND, CFileDetailDialog::OnClosewnd)
+EVT_BUTTON(ID_CLOSEWND, CFileDetailDialog::OnClosewnd)
 
-    EVT_BUTTON(XRCID("IDC_BUTTONSTRIP"), CFileDetailDialog::OnBnClickedButtonStrip)
-    EVT_BUTTON(XRCID("IDC_TAKEOVER"), CFileDetailDialog::TakeOver)
-    EVT_BUTTON(XRCID("IDC_FILEINFO"), CFileDetailDialog::OnBnClickedFileinfo)
-    //for comment:
-    EVT_BUTTON(XRCID("IDC_CMTBT"), CFileDetailDialog::OnBnClickedShowComment)
-    // Added by Tarod [Juanjo]:
-    EVT_BUTTON(XRCID("IDC_RENAME"), CFileDetailDialog::Rename)
+EVT_BUTTON(XRCID("IDC_BUTTONSTRIP"), CFileDetailDialog::OnBnClickedButtonStrip)
+EVT_BUTTON(XRCID("IDC_TAKEOVER"), CFileDetailDialog::TakeOver)
+EVT_BUTTON(XRCID("IDC_FILEINFO"), CFileDetailDialog::OnBnClickedFileinfo)
+//for comment:
+EVT_BUTTON(XRCID("IDC_CMTBT"), CFileDetailDialog::OnBnClickedShowComment)
+// Added by Tarod [Juanjo]:
+EVT_BUTTON(XRCID("IDC_RENAME"), CFileDetailDialog::Rename)
 
-    EVT_TIMER(ID_MY_TIMER, CFileDetailDialog::OnTimer)
+EVT_TIMER(ID_MY_TIMER, CFileDetailDialog::OnTimer)
 END_EVENT_TABLE()
 
 CFileDetailDialog::CFileDetailDialog(wxWindow *parent, CPartFile *file)
@@ -92,6 +93,23 @@ void CFileDetailDialog::OnTimer(wxTimerEvent &evt)
     UpdateData();
 }
 
+#if 0
+void CFileDetailDialog::DoDataExchange(CDataExchange *pDX)
+{
+    CDialog::DoDataExchange(pDX);
+}
+
+bool CFileDetailDialog::OnInitDialog()
+{
+    CDialog::OnInitDialog();
+    Localize();
+    m_timer = SetTimer(301, 5000, 0);
+    UpdateData();
+    return true;
+}
+
+#endif
+
 void CFileDetailDialog::OnClosewnd(wxCommandEvent &evt)
 {
     EndModal(0);
@@ -99,7 +117,7 @@ void CFileDetailDialog::OnClosewnd(wxCommandEvent &evt)
 
 void CFileDetailDialog::UpdateData()
 {
-    CString bufferS;
+    wxString bufferS;
     GetDlgItem(IDC_FNAME, wxControl)->SetLabel(MakeStringEscaped(m_file->GetFileName()));
     GetDlgItem(IDC_METFILE, wxControl)->SetLabel(m_file->GetFullName());
     wxString tmp = GetDlgItem(IDC_FILENAME, wxTextCtrl)->GetValue();
@@ -108,28 +126,28 @@ void CFileDetailDialog::UpdateData()
     GetDlgItem(IDC_FHASH, wxTextCtrl)->SetValue(EncodeBase16(m_file->GetFileHash(), 16));
     GetDlgItem(IDC_FSIZE, wxControl)->SetLabel(CastItoXBytes(m_file->GetFileSize()));
     GetDlgItem(IDC_PFSTATUS, wxControl)->SetLabel(m_file->getPartfileStatus());
-    bufferS.Format("%i(%i)", m_file->GetPartCount(), m_file->GetHashCount());
+    bufferS.Printf("%i(%i)", m_file->GetPartCount(), m_file->GetHashCount());
     GetDlgItem(IDC_PARTCOUNT, wxControl)->SetLabel(bufferS);
     GetDlgItem(IDC_TRANSFERED, wxControl)->SetLabel(CastItoXBytes(m_file->GetTransfered()));
-    bufferS.Format(GetResString(IDS_FD_STATS), CastItoXBytes(m_file->GetLostDueToCorruption()) .GetData(), CastItoXBytes(m_file->GetGainDueToCompression()) .GetData(), m_file->TotalPacketsSavedDueToICH());
+    bufferS.Printf(GetResString(IDS_FD_STATS), CastItoXBytes(m_file->GetLostDueToCorruption()) .GetData(), CastItoXBytes(m_file->GetGainDueToCompression()) .GetData(), m_file->TotalPacketsSavedDueToICH());
     GetDlgItem(IDC_FD_STATS, wxControl)->SetLabel(bufferS);
     GetDlgItem(IDC_COMPLSIZE, wxControl)->SetLabel(CastItoXBytes(m_file->GetCompletedSize()));
-    bufferS.Format("%.2f ", m_file->GetPercentCompleted());
+    bufferS.Printf("%.2f ", m_file->GetPercentCompleted());
     GetDlgItem(IDC_PROCCOMPL, wxControl)->SetLabel(bufferS + GetResString(IDS_PROCDONE));
-    bufferS.Format("%.2f %s", (float) m_file->GetDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
+    bufferS.Printf("%.2f %s", (float) m_file->GetDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
     GetDlgItem(IDC_DATARATE, wxControl)->SetLabel(bufferS);
-    bufferS.Format("%i", m_file->GetSourceCount());
+    bufferS.Printf("%i", m_file->GetSourceCount());
     GetDlgItem(IDC_SOURCECOUNT, wxControl)->SetLabel(bufferS);
-    bufferS.Format("%i", m_file->GetTransferingSrcCount());
+    bufferS.Printf("%i", m_file->GetTransferingSrcCount());
     GetDlgItem(IDC_SOURCECOUNT2, wxControl)->SetLabel(bufferS);
-    bufferS.Format("%i (%.1f%%)", m_file->GetAvailablePartCount(), (float)((m_file->GetAvailablePartCount() *100) / m_file->GetPartCount()));
+    bufferS.Printf("%i (%.1f%%)", m_file->GetAvailablePartCount(), (float)((m_file->GetAvailablePartCount() *100) / m_file->GetPartCount()));
     GetDlgItem(IDC_PARTAVAILABLE, wxControl)->SetLabel(bufferS);
-    if (m_file->lastseencomplete == 0) bufferS.Format(GetResString(IDS_UNKNOWN) .MakeLower());
+    if (m_file->lastseencomplete == 0) bufferS.Printf(GetResString(IDS_UNKNOWN) .MakeLower());
     else
     {
         char tmps[80];
         strftime(tmps, sizeof(tmps), "%A, %x, %X", localtime( &m_file->lastseencomplete));
-        //.Format( "%s",m_file->lastseencomplete.Format( "%A, %x, %X"));:
+        //.Printf( "%s",m_file->lastseencomplete.Printf( "%A, %x, %X"));:
         bufferS = tmps;
     }
     GetDlgItem(IDC_LASTSEENCOMPL, wxControl)->SetLabel(bufferS);
@@ -139,6 +157,24 @@ void CFileDetailDialog::UpdateData()
     GetDlgItem(IDC_FILEINFO, wxControl)->Enable(m_file->IsMovie());
 }
 
+#if 0
+void CFileDetailDialog::OnDestroy()
+{
+    if (m_timer) KillTimer(m_timer);
+}
+
+BEGIN_MESSAGE_MAP(CFileDetailDialog, CDialog)
+ON_WM_TIMER()
+ON_WM_DESTROY()
+// Added by Tarod [Juanjo]:
+ON_BN_CLICKED(IDC_BUTTONRENAME, OnBnClickedButtonrename)
+ON_BN_CLICKED(IDC_BUTTONSTRIP, OnBnClickedButtonStrip)
+ON_BN_CLICKED(IDC_TAKEOVER, TakeOver)
+END_MESSAGE_MAP()
+#endif
+
+// CFileDetailDialog message handlers
+
 #define LVCFMT_LEFT wxLIST_FORMAT_LEFT
 
 void CFileDetailDialog::Localize()
@@ -180,7 +216,7 @@ void CFileDetailDialog::FillSourcenameList()
     //info.flags = LVFI_STRING;
     int itempos;
     int namecount;
-    CString nameCountStr;
+    wxString nameCountStr;
     pmyListCtrl = (wxListCtrl *) GetDlgItem(IDC_LISTCTRLFILENAMES, wxListCtrl);
     if (pmyListCtrl->GetColumnCount() < 2)
     {
@@ -188,13 +224,13 @@ void CFileDetailDialog::FillSourcenameList()
         pmyListCtrl->InsertColumn(0, GetResString(IDS_DL_FILENAME), LVCFMT_LEFT, 340);
         pmyListCtrl->InsertColumn(1, GetResString(IDS_DL_SOURCES), LVCFMT_LEFT, 60);
     }
-    CString strText;
+    wxString strText;
     pmyListCtrl->DeleteAllItems();
-    for (int sl = 0 ; sl < SOURCESSLOTS ; sl++) if(!m_file->srclists[sl].IsEmpty())
-    for (pos1 = m_file->srclists[sl].GetHeadPosition() ; (pos2 = pos1) != NULL ;)
+
+    for (pos1 = m_file->srclist.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
-        m_file->srclists[sl].GetNext(pos1);
-        cur_src = m_file->srclists[sl].GetAt(pos2);
+        m_file->srclist.GetNext(pos1);
+        cur_src = m_file->srclist.GetAt(pos2);
         //info.psz = cur_src->GetClientFilename();
         if (cur_src->GetClientFilename() != 0)
         {
@@ -213,7 +249,7 @@ void CFileDetailDialog::FillSourcenameList()
             {
                 namecount = (pmyListCtrl->GetItemData(itempos));
                 namecount++;
-                nameCountStr.Format("%i", namecount);
+                nameCountStr.Printf("%i", namecount);
                 pmyListCtrl->SetItem(itempos, 1, nameCountStr);
                 pmyListCtrl->SetItemData(itempos, namecount);
             }
@@ -224,6 +260,27 @@ void CFileDetailDialog::FillSourcenameList()
     // End by Juanjo
 }
 
+#if 0
+void CFileDetailDialog::OnBnClickedButtonrename()
+{
+    wxString NewFileName;
+    GetDlgItem(IDC_FILENAME)->GetWindowText(NewFileName);
+    m_file->SetFileName(NewFileName.GetBuffer());
+    m_file->SavePartFile();
+    GetDlgItem(IDC_FNAME)->SetWindowText(m_file->GetFileName());
+    GetDlgItem(IDC_METFILE)->SetWindowText(m_file->GetFullName());
+    GetDlgItem(IDC_FILENAME)->SetWindowText(m_file->GetFileName());
+}
+
+int CALLBACK CFileDetailDialog::CompareListNameItems(LPARAM lParam1, LPARAM lParam2, LPARAM lParamSort)
+{
+    if (lParam1 == lParam2) return 0;
+    if (lParam1 > lParam2) return - 1;
+    else return 1;
+}
+
+#endif
+
 void CFileDetailDialog::OnBnClickedShowComment(wxCommandEvent &evt)
 {
     CCommentDialogLst *dialog = new CCommentDialogLst(this, m_file);
@@ -284,7 +341,7 @@ void CFileDetailDialog::OnBnClickedButtonStrip(wxCommandEvent &evt)
             }
         }
     }
-    GetDlgItem(IDC_FILENAME, wxTextCtrl)->SetValue(MakeStringEscaped(CString(filename.GetData())));
+    GetDlgItem(IDC_FILENAME, wxTextCtrl)->SetValue(MakeStringEscaped(wxString(filename.GetData())));
 }
 
 // added by quekky
