@@ -24,15 +24,11 @@
 #include "FlowChart.h"                      // Needed for this Interface's Prototype
 
 #include "wxTreeMultiCtrl.h"                // Needed for wxTreeMultiCtrl
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
 
-//#include <wx/dc.h>                          // Needed for wxClientDC
-//#include <wx/dirdlg.h>                      // Needed for wxDirDialog
-//#include <wx/msgdlg.h>                      // Needed for wxMessageDialog
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefsCtrl.h>          // Needed for DynamicPreferencesCtrl
+
 #include <wx/sizer.h>                       // Needed for wxBoxSizer
-//#include <wx/statline.h>                    // Needed for wxStaticLine
-//#include <wx/textdlg.h>                     // Needed for wxTextEntryDialog
-
 
 BEGIN_EVENT_TABLE(CFlowChart, wxScrolledWindow)
     EVT_KILL_FOCUS(CFlowChart::OnLoseFocus)
