@@ -22,23 +22,34 @@
 
 #ifdef PRECOMP
 #	include "xmule-headers.h"
-#else
-#	include "ini2.h"
-#	include "KnownFile.h"
-#	include "KnownFileList.h"
-#	include "opcodes.h"
-#	include "otherfunctions.h"
-#include "packets.h"                        // Packet
-#include "PartFile.h"                       // PR_HIGH
-#	include "SharedFileList.h"
-#	include "SharedFilesWnd.h"
-#	include "updownclient.h"
-#	include "UploadQueue.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+//#include "CFile.h"                          // CFile
+
+/*#include "wintypes.h"
+#include "otherstructs.h"
+#include "types.h"
+#include "wx/dynarray.h"
+#include "BarShader.h"
+#include "MD5Sum.h"
+*/
+
+#include "CMemFile.h"                       // CMemFile - audited 5 Nov 2004
+#include "ini2.h"
+#include "KnownFile.h"
+#include "KnownFileList.h"
+#include "opcodes.h"
+#include "otherfunctions.h"
+#include "packets.h"                        // Packet
+#include "PartFile.h"                       // PR_HIGH
+#include "SharedFileList.h"
+#include "SharedFilesWnd.h"
+#include "updownclient.h"
+#include "UploadQueue.h"
+#include "xmule.h"
+#include "xmuleDlg.h"
+
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -59,7 +70,7 @@
 #define S33 11
 #define S34 15
 
-static void MD4Transform(uint32 Hash[4], uint32 x[16]);
+static void MD4Transform(uint32_t Hash[4], uint32_t x[16]);
 
 void CFileStatistic::AddRequest()
 {
@@ -77,7 +88,7 @@ void CFileStatistic::AddAccepted()
     theApp.sharedfiles->UpdateItem(fileParent);
 }
 
-void CFileStatistic::AddTransferred(uint64 bytes)
+void CFileStatistic::AddTransferred(uint64_t bytes)
 {
     transfered += bytes;
     alltimetransfered += bytes;
@@ -114,21 +125,28 @@ CKnownFile::CKnownFile()
 CKnownFile::~CKnownFile()
 {
     for (int i = 0 ; i != hashlist.GetSize() ; i++)
-    if (hashlist[i])
-    delete[] hashlist[i];
+    {
+        delete[] hashlist[i];
+    }
+
     for (int i = 0 ; i != taglist.GetSize() ; i++)
-    safe_delete(taglist[i]);
-    //	if (filename)	// done by CAbstractFile destructor
-    //		delete[] filename;
-    if (directory)
+    {
+        delete taglist[i];
+
+    }
+
+    hashlist.RemoveAll();
+    taglist.RemoveAll();
     delete[] directory;
+
     m_AvailPartFrequency.RemoveAll();
 }
 
-CBarShader CKnownFile::s_ShareStatusBar(16);
-
 void CKnownFile::DrawShareStatusBar(wxDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
 {
+    static	CBarShader s_ShareStatusBar(16);
+
+ 
  /*
  DWORD crBoth;
  DWORD crNeither;
@@ -170,7 +188,7 @@ void CKnownFile::DrawShareStatusBar(wxDC *dc, wxRect rect, bool onlygreyrect, bo
 void CKnownFile::NewAvailPartsInfo()
 {
     // Cache part count
-    uint16 partcount = GetPartCount();
+    uint16_t partcount = GetPartCount();
     if (m_AvailPartFrequency.GetSize() < partcount)
     m_AvailPartFrequency.SetSize(partcount);
     // Reset part counters
@@ -179,8 +197,12 @@ void CKnownFile::NewAvailPartsInfo()
         m_AvailPartFrequency.Add(0);
     }
     CUpDownClient *cur_src;
+
     if (this->IsPartFile())
-    cur_src = NULL;
+    {
+        cur_src = NULL;
+    }
+
     for (POSITION pos = m_ClientUploadList.GetHeadPosition() ; pos != 0 ;)
     {
         cur_src = m_ClientUploadList.GetNext(pos);
@@ -213,11 +235,15 @@ void CKnownFile::RemoveUploadingClient(CUpDownClient *client)
     }
 }
 
-void CKnownFile::SetPath(char *path)
+void CKnownFile::SetPath(const wxString& path)
 {
     if (directory)
-    delete[] directory;
-    directory = nstrdup(path);
+    {
+        delete[] directory;
+    }
+
+    directory = new char[path.length()];
+    strcpy(directory, path.c_str());
 }
 
 bool CKnownFile::CreateFromFile(char *in_directory, char *in_filename, volatile int const *notify)
@@ -243,14 +269,14 @@ bool CKnownFile::CreateFromFile(char *in_directory, char *in_filename, volatile
     m_nFileSize = ftell(file);
     fseek(file, curpos, SEEK_SET);
     m_AvailPartFrequency.SetSize(GetPartCount());
-    for (uint32 i = 0 ; i != GetPartCount() ; i++)
+    for (uint32_t i = 0 ; i != GetPartCount() ; i++)
     m_AvailPartFrequency.Add(0);
     // create hashset
-    uint32 togo = m_nFileSize;
-    uint16 hashcount;
+    uint32_t togo = m_nFileSize;
+    uint16_t hashcount;
     for (hashcount = 0 ; togo >= PARTSIZE ;)
     {
-        uchar *newhash = new uchar[16];
+        unsigned char *newhash = new unsigned char[16];
         CreateHashFromFile(file, PARTSIZE, newhash);
         hashlist.Add(newhash);
         togo -= PARTSIZE;
@@ -261,7 +287,7 @@ bool CKnownFile::CreateFromFile(char *in_directory, char *in_filename, volatile
             return false;
         }
     }
-    uchar *lasthash = new uchar[16];
+    unsigned char *lasthash = new unsigned char[16];
     memset(lasthash, 0, 16);
     CreateHashFromFile(file, togo, lasthash);
     if (!hashcount)
@@ -273,7 +299,7 @@ bool CKnownFile::CreateFromFile(char *in_directory, char *in_filename, volatile
     else
     {
         hashlist.Add(lasthash);
-        uchar *buffer = new uchar[hashlist.GetCount() *16];
+        unsigned char *buffer = new unsigned char[hashlist.GetCount() *16];
         for (int i = 0 ; i != hashlist.GetCount() ; i++)
         memcpy(buffer + (i *16), hashlist[i], 16);
         CreateHashFromString(buffer, hashlist.GetCount() *16, m_abyFileHash);
@@ -292,13 +318,13 @@ bool CKnownFile::CreateFromFile(char *in_directory, char *in_filename, volatile
 // needed for memfiles. its probably better to switch everything to CFile...
 bool CKnownFile::LoadHashsetFromFile(CFile *file, bool checkhash)
 {
-    uchar checkid[16];
+    unsigned char checkid[16];
     file->Read( &checkid, 16);
-    uint16 parts;
+    uint16_t parts;
     file->Read( &parts, 2);
     for (int i = 0 ; i != parts ; i++)
     {
-        uchar *cur_hash = new uchar[16];
+        unsigned char *cur_hash = new unsigned char[16];
         file->Read(cur_hash, 16);
         hashlist.Add(cur_hash);
     }
@@ -310,7 +336,7 @@ bool CKnownFile::LoadHashsetFromFile(CFile *file, bool checkhash)
     // trust noone ;-)
     if (!hashlist.IsEmpty())
     {
-        uchar *buffer = new uchar[hashlist.GetCount() *16];
+        unsigned char *buffer = new unsigned char[hashlist.GetCount() *16];
         for (int i = 0 ; i != hashlist.GetCount() ; i++)
         {
             memcpy(buffer + (i *16), hashlist[i], 16);
@@ -335,10 +361,10 @@ bool CKnownFile::LoadTagsFromFile(CFile *file)
 {
     try
     {
-        uint32 tagcount;
+        uint32_t tagcount;
         if (4 != file->Read( &tagcount, 4))
         throw CInvalidPacket("short file reading tag count");
-        for (uint32 j = 0 ; j < tagcount ; j++)
+        for (uint32_t j = 0 ; j < tagcount ; j++)
         {
             try
             {
@@ -355,7 +381,7 @@ bool CKnownFile::LoadTagsFromFile(CFile *file)
                     {
                         m_nFileSize = newtag->tag->intvalue;
                         m_AvailPartFrequency.SetSize(GetPartCount());
-                        for (uint32 i = 0 ; i != GetPartCount() ; i++)
+                        for (uint32_t i = 0 ; i != GetPartCount() ; i++)
                         m_AvailPartFrequency.Add(0);
                         delete newtag;
                         break;
@@ -386,7 +412,7 @@ bool CKnownFile::LoadTagsFromFile(CFile *file)
                 case FT_DLPRIORITY:
                 case FT_ULPRIORITY:
                     {
-                        uint8 autoprio = PR_AUTO;
+                        uint8_t autoprio = PR_AUTO;
                         m_iUpPriority = newtag->tag->intvalue;
                         if (m_iUpPriority == autoprio)
                         {
@@ -437,13 +463,13 @@ bool CKnownFile::WriteToFile(FILE *file)
     fwrite( &date, 4, 1, file);
     // hashset
     fwrite( &m_abyFileHash, 16, 1, file);
-    uint16 parts = hashlist.GetCount();
+    uint16_t parts = hashlist.GetCount();
     fwrite( &parts, 2, 1, file);
     for (int i = 0 ; i != parts ; i++)
     fwrite(hashlist[i], 16, 1, file);
     //tags
 #define NR_TAGS 10
-    uint32 tagcount = taglist.GetCount() + NR_TAGS;
+    uint32_t tagcount = taglist.GetCount() + NR_TAGS;
     // standard tags
     fwrite( &tagcount, 4, 1, file);
     CTag(FT_FILENAME, m_pszFileName) .WriteTagToFile(file);
@@ -460,17 +486,17 @@ bool CKnownFile::WriteToFile(FILE *file)
     CTag(FT_DLPRIORITY, m_iUpPriority) .WriteTagToFile(file);
     CTag(FT_PERMISSIONS, m_iPermissions) .WriteTagToFile(file);
     //other tags
-    for (uint32 j = 0 ; j < tagcount - NR_TAGS ; j++)
+    for (uint32_t j = 0 ; j < tagcount - NR_TAGS ; j++)
     taglist[j]->WriteTagToFile(file);
     return ferror(file);
 #undef NR_TAGS
 }
 
-void CKnownFile::CreateHashFromInput(FILE *file, CFile *file2, int Length, uchar *Output, uchar *in_string)
+void CKnownFile::CreateHashFromInput(FILE *file, CFile *file2, int Length, unsigned char *Output, unsigned char *in_string)
 {
     // time critial
     bool PaddingStarted = false;
-    uint32 Hash[4];
+    uint32_t Hash[4];
     Hash[0] = 0x67452301;
     Hash[1] = 0xEFCDAB89;
     Hash[2] = 0x98BADCFE;
@@ -480,11 +506,11 @@ void CKnownFile::CreateHashFromInput(FILE *file, CFile *file2, int Length, uchar
     {
         data = new CMemFile(in_string, Length);
     }
-    uint32 Required = Length;
-    uchar X[64 *128];
+    uint32_t Required = Length;
+    unsigned char X[64 *128];
     while (Required >= 64)
     {
-        uint32 len = Required / 64;
+        uint32_t len = Required / 64;
         if (len > sizeof(X) / (64 *sizeof(X[0])))
         len = sizeof(X) / (64 *sizeof(X[0]));
         if (in_string)
@@ -493,9 +519,9 @@ void CKnownFile::CreateHashFromInput(FILE *file, CFile *file2, int Length, uchar
         fread( &X, len *64, 1, file);
         else if(file2)
         file2->Read( &X, len *64);
-        for (uint32 i = 0 ; i < len ; i++)
+        for (uint32_t i = 0 ; i < len ; i++)
         {
-            MD4Transform(Hash, (uint32 *)(X + i *64));
+            MD4Transform(Hash, (uint32_t *)(X + i *64));
         }
         Required -= len *64;
     }
@@ -516,7 +542,7 @@ void CKnownFile::CreateHashFromInput(FILE *file, CFile *file2, int Length, uchar
         X[Required] = 0x80;
         PaddingStarted = TRUE;
         memset( &X[Required + 1], 0, 63 - Required);
-        MD4Transform(Hash, (uint32 *) X);
+        MD4Transform(Hash, (uint32_t *) X);
         Required = 0;
     }
     if (!PaddingStarted)
@@ -525,28 +551,28 @@ void CKnownFile::CreateHashFromInput(FILE *file, CFile *file2, int Length, uchar
     }
     memset( &X[Required], 0, 64 - Required);
     // add size (convert to bits)
-    uint32 Length2 = Length >> 29;
+    uint32_t Length2 = Length >> 29;
     Length <<= 3;
     memcpy( &X[56], &Length, 4);
     memcpy( &X[60], &Length2, 4);
-    MD4Transform(Hash, (uint32 *) X);
+    MD4Transform(Hash, (uint32_t *) X);
     memcpy(Output, Hash, 16);
-    safe_delete(data);
+    delete data;
 }
 
-uchar *CKnownFile::GetPartHash(uint16 part)
+unsigned char *CKnownFile::GetPartHash(uint16_t part)
 {
     if (part >= hashlist.GetCount())
     return 0;
     return hashlist[part];
 }
 
-static void MD4Transform(uint32 Hash[4], uint32 x[16])
+static void MD4Transform(uint32_t Hash[4], uint32_t x[16])
 {
-    uint32 a = Hash[0];
-    uint32 b = Hash[1];
-    uint32 c = Hash[2];
-    uint32 d = Hash[3];
+    uint32_t a = Hash[0];
+    uint32_t b = Hash[1];
+    uint32_t c = Hash[2];
+    uint32_t d = Hash[3];
     /* Round 1 */
     // 01:
     MD4_FF(a, b, c, d, x[ 0], S11);
@@ -660,7 +686,7 @@ void CAbstractFile::SetFileName(char *NewName)
         delete[] m_pszFileName;
         m_pszFileName = new char[strlen(NewName) + 1];
         wxString filenametemp;
-        //.Format("%s",NewName);:
+        //.Printf("%s",NewName);:
         filenametemp = NewName;
         filenametemp.Replace("\\", "-");
         filenametemp.Replace(">", "-");
@@ -686,7 +712,7 @@ Packet* CKnownFile::CreateSrcInfoPacket(CUpDownClient* forClient)
     }
 
     CMemFile data;
-    uint16 nCount = 0;
+    uint16_t nCount = 0;
     data.Write(forClient->GetUploadFileID(), 16);
     data.Write( &nCount, 2);
 
@@ -703,10 +729,10 @@ Packet* CKnownFile::CreateSrcInfoPacket(CUpDownClient* forClient)
         if (!cur_src->HasLowID() && cur_src != forClient)
         {
             nCount++;
-            uint32 dwID = cur_src->GetUserID();
-            uint16 nPort = cur_src->GetUserPort();
-            uint32 dwServerIP = cur_src->GetServerIP();
-            uint16 nServerPort = cur_src->GetServerPort();
+            uint32_t dwID = cur_src->GetUserID();
+            uint16_t nPort = cur_src->GetUserPort();
+            uint32_t dwServerIP = cur_src->GetServerIP();
+            uint16_t nServerPort = cur_src->GetServerPort();
             data.Write( &dwID, 4);
             data.Write( &nPort, 2);
             data.Write( &dwServerIP, 4);
@@ -780,7 +806,7 @@ void CKnownFile::LoadComment()
 //    char *fullpath = new char[theApp.dynprefs->Get<wxString>("app-directory").length() + 13];
 //    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
     buffer[0] = 0;
-    for (uint16 i = 0 ; i != 16 ; i++)
+    for (uint16_t i = 0 ; i != 16 ; i++)
     sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
     CIni ini(theApp.dynprefs->Get<wxString>("app-directory") + wxT("fileinfo.ini"), buffer);
     m_strComment = ini.GetString("Comment") .GetData();
@@ -790,14 +816,14 @@ void CKnownFile::LoadComment()
 //    delete[] fullpath;
 }
 
-void CKnownFile::SetFileComment(CString strNewComment)
+void CKnownFile::SetFileComment(wxString strNewComment)
 {
     char buffer[100];
 //    char* fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 13];
 //    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
     buffer[0] = 0;
 
-    for (uint16 i=0; i!=16; ++i)
+    for (uint16_t i=0; i!=16; ++i)
     {
         sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
     }
@@ -817,14 +843,14 @@ void CKnownFile::SetFileComment(CString strNewComment)
     }
 }
 
-void CKnownFile::SetFileRate(int8 iNewRate)
+void CKnownFile::SetFileRate(int8_t iNewRate)
 {
     char buffer[100];
 //    char* fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 13];
 //    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
     buffer[0] = 0;
     
-    for (uint16 i=0; i!=16; ++i)
+    for (uint16_t i=0; i!=16; ++i)
     {
         sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
     }
@@ -844,10 +870,12 @@ void CKnownFile::SetFileRate(int8 iNewRate)
     }
 }
 
-void CKnownFile::SetUpPriority(uint8 iNewUpPriority, bool m_bsave)
+void CKnownFile::SetUpPriority(uint8_t iNewUpPriority, bool m_bsave)
 {
     m_iUpPriority = iNewUpPriority;
-    if (this->IsPartFile() &&m_bsave)
-    ((CPartFile *) this)->SavePartFile();
+    if (this->IsPartFile() && m_bsave)
+    {
+        ((CPartFile *) this)->SavePartFile();
+    }
 }
 
