@@ -3,34 +3,37 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "KnownFile.h"
+#	include "KnownFileList.h"
+#	include "SafeFile.h"
+#	include "wintypes.h"
+#	include "xmule.h"
 #endif
 
-#include "KnownFileList.h"                  // Needed for this Interface's Prototype
+#include <wx/utils.h>
 
-#include "KnownFile.h"                      // Needed for CKnownFile
-#include "SafeFile.h"                       // Needed for CSafeFile
-
-static wxString KnownFileHash(const char *filename, uint32 date, uint32 size)
+static wxString KnownFileHash(const char *filename, uint32_t date, uint32_t size)
 {
-    return wxString::Format("%s%08lx%08lx", filename, date, size);
+    return wxString::Format("%s%08lx%08lx", filename, static_cast<long unsigned int>(date), static_cast<long unsigned int>(size));
 }
 
 static wxString KnownFileHash(CKnownFile *file)
@@ -70,7 +73,7 @@ bool CKnownFileList::Init()
             delete[] fullpath;
             return false;
         }
-        uint8 header;
+        uint8_t header;
         file.Open(fullpath);
         delete[] fullpath;
         fullpath = NULL;
@@ -82,9 +85,9 @@ bool CKnownFileList::Init()
         }
         //CSingleLock sLock(&list_mut,true); // to make sure that its thread-safe
         wxMutexLocker sLock(list_mut);
-        uint32 RecordsNumber;
+        uint32_t RecordsNumber;
         file.Read( &RecordsNumber, 4);
-        for (uint32 i = 0 ; i != RecordsNumber ; i++)
+        for (uint32_t i = 0 ; i != RecordsNumber ; i++)
         {
             Record = new CKnownFile();
             Record->LoadFromFile( &file);
@@ -95,6 +98,22 @@ bool CKnownFileList::Init()
         file.Close();
         return true;
     }
+#if 0
+    catch(CFileException *error)
+    {
+        if (error->m_cause == CFileException::endOfFile)
+        theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_SERVERMET_BAD));
+        else
+        {
+            char buffer[150];
+            error->GetErrorMessage(buffer, 150);
+            theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_SERVERMET_UNKNOWN), buffer);
+        }
+        //memleak fix:
+        error->Delete();
+        return false;
+    }
+#endif
 }
 
 void CKnownFileList::Save()
@@ -113,10 +132,10 @@ void CKnownFileList::Save()
     fullpath = NULL;
     wxMutexLocker sLock(list_mut);
     fputc(MET_HEADER, file);
-    uint32 RecordsNumber = m_map.size();
+    uint32_t RecordsNumber = m_map.size();
     fwrite( &RecordsNumber, 4, 1, file);
     KnownFileMap::iterator it = m_map.begin();
-    for (uint32 i = 0 ; i != RecordsNumber ; i++, it++)
+    for (uint32_t i = 0 ; i != RecordsNumber ; i++, it++)
     {
         if (it == m_map.end())
         // TODO: Throw an exception:
@@ -134,7 +153,7 @@ void CKnownFileList::Clear()
     m_map.clear();
 }
 
-CKnownFile *CKnownFileList::FindKnownFile(char *filename, uint32 in_date, uint32 in_size)
+CKnownFile *CKnownFileList::FindKnownFile(char *filename, uint32_t in_date, uint32_t in_size)
 {
     wxMutexLocker sLock(list_mut);
     KnownFileMap::iterator it = m_map.find(KnownFileHash(filename, in_date, in_size));
@@ -143,7 +162,7 @@ CKnownFile *CKnownFileList::FindKnownFile(char *filename, uint32 in_date, uint32
     return 0;
 }
 
-bool CKnownFileList::SafeAddKFile(wxUint8 type,CKnownFile *toadd)
+bool CKnownFileList::SafeAddKFile(CKnownFile *toadd)
 {
     wxMutexLocker sLock(list_mut);
     return Append(toadd);
