@@ -3,7 +3,7 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -24,33 +24,41 @@
 #ifndef LISTENSOCKET_H
 #define LISTENSOCKET_H
 
-#include "EMSocket.h"                       // Needed for CEMSocket
+#include "EMSocket.h"                       // CEMSocket - audited 5 Nov 2004
+
+#include <wx/socket.h>
+#include <wx/hashmap.h>
+#include <string.h>
 
-class CEMSocket;
 class CPreferences;
-class CTimerWnd;
-class CUpDownClient;
+class Packet;
+class wxEvtHandler;
 
-class MyIntegerHash
+class WXDLLEXPORT MyIntegerHash
 {
 public:
     MyIntegerHash() { }
-    uint64 operator()( uint64 x ) const { return x; }
+    uint64_t operator()( uint64_t x ) const { return x; }
 
     MyIntegerHash& operator=(const MyIntegerHash&) { return *this; }
 };
 
-class MyIntegerEqual
+class WXDLLEXPORT MyIntegerEqual
 {
 public:
     MyIntegerEqual() { }
-    bool operator()( uint64 a, uint64 b ) const { return a == b; }
+    bool operator()( uint64_t a, uint64_t b ) const { return a == b; }
 
     MyIntegerEqual& operator=(const MyIntegerEqual&) { return *this; }
 };
 
-WX_DECLARE_HASH_MAP(uint64, uint32, MyIntegerHash, MyIntegerEqual, MyHashMap1);
-WX_DECLARE_HASH_MAP(uint64, uint64, MyIntegerHash, MyIntegerEqual, MyHashMap2);
+WX_DECLARE_HASH_MAP(uint64_t, uint32_t, MyIntegerHash, MyIntegerEqual, MyHashMap1);
+WX_DECLARE_HASH_MAP(uint64_t, uint64_t, MyIntegerHash, MyIntegerEqual, MyHashMap2);
+
+class CUpDownClient;
+class CTimerWnd;
+
+//class CClientReqSocket;
 
 class CClientReqSocket : public CEMSocket
 {
@@ -81,8 +89,8 @@ public:
 	virtual	void OnInit();
 	virtual	bool Close(); /*	{return wxSocketBase::Close();}*/
 	
-	uint32		timeout_timer;
-	uint32		deltimer;  
+	uint32_t		timeout_timer;
+	uint32_t		deltimer;  
 	bool		hotrank;
 	CUpDownClient*	client;
 	CPreferences* 	app_prefs;
@@ -92,17 +100,26 @@ protected:
 	void		 PacketReceived(Packet* packet);
 private:
 	void		Delete_Timed();
-	bool		ProcessPacket(char* packet, uint32 size,uint8 opcode);
-	bool		ProcessExtPacket(char* packet, uint32 size,uint8 opcode);
+	bool		ProcessPacket(char* packet, uint32_t size,uint8_t opcode);
+	bool		ProcessExtPacket(char* packet, uint32_t size,uint8_t opcode);
+    wxEvtHandler* m_event_handler;
 };
 
 #include <wx/list.h>
+#include <wx/version.h>                     // wxCHECK_VERSION
+//WX_DECLARE_LIST(CClientReqSocket,SocketListL);
 
-class CListenSocket : public wxSocketServer{
+// CListenSocket command target
+class CListenSocket : public wxSocketServer
+{
   DECLARE_DYNAMIC_CLASS(CListenSocket)
 
 public:
-	CListenSocket() : wxSocketServer(happyCompiler) {};
+    #if wxCHECK_VERSION(2,5,3)
+	CListenSocket(): wxSocketServer(happyCompiler, wxSOCKET_NOWAIT | wxSOCKET_REUSEADDR) {};
+    #else
+	CListenSocket(): wxSocketServer(happyCompiler, wxSOCKET_NOWAIT) {};
+    #endif
 	CListenSocket(CPreferences* in_prefs,wxSockAddress& addr);
 	~CListenSocket();
 	bool	StartListening();
@@ -111,10 +128,10 @@ public:
 	void	Process();
 	void	RemoveSocket(CClientReqSocket* todel);
 	void	AddSocket(CClientReqSocket* toadd);
-	uint16	GetOpenSockets()		{return socket_list.GetCount();}
+	uint16_t	GetOpenSockets()		{return socket_list.GetCount();}
 	void	KillAllSockets();
 	bool	TooManySockets(bool bIgnoreInterval = false);
-	uint32	GetMaxConnectionReached()	{return maxconnectionreached;}
+	uint32_t	GetMaxConnectionReached()	{return maxconnectionreached;}
 	bool    IsValidSocket(CClientReqSocket* totest);
 	void	AddConnection();
 	void	RecalculateStats();
@@ -125,12 +142,14 @@ private:
 	bool bListening;
 	CPreferences* app_prefs;
 	CTypedPtrList<CPtrList, CClientReqSocket*> socket_list;
-	uint16 opensockets;
-	uint16 m_OpenSocketsInterval;
-	uint32 maxconnectionreached;
+	//SocketListL socket_list;
+	uint16_t opensockets;
+	uint16_t m_OpenSocketsInterval;
+	uint32_t maxconnectionreached;
 	wxIPV4address happyCompiler;
-	uint16	m_ConnectionStates[3];
-	uint16	m_nPeningConnections;
+	uint16_t	m_ConnectionStates[3];
+	uint16_t	m_nPeningConnections;
+    wxEvtHandler* m_event_handler;
 
 public:
 	MyHashMap1 offensecounter;
