@@ -23,7 +23,7 @@
 
 #include "MuleListCtrl.h"                   // Needed for this Interface's Prototype
 #include "opcodes.h"                        // Needed for MP_LISTCOL_1
-#include "Preferences.h"                    // Needed for CPreferences
+#include "Preferences.h"                    // Needed for CPreferences::SetColumnWidth
 #include "xmule.h"                          // Needed for theApp
 
 #include <wx/menu.h>                        // Needed for wxMenu
@@ -80,7 +80,7 @@ void CMuleListCtrl::SetNamxMule(LPCTSTR lpszName)
 }
 
 //new fix for old problem... normally Update(int) causes entire list to redraw
-BOOL CMuleListCtrl::Update(int iItem)
+bool CMuleListCtrl::Update(int iItem)
 {
 }
 
@@ -169,6 +169,7 @@ bool CMuleListCtrl::ProcessEvent(wxEvent& evt)
     if ((evt.GetEventType() == wxEVT_COMMAND_MENU_SELECTED) && (evt.GetId() >= MP_LISTCOL_1) && (evt.GetId() <= MP_LISTCOL_15))
     {
         int col = evt.GetId() - MP_LISTCOL_1;
+
         if (wxODListCtrl::GetColumnWidth(col) > m_col_minsize)
         {
             SetColumnWidth(col, 0);
@@ -178,6 +179,7 @@ bool CMuleListCtrl::ProcessEvent(wxEvent& evt)
             SetColumnWidth(col, wxLIST_AUTOSIZE);
         }
     }
+
     return wxODListCtrl::ProcessEvent(evt);
 }
 
