@@ -20,13 +20,22 @@
 // OScopeCtrl.cpp : implementation file//
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "OScopeCtrl.h"
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
 #endif
 
-#include "OScopeCtrl.h"                     // Needed for this Interface's Prototype
+#include <math.h>
 
-#include <cmath>                            // Needed for fabs
-#include <wx/dcmemory.h>                    // Needed for wxMemoryDC
+#ifdef _DEBUG
+#define new DEBUG_NEW
+#undef THIS_FILE
+static char THIS_FILE[] = __FILE__;
+
+#endif
 
 #define GetRValue(rgb) (((rgb)>>16)&0xff)
 #define GetGValue(rgb) (((rgb)>>8)&0xff)
@@ -133,9 +142,9 @@ COScopeCtrl::COScopeCtrl(int NTrends, wxWindow *parent)
     //*wxBLACK_BRUSH;//.CreateSolidBrush( m_crBackColor ) ;
     // public member variables, can be set directly
     // can also be set with SetXUnits:
-    m_str.XUnits.Format("Samples");
+    m_str.XUnits.Printf("Samples");
     // can also be set with SetYUnits:
-    m_str.YUnits.Format("Y units");
+    m_str.YUnits.Printf("Y units");
     // protected bitmaps to restore the memory DC's
     m_pbitmapOldGrid = NULL;
     m_pbitmapOldPlot = NULL;
@@ -169,6 +178,37 @@ COScopeCtrl::~COScopeCtrl()
     // ~COScopeCtrl:
 }
 
+#if 0
+BEGIN_MESSAGE_MAP(COScopeCtrl, CWnd)
+//{{AFX_MSG_MAP(COScopeCtrl)
+ON_WM_PAINT()
+ON_WM_SIZE()
+//}}AFX_MSG_MAP
+END_MESSAGE_MAP()
+#endif
+
+/////////////////////////////////////////////////////////////////////////////
+// COScopeCtrl message handlers
+
+/////////////////////////////////////////////////////////////////////////////
+#if 0
+bool COScopeCtrl::Create(DWORD dwStyle, const RECT &rect,
+CWnd *pParentWnd, UINT nID)
+{
+    bool result;
+    static wxString className = AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW);
+    result = CWnd::CreateEx(WS_EX_CLIENTEDGE | WS_EX_STATICEDGE,
+    className, NULL, dwStyle,
+    rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top,
+    pParentWnd->GetSafeHwnd(), (HMENU) nID);
+    if (result != 0)
+    InvalidateCtrl();
+    return result;
+    // Create:
+}
+
+#endif
+
 /////////////////////////////////////////////////////////////////////////////
 void COScopeCtrl::SetRange(double dLower, double dUpper, int iTrend)
 {
@@ -200,7 +240,7 @@ void COScopeCtrl::SetRanges(double dLower, double dUpper)
 // G.Hayduk: Apart from setting title of axis, now you can optionally set
 // the limits strings
 // (string which will be placed on the left and right of axis)
-void COScopeCtrl::SetXUnits(CString string, CString XMin, CString XMax)
+void COScopeCtrl::SetXUnits(wxString string, wxString XMin, wxString XMax)
 {
     m_str.XUnits = string;
     m_str.XMin = XMin;
@@ -213,7 +253,7 @@ void COScopeCtrl::SetXUnits(CString string, CString XMin, CString XMax)
 // G.Hayduk: Apart from setting title of axis, now you can optionally set
 // the limits strings
 // (string which will be placed on the bottom and top of axis)
-void COScopeCtrl::SetYUnits(CString string, CString YMin, CString YMax)
+void COScopeCtrl::SetYUnits(wxString string, wxString YMin, wxString YMax)
 {
     m_str.YUnits = string;
     m_str.YMin = YMin;
@@ -277,7 +317,7 @@ void COScopeCtrl::InvalidateCtrl(bool deleteGraph)
     //CPen solidPen(PS_SOLID, 0, m_crGridColor) ;
     wxPen solidPen = * (wxThePenList->FindOrCreatePen(wxColour(GetRValue(m_crGridColor), GetGValue(m_crGridColor), GetBValue(m_crGridColor)), 1, wxSOLID));
     //wxFont axisFont, yUnitFont, *oldFont ;
-    CString strTemp;
+    wxString strTemp;
     // in case we haven't established the memory dc's
     //CClientDC dc(this) ;
     wxClientDC dc(this);
@@ -315,7 +355,14 @@ void COScopeCtrl::InvalidateCtrl(bool deleteGraph)
     // draw the plot rectangle
     //oldPen = m_dcGrid.SelectObject (&solidPen) ;
     m_dcGrid->SetPen(solidPen);
-
+#if 0
+    m_dcGrid.MoveTo(m_rectPlot.left, m_rectPlot.top);
+    m_dcGrid.LineTo(m_rectPlot.right + 1, m_rectPlot.top);
+    m_dcGrid.LineTo(m_rectPlot.right + 1, m_rectPlot.bottom + 1);
+    m_dcGrid.LineTo(m_rectPlot.left, m_rectPlot.bottom + 1);
+    m_dcGrid.LineTo(m_rectPlot.left, m_rectPlot.top);
+    m_dcGrid.SelectObject(oldPen);
+#endif
     m_dcGrid->DrawLine(m_rectPlot.left, m_rectPlot.top, m_rectPlot.right + 1, m_rectPlot.top);
     m_dcGrid->DrawLine(m_rectPlot.right + 1, m_rectPlot.top, m_rectPlot.right + 1, m_rectPlot.bottom + 1);
     m_dcGrid->DrawLine(m_rectPlot.right + 1, m_rectPlot.bottom + 1, m_rectPlot.left, m_rectPlot.bottom + 1);
@@ -334,6 +381,30 @@ void COScopeCtrl::InvalidateCtrl(bool deleteGraph)
         //m_dcGrid.SetPixel ( i, GridPos, m_crGridColor ) ;
         m_dcGrid->DrawPoint(i, GridPos);
     }
+ /*
+ for( j=1 ; j<(m_nXGrids+1) ; j++ ){
+ GridPos = m_rectPlot.Width()*j/( m_nXGrids + 1 ) + m_rectPlot.left ;
+ for (i=m_rectPlot.top; i<m_rectPlot.bottom; i+=4)
+ m_dcGrid.SetPixel ( GridPos, i, m_crGridColor ) ;
+ }
+    */
+    // create some fonts (horizontal and vertical)
+    // use a height of 14 pixels and 300 weight
+    // (these may need to be adjusted depending on the display)
+#if 0
+    axisFont.CreateFont(14, 0, 0, 0, 300,
+    FALSE, FALSE, 0, ANSI_CHARSET,
+    OUT_DEFAULT_PRECIS,
+    CLIP_DEFAULT_PRECIS,
+    DEFAULT_QUALITY,
+    DEFAULT_PITCH |FF_SWISS, "Arial");
+    yUnitFont.CreateFont(14, 0, 900, 0, 300,
+    FALSE, FALSE, 0, ANSI_CHARSET,
+    OUT_DEFAULT_PRECIS,
+    CLIP_DEFAULT_PRECIS,
+    DEFAULT_QUALITY,
+    DEFAULT_PITCH |FF_SWISS, "Arial");
+#endif
     wxFont *axisFont, *oldFont;
     axisFont = new wxFont(10, wxSWISS, wxNORMAL, wxNORMAL, FALSE);
     // grab the horizontal font
@@ -345,7 +416,7 @@ void COScopeCtrl::InvalidateCtrl(bool deleteGraph)
     m_dcGrid->SetTextForeground(wxColour(GetRValue(m_crGridColor), GetGValue(m_crGridColor), GetBValue(m_crGridColor)));
     //m_dcGrid.SetTextAlign (TA_RIGHT|TA_TOP) ;
     if (m_str.YMax.IsEmpty())
-    strTemp.Format("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dUpperLimit);
+    strTemp.Printf("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dUpperLimit);
     else
     strTemp = m_str.YMax;
     //m_dcGrid.TextOut (m_rectPlot.left-4, m_rectPlot.top-7, strTemp) ;
@@ -366,7 +437,7 @@ m_dcGrid->DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.top - 7);
 m_dcGrid->SetPen(wxNullPen);
 
 // y/2
-strTemp.Format("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dUpperLimit / 2);
+strTemp.Printf("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dUpperLimit / 2);
 
 //m_dcGrid.TextOut (m_rectPlot.left-2, m_rectPlot.bottom+((m_rectPlot.top-m_rectPlot.bottom)/2)-7 , strTemp) ;
 #ifdef __WXGTK20__
@@ -387,7 +458,7 @@ m_dcGrid->DrawText(strTemp, m_rectPlot.left - 2 - sizX, m_rectPlot.bottom + ((m_
 // y min
 //m_dcGrid.SetTextAlign (TA_RIGHT|TA_BASELINE) ;
 if (m_str.YMin.IsEmpty())
-strTemp.Format("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dLowerLimit);
+strTemp.Printf("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dLowerLimit);
 
 else
 strTemp = m_str.YMin;
@@ -419,9 +490,9 @@ m_dcGrid->DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.bottom);
  m_dcGrid.SetTextAlign (TA_RIGHT|TA_TOP) ;
  if( m_str.XMax.IsEmpty() ){
  if( m_nTrendPoints<0 )
- strTemp.Format ("%d", m_nPlotWidth/m_nShiftPixels) ;
+ strTemp.Printf ("%d", m_nPlotWidth/m_nShiftPixels) ;
  else
- strTemp.Format ("%d", m_nTrendPoints-1 ) ;
+ strTemp.Printf ("%d", m_nTrendPoints-1 ) ;
  } else
  strTemp = m_str.XMax;
  m_dcGrid.TextOut (m_rectPlot.right, m_rectPlot.bottom+4, strTemp) ;
@@ -796,7 +867,12 @@ void COScopeCtrl::OnSize(wxSizeEvent &evt)
 {
     int iTrend;
     //CWnd::OnSize(nType, cx, cy) ;
-
+#if 0
+    if (!theApp.xmuledlg)
+    return;
+    if (!theApp.xmuledlg->IsRunning())
+    return;
+#endif
     if (oldwidth == evt.GetSize() .GetWidth() &&oldheight == evt.GetSize() .GetHeight())
     {
         // same size. don't touch
@@ -854,7 +930,27 @@ void COScopeCtrl::OnSize(wxSizeEvent &evt)
         m_bitmapPlot = NULL;
         m_dcPlot = NULL;
     }
-
+#if 0
+    // destroy and recreate the grid bitmap
+    CClientDC dc(this);
+    if (m_pbitmapOldGrid &&m_bitmapGrid.GetSafeHandle() &&m_dcGrid.GetSafeHdc())
+    {
+        m_dcGrid.SelectObject(m_pbitmapOldGrid);
+        m_bitmapGrid.DeleteObject();
+        m_bitmapGrid.CreateCompatibleBitmap( &dc, m_nClientWidth, m_nClientHeight);
+        m_pbitmapOldGrid = m_dcGrid.SelectObject( &m_bitmapGrid);
+    }
+    // destroy and recreate the plot bitmap
+    if (m_pbitmapOldPlot &&m_bitmapPlot.GetSafeHandle() &&m_dcPlot.GetSafeHdc())
+    {
+        m_dcPlot.SelectObject(m_pbitmapOldPlot);
+        m_bitmapPlot.DeleteObject();
+        m_bitmapPlot.CreateCompatibleBitmap( &dc, m_nClientWidth, m_nClientHeight);
+        m_pbitmapOldPlot = m_dcPlot.SelectObject( &m_bitmapPlot);
+    }
+    if (m_nPlotWidth > 0 &&m_nPlotHeight > 0)
+    InvalidateCtrl();
+#endif
     if (m_nPlotWidth > 0 &&m_nPlotHeight > 0)
     InvalidateCtrl();
     // OnSize:
@@ -882,6 +978,10 @@ int COScopeCtrl::ReCreateGraph(void)
     {
         for (int iTrend = 0 ; iTrend < m_NTrends ; iTrend++)
         {
+#if 0
+            m_PlotData[iTrend].nPrevY = - 1;
+            m_PlotData[iTrend].dPreviousPosition = 0.0;
+#endif
             POSITION pos = m_PlotData[iTrend].lstPoints.FindIndex(i);
             if (pos)
             pAddPoints[iTrend] = m_PlotData[iTrend].lstPoints.GetAt(pos);
@@ -897,8 +997,20 @@ int COScopeCtrl::ReCreateGraph(void)
 //void COScopeCtrl::OnTimer(UINT nIDEvent)
 void COScopeCtrl::OnTimer(wxTimerEvent &evt)
 {
+    if (!theApp.xmuledlg->IsRunning())
+    return;
     m_nRedrawTimer.Stop();
     m_bDoUpdate = true;
     ReCreateGraph();
+#if 0
+    if (nIDEvent == m_nRedrawTimer)
+    {
+        KillTimer(m_nRedrawTimer);
+        m_nRedrawTimer = 0;
+        m_bDoUpdate = true;
+        ReCreateGraph();
+    }
+    CWnd::OnTimer(nIDEvent);
+#endif
 }
 
