@@ -17,49 +17,78 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+// PPgDirectories.cpp : implementation file
+
+#include "PPgDirectories.h"
+
+IMPLEMENT_DYNAMIC_CLASS(CPPgDirectories, wxPanel)
+
+//void Localize(void);
+void CPPgDirectories::LoadSettings(void) { }
+bool CPPgDirectories::OnApply() { return true; }
+
+
+BEGIN_EVENT_TABLE(CPPgDirectories, wxPanel)
+END_EVENT_TABLE()
+
+#if 0
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif // HAVE_CONFIG_H
+
+// Test if we have _GNU_SOURCE before the next step will mess up
+// setting __USE_GNU
+// (only needed for gcc-2.95 compatibility, gcc 3.2 always defines it)
+#include "wx/setup.h"
+
 // Mario Sergio Fujikawa Ferreira <lioux@FreeBSD.org>
 // to detect if this is a *BSD system
+#if defined(HAVE_SYS_PARAM_H)
+#include <sys/param.h>
+#endif
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+//#	include "DirectoryTreeCtrl.h"
+#	include "otherfunctions.h"
+#include "PPgDirectories.h"
+#include "Preferences.h"                    // CPreferences
+#	include "SharedFileList.h"
+#	include "wintypes.h"
+#	include "xmule.h"
 #endif
 
-#include "PPgDirectories.h"                 // Needed for this Interface's Prototype
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
-#include "DirectoryTreeCtrl.h"              // Needed for CDirectoryTreeCtrl
-#include "Preferences.h"                    // Needed for CPreferences
-#include "otherfunctions.h"                 // Needed for GetResString
-#include "resource.h"                       // Needed for IDS_SELECT_INCOMINGDIR
-#include "SharedFileList.h"                 // Needed for CSharedFileList
-#include "xmule.h"                          // Needed for theApp
+#include <wx/checkbox.h>
+#include <wx/notebook.h>
+#include <wx/slider.h>
+#include <wx/textctrl.h>
+#include <wx/treectrl.h>
 
-#include <wx/checkbox.h>                    // Needed for wxCheckBox
-#include <wx/notebook.h>                    // Needed for wxNotebook
-#include <wx/textctrl.h>                    // Needed for wxTextCtrl
-#include <wx/treectrl.h>                    // Needed for wxTreeCtrl
-
-#if defined(HAVE_SYS_PARAM_H)
-    #include <sys/param.h>                  // Needed for *BSD systems, apparently.
-#endif
-
-#include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
+#include <wx/xrc/xmlres.h>
 
 // *BSD compatibility
 #ifndef MAX_PATH
-    #if (defined(BSD) && (BSD >= 199103))
-        #define MAX_PATH MAXPATHLEN
-    #else
-        #define MAX_PATH 2048
-    #endif
+#if (defined(BSD) && (BSD >= 199103))
+#define MAX_PATH MAXPATHLEN
+#else
+#define MAX_PATH 2048
+#endif
 #endif
 
 #define GetDlgItem(x,clas) XRCCTRL(*this,#x,clas)
 #define IsDlgButtonChecked(x) XRCCTRL(*this,#x,wxCheckBox)->GetValue()
 #define CheckDlgButton(x,y) XRCCTRL(*this,#x,wxCheckBox)->SetValue(y)
 
+// CPPgDirectories dialog
+
 IMPLEMENT_DYNAMIC_CLASS(CPPgDirectories, wxPanel)
 
-CPPgDirectories::CPPgDirectories(wxWindow *parent): wxPanel(parent, CPPgDirectories::IDD)
+//IMPLEMENT_DYNAMIC(CPPgDirectories, CPropertyPage)
+CPPgDirectories::CPPgDirectories(wxWindow *parent)
+: wxPanel(parent, CPPgDirectories::IDD)
 {
     wxNotebook *book = (wxNotebook *) parent;
     wxPanel *page1 = wxXmlResource::Get()->LoadPanel(this, "DLG_PPG_DIRECTORIES");
@@ -72,7 +101,7 @@ CPPgDirectories::CPPgDirectories(wxWindow *parent): wxPanel(parent, CPPgDirector
     // then replace it with our own
     oldtree->Destroy();
     CDirectoryTreeCtrl *newtree = new CDirectoryTreeCtrl((wxWindow *) page1, XRCID("IDC_SHARESELECTOR"),
-    pos, siz, wxTR_CHECKBOX |wxSUNKEN_BORDER |wxTR_DEFAULT_STYLE);
+    pos, siz/*, wxTR_CHECKBOX |wxSUNKEN_BORDER |wxTR_DEFAULT_STYLE*/);
     m_ShareSelector = newtree;
     Localize();
 }
@@ -82,15 +111,50 @@ CPPgDirectories::~CPPgDirectories()
 }
 
 BEGIN_EVENT_TABLE(CPPgDirectories, wxPanel)
-    EVT_BUTTON(XRCID("IDC_SELTEMPDIR"), CPPgDirectories::OnBnClickedSeltempdir)
-    EVT_BUTTON(XRCID("IDC_SELINCDIR"), CPPgDirectories::OnBnClickedSelincdir)
-    EVT_BUTTON(XRCID("IDC_BROWSEV"), CPPgDirectories::BrowseVideoplayer)
+EVT_BUTTON(XRCID("IDC_SELTEMPDIR"), CPPgDirectories::OnBnClickedSeltempdir)
+EVT_BUTTON(XRCID("IDC_SELINCDIR"), CPPgDirectories::OnBnClickedSelincdir)
+EVT_BUTTON(XRCID("IDC_BROWSEV"), CPPgDirectories::BrowseVideoplayer)
 END_EVENT_TABLE()
 
+#if 0
+void CPPgDirectories::DoDataExchange(CDataExchange *pDX)
+{
+    CPropertyPage::DoDataExchange(pDX);
+    DDX_Control(pDX, IDC_SHARESELECTOR, m_ShareSelector);
+}
+
+BEGIN_MESSAGE_MAP(CPPgDirectories, CPropertyPage)
+ON_BN_CLICKED(IDC_SELTEMPDIR, OnBnClickedSeltempdir)
+ON_BN_CLICKED(IDC_SELINCDIR, OnBnClickedSelincdir)
+ON_EN_CHANGE(IDC_INCFILES, OnSettingsChange)
+ON_EN_CHANGE(IDC_TEMPFILES, OnSettingsChange)
+ON_BN_CLICKED(IDC_CHECK1, OnSettingsChange)
+ON_EN_CHANGE(IDC_VIDEOPLAYER, OnSettingsChange)
+ON_BN_CLICKED(IDC_VIDEOBACKUP, OnSettingsChange)
+ON_BN_CLICKED(IDC_BROWSEV, BrowseVideoplayer)
+END_MESSAGE_MAP()
+
+// CPPgDirectories message handlers
+
+bool CPPgDirectories::OnInitDialog()
+{
+    CPropertyPage::OnInitDialog();
+    m_ShareSelector.Init();
+    ((CEdit *) GetDlgItem(IDC_INCFILES))->SetLimitText(509);
+    ((CEdit *) GetDlgItem(IDC_TEMPFILES))->SetLimitText(509);
+    LoadSettings();
+    Localize();
+    // return TRUE unless you set the focus to a control:
+    return TRUE;
+    // EXCEPTION: OCX Property Pages should return FALSE
+}
+
+#endif
+
 void CPPgDirectories::LoadSettings(void)
 {
-    GetDlgItem(IDC_INCFILES, wxTextCtrl)->SetValue(app_prefs->prefs->incomingdir);
-    GetDlgItem(IDC_TEMPFILES, wxTextCtrl)->SetValue(app_prefs->prefs->tempdir);
+    GetDlgItem(IDC_INCFILES, wxTextCtrl)->SetValue(theApp.dynprefs->Get<wxString>("incoming-directory"));
+    GetDlgItem(IDC_TEMPFILES, wxTextCtrl)->SetValue(theApp.dynprefs->Get<wxString>("temp-directory"));
     m_ShareSelector->SetSharedDirectories( &app_prefs->shareddir_list);
     GetDlgItem(IDC_VIDEOPLAYER, wxTextCtrl)->SetValue(app_prefs->prefs->VideoPlayer);
     if (app_prefs->prefs->moviePreviewBackup)
@@ -111,6 +175,23 @@ bool CPPgDirectories::SelectDir(char *outdir, char *titletext)
     }
     strcpy(outdir, str.GetData());
     return TRUE;
+#if 0
+    CoInitialize(0);
+    bool done;
+    char *buffer = new char[MAX_PATH];
+    BROWSEINFO bi =
+    {
+        GetSafeHwnd(), 0, buffer, titletext, BIF_VALIDATE | BIF_NEWDIALOGSTYLE | BIF_RETURNONLYFSDIRS, 0, 0, 0
+        };
+    LPITEMIDLIST pidl = SHBrowseForFolder( &bi);
+    delete[] buffer;
+    done = SHGetPathFromIDList(pidl, outdir);
+    LPMALLOC ppMalloc;
+    if (SHGetMalloc( &ppMalloc) == NOERROR)
+    ppMalloc->Free(pidl);
+    CoUninitialize();
+    return done;
+#endif
 }
 
 void CPPgDirectories::OnBnClickedSelincdir(wxCommandEvent &e)
@@ -124,13 +205,15 @@ void CPPgDirectories::OnBnClickedSeltempdir(wxCommandEvent &e)
 {
     char buffer[MAX_PATH];
     if (SelectDir(buffer, (char *)(GetResString(IDS_SELECT_TEMPDIR) .GetData())))
-    {
-        GetDlgItem(IDC_TEMPFILES, wxTextCtrl)->SetValue(buffer);
-    }
+    GetDlgItem(IDC_TEMPFILES, wxTextCtrl)->SetValue(buffer);
 }
 
 void CPPgDirectories::BrowseVideoplayer(wxCommandEvent &e)
 {
+#if 0
+    CFileDialog dlgFile(TRUE, "*.exe", NULL, OFN_FILEMUSTEXIST | OFN_NOREADONLYRETURN, "Executable (*.exe)|*.exe||");
+    if (dlgFile.DoModal() == IDOK) GetDlgItem(IDC_VIDEOPLAYER)->SetWindowText(dlgFile.GetPathName());
+#endif
     wxString str = wxFileSelector(_("Browse for videoplayer"), "", "", "", _("Executable (*)|*||"));
     if (!str.IsEmpty())
     {
@@ -148,20 +231,20 @@ bool CPPgDirectories::OnApply()
     if (GetDlgItem(IDC_INCFILES, wxTextCtrl)->GetValue() .Length())
     {
         buffer = GetDlgItem(IDC_INCFILES, wxTextCtrl)->GetValue();
-        if (strcmp(app_prefs->prefs->incomingdir, buffer.GetData()) != 0)
+        if (theApp.dynprefs->Get<wxString>("incoming-directory").Cmp(buffer) != 0)
         {
             IncomingChanged = true;
+            theApp.dynprefs->Add("incoming-directory", buffer);
         }
-        strcpy(app_prefs->prefs->incomingdir, buffer.GetData());
     }
     if (GetDlgItem(IDC_TEMPFILES, wxTextCtrl)->GetValue() .Length())
     {
         buffer = GetDlgItem(IDC_TEMPFILES, wxTextCtrl)->GetValue();
-        if (strcmp(app_prefs->prefs->tempdir, buffer.GetData()) != 0)
+        if (theApp.dynprefs->Get<wxString>("temp-directory").Cmp(buffer) != 0)
         {
             TempChanged = true;
+            theApp.dynprefs->Add("temp-directory", buffer);
         }
-        strcpy(app_prefs->prefs->tempdir, buffer.GetData());
     }
     buffer = GetDlgItem(IDC_VIDEOPLAYER, wxTextCtrl)->GetValue();
     strcpy(app_prefs->prefs->VideoPlayer, buffer.GetData());
@@ -174,6 +257,16 @@ bool CPPgDirectories::OnApply()
     return TRUE;
 }
 
+#if 0
+bool CPPgDirectories::OnCommand(WPARAM wParam, LPARAM lParam)
+{
+    //	if(wParam == USRMSG_ITEMSTATECHANGED)
+    //		SetModified();
+    return CPropertyPage::OnCommand(wParam, lParam);
+}
+
+#endif
+
 void CPPgDirectories::Localize(void)
 {
     if (1)
@@ -192,3 +285,4 @@ void CPPgDirectories::Localize(void)
     }
 }
 
+#endif
