@@ -18,26 +18,29 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "otherfunctions.h"
+#	include "PPgNotify.h"
+#include "Preferences.h"                    // CPreferences
+#	include "wintypes.h"
+#	include "xmule.h"
 #endif
 
-#include "PPgNotify.h"                      // Needed for this Interface's Prototype
+#include "wx/xrc/xmlres.h"
+#include "wx/xrc/xh_all.h"
 
-#include "otherfunctions.h"                 // Needed for GetResString
-#include "Preferences.h"                    // Needed for CPreferences
-#include "resource.h"                       // Needed for IDS_PW_TBN_USESOUND
+#include <wx/checkbox.h>
+#include <wx/filedlg.h>
+#include <wx/notebook.h>
+#include <wx/textctrl.h>
 
-#include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
-
-#include <wx/checkbox.h>                    // Needed for wxCheckBox
-#include <wx/filedlg.h>                     // Needed for wxFileSelector
-#include <wx/intl.h>                        // Needed for _
-#include <wx/notebook.h>                    // Needed for wxNotebook
-#include <wx/textctrl.h>                    // Needed for wxTextCtrl
+class CPreferences;
 
 #define GetDlgItem(x,clas) XRCCTRL(*this,#x,clas)
 #define IsDlgButtonChecked(x) XRCCTRL(*this,#x,wxCheckBox)->GetValue()
 
+//IMPLEMENT_DYNAMIC(CPPgNotify, CPropertyPage)
 IMPLEMENT_DYNAMIC_CLASS(CPPgNotify, wxPanel)
 
 CPPgNotify::CPPgNotify(wxWindow *parent)
@@ -57,12 +60,47 @@ CPPgNotify::~CPPgNotify()
 {
 }
 
+#if 0
+void CPPgNotify::DoDataExchange(CDataExchange *pDX)
+{
+    CPropertyPage::DoDataExchange(pDX);
+}
+
+#endif
+
 void CPPgNotify::LoadSettings(void)
 {
+#if 0
+    CEdit *editPtr;
+    CButton *btnPTR;
+    if (m_hWnd)
+    {
+        if (app_prefs->prefs->useDownloadNotifier)
+        CheckDlgButton(IDC_CB_TBN_ONDOWNLOAD, BST_CHECKED);
+        if (app_prefs->prefs->useChatNotifier)
+        CheckDlgButton(IDC_CB_TBN_ONCHAT, BST_CHECKED);
+        if (app_prefs->prefs->useSoundInNotifier)
+        CheckDlgButton(IDC_CB_TBN_USESOUND, BST_CHECKED);
+        if (app_prefs->prefs->useLogNotifier)
+        CheckDlgButton(IDC_CB_TBN_ONLOG, BST_CHECKED);
+        if (app_prefs->prefs->notifierPopsEveryChatMsg)
+        CheckDlgButton(IDC_CB_TBN_POP_ALWAYS, BST_CHECKED);
+        btnPTR = (CButton *) GetDlgItem(IDC_CB_TBN_POP_ALWAYS);
+        btnPTR->EnableWindow(IsDlgButtonChecked(IDC_CB_TBN_ONCHAT));
+        editPtr = (CEdit *) GetDlgItem(IDC_EDIT_TBN_WAVFILE);
+        editPtr->SetWindowText(LPCTSTR(app_prefs->prefs->notifierSoundFilePath));
+    }
+#endif
 }
 
 wxString CPPgNotify::DialogBrowseFile(wxString Filters, wxString DefaultFileName)
 {
+#if 0
+    CFileDialog myFileDialog(true, NULL, LPCTSTR(DefaultFileName),
+    OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT, LPCTSTR(Filters));
+    myFileDialog.DoModal();
+    return myFileDialog.GetPathName();
+#endif
     return "";
 }
 
@@ -70,6 +108,7 @@ void CPPgNotify::Localize(void)
 {
     if (1)
     {
+        //SetWindowText(GetResString(IDS_PW_EKDEV_OPTIONS));
         GetDlgItem(IDC_CB_TBN_USESOUND, wxControl)->SetLabel(GetResString(IDS_PW_TBN_USESOUND));
         GetDlgItem(IDC_BTN_BROWSE_WAV, wxControl)->SetLabel(GetResString(IDS_PW_BROWSE));
         GetDlgItem(IDC_CB_TBN_ONLOG, wxControl)->SetLabel(GetResString(IDS_PW_TBN_ONLOG));
@@ -86,6 +125,30 @@ BEGIN_EVENT_TABLE(CPPgNotify, wxPanel)
 EVT_BUTTON(XRCID("IDC_BTN_BROWSE_WAV"), CPPgNotify::OnBnClickedBtnBrowseWav)
 END_EVENT_TABLE()
 
+#if 0
+BEGIN_MESSAGE_MAP(CPPgNotify, CPropertyPage)
+ON_BN_CLICKED(IDC_CB_TBN_USESOUND, OnBnClickedCbTbnUsesound)
+ON_BN_CLICKED(IDC_CB_TBN_ONLOG, OnBnClickedCbTbnOnlog)
+ON_BN_CLICKED(IDC_CB_TBN_ONCHAT, OnBnClickedCbTbnOnchat)
+ON_BN_CLICKED(IDC_CB_TBN_POP_ALWAYS, OnBnClickedCbTbnPopAlways)
+ON_BN_CLICKED(IDC_CB_TBN_ONDOWNLOAD, OnBnClickedCbTbnOndownload)
+ON_BN_CLICKED(IDC_BTN_BROWSE_WAV, OnBnClickedBtnBrowseWav)
+END_MESSAGE_MAP()
+
+// gestori di messaggi CPPgNotify
+
+bool CPPgNotify::OnInitDialog()
+{
+    CPropertyPage::OnInitDialog();
+    LoadSettings();
+    Localize();
+    // return TRUE unless you set the focus to a control:
+    return TRUE;
+    // EXCEPTION: OCX Property Pages should return FALSE
+}
+
+#endif
+
 bool CPPgNotify::OnApply()
 {
     wxTextCtrl *editPTR;
@@ -98,18 +161,34 @@ bool CPPgNotify::OnApply()
     editPTR = GetDlgItem(IDC_EDIT_TBN_WAVFILE, wxTextCtrl);
     buffer = editPTR->GetValue();
     sprintf(app_prefs->prefs->notifierSoundFilePath, "%s", buffer.GetData());
+    //SaveConfiguration();
+    //SetModified(FALSE);
+    //return CPropertyPage::OnApply();
     return TRUE;
 }
 
+#if 0
+void CPPgNotify::OnBnClickedCbTbnOnchat()
+{
+    CButton *btnPTR;
+    btnPTR = (CButton *) GetDlgItem(IDC_CB_TBN_POP_ALWAYS);
+    btnPTR->EnableWindow(IsDlgButtonChecked(IDC_CB_TBN_ONCHAT));
+    SetModified();
+}
+
+#endif
+
 void CPPgNotify::OnBnClickedBtnBrowseWav(wxCommandEvent &evt)
 {
     wxTextCtrl *editPTR;
     wxString buffer;
+    //DialogBrowseFile("File wav (*.wav)|*.wav||");:
     buffer =
     wxFileSelector(_("Browse wav"), "", "", "*.wav", _("File wav (*.wav)|*.wav||"));
     editPTR = (wxTextCtrl *) GetDlgItem(IDC_EDIT_TBN_WAVFILE, wxTextCtrl);
     editPTR->SetValue((buffer));
     // Added by enkeyDEV:
     sprintf(app_prefs->prefs->notifierSoundFilePath, "%s", buffer.GetData());
+    //SetModified();
 }
 
