@@ -11,61 +11,83 @@
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-#ifdef PRECOMP
-    #include "xmule-headers.h"
-#endif
+#include "config.h"
 
-#include "Preferences.h"                    // Needed for this Interface's Prototype
-
-#include "ini2.h"                           // Needed for CIni
-#include "opcodes.h"                        // Needed for MAXCONPER5SEC
-#include "otherfunctions.h"                 // Needed for md4cpy
-#include "xmule.h"                          // Needed for theApp
-
-#include "DynPrefs/DynPrefs.h"              // Needed for theApp.dynprefs
-
-#ifdef HAVE_CONFIG_H
-    #include "config.h"                     // Needed for PACKAGE_NAME
-#endif
+// Test if we have _GNU_SOURCE before the next step will mess up
+// setting __USE_GNU
+// (only needed for gcc-2.95 compatibility, gcc 3.2 always defines it)
+#include "wx/setup.h"
 
 // Mario Sergio Fujikawa Ferreira <lioux@FreeBSD.org>
 // to detect if this is a *BSD system
 #if defined(HAVE_SYS_PARAM_H)
-    #include <sys/param.h>                  // Needed for *BSD systems, apparently.
+#include <sys/param.h>
 #endif
 
-#include <wx/filename.h>                    // Needed for wxFileName
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "Preferences.h"
+#	include "opcodes.h"
+#	include "otherfunctions.h"
+#	include "ini2.h"
+#	include "stdlib.h"
+#	include "stdio.h"
+#	include "resource.h"
+#include "xmule.h"                          // Needed for theApp - audited 4 Nov 2004
+#endif
+
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
+
+#include <cstdlib>
+#include <ctime>
+#include <fstream>                          // Needed for std::ofstream std::endl
+#include <iomanip>                          // std::hex std::setprecision
+#include <locale.h>
+#include <sstream>                          // Needed for std::stringstream
+#include <string>                           // Needed for std::string
+#include <wx/filename.h>
 
 #define ELEMENT_COUNT(X) (sizeof(X) / sizeof(X[0]))
 #define RGB(a,b,c) ((a&0xff)<<16|(b&0xff)<<8|(c&0xff))
 
+#include <sys/stat.h>
+#include <sys/types.h>
+
 #ifndef MAX_PATH
-    // *BSD compatibility
-    #if (defined(BSD) && (BSD >= 199103))
-        #define MAX_PATH MAXPATHLEN
-    #else
-        #define MAX_PATH 2048
-    #endif
+// *BSD compatibility
+#if (defined(BSD) && (BSD >= 199103))
+#define MAX_PATH MAXPATHLEN
+#else
+#define MAX_PATH 2048
+#endif
 #endif
 
 #ifdef __FreeBSD__
-    extern long long atoll(char *s);
+extern long long atoll(char *s);
 #endif /* __FreeBSD__ */
 
+using std::endl;
+using std::hex;
+using std::ifstream;
+using std::ios;
+using std::ofstream;
+using std::stringstream;
+
 CPreferences::CPreferences()
 {
     // we need random numbers sometimes:
-    srand((uint32) time(0));
+    srand((uint32_t) time(0));
     // Define prefs 
     prefs = new Preferences_Struct;
     memset(prefs, 0, sizeof(Preferences_Struct));
@@ -74,14 +96,12 @@ CPreferences::CPreferences()
     // Use home directory to save preferences
     char buffer[490];
     snprintf(buffer, 400, "%s/." PACKAGE_NAME, getenv("HOME"));
-    if (!wxDirExists(buffer))
-    {
-        wxMkdir(buffer, 0777);
-    }
-    strncat(buffer, "/", 1);
-    SetAppDir(CString(buffer)); 
+    theApp.dynprefs->Add("app-directory", wxString(buffer, *wxConvCurrent) + wxT("/"));
+    mkdir(buffer, 0777);
 
-    md4cpy( &prefs->userhash, &userhash);
+    // Create UserHash
+    CreateUserHash();
+    md4cpy(&prefs->userhash, &userhash);
     if (((int *) prefs->userhash) [0] == 0 && ((int *) prefs->userhash) [1] == 0 && ((int *) prefs->userhash) [2] == 0 && ((int *) prefs->userhash) [3] == 0)
     {
        CreateUserHash();
@@ -199,7 +219,7 @@ void CPreferences::CreateUserHash()
 {
     for (int i = 0 ; i != 8 ; i++)
     {
-        uint16 random = rand();
+        uint16_t random = rand();
         memcpy( &userhash[i*2], &random, 2);
     }
     // mark as emule client. that will be need in later version
@@ -209,31 +229,22 @@ void CPreferences::CreateUserHash()
 
 int CPreferences::GetRecommendedMaxConnections()
 {
-#if defined(__WIN32__)
     int iRealMax =::GetMaxConnections();
-    
-    if (iRealMax == -1 || iRealMax > 520)
-    {
-        return 500;
-    }
-    
-    if (iRealMax < 20)
-    {
-        return iRealMax;
-    }
-
-    if (iRealMax <= 256)
-    {
-        return iRealMax - 10;
-    }
-    
-    return iRealMax - 20;
-#else
+    if (iRealMax == - 1 || iRealMax > 520)
     return 500;
-#endif
+    if (iRealMax < 20)
+    return iRealMax;
+    if (iRealMax <= 256)
+    return iRealMax - 10;
+    return iRealMax - 20;
 }
 
-uint16 CPreferences::GetDefaultMaxConperFive()
+WORD CPreferences::GetWindowsVersion()
+{
+    return 1;
+}
+
+uint16_t CPreferences::GetDefaultMaxConperFive()
 {
     return MAXCONPER5SEC;
 }
@@ -275,74 +286,70 @@ void CPreferences::ResetStatsColor(int index)
 
 void CPreferences::SavePreferences(void)
 {
-    CString buffer;
-    CString buffer2;
-    char *full_path = new char[strlen(getenv("HOME")) + 2];
-    sprintf(full_path, "%s/", getenv("HOME"));
+    wxString buffer;
+    wxString buffer2;
+    wxString full_path(getenv("HOME"), *wxConvCurrent);
+    full_path += "/";
     CIni ini(full_path, "eMule");
-    delete[] full_path;
+
     ini.WriteString("AppVersion", PACKAGE_STRING);
-    buffer.Format("%s", prefs->nick);
-    ini.WriteString("Nick", buffer);
-    buffer.Format("%s", prefs->incomingdir);
-    ini.WriteString("IncomingDir", buffer);
-    buffer.Format("%s", prefs->tempdir);
-    ini.WriteString("TempDir", buffer);
-    ini.WriteInt("MaxUpload", prefs->maxupload);
-    ini.WriteInt("MaxDownload", prefs->maxdownload);
-    ini.WriteInt("MaxConnections", prefs->maxconnections);
-    ini.WriteInt("RemoveDeadServer", prefs->deadserver);
-    ini.WriteInt("Port", prefs->port);
-    ini.WriteInt("UDPPort", prefs->udpport);
-    ini.WriteInt("MaxSourcesPerFile", prefs->maxsourceperfile);
+    ini.WriteString("Nick",                         theApp.dynprefs->Get<wxString>("nickname"));
+    ini.WriteString("IncomingDir",                  theApp.dynprefs->Get<wxString>("incoming-directory"));
+    ini.WriteString("TempDir",                      theApp.dynprefs->Get<wxString>("temp-directory"));
+    ini.WriteInt("MaxUpload",                       theApp.dynprefs->Get<long>( "limits-upload"));
+    ini.WriteInt("MaxDownload",                     theApp.dynprefs->Get<long>("limits-download"));
+    ini.WriteInt("MaxConnections",                  theApp.dynprefs->Get<long>("max-connections"));
+    ini.WriteInt("RemoveDeadServer",                theApp.dynprefs->Get<bool>("remove-dead-server"));
+    ini.WriteInt("Port",                            theApp.dynprefs->Get<long>("tcp-port"));
+    ini.WriteInt("UDPPort",                         theApp.dynprefs->Get<long>("udp-port"));
+    ini.WriteInt("MaxSourcesPerFile",               theApp.dynprefs->Get<long>("max-sources"));
     ini.WriteWORD("Language", prefs->languageID);
-    ini.WriteInt("SeeShare", prefs->m_iSeeShares);
+    ini.WriteInt("SeeShare",                        theApp.dynprefs->Get<long>("see-share"));
     ini.WriteInt("ToolTipDelay", prefs->m_iToolDelayTime);
-    ini.WriteInt("StatGraphsInterval", prefs->trafficOMeterInterval);
-    ini.WriteInt("StatsInterval", prefs->statsInterval);
-    ini.WriteInt("DownloadCapacity", prefs->maxGraphDownloadRate);
-    ini.WriteInt("UploadCapacity", prefs->maxGraphUploadRate);
-    ini.WriteInt("DeadServerRetry", prefs->deadserverretries);
+    ini.WriteInt("StatGraphsInterval",              theApp.dynprefs->Get<long>("graph-delay"));
+    ini.WriteInt("StatsInterval",                   theApp.dynprefs->Get<long>("tree-delay"));
+    ini.WriteInt("DownloadCapacity",                theApp.dynprefs->Get<long>("capacities-download"));
+    ini.WriteInt("UploadCapacity",                  theApp.dynprefs->Get<long>("capacities-upload"));
+    ini.WriteInt("DeadServerRetry",                 theApp.dynprefs->Get<long>("server-connect-tries"));
     ini.WriteInt("SplitterbarPosition", prefs->splitterbarPosition + 2);
-    ini.WriteInt("VariousStatisticsMaxValue", prefs->statsMax);
-    ini.WriteInt("StatsAverageMinutes", prefs->statsAverageMinutes);
-    ini.WriteInt("MaxConnectionsPerFiveSeconds", prefs->MaxConperFive);
+    ini.WriteInt("StatsAverageMinutes",             theApp.dynprefs->Get<long>("graph-average"));
+    ini.WriteInt("MaxConnectionsPerFiveSeconds",    theApp.dynprefs->Get<long>("max-per-5"));
     ini.WriteInt("Check4NewVersionDelay", prefs->versioncheckdays);
-    ini.WriteBool("Reconnect", prefs->reconnect);
-    ini.WriteBool("Scoresystem", prefs->scorsystem);
-    ini.WriteBool("ICH", prefs->ICH);
-    ini.WriteBool("Serverlist", prefs->autoserverlist);
+    ini.WriteBool("Reconnect",                      theApp.dynprefs->Get<bool>("reconnect-on-loss"));
+    ini.WriteBool("Scoresystem",                    theApp.dynprefs->Get<bool>("priority-system"));
+    ini.WriteBool("ICH",                            theApp.dynprefs->Get<bool>("enable-ich"));
+    ini.WriteBool("Serverlist",                     theApp.dynprefs->Get<bool>("autoupdate-server"));
     ini.WriteString("LRUServermetURL", prefs->m_szLRUServermetURL);
     ini.WriteBool("UpdateNotify", prefs->updatenotify);
-    ini.WriteBool("MinToTray", prefs->mintotray);
-    ini.WriteBool("AddServersFromServer", prefs->addserversfromserver);
-    ini.WriteBool("AddServersFromClient", prefs->addserversfromclient);
-    ini.WriteBool("Splashscreen", prefs->splashscreen);
-    ini.WriteBool("BringToFront", prefs->bringtoforeground);
-    ini.WriteBool("TransferDoubleClick", prefs->transferDoubleclick);
-    ini.WriteBool("BeepOnError", prefs->beepOnError);
-    ini.WriteBool("ConfirmExit", prefs->confirmExit);
-    ini.WriteBool("FilterBadIPs", prefs->filterBadIP);
-    ini.WriteBool("Autoconnect", prefs->autoconnect);
-    ini.WriteBool("OnlineSignature", prefs->onlineSig);
-    ini.WriteBool("StartupMinimized", prefs->startMinimized);
-    ini.WriteBool("SafeServerConnect", prefs->safeServerConnect);
-    ini.WriteBool("ShowRatesOnTitle", prefs->showRatesInTitle);
+    ini.WriteBool("MinToTray",                      theApp.dynprefs->Get<bool>("minimize-to-tray"));
+    ini.WriteBool("AddServersFromServer",           theApp.dynprefs->Get<bool>("add-server-server"));
+    ini.WriteBool("AddServersFromClient",           theApp.dynprefs->Get<bool>("add-server-client"));
+    ini.WriteBool("Splashscreen",                   theApp.dynprefs->Get<bool>("show-splashscreen"));
+    ini.WriteBool("BringToFront",                   theApp.dynprefs->Get<bool>("bring-to-front"));
+    ini.WriteBool("TransferDoubleClick",            theApp.dynprefs->Get<bool>("download-doubleclick"));
+    ini.WriteBool("BeepOnError",                    theApp.dynprefs->Get<bool>("beep-on-errors"));
+    ini.WriteBool("ConfirmExit",                    theApp.dynprefs->Get<bool>("prompt-on-exit"));
+    ini.WriteBool("FilterBadIPs",                   theApp.dynprefs->Get<bool>("filter-bad-ip"));
+    ini.WriteBool("Autoconnect",                    theApp.dynprefs->Get<bool>("autoconnect"));
+    ini.WriteBool("OnlineSignature",                theApp.dynprefs->Get<bool>("online-signature"));
+    ini.WriteBool("StartupMinimized",               theApp.dynprefs->Get<bool>("start-minimized"));
+    ini.WriteBool("SafeServerConnect",              theApp.dynprefs->Get<bool>("use-safe-connect"));
+    ini.WriteBool("ShowRatesOnTitle",               theApp.dynprefs->Get<bool>("xfer-on-title"));
     ini.WriteBool("IndicateRatings", prefs->indicateratings);
     ini.WriteBool("WatchClipboard4ED2kFilelinks", prefs->watchclipboard);
-    ini.WriteBool("AutoConnectStaticOnly", prefs->autoconnectstaticonly);
+    ini.WriteBool("AutoConnectStaticOnly",          theApp.dynprefs->Get<bool>("auto-static"));
     ini.WriteBool("AutoTakeED2KLinks", prefs->autotakeed2klinks);
-    ini.WriteBool("AddNewFilesPaused", prefs->addnewfilespaused);
-    ini.WriteInt("3DDepth", prefs->depth3D);
+    ini.WriteBool("AddNewFilesPaused",              theApp.dynprefs->Get<bool>("add-paused"));
+    ini.WriteInt("3DDepth",                         theApp.dynprefs->Get<long>("progress-bar-style"));
     ini.WriteBool("NotifyOnDownload", prefs->useDownloadNotifier);
     ini.WriteBool("NotifyOnChat", prefs->useChatNotifier);
     ini.WriteBool("NotifyOnLog", prefs->useLogNotifier);
     ini.WriteBool("NotifierUseSound", prefs->useSoundInNotifier);
     ini.WriteBool("NotifierPopEveryChatMessage", prefs->notifierPopsEveryChatMsg);
     ini.WriteBool("NotifierPopNewVersion", prefs->notifierNewVersion);
-    buffer.Format("%s", prefs->notifierSoundFilePath);
+    buffer.Printf("%s", prefs->notifierSoundFilePath);
     ini.WriteString("NotifierSoundPath", buffer);
-    buffer.Format("%s", prefs->notifierConfiguration);
+    buffer.Printf("%s", prefs->notifierConfiguration);
     ini.WriteString("NotifierConfiguration", buffer);
     ini.WriteString("TxtEditor", prefs->TxtEditor);
     ini.WriteString("VideoPlayer", prefs->VideoPlayer);
@@ -363,22 +370,20 @@ void CPreferences::SavePreferences(void)
     ini.WriteBool("IRCIgnoreInfoMessage", prefs->m_bircignoreinfomessage);
     ini.WriteBool("IRCIgnoreEmuleProtoInfoMessage", prefs->m_bircignoreemuleprotoinfomessage);
     ini.WriteBool("NotifyOnImportantError", prefs->notifierImportantError);
-    ini.WriteBool("SmartIdCheck", prefs->smartidcheck);
+    ini.WriteBool("SmartIdCheck",                   theApp.dynprefs->Get<bool>("smart-lowid-check"));
     ini.WriteBool("Verbose", prefs->m_bVerbose);
-    ini.WriteBool("PreviewPrio", prefs->m_bpreviewprio);
-    ini.WriteBool("UpdateQueueListPref", prefs->m_bupdatequeuelist);
-    ini.WriteBool("ManualHighPrio", prefs->m_bmanualhighprio);
-    ini.WriteBool("FullChunkTransfers", prefs->m_btransferfullchunks);
-    ini.WriteBool("StartNextFile", prefs->m_bstartnextfile);
-    ini.WriteBool("ShowOverhead", prefs->m_bshowoverhead);
+    ini.WriteBool("PreviewPrio",                    theApp.dynprefs->Get<bool>("last-chunk-first"));
+    ini.WriteBool("UpdateQueueListPref",            theApp.dynprefs->Get<bool>("realtime-queue"));
+    ini.WriteBool("ManualHighPrio",                 theApp.dynprefs->Get<bool>("add-server-high"));
+    ini.WriteBool("FullChunkTransfers",             theApp.dynprefs->Get<bool>("transfer-full-chunks"));
+    ini.WriteBool("StartNextFile",                  theApp.dynprefs->Get<bool>("start-next-file"));
+    ini.WriteBool("ShowOverhead",                   theApp.dynprefs->Get<bool>("show-overhead"));
     ini.WriteBool("VideoPreviewBackupped", prefs->moviePreviewBackup);
-    ini.WriteInt("FileBufferSizePref", prefs->m_iFileBufferSize);
-    ini.WriteInt("QueueSizePref", prefs->m_iQueueSize);
-    ini.WriteBool("DAPPref", prefs->m_bDAP);
-    ini.WriteBool("UAPPref", prefs->m_bUAP);
+    ini.WriteInt("FileBufferSizePref",              theApp.dynprefs->Get<long>("file-buffer-size"));
+    ini.WriteInt("QueueSizePref",                   theApp.dynprefs->Get<long>("upload-queue-size"));
+    ini.WriteBool("UAPPref",                        theApp.dynprefs->Get<bool>("auto-priority-share"));
     ini.WriteInt("AllcatType", prefs->allcatType);
     ini.WriteBool("ShowAllNotCats", prefs->showAllNotCats);
-    ini.WriteBool("FilterServersByIP", prefs->filterserverbyip);
     ini.WriteBool("DisableKnownClientList", prefs->m_bDisableKnownClientList);
     ini.WriteBool("DisableQueueList", prefs->m_bDisableQueueList);
     ini.WriteBool("UseCreditSystem", prefs->m_bCreditSystem);
@@ -436,15 +441,15 @@ void CPreferences::SavePreferences(void)
     ini.WriteInt("ProxyType", prefs->proxy.type, "Proxy");
     for (int i = 0 ; i < 13 ; i++)
     {
-        buffer.Format("%lu", (unsigned long) GetStatsColor(i));
-        buffer2.Format("StatColor%i", i);
+        buffer.Printf("%lu", (unsigned long) GetStatsColor(i));
+        buffer2.Printf("StatColor%i", i);
         ini.WriteString(buffer2, buffer, "eMule");
     }
-    buffer.Format("%llu", (unsigned long long) prefs->totalDownloadedBytes);
+    buffer.Printf("%llu", (unsigned long long) prefs->totalDownloadedBytes);
     ini.WriteString("TotalDownloadedBytes", buffer, "Statistics");
-    buffer.Format("%llu", (unsigned long long) prefs->totalUploadedBytes);
+    buffer.Printf("%llu", (unsigned long long) prefs->totalUploadedBytes);
     ini.WriteString("TotalUploadedBytes", buffer, "Statistics");
-    ini.WriteInt("DesktopMode", prefs->desktopMode);
+    ini.WriteInt("DesktopMode", theApp.dynprefs->Get<long>("systray-integration"));
     ini.WriteString("Password", GetWSPass(), "WebServer");
     ini.WriteString("PasswordLow", GetWSLowPass());
     ini.WriteInt("Port", prefs->m_nWebPort);
@@ -464,78 +469,63 @@ bool CPreferences::LoadPreferences(void)
 {
     bool error = false;
     bool NoColor = true;    
-    CString buffer2;
+    wxString buffer2;
     char buffer[200];
     //Open File for Test
-    char *full_path = new char[strlen(getenv("HOME")) + 2];
-    sprintf(full_path, "%s/", getenv("HOME"));
-    char *test_file = new char[strlen(full_path) + 7];
-    sprintf(test_file, "%s.eMule", full_path); 
-    FILE *testfile = fopen(test_file, "r");
-    delete[] test_file;
-    if (!testfile)
-    {
-         error = true;      
-    }
-    else 
-    {
-         fclose(testfile);  
-    }
+    wxString full_path(getenv("HOME"), *wxConvCurrent);
+
+    full_path += wxT("/.eMule");
+
+    error = wxFileExists(full_path) == false;
     // Use CIni anyway to load or to create the values
     CIni ini(full_path, "eMule");
-    delete[] full_path;
-    sprintf(prefs->nick, "%s", ini.GetString("Nick", "http://xmule.hopto.org/") .GetData());
-    sprintf(buffer, "%sIncoming", appdir);
-    sprintf(prefs->incomingdir, "%s", ini.GetString("IncomingDir", buffer) .GetData());
-    MakeFoldername(prefs->incomingdir);
-    sprintf(buffer, "%sTemp", appdir);
-    sprintf(prefs->tempdir, "%s", ini.GetString("TempDir", buffer) .GetData());
-    MakeFoldername(prefs->tempdir);
-    prefs->maxupload = ini.GetInt("MaxUpload", UNLIMITED);
-    prefs->maxdownload = ini.GetInt("MaxDownload", UNLIMITED);
-    prefs->maxconnections = ini.GetInt("MaxConnections", GetRecommendedMaxConnections());
-    prefs->deadserver = ini.GetInt("RemoveDeadServer", 2);
-    prefs->port = ini.GetInt("Port", 4662);
-    prefs->udpport = ini.GetInt("UDPPort", prefs->port + 10);
-    prefs->maxsourceperfile = ini.GetInt("MaxSourcesPerFile", 400);
+
+    theApp.dynprefs->Add("nickname",               ini.GetString("Nick", "http://www.xmule.ws/"));
+    theApp.dynprefs->Add("incoming-directory",     ini.GetString("IncomingDir", const_cast<char *>(wxString(theApp.dynprefs->Get<wxString>("app-directory") + "Incoming").c_str())));
+    theApp.dynprefs->Add("temp-directory",         ini.GetString("TempDir", const_cast<char *>(wxString(theApp.dynprefs->Get<wxString>("app-directory") + "Temp").c_str())));
+    theApp.dynprefs->Add("limits-upload",          static_cast<long>(ini.GetInt("MaxUpload", UNLIMITED)));
+    theApp.dynprefs->Add("limits-download",        static_cast<long>(ini.GetInt("MaxDownload", UNLIMITED)));
+    theApp.dynprefs->Add("max-connections",        static_cast<long>(ini.GetInt("MaxConnections", 500)));
+    theApp.dynprefs->Add("remove-dead-server",     static_cast<long>(ini.GetInt("RemoveDeadServer", 2)));
+    theApp.dynprefs->Add("tcp-port",               static_cast<long>(ini.GetInt("Port", 4662)));
+    theApp.dynprefs->Add("udp-port",               static_cast<long>(ini.GetInt("UDPPort", theApp.dynprefs->Get<long>("tcp-port") + 10)));
+    theApp.dynprefs->Add("max-sources",            static_cast<long>(ini.GetInt("MaxSourcesPerFile", 400)));
     prefs->languageID = ini.GetWORD("Language", 0);
-    prefs->m_iSeeShares = ini.GetInt("SeeShare", 2);
+    theApp.dynprefs->Add("see-share",              static_cast<long>(ini.GetInt("SeeShare", 2)));
     prefs->m_iToolDelayTime = ini.GetInt("ToolTipDelay", 1);
-    prefs->trafficOMeterInterval = ini.GetInt("StatGraphsInterval", 3);
-    prefs->statsInterval = ini.GetInt("statsInterval", 5);
-    prefs->maxGraphDownloadRate = ini.GetInt("DownloadCapacity", 96);
-    prefs->maxGraphUploadRate = ini.GetInt("UploadCapacity", 16);
-    prefs->deadserverretries = ini.GetInt("DeadServerRetry", 1);
+    theApp.dynprefs->Add("graph-delay",            static_cast<long>(ini.GetInt("StatGraphsInterval", 3)));
+    theApp.dynprefs->Add("tree-delay",             static_cast<long>(ini.GetInt("statsInterval", 5)));
+    theApp.dynprefs->Add("capacities-download",    static_cast<long>(ini.GetInt("DownloadCapacity", 96)));
+    theApp.dynprefs->Add("capacities-upload",      static_cast<long>(ini.GetInt("UploadCapacity", 16)));
+    theApp.dynprefs->Add("server-connect-retries", static_cast<long>(ini.GetInt("DeadServerRetry", 1)));
     prefs->splitterbarPosition = ini.GetInt("SplitterbarPosition", 75);
-    prefs->statsMax = ini.GetInt("VariousStatisticsMaxValue", 100);
-    prefs->statsAverageMinutes = ini.GetInt("StatsAverageMinutes", 5);
-    prefs->MaxConperFive = ini.GetInt("MaxConnectionsPerFiveSeconds", GetDefaultMaxConperFive());
-    prefs->reconnect = ini.GetBool("Reconnect", true);
-    prefs->scorsystem = ini.GetBool("Scoresystem", true);
-    prefs->ICH = ini.GetBool("ICH", true);
-    prefs->autoserverlist = ini.GetBool("Serverlist", false);
+    theApp.dynprefs->Add("graph-average",          static_cast<long>(ini.GetInt("StatsAverageMinutes", 5)));
+    theApp.dynprefs->Add("max-per-5",              static_cast<long>(ini.GetInt("MaxConnectionsPerFiveSeconds", GetDefaultMaxConperFive())));
+    theApp.dynprefs->Add("reconnect-on-loss",      ini.GetBool("Reconnect", true));
+    theApp.dynprefs->Add("priority-system",        ini.GetBool("Scoresystem", true));
+    theApp.dynprefs->Add("enable-ich",             ini.GetBool("ICH", true));
+    theApp.dynprefs->Add("autoupdate-server",      ini.GetBool("Serverlist", false));    
     snprintf(prefs->m_szLRUServermetURL, sizeof prefs->m_szLRUServermetURL, "%s", ini.GetString("LRUServermetURL") .GetData());
     prefs->updatenotify = ini.GetBool("UpdateNotify", false);
-    prefs->mintotray = ini.GetBool("MinToTray", false);
-    prefs->addserversfromserver = ini.GetBool("AddServersFromServer", true);
-    prefs->addserversfromclient = ini.GetBool("AddServersFromClient", true);
-    prefs->splashscreen = ini.GetBool("Splashscreen", true);
-    prefs->bringtoforeground = ini.GetBool("BringToFront", true);
-    prefs->transferDoubleclick = ini.GetBool("TransferDoubleClick", true);
-    prefs->beepOnError = ini.GetBool("BeepOnError", true);
-    prefs->confirmExit = ini.GetBool("ConfirmExit", false);
-    prefs->filterBadIP = ini.GetBool("FilterBadIPs", true);
-    prefs->autoconnect = ini.GetBool("Autoconnect", false);
-    prefs->showRatesInTitle = ini.GetBool("ShowRatesOnTitle", false);
-    prefs->onlineSig = ini.GetBool("OnlineSignature", false);
-    prefs->startMinimized = ini.GetBool("StartupMinimized", false);
-    prefs->safeServerConnect = ini.GetBool("SafeServerConnect", false);
-    prefs->filterserverbyip = ini.GetBool("FilterServersByIP", false);
+    theApp.dynprefs->Add("minimize-to-tray",       ini.GetBool("MinToTray", false));
+    theApp.dynprefs->Add("add-server-server",      ini.GetBool("AddServersFromServer", true));
+    theApp.dynprefs->Add("add-server-client",      ini.GetBool("AddServersFromClient", true));
+    theApp.dynprefs->Add("show-splashscreen",      ini.GetBool("Splashscreen", true));
+    theApp.dynprefs->Add("bring-to-front",         ini.GetBool("BringToFront", true));
+    theApp.dynprefs->Add("download-doubleclick",   ini.GetBool("TransferDoubleClick", true));
+    theApp.dynprefs->Add("beep-on-errors",         ini.GetBool("BeepOnError", true));
+    theApp.dynprefs->Add("prompt-on-exit",         ini.GetBool("ConfirmExit", false));
+    theApp.dynprefs->Add("filter-bad-ip",          ini.GetBool("FilterBadIPs", true));
+    theApp.dynprefs->Add("autoconnect",            ini.GetBool("Autoconnect", false));
+    theApp.dynprefs->Add("xfer-on-title",          ini.GetBool("ShowRatesOnTitle", false));
+    theApp.dynprefs->Add("online-signature",       ini.GetBool("OnlineSignature", false));
+    theApp.dynprefs->Add("start-minimized",        ini.GetBool("StartupMinimized", false));
+    theApp.dynprefs->Add("use-safe-connect",       ini.GetBool("SafeServerConnect", false));
     prefs->filterlevel = ini.GetInt("FilterLevel", 127);
-    prefs->autoconnectstaticonly = ini.GetBool("AutoConnectStaticOnly", false);
+    theApp.dynprefs->Add("auto-static",            ini.GetBool("AutoConnectStaticOnly", false));
     prefs->autotakeed2klinks = ini.GetBool("AutoTakeED2KLinks", true);
-    prefs->addnewfilespaused = ini.GetBool("AddNewFilesPaused", false);
-    prefs->depth3D = ini.GetInt("3DDepth", 0);
+    theApp.dynprefs->Add("add-paused",             ini.GetBool("AddNewFilesPaused", false));
+    theApp.dynprefs->Add("progress-bar-style",     static_cast<long>(ini.GetInt("3DDepth", 0)));
     prefs->useDownloadNotifier = ini.GetBool("NotifyOnDownload", false);
     prefs->useChatNotifier = ini.GetBool("NotifyOnChat", false);
     prefs->useLogNotifier = ini.GetBool("NotifyOnLog", false);
@@ -558,20 +548,19 @@ bool CPreferences::LoadPreferences(void)
     prefs->m_bircacceptlinks = ini.GetBool("IRCAcceptLinks", false);
     prefs->m_bircignoreinfomessage = ini.GetBool("IRCIgnoreInfoMessage", false);
     prefs->m_bircignoreemuleprotoinfomessage = ini.GetBool("IRCIgnoreEmuleProtoInfoMessage", true);
-    prefs->smartidcheck = ini.GetBool("SmartIdCheck", true);
+    theApp.dynprefs->Add("smart-lowid-check",      ini.GetBool("SmartIdCheck", true));
     prefs->m_bVerbose = ini.GetBool("Verbose", false);
-    prefs->m_bpreviewprio = ini.GetBool("PreviewPrio", false);
-    prefs->m_bupdatequeuelist = ini.GetBool("UpdateQueueListPref", false);
-    prefs->m_bmanualhighprio = ini.GetBool("ManualHighPrio", false);
-    prefs->m_btransferfullchunks = ini.GetBool("FullChunkTransfers", true);
-    prefs->m_bstartnextfile = ini.GetBool("StartNextFile", false);
-    prefs->m_bshowoverhead = ini.GetBool("ShowOverhead", false);
+    theApp.dynprefs->Add("last-chunk-first",       ini.GetBool("PreviewPrio", false));
+    theApp.dynprefs->Add("realtime-queue",         ini.GetBool("UpdateQueueListPref", false));
+    theApp.dynprefs->Add("add-server-high",        ini.GetBool("ManualHighPrio", false));
+    theApp.dynprefs->Add("transfer-full-chunks",   ini.GetBool("FullChunkTransfers", true));
+    theApp.dynprefs->Add("start-next-file",        ini.GetBool("StartNextFile", false));
+    theApp.dynprefs->Add("show-overhead",          ini.GetBool("ShowOverhead", false));
     prefs->moviePreviewBackup = ini.GetBool("VideoPreviewBackupped", true);
-    prefs->m_iFileBufferSize = ini.GetInt("FileBufferSizePref", 16);
-    prefs->m_iQueueSize = ini.GetInt("QueueSizePref", 50);
+    theApp.dynprefs->Add("file-buffer-size",       static_cast<long>(ini.GetInt("FileBufferSizePref", 16)));
+    theApp.dynprefs->Add("upload-queue-size",      static_cast<long>(ini.GetInt("QueueSizePref", 50)));
     prefs->versioncheckdays = ini.GetInt("Check4NewVersionDelay", 5);
-    prefs->m_bDAP = ini.GetBool("DAPPref", true);
-    prefs->m_bUAP = ini.GetBool("UAPPref", true);
+    theApp.dynprefs->Add("auto-priority-share",    ini.GetBool("UAPPref", true));
     prefs->indicateratings = ini.GetBool("IndicateRatings", true);
     prefs->allcatType = ini.GetInt("AllcatType", 0);
     prefs->showAllNotCats = ini.GetBool("ShowAllNotCats", false);
@@ -636,14 +625,14 @@ bool CPreferences::LoadPreferences(void)
     sprintf(prefs->proxy.name, "%s", ini.GetString("ProxyName", buffer, "Proxy") .GetData());
     sprintf(prefs->proxy.password, "%s", ini.GetString("ProxyPassword", buffer, "Proxy") .GetData());
     sprintf(prefs->proxy.user, "%s", ini.GetString("ProxyUser", buffer, "Proxy") .GetData());
-    prefs->proxy.port = ini.GetInt("ProxyPort", 1080, "Proxy");
-    prefs->proxy.type = ini.GetInt("ProxyType", 0, "Proxy");
+    
     for (int i = 0 ; i < 13 ; i++)
     {
-         buffer2.Format("StatColor%i", i);
+         buffer2.Printf("StatColor%i", i);
          sprintf(buffer, "%s", ini.GetString(buffer2, "0", "eMule") .c_str());
          if ((prefs->statcolors[i] = atoll(buffer))) NoColor = false;
     }
+    
     if (NoColor)
     {
          for (int i = 0 ; i < 13 ; i++)
@@ -651,11 +640,12 @@ bool CPreferences::LoadPreferences(void)
               ResetStatsColor(i);
          }
     }
+    
     sprintf(buffer, "%s", ini.GetString("TotalDownloadedBytes", 0, "Statistics") .c_str());
     prefs->totalDownloadedBytes = atoll(buffer);
     sprintf(buffer, "%s", ini.GetString("TotalUploadedBytes", 0, "Statistics") .c_str());
     prefs->totalUploadedBytes = atoll(buffer);
-    prefs->desktopMode = ini.GetInt("DesktopMode", 0);
+    theApp.dynprefs->Add("systray-integration", static_cast<long>(ini.GetInt("DesktopMode", 0)));
     sprintf(prefs->m_sWebPassword, "%s", ini.GetString("Password", "", "WebServer") .GetData());
     sprintf(prefs->m_sWebLowPassword, "%s", ini.GetString("PasswordLow", "") .GetData());
     prefs->m_nWebPort = ini.GetInt("Port", 4711);
@@ -670,7 +660,7 @@ bool CPreferences::LoadPreferences(void)
     prefs->DropHighQueueRankingSources = ini.GetBool("HighQueueRankingSources", false);
     prefs->HighQueueRanking = ini.GetInt("HighQueueRanking", 1200);
     prefs->AutoDropTimer = ini.GetInt("AutoDropTimer", 240);
-    if (prefs->statsAverageMinutes < 1) prefs->statsAverageMinutes = 5;
+
     return error;
 }
 
@@ -678,28 +668,39 @@ bool CPreferences::Load_Adresses(void)
 {
     //serverlist adresses
     bool error = false;
-    char *full_path = new char[strlen(GetAppDir()) + 13];
-    sprintf(full_path, "%sadresses.dat", GetAppDir());
+    char *full_path = new char[theApp.dynprefs->Get<wxString>("app-directory").length() + 13];
+    sprintf(full_path, "%sadresses.dat", static_cast<const char *>(theApp.dynprefs->Get<wxString>("app-directory").c_str()));
     FILE *sdirfile = fopen(full_path, "r");
     delete[] full_path;
+
     if (sdirfile)
     {
         char buffer[MAX_PATH];
+
         while (!feof(sdirfile))
         {
             memset(buffer, 0, sizeof(buffer));
             fgets(buffer, sizeof(buffer) - 1, sdirfile);
             char *ptr = strchr(buffer, '\n');
-            if (ptr) *ptr = 0;
+
+            if (ptr)
+            {
+                *ptr = 0;
+            }
+
             if (strlen(buffer) > 1)
-            adresses_list.Append(new CString(buffer));
+            {
+                addresses_list.push_back(wxString(buffer, *wxConvCurrent));
+            }
         }
+
         fclose(sdirfile);
     }
     else
     {
         error = true;
     }
+
     return error;
 }
 
@@ -713,8 +714,8 @@ bool CPreferences::Save_Adresses(void)
 bool CPreferences::Load_Shared_Dirs(void)
 {
     bool error;
-    char *full_path = new char[strlen(GetAppDir()) + 14];
-    sprintf(full_path, "%sshareddir.dat", GetAppDir());
+    char *full_path = new char[theApp.dynprefs->Get<wxString>("app-directory").length() + 14];
+    sprintf(full_path, "%sshareddir.dat", static_cast<const char *>(theApp.dynprefs->Get<wxString>("app-directory").c_str()));
     FILE *sdirfile = fopen(full_path, "r");
     delete[] full_path;
     if (sdirfile)
@@ -741,8 +742,8 @@ bool CPreferences::Load_Shared_Dirs(void)
 bool CPreferences::Save_Shared_Dirs(void)
 {
     bool error = false;
-    char *full_path = new char[strlen(GetAppDir()) + 14];
-    sprintf(full_path, "%sshareddir.dat", GetAppDir());
+    char *full_path = new char[theApp.dynprefs->Get<wxString>("app-directory").length() + 14];
+    sprintf(full_path, "%sshareddir.dat", static_cast<const char *>(theApp.dynprefs->Get<wxString>("app-directory").c_str()));
     FILE *sdirfile = fopen(full_path, "w");
     delete[] full_path;
     if (sdirfile)
@@ -764,93 +765,111 @@ bool CPreferences::Save_Shared_Dirs(void)
 bool CPreferences::SaveCats(void)
 {
     bool error = false;
-    FILE *category_fd;    
-    wxString catinif, buffer;
-    catinif.Printf("%sCategory.dat", GetAppDir());
+    ofstream fout;
+    wxString buffer;
+    wxString catinif(theApp.dynprefs->Get<wxString>("app-directory") + wxT("Category.dat"));
+
     if (GetCatCount() > 0)
     {
-         category_fd = fopen(catinif, "w");
-	 if (category_fd != NULL)
-	 {
-	     fprintf(category_fd, "%d ", catMap.GetCount() - 1);
-             for (int ix = 1 ; ix < catMap.GetCount() ; ix++)
-             { 
-  	          fprintf(category_fd,"%s\n",catMap.GetAt(ix)->title);              
-                  fprintf(category_fd,"%s\n",catMap.GetAt(ix)->incomingpath);
-                  fprintf(category_fd,"%s\n",catMap.GetAt(ix)->comment);
-                  fprintf(category_fd,"0x%lx\n", catMap.GetAt(ix)->color);
-                  fprintf(category_fd,"%.3u\n", catMap.GetAt(ix)->prio + 1);
-	     }
-             fclose(category_fd);
-         } 
-         else
-	 {
-	     error = true;
-         }
+        fout.open(catinif.c_str());
+
+        if (fout.good() == true)
+        {
+            fout << catMap.GetCount() - 1 << " ";
+
+            for (int ix = 1; ix < catMap.GetCount(); ++ix)
+            { 
+                fout << catMap.GetAt(ix)->title << endl;
+                fout << catMap.GetAt(ix)->incomingpath << endl;
+
+                if (catMap.GetAt(ix)->comment != "")
+                {
+                    fout << catMap.GetAt(ix)->comment << endl;
+                }
+                else
+                {
+                    fout << "-1" << endl;
+                }
+
+                fout << "0x" << std::hex << catMap.GetAt(ix)->color << endl;
+                fout << std::setprecision(3) << std::fixed << catMap.GetAt(ix)->prio + 1 << endl;
+            }
+
+            fout.close();
+        } 
+        else
+        {
+            error = true;
+        }
     }
     return error;
 }
-
+#include <iostream>
+using std::cout;
 bool CPreferences::LoadCats(void)
 {
     bool error = false;
     int max;
-    wxString catinif;
     char buffer[2051];
     char *dummy;
-    FILE *category_fd; 
+
     // default cat
-    Category_Struct *newcat = new Category_Struct;
-    sprintf(newcat->title, "");
-    sprintf(newcat->incomingpath, "");
-    sprintf(newcat->comment, "");
+    Category_Struct* newcat = new Category_Struct;
     newcat->prio = 0;
     newcat->color = 0;
     AddCat(newcat);
     // Load cats
-    catinif.Printf("%sCategory.dat", GetAppDir());
-    category_fd = fopen(catinif, "r");
-    if (category_fd != NULL)
+    wxString catinif(theApp.dynprefs->Get<wxString>("app-directory") + wxT("Category.dat"));
+
+    ifstream fin(catinif.c_str());
+    
+    if (fin.good() == true)
     {
-        fscanf(category_fd, "%d ", &max);
-       for (int i = 1 ; i <= max ; i++)
-       {
-            Category_Struct *newcat = new Category_Struct;
-            fgets(buffer, 66, category_fd);
-            sprintf(newcat->title, "");
-            strncat(newcat->title, buffer, strlen(buffer) - 1);          
-            fgets(buffer, 2050, category_fd);                                  
-            sprintf(newcat->incomingpath, "");
-            strncat(newcat->incomingpath, buffer, strlen(buffer) - 1);
-            fgets(buffer, 258, category_fd);
-            sprintf(newcat->comment, "");
-            strncat(newcat->comment, buffer, strlen(buffer) - 1);
-            fgets(buffer, 15, category_fd);
-            newcat->color = (uint32)strtoul(buffer, &dummy, 0);
-            fgets(buffer, 5, category_fd);
-            newcat->prio = (uint8) atoi(buffer) - 1;
+        fin >> max;
+
+        std::string temp;
+
+        for (int i = 1; i <= max; ++i)
+        {
+            Category_Struct* newcat = new Category_Struct;
+
+            fin >> temp;
+            newcat->title = wxString(temp.c_str(), *wxConvCurrent);
+
+            fin >> temp;
+            newcat->incomingpath = wxString(temp.c_str(), *wxConvCurrent);
+
+            fin >> temp;
+
+            if (temp == "-1")
+            {
+                newcat->comment = "";
+            }
+            else
+            {
+                newcat->comment = wxString(temp.c_str(), *wxConvCurrent);
+            }
+
+            fin >> std::hex >> newcat->color;
+            fin >> std::dec >> newcat->prio;
+
             AddCat(newcat);
 
             if (!wxFileName::DirExists(newcat->incomingpath)) 
             {
                 wxMkdir(newcat->incomingpath, 0777);
             }
-       }
-           fclose(category_fd);
+        }
+
+        fin.close();
     } 
     else
     {
-        error = true;
+       error = true;
     }
     return error;
 }
 
-bool CPreferences::IsSecureIdentEnabled()
-{
-    if (theApp.dynprefs->Get<bool>("secure-ident")) return true;
-    else return false;
-}
-
 void CPreferences::RemoveCat(int index)
 {
     if (index >= 0 &&index < catMap.GetCount())
@@ -1015,6 +1034,56 @@ void CPreferences::SetColumnWidth(const short int t, int index, int width)
     }
 }
 
+bool CPreferences::GetColumnHidden(Table t, int index) const
+{
+    switch (t)
+    {
+    case tableDownload:
+        return prefs->downloadColumnHidden[index];
+    case tableUpload:
+        return prefs->uploadColumnHidden[index];
+    case tableQueue:
+        return prefs->queueColumnHidden[index];
+    case tableSearch:
+        return prefs->searchColumnHidden[index];
+    case tableShared:
+        return prefs->sharedColumnHidden[index];
+    case tableServer:
+        return prefs->serverColumnHidden[index];
+    case tableClientList:
+        return prefs->clientListColumnHidden[index];
+    }
+    return FALSE;
+}
+
+void CPreferences::SetColumnHidden(Table t, int index, bool bHidden)
+{
+    switch (t)
+    {
+    case tableDownload:
+        prefs->downloadColumnHidden[index] = bHidden;
+        break;
+    case tableUpload:
+        prefs->uploadColumnHidden[index] = bHidden;
+        break;
+    case tableQueue:
+        prefs->queueColumnHidden[index] = bHidden;
+        break;
+    case tableSearch:
+        prefs->searchColumnHidden[index] = bHidden;
+        break;
+    case tableShared:
+        prefs->sharedColumnHidden[index] = bHidden;
+        break;
+    case tableServer:
+        prefs->serverColumnHidden[index] = bHidden;
+        break;
+    case tableClientList:
+        prefs->clientListColumnHidden[index] = bHidden;
+        break;
+    }
+}
+
 int CPreferences::GetColumnOrder(const short int t, int index) const
 {
     switch (t)
@@ -1064,3 +1133,16 @@ void CPreferences::SetColumnOrder(const short int t, INT *piOrder)
         break;
     }
 }
+
+//bool CPreferences::IsSecureIdentEnabled()
+//{
+//    if (theApp.dynprefs->Get<bool>("secure-ident"))
+//    {
+//        return true;
+//    }
+//    else
+//    {
+//        return false;
+//
+//    }
+//}
