@@ -17,25 +17,16 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-// PreferencesDlg.cpp : implementation file
-
 #ifdef PRECOMP
     #include "xmule-headers.h"
 #endif
 
 #include "PreferencesDlg.h"                 // Needed for this Interface's Prototype
 
-#include "PPgGeneral.h"                     // Needed for CPPgGeneral
-#include "PPgConnection.h"                  // Needed for CPPgConnection
-#include "PPgServer.h"                      // Needed for CPPgServer
 #include "PPgDirectories.h"                 // Needed for CPPgDirectories
-#include "PPgFiles.h"                       // Needed for CPPgFiles
-#include "PPgStats.h"                       // Needed for CPPgStats
 #include "PPgNotify.h"                      // Needed for CPPgNotify
-#include "PPgTweaks.h"                      // Needed for CPPgTweaks
 #include "PPgSourcesDropping.h"             // Needed for CPPgSourcesDropping
-#include "Preferences.h"                    // Needed for CPreferences
-#include "Wizard.h"                         // Needed for Wizard
+#include "Preferences.h"                    // CPreferences
 #include "xmule.h"                          // Needed for theApp
 
 #include <wx/button.h>                      // Needed for wxButton;
@@ -45,31 +36,30 @@
 IMPLEMENT_DYNAMIC_CLASS(CPreferencesDlg, wxDialog)
 
 BEGIN_EVENT_TABLE(CPreferencesDlg, wxDialog)
-EVT_BUTTON(wxOK, CPreferencesDlg::OnBtnOk)
-EVT_BUTTON(wxCANCEL, CPreferencesDlg::OnBtnCancel)
+    EVT_BUTTON(wxOK, CPreferencesDlg::OnBtnOk)
+    EVT_BUTTON(wxCANCEL, CPreferencesDlg::OnBtnCancel)
 END_EVENT_TABLE()
 
-CPreferencesDlg::CPreferencesDlg(wxWindow *parent, CPreferences *prefs)
+CPreferencesDlg::CPreferencesDlg(wxWindow *parent, CPreferences* prefs)
 : wxDialog(parent, 9999, _("Preferences"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE |wxSYSTEM_MENU)
+{
+    OnInit(prefs);
+}
+
+void CPreferencesDlg::OnInit(CPreferences* prefs)
 {
     //SetFont(wxFont(8,wxSWISS,wxNORMAL,wxNORMAL));
     // here comes brave new resource system
     wxNotebook *book = new wxNotebook(this, 7773, wxPoint(0, 0), wxSize(200, 200));
     wxPanel *page1;
     // load pages
-    m_wndGeneral = new CPPgGeneral(book);
-    m_wndConnection = new CPPgConnection(book);
-    m_wndServer = new CPPgServer(book);
-    m_wndFiles = new CPPgFiles(book);
     m_wndDirectories = new CPPgDirectories(book);
-    m_wndStats = new CPPgStats(book);
     m_wndNotify = new CPPgNotify(book);
-    m_wndTweaks = new CPPgTweaks(book);
     // Creating Sources Dropping window:
     m_wndSourcesDropping = new CPPgSourcesDropping(book);
     // Creating GUI Tweaks window:
     wxSize pageSize(520, 460);
-    pageSize = m_wndGeneral->GetSize();
+    pageSize = m_wndNotify->GetSize();
     SetSize(pageSize.GetWidth(), pageSize.GetHeight() + 40);
     book->SetSize(pageSize);
     // then the ok/cancel buttons please
@@ -93,14 +83,8 @@ CPreferencesDlg::~CPreferencesDlg()
 int CPreferencesDlg::ShowModal()
 {
     // setup pages
-    m_wndGeneral->LoadSettings();
-    m_wndFiles->LoadSettings();
-    m_wndServer->LoadSettings();
-    m_wndConnection->LoadSettings();
     m_wndDirectories->LoadSettings();
-    m_wndStats->LoadSettings();
     m_wndNotify->LoadSettings();
-    m_wndTweaks->LoadSettings();
     // Load settings in Dropping Sources window:
     m_wndSourcesDropping->LoadSettings();
     // and then do the show
@@ -109,31 +93,19 @@ int CPreferencesDlg::ShowModal()
 
 void CPreferencesDlg::OnBtnWizard(wxCommandEvent&evt)
 {
-    Wizard *test = new Wizard(this);
-    //app_prefs);:
-    test->SetPrefs(theApp.glob_prefs);
-    test->OnInitDialog();
-    test->ShowModal();
-    delete test;
 }
 
 void CPreferencesDlg::OnBtnOk(wxCommandEvent&evt)
 {
     // apply all pages
-    m_wndGeneral->OnApply();
-    m_wndConnection->OnApply();
-    m_wndServer->OnApply();
-    m_wndFiles->OnApply();
     m_wndDirectories->OnApply();
-    m_wndStats->OnApply();
     m_wndNotify->OnApply();
-    m_wndTweaks->OnApply();
     // OnApply in Sources Dropping:
     m_wndSourcesDropping->OnApply();
     // Save Preferences & Shared Directories
     app_prefs->Save(5);
 
-    theApp.LoadCompatiblePrefs();
+//    theApp.LoadCompatiblePrefs();
 
     EndModal(0);
 }
@@ -146,13 +118,7 @@ void CPreferencesDlg::OnBtnCancel(wxCommandEvent&evt)
 void CPreferencesDlg::SetPrefs(CPreferences* in_prefs)
 {
     app_prefs = in_prefs;
-    m_wndGeneral->SetPrefs(in_prefs);
-    m_wndConnection->SetPrefs(in_prefs);
-    m_wndServer->SetPrefs(in_prefs);
     m_wndDirectories->SetPrefs(in_prefs);
-    m_wndFiles->SetPrefs(in_prefs);
-    m_wndStats->SetPrefs(in_prefs);
     m_wndNotify->SetPrefs(in_prefs);
-    m_wndTweaks->SetPrefs(in_prefs);
     m_wndSourcesDropping->SetPrefs(in_prefs);  // Setting preferences to Sources Dropping
 }
