@@ -29,13 +29,11 @@ class CPPgDirectories;
 class CPPgFiles;
 class CPPgStats;
 class CPPgNotify;
-class CPPgTweaks;
 class CPPgSourcesDropping;
 class CPreferences;
 
 class CPreferencesDlg : public wxDialog
 {
-    friend class Wizard;
     DECLARE_DYNAMIC_CLASS(CPreferencesDlg)
 
 public:
@@ -50,16 +48,11 @@ protected:
 private:
     DECLARE_EVENT_TABLE()
 
-    CPPgGeneral* m_wndGeneral;
-    CPPgConnection* m_wndConnection;
-    CPPgServer* m_wndServer;
+    void OnInit(CPreferences *prefs);
     CPPgDirectories* m_wndDirectories;
-    CPPgFiles* m_wndFiles;
-    CPPgStats* m_wndStats;
     CPPgNotify* m_wndNotify;
-    CPPgTweaks* m_wndTweaks;
     CPPgSourcesDropping* m_wndSourcesDropping;
-    CPreferences *app_prefs;
+    CPreferences* app_prefs;
 
     void OnBtnOk(wxCommandEvent& evt);
     void OnBtnCancel(wxCommandEvent& evt);
