@@ -3,43 +3,50 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+// QueueListCtrl.cpp : implementation file
+
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "ChatWnd.h"
+#include "ClientCredits.h"                  // CClientCredits
+#	include "ClientDetailDialog.h"
+#	include "FriendList.h"
+#	include "KnownFile.h"
+#	include "muuli_wdr.h"
+#	include "opcodes.h"
+#	include "otherfunctions.h"
+#include "otherstructs.h"                   // ServerMet_Struct - audited 5 Nov 2004
+#include "PartFile.h"                       // Needed for PR_VERYHIGH - audited 5 Nov 2004
+#include "Preferences.h"                    // CPreferences::List Settings
+#	include "QueueListCtrl.h"
+#	include "SharedFileList.h"
+#	include "TransferWnd.h"
+#include "updownclient.h"                   // Needed for CUpDownClient - audited 5 Nov 2004
+#	include "UploadQueue.h"
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
 #endif
 
-#include "QueueListCtrl.h"                  // Needed for this Interface's Prototype
- 
-#include "ChatWnd.h"                        // Needed for CChatWnd
-#include "ClientCredits.h"                  // Needed for CClientCredits
-#include "ClientDetailDialog.h"             // Needed for CClientDetailDialog
-#include "FriendList.h"                     // Needed for CFriendList
-#include "muuli_wdr.h"                      // Needed for ID_QUEUELIST
-#include "PartFile.h"                       // Needed for PR_VERYHIGH
-#include "Preferences.h"                    // Needed for CPreferences
-#include "SharedFileList.h"                 // Needed for CSharedFileList
-#include "TransferWnd.h"                    // Needed for CTransferWnd
-#include "updownclient.h"                   // Needed for CUpDownClient
-#include "UploadQueue.h"                    // Needed for CUploadQueue
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for CxmuleDlg
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
-#include <wx/dcmemory.h>                    // Needed for wxMemoryDC
 #include <wx/menu.h>                        // Needed for wxMenu
 
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
@@ -50,7 +57,7 @@
 #include "pixmaps/plus.ICO.xpm"
 #include "pixmaps/pluscompa.ICO.xpm"
 #include "pixmaps/Friend.ico.xpm"
-#include "pixmaps/mldonk.xpm"
+#include "pixmaps/mldonk.ico.xpm"
 #include "pixmaps/plusmldonk.ico.xpm"
 #include "pixmaps/eDonkeyHybrid.ico.xpm"
 #include "pixmaps/pluseDonkeyHybrid.ico.xpm"
@@ -60,9 +67,9 @@
 
 //IMPLEMENT_DYNAMIC(CQueueListCtrl, CMuleListCtrl)
 BEGIN_EVENT_TABLE(CQueueListCtrl, CMuleListCtrl)
-EVT_RIGHT_DOWN(CQueueListCtrl::OnNMRclick)
-EVT_LIST_COL_CLICK(ID_QUEUELIST, CQueueListCtrl::OnColumnClick)
-EVT_TIMER(2349, CQueueListCtrl::OnTimer)
+    EVT_RIGHT_DOWN(CQueueListCtrl::OnNMRclick)
+    EVT_LIST_COL_CLICK(ID_QUEUELIST, CQueueListCtrl::OnColumnClick)
+    EVT_TIMER(2349, CQueueListCtrl::OnTimer)
 END_EVENT_TABLE()
 
 CQueueListCtrl::CQueueListCtrl()
@@ -91,7 +98,7 @@ CQueueListCtrl::CQueueListCtrl(wxWindow *&parent, int id, const wxPoint &pos, wx
     imagelist.Add(wxBitmap(plus_ICO));
     imagelist.Add(wxBitmap(pluscompa_ICO));
     imagelist.Add(wxBitmap(Friend_ico));
-    imagelist.Add(wxBitmap(mldonk));
+    imagelist.Add(wxBitmap(mldonk_ico));
     imagelist.Add(wxBitmap(plusmldonk_ico));
     imagelist.Add(wxBitmap(eDonkeyHybrid_ico));
     imagelist.Add(wxBitmap(pluseDonkeyHybrid_ico));
@@ -126,6 +133,42 @@ void CQueueListCtrl::Init()
     InsertColumn(7, GetResString(IDS_ENTERQUEUE), LVCFMT_LEFT, 110);
     InsertColumn(8, GetResString(IDS_BANNED), LVCFMT_LEFT, 60);
     InsertColumn(9, GetResString(IDS_UPSTATUS), LVCFMT_LEFT, 100);
+#if 0
+    // something that can't be done here and now. moved to InitSort()
+    // Barry - Use preferred sort order from preferences
+    int sortItem = theApp.glob_prefs->GetColumnSortItem(CPreferences::tableQueue);
+    bool sortAscending = theApp.glob_prefs->GetColumnSortAscending(CPreferences::tableQueue);
+    SetSortArrow(sortItem, sortAscending);
+    SortItems(SortProc, sortItem + (sortAscending ? 0: 10));
+#endif
+#if 0
+    SetExtendedStyle(LVS_EX_FULLROWSELECT);
+    InsertColumn(0, GetResString(IDS_QL_USERNAME), LVCFMT_LEFT, 150, 0);
+    InsertColumn(1, GetResString(IDS_FILE), LVCFMT_LEFT, 275, 1);
+    InsertColumn(2, GetResString(IDS_FILEPRIO), LVCFMT_LEFT, 110, 2);
+    InsertColumn(3, GetResString(IDS_QL_RATING), LVCFMT_LEFT, 60, 3);
+    InsertColumn(4, GetResString(IDS_SCORE), LVCFMT_LEFT, 60, 4);
+    InsertColumn(5, GetResString(IDS_ASKED), LVCFMT_LEFT, 60, 5);
+    InsertColumn(6, GetResString(IDS_LASTSEEN), LVCFMT_LEFT, 110, 6);
+    InsertColumn(7, GetResString(IDS_ENTERQUEUE), LVCFMT_LEFT, 110, 7);
+    InsertColumn(8, GetResString(IDS_BANNED), LVCFMT_LEFT, 60, 8);
+    imagelist.Create(16, 16, ILC_COLOR32 |ILC_MASK, 0, 10);
+    imagelist.SetBkColor(RGB(255, 255, 255));
+    imagelist.Add(theApp.LoadIcon(IDI_USER0));
+    imagelist.Add(theApp.LoadIcon(IDI_COMPPROT));
+    imagelist.Add(theApp.LoadIcon(IDI_PLUS));
+    imagelist.Add(theApp.LoadIcon(IDI_PLUSCOMPROT));
+    SetImageList( &imagelist, LVSIL_SMALL);
+    m_ClientMenu.CreatePopupMenu();
+    m_ClientMenu.AddMenuTitle(GetResString(IDS_CLIENTS));
+    m_ClientMenu.AppendMenu(MF_STRING, MP_DETAIL, GetResString(IDS_SHOWDETAILS));
+    m_ClientMenu.AppendMenu(MF_STRING, MP_MESSAGE, GetResString(IDS_SEND_MSG));
+    m_ClientMenu.AppendMenu(MF_STRING, MP_UNBAN, GetResString(IDS_UNBAN));
+    m_ClientMenu.AppendMenu(MF_SEPARATOR);
+    m_ClientMenu.AppendMenu(MF_STRING, MP_SWITCHCTRL, GetResString(IDS_VIEWUPLOADS));
+    SetMenu( &m_ClientMenu);
+    LoadSettings(CPreferences::tableQueue);
+#endif
 }
 
 CQueueListCtrl::~CQueueListCtrl()
@@ -168,11 +211,56 @@ void CQueueListCtrl::OnNMRclick(wxMouseEvent &evt)
 
 void CQueueListCtrl::Localize()
 {
+#if 0
+    CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
+    HDITEM hdi;
+    hdi.mask = HDI_TEXT;
+    if (pHeaderCtrl->GetItemCount() != 0)
+    {
+        wxString strRes;
+        strRes = GetResString(IDS_QL_USERNAME);
+        hdi.pszText = strRes.GetBuffer();
+        pHeaderCtrl->SetItem(0, &hdi);
+        strRes.ReleaseBuffer();
+        strRes = GetResString(IDS_FILE);
+        hdi.pszText = strRes.GetBuffer();
+        pHeaderCtrl->SetItem(1, &hdi);
+        strRes.ReleaseBuffer();
+        strRes = GetResString(IDS_FILEPRIO);
+        hdi.pszText = strRes.GetBuffer();
+        pHeaderCtrl->SetItem(2, &hdi);
+        strRes.ReleaseBuffer();
+        strRes = GetResString(IDS_QL_RATING);
+        hdi.pszText = strRes.GetBuffer();
+        pHeaderCtrl->SetItem(3, &hdi);
+        strRes.ReleaseBuffer();
+        strRes = GetResString(IDS_SCORE);
+        hdi.pszText = strRes.GetBuffer();
+        pHeaderCtrl->SetItem(4, &hdi);
+        strRes.ReleaseBuffer();
+        strRes = GetResString(IDS_ASKED);
+        hdi.pszText = strRes.GetBuffer();
+        pHeaderCtrl->SetItem(5, &hdi);
+        strRes.ReleaseBuffer();
+        strRes = GetResString(IDS_LASTSEEN);
+        hdi.pszText = strRes.GetBuffer();
+        pHeaderCtrl->SetItem(6, &hdi);
+        strRes.ReleaseBuffer();
+        strRes = GetResString(IDS_ENTERQUEUE);
+        hdi.pszText = strRes.GetBuffer();
+        pHeaderCtrl->SetItem(7, &hdi);
+        strRes.ReleaseBuffer();
+        strRes = GetResString(IDS_BANNED);
+        hdi.pszText = strRes.GetBuffer();
+        pHeaderCtrl->SetItem(8, &hdi);
+        strRes.ReleaseBuffer();
+    }
+#endif
 }
 
 void CQueueListCtrl::AddClient(CUpDownClient *client)
 {
-    uint32 itemnr = GetItemCount();
+    uint32_t itemnr = GetItemCount();
     itemnr = InsertItem(itemnr, client->GetUserName());
     SetItemData(itemnr, (long) client);
     wxListItem myitem;
@@ -184,14 +272,14 @@ void CQueueListCtrl::AddClient(CUpDownClient *client)
 
 void CQueueListCtrl::RemoveClient(CUpDownClient *client)
 {
-    sint32 itemnr = FindItem( - 1, (long) client);
+    int32_t itemnr = FindItem( - 1, (long) client);
     if (itemnr != ( - 1))
     DeleteItem(itemnr);
 }
 
 void CQueueListCtrl::RefreshClient(CUpDownClient *client)
 {
-    sint16 result = FindItem( - 1, (long) client);
+    int16_t result = FindItem( - 1, (long) client);
     if (result != - 1)
     {
         long first, last;
@@ -289,12 +377,12 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
             {
             case 0:
                 {
-                    uint8 image;
+                    uint8_t image;
                     if (client->IsFriend())
                     image = 4;
                     else if(client->ExtProtocolAvailable())
                     {
-                        if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                        if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                         image = 3;
                         else
                         image = 1;
@@ -303,21 +391,21 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                     {
                         if (client->GetClientSoft() == SO_MLDONKEY || client->GetClientSoft() == SO_NEW_MLDONKEY)
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 6;
                             else
                             image = 5;
                         }
                         else if(client->GetClientSoft() == SO_EDONKEYHYBRID)
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 8;
                             else
                             image = 7;
                         }
                         else
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 2;
                             else
                             image = 0;
@@ -332,7 +420,7 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                                         };
                     //imagelist.Draw(dc,image, point, ILD_NORMAL);
                     imagelist.Draw(image, *dc, cur_rec.left, cur_rec.top + 1, wxIMAGELIST_DRAW_TRANSPARENT);
-                    Sbuffer = client->GetUserName();
+                    Sbuffer.Printf("%s", client->GetUserName());
                     cur_rec.left += 20;
                     dc->DrawText(Sbuffer, cur_rec.left, cur_rec.top + 3);
                     cur_rec.left -= 20;
@@ -340,7 +428,7 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                 }
             case 1:
                 if (file)
-                Sbuffer = file->GetFileName();
+                Sbuffer.Printf("%s", file->GetFileName());
                 else
                 Sbuffer = "?";
                 break;
@@ -350,19 +438,19 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                     switch (file->GetUpPriority())
                     {
                     case PR_VERYHIGH:
-                        Sbuffer = GetResString(IDS_PRIORELEASE);
+                        Sbuffer.Printf("%s", GetResString(IDS_PRIORELEASE) .GetData());
                         break;
                     case PR_HIGH:
-                        Sbuffer = GetResString(IDS_PRIOHIGH);
+                        Sbuffer.Printf("%s", GetResString(IDS_PRIOHIGH) .GetData());
                         break;
                     case PR_LOW:
-                        Sbuffer = GetResString(IDS_PRIOLOW);
+                        Sbuffer.Printf("%s", GetResString(IDS_PRIOLOW) .GetData());
                         break;
                     case PR_VERYLOW:
-                        Sbuffer = GetResString(IDS_PRIOVERYLOW);
+                        Sbuffer.Printf("%s", GetResString(IDS_PRIOVERYLOW) .GetData());
                         break;
                     default:
-                        Sbuffer = GetResString(IDS_PRIONORMAL);
+                        Sbuffer.Printf("%s", GetResString(IDS_PRIONORMAL) .GetData());
                         break;
                     }
                 }
@@ -370,7 +458,7 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                 Sbuffer = "?";
                 break;
             case 3:
-                Sbuffer.Printf("%.1f", (float)client->GetScore(false, false, true));
+                Sbuffer.Printf("%.1f", (float) client->GetScore(false, false, true));
                 break;
             case 4:
                 Sbuffer.Printf("%i", client->GetScore(false));
@@ -379,20 +467,16 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                 Sbuffer.Printf("%i", client->GetAskedCount());
                 break;
             case 6:
-                Sbuffer = CastSecondsToHM((::GetTickCount() - client->GetLastUpRequest()) / 1000);
+                Sbuffer.Printf("%s", CastSecondsToHM((::GetTickCount() - client->GetLastUpRequest()) /1000) .GetData());
                 break;
             case 7:
-                Sbuffer = CastSecondsToHM((::GetTickCount() - client->GetWaitStartTime()) / 1000);
+                Sbuffer.Printf("%s", CastSecondsToHM((::GetTickCount() - client->GetWaitStartTime()) /1000) .GetData());
                 break;
             case 8:
                 if (client->IsBanned())
-                {
-                    Sbuffer = GetResString(IDS_YES);
-                }
+                Sbuffer.Printf("%s", GetResString(IDS_YES) .GetData());
                 else
-                {
-                    Sbuffer = GetResString(IDS_NO);
-                }
+                Sbuffer.Printf("%s", GetResString(IDS_NO) .GetData());
                 break;
             case 9:
                 if (client->GetUpPartCount())
@@ -425,7 +509,26 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
     }
 }
 
-bool CQueueListCtrl::ProcessEvent(wxEvent& evt)
+#if 0
+BEGIN_MESSAGE_MAP(CQueueListCtrl, CMuleListCtrl)
+ON_NOTIFY_REFLECT(NM_RCLICK, OnNMRclick)
+ON_NOTIFY_REFLECT(LVN_COLUMNCLICK, OnColumnClick)
+END_MESSAGE_MAP()
+#endif
+
+#if 0
+// CQueueListCtrl message handlers
+void CQueueListCtrl::OnNMRclick(NMHDR *pNMHDR, LRESULT *pResult)
+{
+    POINT point;
+    ::GetCursorPos( &point);
+    m_ClientMenu.TrackPopupMenu(TPM_LEFTALIGN |TPM_RIGHTBUTTON, point.x, point.y, this);
+    *pResult = 0;
+}
+
+#endif
+
+bool CQueueListCtrl::ProcessEvent(wxEvent &evt)
 {
     if (evt.GetEventType() != wxEVT_COMMAND_MENU_SELECTED)
     return CMuleListCtrl::ProcessEvent(evt);
@@ -511,19 +614,19 @@ int CQueueListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
     switch (lParamSort)
     {
     case 0:
-        return CString(item1->GetUserName()) .CmpNoCase(item2->GetUserName());
+        return wxString(item1->GetUserName()) .CmpNoCase(item2->GetUserName());
     case 100:
-        return CString(item2->GetUserName()) .CmpNoCase(item1->GetUserName());
+        return wxString(item2->GetUserName()) .CmpNoCase(item1->GetUserName());
     case 1:
         if ((file1 != NULL) && (file2 != NULL))
-        return CString(file1->GetFileName()) .CmpNoCase(file2->GetFileName());
+        return wxString(file1->GetFileName()) .CmpNoCase(file2->GetFileName());
         else if(file1 == NULL)
         return 1;
         else
         return 0;
     case 101:
         if ((file1 != NULL) && (file2 != NULL))
-        return CString(file2->GetFileName()) .CmpNoCase(file1->GetFileName());
+        return wxString(file2->GetFileName()) .CmpNoCase(file1->GetFileName());
         else if(file1 == NULL)
         return 1;
         else
@@ -574,9 +677,12 @@ int CQueueListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
 void CQueueListCtrl::OnTimer(wxTimerEvent &evt)
 {
     // Don't do anything if the app is shutting down - can cause unhandled exceptions
-    if (!theApp.xmuledlg->IsRunning() || !theApp.glob_prefs->GetUpdateQueueList())
-    return;
-    CUpDownClient *update = theApp.uploadqueue->GetNextClient(NULL);
+    if (!theApp.xmuledlg->IsRunning() || theApp.dynprefs->Get<bool>("realtime-queue") == false)
+	{
+		return;
+	}
+
+	CUpDownClient *update = theApp.uploadqueue->GetNextClient(NULL);
     while (update)
     {
         theApp.xmuledlg->transferwnd->queuelistctrl->RefreshClient(update);
@@ -589,8 +695,11 @@ void CQueueListCtrl::OnTimer(wxTimerEvent &evt)
 void CQueueListCtrl::QueueUpdateTimer()
 {
     // Don't do anything if the app is shutting down - can cause unhandled exceptions
-    if (!theApp.xmuledlg->IsRunning() || !theApp.glob_prefs->GetUpdateQueueList())
-    return;
+    if (!theApp.xmuledlg->IsRunning() || theApp.dynprefs->Get<bool>("realtime-queue") == false)
+	{
+		return;
+	}
+
     CUpDownClient *update = theApp.uploadqueue->GetNextClient(NULL);
     while (update)
     {
