@@ -3,7 +3,7 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -22,7 +22,10 @@
 #ifndef QUEUELISTCTRL_H
 #define QUEUELISTCTRL_H
 
-#include "MuleListCtrl.h"                   // Needed for CMuleListCtrl
+#include "MuleListCtrl.h"
+
+#include <stdint.h>                         // uint32_t
+#include <sys/timeb.h>
 
 class CUpDownClient;
 
@@ -31,6 +34,8 @@ class CUpDownClient;
 
 class CQueueListCtrl : public CMuleListCtrl
 {
+  //DECLARE_DYNAMIC(CQueueListCtrl)
+
 public:
 	CQueueListCtrl();
 	CQueueListCtrl(wxWindow*& parent,int id,const wxPoint& pos,wxSize siz,int flags);
@@ -45,7 +50,14 @@ public:
 	void	Visable() {/*ShowWindow(SW_SHOW);*/}
 	void	Localize();
 
+	//virtual bool OnCommand(WPARAM wParam,LPARAM lParam );
 protected:
+	/*
+	static int CALLBACK SortProc(LPARAM lParam1, LPARAM lParam2, LPARAM lParamSort);
+	afx_msg	void OnColumnClick( NMHDR* pNMHDR, LRESULT* pResult);
+	afx_msg void OnNMRclick(NMHDR *pNMHDR, LRESULT *pResult);
+	DECLARE_MESSAGE_MAP()
+	*/
 	static int SortProc(long lp1,long lp2,long lpsort);
 	void OnNMRclick(wxMouseEvent& evt);
 	void OnColumnClick(wxListEvent& evt);
@@ -60,11 +72,13 @@ private:
 	// Barry - Refresh the queue every 10 seconds
 	wxTimer  m_hTimer;
  public:
-	static void  QueueUpdateTimer();
+	static void  QueueUpdateTimer(); //HWND hwnd, UINT uiMsg, UINT idEvent, DWORD dwTime);
 	void OnTimer(wxTimerEvent& evt);
 
 	void	ShowSelectedUserDetails();
 	wxBrush* m_hilightBrush,*m_hilightUnfocusBrush;
 };
 
+
+
 #endif
