@@ -3,7 +3,7 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -22,23 +22,20 @@
 #ifndef SAFEFILE_H
 #define SAFEFILE_H
 
-#include "CFile.h"                          // Needed for CFile
-#include "CMemFile.h"                       // Needed for CMemFile
+#include "CFile.h"                          // CFile - audited 5 Nov 2004
+#include "CMemFile.h"                       // CMemFile - audited 5 Nov 2004
 
-class CSafeFile : public CFile
-{
+class CSafeFile : public CFile{
 public:
 	CSafeFile();
-	CSafeFile(LPCSTR lpszFileName, UINT nOpenFlags);
+	CSafeFile::CSafeFile(LPCSTR lpszFileName,UINT nOpenFlags);
 	UINT Read(void* lpBuf,UINT nCount);
 };
 
-class CSafeMemFile : public CMemFile
-{
+class CSafeMemFile : public CMemFile{ // memFile
 public:
 	CSafeMemFile(UINT nGrowBytes = 0);
-	CSafeMemFile(BYTE* lpBuffer,UINT nBufferSize,UINT nGrowBytes = 0);
+	CSafeMemFile::CSafeMemFile(BYTE* lpBuffer,UINT nBufferSize,UINT nGrowBytes = 0);
 	UINT Read(void* lpBuf,UINT nCount);
 };
-
 #endif
