@@ -3,33 +3,37 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "muuli_wdr.h"
+#include "packets.h"                        // Packet
+#	include "SearchDlg.h"
+#	include "SearchList.h"
+#	include "updownclient.h"
+#	include "xmuleDlg.h"
 #endif
 
-#include "SearchList.h"                     // Needed for this Interface's Prototype
+#include "wx/xrc/xmlres.h"
+#include "wx/xrc/xh_all.h"
 
-#include "CFile.h"                          // Needed for CFile
-#include "otherfunctions.h"                 // Needed for md4cpy
-#include "packets.h"                        // Needed for CTag
-
-bool IsValidClientIPPort(uint32 nIP, uint16 nPort)
+bool IsValidClientIPPort(uint32_t nIP, uint16_t nPort)
 {
     // this filters most of the false data:
     return nIP != 0 &&nPort != 0 && ((nIP) != nPort)
@@ -156,7 +160,7 @@ CSearchFile::CSearchFile(char *in_data, wxUint32 nSearchID)
     m_bPreviewPossible = false;
 }
 
-CSearchFile::CSearchFile(CFile *in_data, uint32 nSearchID, uint32 nServerIP, uint16 nServerPort, LPCTSTR pszDirectory)
+CSearchFile::CSearchFile(CFile *in_data, uint32_t nSearchID, uint32_t nServerIP, uint16_t nServerPort, LPCTSTR pszDirectory)
 {
     m_nSearchID = nSearchID;
     in_data->Read( &m_abyFileHash, 16);
@@ -167,7 +171,7 @@ CSearchFile::CSearchFile(CFile *in_data, uint32 nSearchID, uint32 nServerIP, uin
         m_nClientID = 0;
         m_nClientPort = 0;
     }
-    uint32 tagcount;
+    uint32_t tagcount;
     in_data->Read( &tagcount, 4);
     for (unsigned int i = 0 ; i != tagcount ;++i)
     {
@@ -200,7 +204,7 @@ CSearchFile::CSearchFile(CFile *in_data, uint32 nSearchID, uint32 nServerIP, uin
     m_bPreviewPossible = false;
 }
 
-CSearchFile::CSearchFile(uint32 nSearchID, const uchar *pucFileHash, uint32 uFileSize, char *pszFileName, int iFileType, int iAvailability)
+CSearchFile::CSearchFile(uint32_t nSearchID, const unsigned char *pucFileHash, uint32_t uFileSize, char *pszFileName, int iFileType, int iAvailability)
 {
     m_nSearchID = nSearchID;
     md4cpy(m_abyFileHash, pucFileHash);
@@ -223,12 +227,15 @@ CSearchFile::CSearchFile(uint32 nSearchID, const uchar *pucFileHash, uint32 uFil
 CSearchFile::~CSearchFile()
 {
     for (int i = 0 ; i != taglist.GetSize() ; i++)
-    safe_delete(taglist[i]);
+    {
+        delete taglist[i];
+    }
+
     taglist.RemoveAll();
     taglist.SetSize(0);
 }
 
-uint32 CSearchFile::GetIntTagValue(uint8 tagname)
+uint32_t CSearchFile::GetIntTagValue(uint8_t tagname)
 {
     for (int i = 0 ; i != taglist.GetSize() ; i++)
     {
@@ -238,7 +245,7 @@ uint32 CSearchFile::GetIntTagValue(uint8 tagname)
     return 0;
 }
 
-char *CSearchFile::GetStrTagValue(uint8 tagname)
+char *CSearchFile::GetStrTagValue(uint8_t tagname)
 {
     for (int i = 0 ; i != taglist.GetSize() ; i++)
     {
@@ -248,7 +255,7 @@ char *CSearchFile::GetStrTagValue(uint8 tagname)
     return 0;
 }
 
-uint32 CSearchFile::AddSources(uint32 count)
+uint32_t CSearchFile::AddSources(uint32_t count)
 {
     for (int i = 0 ; i != taglist.GetSize() ; i++)
     {
@@ -261,7 +268,7 @@ uint32 CSearchFile::AddSources(uint32 count)
     return 0;
 }
 
-uint32 CSearchFile::GetSourceCount()
+uint32_t CSearchFile::GetSourceCount()
 {
     return GetIntTagValue(FT_SOURCES);
 }
