@@ -25,11 +25,12 @@
 
 #include "opcodes.h"
 #include "xmule.h"
-#include "types.h"
 #include "KnownFile.h"
 #include "otherfunctions.h"
 #include "SafeFile.h"
 
+#include <stdint.h>                         // uint32_t
+
 class CPreferences;
 class Packet;
 
@@ -38,24 +39,24 @@ class CSearchFile : public CAbstractFile {
 public:
 	//CSearchFile() {};
 	CSearchFile(char* data, wxUint32 nSearchID);
-	CSearchFile(CFile* in_data, wxUint32 nSearchID, wxUint32 nServerIP=0, uint16 nServerPort=0, LPCTSTR pszDirectory = NULL);
-	CSearchFile(wxUint32 nSearchID, const uchar* pucFileHash, wxUint32 uFileSize, char *pszFileName, int iFileType, int iAvailability);
+	CSearchFile(CFile* in_data, wxUint32 nSearchID, wxUint32 nServerIP=0, uint16_t nServerPort=0, LPCTSTR pszDirectory = NULL);
+	CSearchFile(wxUint32 nSearchID, const unsigned char* pucFileHash, wxUint32 uFileSize, char *pszFileName, int iFileType, int iAvailability);
 
 	~CSearchFile();
-	wxUint32	GetIntTagValue(uint8 tagname);
-	char*	GetStrTagValue(uint8 tagname);
+	wxUint32	GetIntTagValue(uint8_t tagname);
+	char*	GetStrTagValue(uint8_t tagname);
 	wxUint32	AddSources(wxUint32 count);
 	wxUint32	GetSourceCount();
 	wxUint32	GetSearchID() {return m_nSearchID;}
 
 	wxUint32	GetClientID() const	{ return m_nClientID; }
 	void		SetClientID(wxUint32 nClientID)	{ m_nClientID = nClientID; }
-	uint16	GetClientPort() const			{ return m_nClientPort; }
-	void		SetClientPort(uint16 nPort)		{ m_nClientPort = nPort; }
+	uint16_t	GetClientPort() const			{ return m_nClientPort; }
+	void		SetClientPort(uint16_t nPort)		{ m_nClientPort = nPort; }
 	wxUint32	GetClientServerIP() const		{ return m_nClientServerIP; }
 	void		SetClientServerIP(wxUint32 uIP)   	{ m_nClientServerIP = uIP; }
-	uint16	GetClientServerPort() const		{ return m_nClientServerPort; }
-	void		SetClientServerPort(uint16 nPort) { m_nClientServerPort = nPort; }
+	uint16_t	GetClientServerPort() const		{ return m_nClientServerPort; }
+	void		SetClientServerPort(uint16_t nPort) { m_nClientServerPort = nPort; }
 	int		GetClientsCount() const		{ return ((GetClientID() && GetClientPort()) ? 1 : 0) + m_aClients.GetSize(); }
 
 	CSearchFile* GetListParent() const		{ return m_list_parent; }
@@ -71,8 +72,8 @@ public:
 		}
 		wxUint32 m_nIP;
 		wxUint32 m_nServerIP;
-		uint16 m_nPort;
-		uint16 m_nServerPort;
+		uint16_t m_nPort;
+		uint16_t m_nServerPort;
 	};
 	void AddClient(SClient* client) { m_aClients.Add(client); }
 	const CArray<SClient*,SClient*>& GetClients() { return m_aClients; }
@@ -88,7 +89,7 @@ public:
 			m_uAvail = 0;
 		}
 		wxUint32 m_nIP;
-		uint16 m_nPort;
+		uint16_t m_nPort;
 		unsigned int m_uAvail;
 	};
 	void AddServer(SServer* server) { m_aServers.Add(server); }
@@ -96,19 +97,19 @@ public:
 	SServer* GetServer(int iServer) { return m_aServers[iServer]; }
 
 private:
-	uint8	clientip[4];
-	uint16	clientport;
+	uint8_t	clientip[4];
+	uint16_t	clientport;
 	wxUint32	m_nSearchID;
 	CArray<CTag*,CTag*> taglist;
 
 	wxUint32	m_nClientID;
-	uint16	m_nClientPort;
+	uint16_t	m_nClientPort;
 	wxUint32	m_nClientServerIP;
-	uint16	m_nClientServerPort;
+	uint16_t	m_nClientServerPort;
 	CArray<SClient*,SClient*> m_aClients;
 	CArray<SServer*,SServer*> m_aServers;
 	bool		 m_list_bExpanded;
-	uint16	 m_list_childcount;
+	uint16_t	 m_list_childcount;
 	CSearchFile* m_list_parent;
 	bool		 m_bPreviewPossible;
 	//CArray<CxImage*,CxImage*> m_listImages;
