@@ -37,19 +37,26 @@
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
+#include "ServerList.h"
+
+#include "config.h"                         // HAVE_CRYPTOPP
 #	include "DownloadQueue.h"
 #	include "HTTPDownloadDlg.h"
 #include "ListenSocket.h"                   // CListenSocket
+#include "otherfunctions.h"                 // Needed for GetResString - audited 5 Nov 2004
+#include "otherstructs.h"                   // Needed for ServerMet_Struct - audited 5 Nov 2004
 #include "packets.h"                        // Packet
-#include "Preferences.h"                    // CPreferences::address_list
+#include "PartFile.h"                       // Needed for SRV_PR_HIGH - audited 5 Nov 2004
+#include "Preferences.h"                    // CPreferences::addresses_list
 #include "SafeFile.h"                       // CSafeMemFile
-#	include "ServerList.h"
+#include "ServerList.h"                     // CServerList
 #	include "ServerWnd.h"
+#include "sockets.h"                        // Needed for CServerConnect - audited 5 Nov 2004
 #	include "xmule.h"
 #	include "xmuleDlg.h"
 #endif
 
-#if !HAVE_CRYPTO
+#if !HAVE_CRYPTOPP
     #include "CryptoXMpp.h"
 #else
     #include <cryptopp/cryptlib.h>
@@ -63,10 +70,10 @@
     #define LE_BE(X) X
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
+#include <wx/filename.h>                    // FileExists wxFileName
 #include <wx/msgdlg.h>
-
 #include <wx/listimpl.cpp>
 //WX_DEFINE_LIST(CServerListList);
 
@@ -91,7 +98,7 @@ list(wxKEY_NONE)
 
 void CServerList::AutoUpdate()
 {
-    if (app_prefs->adresses_list.IsEmpty())
+    if (app_prefs->addresses_list.empty() == true)
     {
         wxMessageBox(GetResString(IDS_ERR_EMPTYADRESSESDAT), GetResString(IDS_ERR_EMPTYADRESSESDAT_TITLE), wxICON_ERROR |wxCENTRE |wxOK);
         return;
@@ -103,14 +110,16 @@ void CServerList::AutoUpdate()
     wxString strURLToDownload;
     BackupFile(servermet, ".old");
     wxRemoveFile(servermetdownload);
-    POSITION Pos = app_prefs->adresses_list.GetHeadPosition();
-    while ((!bDownloaded) && (Pos != NULL))
+
+    std::list<wxString>::iterator it = app_prefs->addresses_list.begin();
+    while (!bDownloaded && (it != app_prefs->addresses_list.end()))
     {
         CHTTPDownloadDlg *dlgDownload;
-        strURLToDownload = app_prefs->adresses_list.GetNext(Pos);
+        strURLToDownload = *it;
         //dlgDownload.m_sURLToDownload = strURLToDownload.GetBuffer();
         //dlgDownload.m_sFileToDownloadInto = servermetdownload;
-        dlgDownload = new CHTTPDownloadDlg(theApp.xmuledlg, wxString(strURLToDownload.GetData()), wxString(servermetdownload.GetData()));
+        dlgDownload = new CHTTPDownloadDlg(theApp.xmuledlg, strURLToDownload, servermetdownload);
+
         if (dlgDownload->ShowModal() == 0)
         {
             bDownloaded = true;
@@ -119,7 +128,9 @@ void CServerList::AutoUpdate()
         {
             theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_FAILEDDOWNLOADMET), strURLToDownload.c_str());
         }
+
         delete dlgDownload;
+        ++it;
     }
     if (bDownloaded)
     {
@@ -143,21 +154,21 @@ bool CServerList::Init()
     printf("*** reading servers\n");
 #endif
     wxString strPath(theApp.dynprefs->Get<wxString>("app-directory") + wxT("server.met"));
-    bool bRes = AddServermetToList(static_cast<CString>(strPath), false);
+    bool bRes = AddServermetToList(strPath, false);
 
     if (theApp.dynprefs->Get<bool>("autoupdate-server"))
     {
-        bool bRes2 = AddServermetToList(static_cast<CString>(strPath));
+        bool bRes2 = AddServermetToList(strPath);
         if (!bRes &&bRes2)
         bRes = true;
     }
     // insert static servers from textfile
     strPath = theApp.dynprefs->Get<wxString>("app-directory") + wxT("staticservers.dat");
-    AddServersFromTextFile(static_cast<CString>(strPath));
+    AddServersFromTextFile(strPath);
     return bRes;
 }
 
-bool CServerList::AddServermetToList(CString strFile, bool merge)
+bool CServerList::AddServermetToList(wxString strFile, bool merge)
 {
     if (!merge)
     {
@@ -177,8 +188,7 @@ bool CServerList::AddServermetToList(CString strFile, bool merge)
         theApp.xmuledlg->AddLogLine(false, _("Failed to load server.met!"));
         return false;
     }
-    if ((1 != servermet.Read( &version, 1)) ||
-    (version != 0xE0 && version != MET_HEADER))
+    if ((1 != servermet.Read( &version, 1)) || (version != 0xE0 && version != MET_HEADER))
     {
         servermet.Close();
         theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_BADSERVERMETVERSION), version);
@@ -186,21 +196,21 @@ bool CServerList::AddServermetToList(CString strFile, bool merge)
     }
     try
     {
-        uint32 fservercount;
+        uint32_t fservercount;
         if (4 != servermet.Read( &fservercount, 4))
         throw CInvalidPacket();
 	fservercount = LE_BE((CryptoXMpp::word32)fservercount);
         ServerMet_Struct sbuffer;
-        uint32 iAddCount = 0;
+        uint32_t iAddCount = 0;
         theApp.xmuledlg->serverwnd->serverlistctrl->Freeze();
-        for (uint32 j = 0 ; j < fservercount ; j++)
+        for (uint32_t j = 0 ; j < fservercount ; j++)
         {
             // get server
             if (sizeof(ServerMet_Struct) != servermet.Read( &sbuffer, sizeof(ServerMet_Struct)))
             throw CInvalidPacket();
             CServer *newserver = new CServer( &sbuffer);
             //add tags
-            for (uint32 i = 0; i < LE_BE((CryptoXMpp::word32)sbuffer.tagcount); i++)
+            for (uint32_t i = 0; i < LE_BE((CryptoXMpp::word32)sbuffer.tagcount); i++)
             {
                 newserver->AddTagFromFile(&servermet);
             }
@@ -302,7 +312,7 @@ void CServerList::ServerStats()
         }
         Packet *packet = new Packet(OP_GLOBSERVSTATREQ, 4);
         srand((unsigned) time(NULL));
-        uint32 time = 0x55AA0000 + (uint16) rand();
+        uint32_t time = 0x55AA0000 + (uint16_t) rand();
         ping_server->SetChallenge(time);
         memcpy(packet->pBuffer, &time, 4);
         ping_server->SetLastPinged(::GetTickCount());
@@ -375,7 +385,7 @@ void CServerList::RemoveAllServers()
     }
 }
 
-void CServerList::GetStatus(uint32 &total, uint32 &failed, uint32 &user, uint32 &file, uint32 &tuser, uint32 &tfile, float &occ)
+void CServerList::GetStatus(uint32_t &total, uint32_t &failed, uint32_t &user, uint32_t &file, uint32_t &tuser, uint32_t &tfile, float &occ)
 {
     total = list.GetCount();
     failed = 0;
@@ -384,8 +394,8 @@ void CServerList::GetStatus(uint32 &total, uint32 &failed, uint32 &user, uint32
     tuser = 0;
     tfile = 0;
     occ = 0;
-    uint32 maxusers = 0;
-    uint32 tuserk = 0;
+    uint32_t maxusers = 0;
+    uint32_t tuserk = 0;
     CServer *curr;
     for (POSITION pos = list.GetHeadPosition() ; pos != 0 ; list.GetNext(pos))
     {
@@ -411,7 +421,7 @@ void CServerList::GetStatus(uint32 &total, uint32 &failed, uint32 &user, uint32
     if (maxusers > 0) occ = (float)(tuserk *100) /maxusers;
 }
 
-void CServerList::GetUserFileStatus(uint32 &user, uint32 &file)
+void CServerList::GetUserFileStatus(uint32_t &user, uint32_t &file)
 {
     user = 0;
     file = 0;
@@ -450,7 +460,7 @@ CServerList::~CServerList()
 #  endif
 #endif
 
-void CServerList::AddServersFromTextFile(CString strFilename, bool isstaticserver)
+void CServerList::AddServersFromTextFile(wxString strFilename, bool isstaticserver)
 {
     wxString strLine;
     //CStdioFile f;
@@ -543,7 +553,7 @@ void CServerList::AddServersFromTextFile(CString strFilename, bool isstaticserve
 void CServerList::MoveServerDown(CServer *aServer)
 {
     POSITION pos1, pos2;
-    uint16 i = 0;
+    uint16_t i = 0;
     for (pos1 = list.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
         list.GetNext(pos1);
@@ -563,7 +573,7 @@ void CServerList::MoveServerDown(CServer *aServer)
 void CServerList::Sort()
 {
     POSITION pos1, pos2;
-    uint16 i = 0;
+    uint16_t i = 0;
     for (pos1 = list.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
         list.GetNext(pos1);
@@ -587,8 +597,8 @@ void CServerList::Sort()
 CServer *CServerList::GetNextServer()
 {
     CServer *nextserver = 0;
-    uint32 i = 0;
-    if (serverpos >= ((uint32) list.GetCount())) return 0;
+    uint32_t i = 0;
+    if (serverpos >= ((uint32_t) list.GetCount())) return 0;
     while (!nextserver &&i != list.GetCount())
     {
         POSITION posIndex = list.FindIndex(serverpos);
@@ -613,7 +623,7 @@ CServer *CServerList::GetNextServer()
 CServer *CServerList::GetNextSearchServer()
 {
     CServer *nextserver = 0;
-    uint32 i = 0;
+    uint32_t i = 0;
     while (!nextserver &&i != list.GetCount())
     {
         POSITION posIndex = list.FindIndex(searchserverpos);
@@ -635,7 +645,7 @@ CServer *CServerList::GetNextSearchServer()
 CServer *CServerList::GetNextStatServer()
 {
     CServer *nextserver = 0;
-    uint32 i = 0;
+    uint32_t i = 0;
     while (!nextserver &&i != list.GetCount())
     {
         POSITION posIndex = list.FindIndex(statserverpos);
@@ -751,7 +761,7 @@ CServer *CServerList::GetServerByIP(wxUint32 nIP, wxUint16 nPort)
     return NULL;
 }
 
-CServer *CServerList::GetServerByAddress(char *address, uint16 port)
+CServer *CServerList::GetServerByAddress(char *address, uint16_t port)
 {
     for (POSITION pos = list.GetHeadPosition() ; pos != 0 ; list.GetNext(pos))
     {
@@ -784,18 +794,18 @@ bool CServerList::SaveServermetToFile()
 
         fwrite( &version, 1, 1, servermet);
         
-        uint32 fservercount = list.GetCount();
-        uint32 w_fservercount = LE_BE((CryptoXMpp::word32)fservercount);
+        uint32_t fservercount = list.GetCount();
+        uint32_t w_fservercount = LE_BE((CryptoXMpp::word32)fservercount);
         fwrite(&w_fservercount, 4, 1, servermet);
 
         ServerMet_Struct sbuffer;
         CServer *nextserver;
-        for (uint32 j = 0 ; j != fservercount ; j++)
+        for (uint32_t j = 0 ; j != fservercount ; j++)
         {
             nextserver = this->GetServerAt(j);
             sbuffer.ip = LE_BE((CryptoXMpp::word32)nextserver->GetIP());
             sbuffer.port = LE_BE((CryptoXMpp::word32)nextserver->GetPort());
-            uint16 tagcount = 11;
+            uint16_t tagcount = 11;
             if (nextserver->GetListName())
             tagcount++;
             if (nextserver->GetDynIP())
