@@ -24,18 +24,22 @@
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
+#	include "ServerListCtrl.h"
 #	include "DownloadQueue.h"
 #	include "muuli_wdr.h"
+#include "opcodes.h"                        // MP_PRIOLOW
 #	include "otherfunctions.h"
+#include "PartFile.h"                       // Needed for SRV_PR_HIGH - audited 5 Nov 2004
 #include "Preferences.h"                    // CPreferences::List Settings
-#	include "ServerListCtrl.h"
+#include "server.h"                         // Needed for CServer - audited 5 Nov 2004
+#include "ServerList.h"                     // CServerList
 #	include "ServerWnd.h"
 #	include "sockets.h"
 #	include "xmule.h"
 #	include "xmuleDlg.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <wx/stattext.h>                    // wxStaticText
 
@@ -215,7 +219,7 @@ void CServerListCtrl::OnCopyLink(wxCommandEvent &event)
     while ((item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED)) != - 1)
     {
         CServer *change = (CServer *) this->GetItemData(item);
-        buffer = buffer.Format("ed2k:|server|%s|%d|", change->GetFullIP(), change->GetPort());
+        buffer.Printf("ed2k:|server|%s|%d|", change->GetFullIP(), change->GetPort());
         if (link.Length() > 0)
         buffer = "\n" + buffer;
         link += buffer;
@@ -294,7 +298,7 @@ void CServerListCtrl::Localize()
     CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
     HDITEM hdi;
     hdi.mask = HDI_TEXT;
-    CString strRes;
+    wxString strRes;
     strRes = GetResString(IDS_SL_SERVERNAME);
     hdi.pszText = strRes.GetBuffer();
     pHeaderCtrl->SetItem(0, &hdi);
@@ -337,7 +341,7 @@ void CServerListCtrl::Localize()
  /*void CServerListCtrl::ShowServers(){
  DeleteAllItems();
  int i=0;
- CString temp;
+ wxString temp;
  for(POSITION pos = server_list->list.GetHeadPosition(); pos != NULL;server_list->list.GetNext(pos)) {
  CServer* cur_server = server_list->list.GetAt(pos);
  InsertItem(LVIF_TEXT|LVIF_PARAM,i,cur_server->GetListName(),0,0,0,(LPARAM)cur_server);
@@ -352,7 +356,7 @@ void CServerListCtrl::RemoveServer(CServer *todel, bool bDelToList)
     //LVFINDINFO find;
     //find.flags = LVFI_PARAM;
     //find.lParam = (LPARAM)todel;
-    sint32 result = FindItem( - 1, (long) todel);
+    int32_t result = FindItem( - 1, (long) todel);
     if (result != ( - 1))
     {
         server_list->RemoveServer((CServer *) GetItemData(result));
@@ -387,15 +391,15 @@ bool CServerListCtrl::AddServer(CServer *toadd, bool bAddToList)
     return false;
     if (bAddToList)
     {
-        uint32 itemnr = GetItemCount();
-        uint32 newid = InsertItem(itemnr, toadd->GetListName());
+        uint32_t itemnr = GetItemCount();
+        uint32_t newid = InsertItem(itemnr, toadd->GetListName());
         SetItemData(newid, (long) toadd);
         wxListItem myitem;
         myitem.m_itemId = newid;
         myitem.SetBackgroundColour(SYSCOLOR(wxSYS_COLOUR_LISTBOX));
         SetItem(myitem);
         RefreshServer(toadd);
-        //uint32 itemnr = GetItemCount();
+        //uint32_t itemnr = GetItemCount();
         //InsertItem(LVIF_TEXT|LVIF_PARAM,itemnr,toadd->GetListName(),0,0,1,(LPARAM)toadd);
         //RefreshServer( toadd );
     }
@@ -468,7 +472,7 @@ void CServerListCtrl::RefreshServer(CServer *server)
         SetItem(itemnr, 6, temp);
         break;
     default:
-        temp.Format(GetResString(IDS_PRIONOPREF));
+        temp.Printf(GetResString(IDS_PRIONOPREF));
         SetItem(itemnr, 6, temp);
     }
     if (server->GetFailedCount() < 0)
@@ -713,11 +717,11 @@ bool CServerListCtrl::ProcessEvent(wxEvent &evt)
             case Irc_SetSendLink:
                 {
                     POSITION pos = this->GetFirstSelectedItemPosition();
-                    CString buffer, link;
+                    wxString buffer, link;
                     while (pos != NULL)
                     {
                         CServer *change = (CServer *) this->GetItemData(this->GetNextSelectedItem(pos));
-                        buffer.Format("ed2k://|server|%s|%d|/", change->GetFullIP(), change->GetPort());
+                        buffer.Printf("ed2k://|server|%s|%d|/", change->GetFullIP(), change->GetPort());
                         if (link.GetLength() > 0) buffer = "\n" + buffer;
                         link += buffer;
                         POSITION pos = this->GetFirstSelectedItemPosition();
@@ -743,7 +747,7 @@ void CServerListCtrl::OnNMLdblclk(NMHDR *pNMHDR, LRESULT *pResult)
     }
 }
 
-bool CServerListCtrl::AddServermetToList(CString strFile)
+bool CServerListCtrl::AddServermetToList(wxString strFile)
 {
     bool flag = server_list->AddServermetToList(strFile);
     RemoveDeadServer();
@@ -755,7 +759,7 @@ bool CServerListCtrl::AddServermetToList(CString strFile)
 bool CServerListCtrl::AddServermetToList(wxString strFile)
 {
     Freeze();
-    bool flag = server_list->AddServermetToList(CString(strFile.GetData()));
+    bool flag = server_list->AddServermetToList(wxString(strFile.GetData()));
     RemoveDeadServer();
     ShowFilesCount();
     Thaw();
@@ -792,22 +796,22 @@ int CServerListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
     {
         //(List) Server-name asc:
     case 0:
-        return CString(item1->GetListName()) .CmpNoCase(item2->GetListName());
+        return wxString(item1->GetListName()) .CmpNoCase(item2->GetListName());
         //(List) Server-name desc:
     case 100:
-        return CString(item2->GetListName()) .CmpNoCase(item1->GetListName());
+        return wxString(item2->GetListName()) .CmpNoCase(item1->GetListName());
     case 1:
         {
             //IP asc
             if (item1->HasDynIP() &&item2->HasDynIP())
-            return CString(item1->GetDynIP()) .CmpNoCase(item2->GetDynIP());
+            return wxString(item1->GetDynIP()) .CmpNoCase(item2->GetDynIP());
             else if(item1->HasDynIP())
             return 1;
             else if(item2->HasDynIP())
             return 0;
             else
             {
-                CString sIP1, sIP2, sTemp1, sTemp2;
+                wxString sIP1, sIP2, sTemp1, sTemp2;
                 counter1 = counter2 = iTemp = 0;
                 sIP1 = item2->GetFullIP();
                 sIP2 = item1->GetFullIP();
@@ -841,14 +845,14 @@ int CServerListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
         {
             //IP desc
             if (item1->HasDynIP() &&item2->HasDynIP())
-            return CString(item2->GetDynIP()) .CmpNoCase(item1->GetDynIP());
+            return wxString(item2->GetDynIP()) .CmpNoCase(item1->GetDynIP());
             else if(item1->HasDynIP())
             return 0;
             else if(item2->HasDynIP())
             return 1;
             else
             {
-                CString s2IP1, s2IP2, s2Temp1, s2Temp2;
+                wxString s2IP1, s2IP2, s2Temp1, s2Temp2;
                 counter1 = counter2 = iTemp = 0;
                 s2IP1 = item2->GetFullIP();
                 s2IP2 = item1->GetFullIP();
@@ -883,7 +887,7 @@ int CServerListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
         if ((item1->GetDescription() != NULL) && (item2->GetDescription() != NULL))
         //the 'if' is necessary, because the Description-String is not
         //always initialisized in server.cpp
-        return CString(item2->GetDescription()) .CmpNoCase(item1->GetDescription());
+        return wxString(item2->GetDescription()) .CmpNoCase(item1->GetDescription());
         else if(item1->GetDescription() == NULL)
         return 1;
         else
@@ -891,7 +895,7 @@ int CServerListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
         //Desciption desc:
     case 102:
         if ((item1->GetDescription() != NULL) && (item2->GetDescription() != NULL))
-        return CString(item1->GetDescription()) .CmpNoCase(item2->GetDescription());
+        return wxString(item1->GetDescription()) .CmpNoCase(item2->GetDescription());
         else if(item1->GetDescription() == NULL)
         return 1;
         else
