@@ -20,7 +20,7 @@
 #ifndef SERVERLISTCTRL_H
 #define SERVERLISTCTRL_H
 
-#include "MuleListCtrl.h"                   // Needed for CMuleListCtrl
+#include "MuleListCtrl.h"                   // CMuleListCtrl - audited 5 Nov 2004
 
 class CServer;
 
@@ -32,13 +32,16 @@ class serverListItem : public wxListItem {
   CServer* data;
 };
 
+// CServerListCtrl
 class CServerList; 
 class CServerListCtrl : public CMuleListCtrl 
 {
+  //	DECLARE_DYNAMIC(CServerListCtrl)
 public:
 	CServerListCtrl();
 	CServerListCtrl(wxWindow*& parent,int id,const wxPoint& pos,wxSize siz,int flags);
 
+//	void	ShowServers();
 	virtual ~CServerListCtrl();
 	bool	Init(CServerList* in_list);
 	void InitSort();
@@ -47,6 +50,8 @@ public:
 	bool	AddServermetToList(wxString strFile);
 	void	RefreshServer(CServer* server);
 	void	RemoveDeadServer();
+	//void	Hide() {ShowWindow(SW_HIDE);}
+	//void	Visable() {ShowWindow(SW_SHOW);}
 	void	Localize();
 	void	ShowFilesCount();
 
@@ -57,9 +62,15 @@ public:
 
 	DECLARE_EVENT_TABLE()
 
-	  void OnRemove(wxCommandEvent & evt);
+	  void OnRemove(wxCommandEvent& evt);
 	void OnLvnColumnclickServlist(wxListEvent& evt);
 	static int SortProc(long item1,long item2,long sortData);
+#if 0
+	afx_msg void OnNMRclickServlist(NMHDR *pNMHDR, LRESULT *pResult);
+protected:
+	afx_msg	void	OnLvnColumnclickServlist(NMHDR *pNMHDR, LRESULT *pResult);
+	static	int		CALLBACK SortProc(LPARAM lParam1, LPARAM lParam2, LPARAM lParamSort);
+#endif
 	bool	asc_sort[9]; 
 	bool ProcessEvent(wxEvent& evt);
 
@@ -67,11 +78,14 @@ public:
 	bool StaticServerFileAppend(CServer *server);
 	bool StaticServerFileRemove(CServer *server);
 
+	//virtual bool OnCommand(WPARAM wParam,LPARAM lParam );
+	//DECLARE_MESSAGE_MAP()
 private:
 	CServerList*	server_list;
 	wxImageList		imagelist;
 	wxMenu* m_ServerPrioMenu;
 	wxMenu* m_ServerMenu;
+	//afx_msg void OnNMLdblclk (NMHDR *pNMHDR, LRESULT *pResult); //<-- mod bb 27.09.02
 };
 
 #endif
