@@ -30,8 +30,7 @@
 #include "DownloadQueue.h"                  // Needed for CDownloadQueue
 #include "ListenSocket.h"                   // Needed for CListenSocket
 #include "otherstructs.h"                   // Needed for LoginAnswer_Struct
-#include "packets.h"                        // Needed for Packets
-#include "Preferences.h"                    // Needed for CPreferences
+#include "packets.h"                        // Needed for Packet
 #include "SafeFile.h"                       // Needed for CSafeFile
 #include "SearchDlg.h"                      // Needed for CSearchDlg
 #include "server.h"                         // Needed for CServer
@@ -43,8 +42,49 @@
 #include "xmule.h"                          // Needed for theApp
 #include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
 
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
+
 #include <arpa/inet.h>                      // Needed for sockaddr_in
 
+class ServerSocketEvt: public wxEvtHandler
+{
+private:
+	void HandleSocket(wxSocketEvent& event);
+	DECLARE_EVENT_TABLE();
+};
+
+BEGIN_EVENT_TABLE(ServerSocketEvt, wxEvtHandler)
+	EVT_SOCKET(-1, ServerSocketEvt::HandleSocket)
+END_EVENT_TABLE()
+
+void ServerSocketEvt::HandleSocket(wxSocketEvent& event)
+{
+    CServerSocket* soc = dynamic_cast<CServerSocket *>(event.GetSocket());
+
+    int id = event.GetSocketEvent();
+
+    if (id == wxSOCKET_CONNECTION)
+    {
+        soc->OnConnect(0);
+    }
+    else if (id == wxSOCKET_LOST)
+    {
+        soc->OnLost(0);
+    }
+    else if (id == wxSOCKET_INPUT)
+    {
+        if (theApp.dynprefs->Get<bool>("enable-serverless") == false)
+        {
+            soc->OnInput(0);
+        }
+    }
+    else if (id == wxSOCKET_OUTPUT)
+    {   
+        soc->OnSend(0);
+    }
+
+}
+
 IMPLEMENT_DYNAMIC_CLASS(CServerSocket, CEMSocket)
 
 CServerSocket::CServerSocket(CServerConnect* in_serverconnect)
@@ -55,7 +95,8 @@ CServerSocket::CServerSocket(CServerConnect* in_serverconnect)
     cur_server = 0;
     info = "";
     m_bIsDeleting = false;
-    SetEventHandler( *theApp.xmuledlg, ID_SOKETTI);
+    m_event_handler = new ServerSocketEvt;
+    SetEventHandler(*m_event_handler, -1);
     SetNotify(wxSOCKET_CONNECTION_FLAG |wxSOCKET_INPUT_FLAG |wxSOCKET_OUTPUT_FLAG |wxSOCKET_LOST_FLAG);
     Notify(TRUE);
 }
@@ -65,8 +106,13 @@ CServerSocket::~CServerSocket()
     // remove event handler...
     SetNotify(0);
     Notify(FALSE);
+    delete m_event_handler;
+
     if (cur_server)
-    delete cur_server;
+    {
+        delete cur_server;
+    }
+
     cur_server = NULL;
 }
 
@@ -90,7 +136,7 @@ void CServerSocket::OnConnect(int nErrorCode)
             {
                 struct sockaddr_in sockAddr;
                 memset( &sockAddr, 0, sizeof(sockAddr));
-                uint32 nSockAddrLen = sizeof(sockAddr);
+                uint32_t nSockAddrLen = sizeof(sockAddr);
                 wxIPV4address tmpaddr;
                 GetPeer(tmpaddr);
                 sockAddr.sin_addr.s_addr = GAddress_INET_GetHostAddress(tmpaddr.GetAddress());
@@ -134,7 +180,7 @@ void CServerSocket::OnInput(int nErrorCode)
     }
 }
 
-bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
+bool CServerSocket::ProcessPacket(char *packet, int32_t size, int8_t opcode)
 {
 //printf("====> CServerSocket::ProcessPacket opcode=0x%02x size=%u\n",opcode,size);
     CServer *update;
@@ -150,18 +196,18 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
                 char *buffer = new char[size - 1];
                 memcpy(buffer, &packet[2], size - 2);
                 buffer[size - 2] = 0;
-                CString message(buffer);
+                wxString message(buffer);
                 if (message.Find("[emDynIP: ") != ( - 1) &&message.Find("]") != ( - 1) &&message.Find("[emDynIP: ") < message.Find("]"))
                 {
-                    CString dynip = message.Mid(message.Find("[emDynIP: ") + 10, message.Find("]") - (message.Find("[emDynIP: ") + 10));
+                    wxString dynip = message.Mid(message.Find("[emDynIP: ") + 10, message.Find("]") - (message.Find("[emDynIP: ") + 10));
                     dynip.Trim(" ");
-                    if (dynip.GetLength() &&dynip.GetLength() < 51)
+                    if (dynip.empty() == false && dynip.length() < 51)
                     {
-                        CServer *eserver = theApp.serverlist->GetServerByAddress(cur_server->GetAddress(), cur_server->GetPort());
+                        CServer* eserver = theApp.serverlist->GetServerByAddress(cur_server->GetAddress(), cur_server->GetPort());
                         if (eserver)
                         {
-                            eserver->SetDynIP((char *) dynip.GetBuffer());
-                            cur_server->SetDynIP((char *) dynip.GetBuffer());
+                            eserver->SetDynIP((char *)dynip.c_str());
+                            cur_server->SetDynIP((char *)dynip.c_str());
                             theApp.xmuledlg->serverwnd->serverlistctrl->RefreshServer(eserver);
                         }
                     }
@@ -178,11 +224,12 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
 #endif
             if (size >= sizeof(LoginAnswer_Struct))
             {
+                static uint8_t state = 0;
                 if (cur_server)
                 {
                     if (size >= 8)
                     {
-                        cur_server->SetTCPFlags(*((uint32*)(packet + 4)));
+                        cur_server->SetTCPFlags(*((uint32_t*)(packet + 4)));
                     }
                     else
                     {
@@ -193,35 +240,33 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
                 LoginAnswer_Struct *la = (LoginAnswer_Struct *) packet;
                 if (la->clientid == 0)
                 {
-                    //					SetConnectionState(CS_ERROR);
-                    uint8 state = theApp.glob_prefs->GetSmartIdState();
+                    SetConnectionState(CS_ERROR);
                     if (state > 0)
                     {
-                        //						SetConnectionState(CS_ERROR);
-                        state++;
+                        SetConnectionState(CS_ERROR);
+                        ++state;
                         if (state > 3)
-                        theApp.glob_prefs->SetSmartIdState(0);
-                        else
-                        theApp.glob_prefs->SetSmartIdState(state);
+                        {
+                            state = 0;
+                        }
                     }
                     break;
                 }
-                if (theApp.glob_prefs->GetSmartIdCheck())
+                if (theApp.dynprefs->Get<bool>("smart-lowid-check") == true)
                 {
                     if (la->clientid >= 16777216)
-                    theApp.glob_prefs->SetSmartIdState(1);
+                    state = 1;
                     else
                     {
-                        uint8 state = theApp.glob_prefs->GetSmartIdState();
                         if (state > 0)
                         {
-                            //	SetConnectionState(CS_ERROR);
-                            state++;
+                            SetConnectionState(CS_ERROR);
+                            ++state;
+
                             if (state > 3)
-                            theApp.glob_prefs->SetSmartIdState(0);
-                            else
-                            theApp.glob_prefs->SetSmartIdState(state);
-                            break;
+                            {
+                                state = 0;
+                            }
                         }
                     }
                 }
@@ -273,7 +318,7 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
             //printf("CServerSocket::ProcessPacket OP_FOUNDSOURCES %02x size=%ld\n", opcode, size);
 #endif
             CMemFile *sources = new CMemFile((BYTE *) packet, size);
-            uchar fileid[16];
+            unsigned char fileid[16];
             sources->Read(fileid, 16);
             if (CPartFile *file = theApp.downloadqueue->GetFileByID(fileid))
             file->AddSources(sources, cur_server->GetIP(), cur_server->GetPort());
@@ -288,9 +333,9 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
             // FIXME some statuspackets have a different size->why? structur?
             if (size > 7)
             {
-                uint32 cur_user;
+                uint32_t cur_user;
                 memcpy( &cur_user, packet, 4);
-                uint32 cur_files;
+                uint32_t cur_files;
                 memcpy( &cur_files, packet + 4, 4);
                 update = theApp.serverlist->GetServerByAddress(cur_server->GetAddress(), cur_server->GetPort());
                 if (update)
@@ -313,7 +358,7 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
             {
                 char *buffer = new char[size - 29];
                 CServer *update = theApp.serverlist->GetServerByAddress(cur_server->GetAddress(), cur_server->GetPort());
-                uint16 num, num2;
+                uint16_t num, num2;
                 // 1st 30 char contain only server address & fillers:
                 memcpy(buffer, &packet[30], size - 30);
                 // length of server_name:
@@ -351,12 +396,12 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
                 CSafeMemFile *servers = new CSafeMemFile((BYTE *) packet, size);
                 unsigned char count;
                 // (servercount*(4bytes ip + 2bytes port) + 1byte servercount):
-                if ((1 != servers->Read( &count, 1)) || ((int32)(count *6 + 1) > size))
+                if ((1 != servers->Read( &count, 1)) || ((int32_t)(count *6 + 1) > size))
                 count = 0;
                 int addcount = 0;
                 while (count)
                 {
-                    uint32 ip;
+                    uint32_t ip;
                     unsigned short port;
                     if (4 != servers->Read( &ip, 4))
                     break;
@@ -386,9 +431,9 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
 #endif
             if (size == 6)
             {
-                uint32 dwIP;
+                uint32_t dwIP;
                 memcpy( &dwIP, packet, 4);
-                uint16 nPort;
+                uint16_t nPort;
                 memcpy( &nPort, packet + 4, 2);
                 CUpDownClient *client = theApp.clientlist->FindClientByIP(dwIP, nPort);
                 if (client)
@@ -451,7 +496,7 @@ void CServerSocket::PacketReceived(Packet *packet)
 {
     if (packet->prot == OP_PACKEDPROT)
     {
-        uint32 uComprSize = packet->size;
+        uint32_t uComprSize = packet->size;
         if (!packet->UnPackPacket(260000))
         {
             theApp.downloadqueue->AddDownDataOverheadServer(packet->size);
@@ -488,7 +533,7 @@ void CServerSocket::OnClose(int nErrorCode)
     serverconnect->DestroySocket(this);
 }
 
-void CServerSocket::SetConnectionState(sint8 newstate)
+void CServerSocket::SetConnectionState(int8_t newstate)
 {
     connectionstate = newstate;
     if (newstate < 1)
