@@ -65,7 +65,7 @@ IMPLEMENT_DYNAMIC_CLASS(CServerReqSocket4661, CEMSocket)
     Notify(TRUE);
     struct sockaddr_in sockAddr;
     memset( & sockAddr, 0, sizeof(sockAddr));
-    uint32 nSockAddrLen = sizeof(sockAddr);
+    uint32_t nSockAddrLen = sizeof(sockAddr);
     wxIPV4address address;
     GetPeer(address);
     sockAddr.sin_addr.s_addr = GAddress_INET_GetHostAddress(address.GetAddress());
@@ -127,7 +127,7 @@ void CServerReqSocket4661::Safe_Delete()
     deletethis = true;
 }
 
-void PrintPacket(unsigned char * packet, uint32 size, uint8 opcode)
+void PrintPacket(unsigned char * packet, uint32_t size, uint8_t opcode)
 {
     int s = 0, z = 0, li = 0;
     unsigned char c = 0;
@@ -425,7 +425,7 @@ bool CServerReqSocket4661::ProcessPacket(unsigned char * packet, wxUint32 size,
     return true;
 }
 
-bool CServerReqSocket4661::ProcessExtPacket(unsigned char * packet, uint32 size, uint8 opcode)
+bool CServerReqSocket4661::ProcessExtPacket(unsigned char * packet, uint32_t size, uint8_t opcode)
 {
     //printf("CServerReqSocket4661: ProcessExtPacket opcode=%02x size=%u\n", opcode, size);
     NewSocket_DebugPP(NULL, opcode, size, (unsigned char *) packet);
