@@ -32,7 +32,7 @@
 #include "NewFunctions.h"                   // Needed for MAP
 #include "opcodes.h"                        // Needed for UNLIMITED
 #include "otherfunctions.h"                 // Needed for GetResString
-#include "Preferences.h"                    // Needed for CPreferences
+#include "Preferences.h"                    // CPreferences::GetUserHash
 #include "resource.h"                       // Needed for IDS_CONNECTING
 #include "server.h"                         // Needed for CServer
 #include "SharedFileList.h"                 // Needed for CSharedFileList
@@ -48,12 +48,15 @@
 #include <netinet/in.h>                     // Needed for sockaddr_in
 #include <sys/ioctl.h>                      // Needed for SIOCGIFADDR
 #include <X11/Xatom.h>                      // Needed for XA_WINDOW
+#include <deque>                            // Needed for std::deque
 
 #ifdef __WXMAC__
     #include <sys/types.h>
     #include <sys/socket.h>
 #endif
 
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
+
 #include "pixmaps/mule_Tr_grey.ico.xpm"
 
 #ifdef __SAFE_TRAY__
@@ -65,63 +68,89 @@ gchar *getIP()
 
 #endif
 
+std::deque<int> m_pLimits;
+std::deque<COLORREF> m_pColors;
+
 #ifndef __SAFE_TRAY__
 gchar *getIP()
 {
-    gchar *ip = "Not Found";
-    wxString interface;
-    int index;
-    index = 0;
-    int sfd;
-    struct ifreq ifr;
-    struct sockaddr_in *sin = (struct sockaddr_in *) &ifr.ifr_addr;
-    memset( &ifr, 0, sizeof ifr);
-    sfd = socket(AF_INET, SOCK_STREAM, 0);
-    strcpy(ifr.ifr_name, "ppp0");
-    sin->sin_family = AF_INET;
-    if (0 == ioctl(sfd, SIOCGIFADDR, &ifr))
+    static gchar* ip = 0;
+
+    if (ip == 0)
     {
-        ip = inet_ntoa(sin->sin_addr);
-        return ip;
-    }
-    else
-    {
-        printf("Not connected at network with ppp0 direct connection\n");
-        do
+        wxString interface;
+        int index;
+        index = 0;
+        int sfd;
+        struct ifreq ifr;
+        struct sockaddr_in *sin = (struct sockaddr_in *) &ifr.ifr_addr;
+        memset( &ifr, 0, sizeof ifr);
+        sfd = socket(AF_INET, SOCK_STREAM, 0);
+        strcpy(ifr.ifr_name, "ppp0");
+        sin->sin_family = AF_INET;
+
+        if (0 == ioctl(sfd, SIOCGIFADDR, &ifr))
         {
-            interface = "eth" + wxString::Format("%d", index);
-            strcpy(ifr.ifr_name, interface);
-            sin->sin_family = AF_INET;
-            if (ioctl(sfd, SIOCGIFADDR, &ifr) == 0)
+            ip = inet_ntoa(sin->sin_addr);
+
+            return ip;
+        }
+        else
+        {
+            printf("Not connected at network with ppp0 direct connection\n");
+
+            do
             {
-                ip = inet_ntoa(sin->sin_addr);
-                index++;
+                interface << "eth" << index;
+                strcpy(ifr.ifr_name, interface);
+                sin->sin_family = AF_INET;
+
+                if (ioctl(sfd, SIOCGIFADDR, &ifr) == 0)
+                {
+                    ip = inet_ntoa(sin->sin_addr);
+                    index++;
+                }
+                else
+                {
+                    interface << "Not connected at network with " << interface;
+                    printf(interface.c_str());
+                }
             }
-            else
-            {
-                printf(wxString("Not connected at network with ") + interface);
-            }
+            while (0 == ioctl(sfd, SIOCGIFADDR, &ifr));
         }
-        while (0 == ioctl(sfd, SIOCGIFADDR, &ifr));
     }
+
     return ip;
 }
 
 #endif
-
+#include <iostream>
+using namespace std;
 // Same check of the connection tab.
 void speed_check()
 {
-    if (theApp.glob_prefs->GetMaxGraphDownloadRate() < theApp.glob_prefs->GetMaxDownload())
-    theApp.glob_prefs->SetDownloadlimit(UNLIMITED);
-    if (theApp.glob_prefs->GetMaxGraphUploadRate() < theApp.glob_prefs->GetMaxUpload())
-    theApp.glob_prefs->SetUploadlimit(UNLIMITED);
-    if (theApp.glob_prefs->GetMaxUpload() != UNLIMITED)
+    if (theApp.dynprefs->Get<long>("capacities-download") < theApp.dynprefs->Get<long>("limits-download"))
     {
-        if (theApp.glob_prefs->GetMaxUpload() < 4 && (theApp.glob_prefs->GetMaxUpload() *3 < theApp.glob_prefs->GetMaxDownload()))
-        theApp.glob_prefs->SetDownloadlimit((theApp.glob_prefs->GetMaxUpload() *3));
-        if (theApp.glob_prefs->GetMaxUpload() < 10 && (theApp.glob_prefs->GetMaxUpload() *4 < theApp.glob_prefs->GetMaxDownload()))
-        theApp.glob_prefs->SetDownloadlimit((theApp.glob_prefs->GetMaxUpload() *4));
+        theApp.dynprefs->Add("limits-download", UNLIMITED);
+    }
+
+    if (theApp.dynprefs->Get<long>("capacities-upload") < theApp.dynprefs->Get<long>("limits-upload"))
+    {
+        theApp.dynprefs->Add("limits-upload", UNLIMITED);
+    }
+
+    long int max_upload = theApp.dynprefs->Get<long>("limits-upload");
+    if (max_upload != UNLIMITED)
+    {
+        cout << "Unlimited: " << UNLIMITED << " | limits-upload: " << max_upload << endl;
+        if ((max_upload < 4) && (max_upload * 3 < theApp.dynprefs->Get<long>("limits-download")))
+        {
+            theApp.dynprefs->Add("limits-download", max_upload * 3);
+        }
+        else if ((max_upload < 10) && (max_upload * 4 < theApp.dynprefs->Get<long>("limits-download")))
+        {
+            theApp.dynprefs->Add("limits-download", max_upload * 4);
+        }
     }
 }
 
@@ -167,15 +196,15 @@ void showgui()
 // Set download and upload speed to max
 void set_all_max()
 {
-    theApp.glob_prefs->SetUploadlimit(theApp.glob_prefs->GetMaxGraphUploadRate());
-    theApp.glob_prefs->SetDownloadlimit(theApp.glob_prefs->GetMaxGraphDownloadRate());
+    theApp.dynprefs->Add("limits-upload", theApp.dynprefs->Get<long>("capacities-upload"));
+    theApp.dynprefs->Add("limits-download", theApp.dynprefs->Get<long>("capacities-download"));
 }
 
 // Set download and upload speed to min
 void set_all_min()
 {
-    theApp.glob_prefs->SetUploadlimit(2);
-    theApp.glob_prefs->SetDownloadlimit(2);
+    theApp.dynprefs->Add("limits-download", 2L);
+    theApp.dynprefs->Add("limits-upload", 2L);
     speed_check();
 }
 
@@ -207,15 +236,15 @@ void disconnect()
 // Set download speed
 void set_dl_speed(GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
-    int temp;
-    temp = atoi(g_strdup_printf("%s", gtk_object_get_data(GTK_OBJECT(widget), "label")));
+    long temp;
+    temp = atol(g_strdup_printf("%s", gtk_object_get_data(GTK_OBJECT(widget), "label")));
     if (temp == 0)
     {
-        theApp.glob_prefs->SetDownloadlimit(UNLIMITED);
+        theApp.dynprefs->Add("limits-download", UNLIMITED);
     }
     else
     {
-        theApp.glob_prefs->SetDownloadlimit(temp);
+        theApp.dynprefs->Add("limits-download", temp);
     }
     speed_check();
 }
@@ -223,15 +252,15 @@ void set_dl_speed(GtkWidget *widget, GdkEventButton *event, gpointer data)
 // Set upload speed
 void set_up_speed(GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
-    int temp;
-    temp = atoi(g_strdup_printf("%s", gtk_object_get_data(GTK_OBJECT(widget), "label")));
+    long temp;
+    temp = atol(g_strdup_printf("%s", gtk_object_get_data(GTK_OBJECT(widget), "label")));
     if (temp == 0)
     {
-        theApp.glob_prefs->SetUploadlimit(UNLIMITED);
+        theApp.dynprefs->Add("limits-upload", UNLIMITED);
     }
     else
     {
-        theApp.glob_prefs->SetUploadlimit(temp);
+        theApp.dynprefs->Add("limits-upload", temp);
     }
     speed_check();
 }
@@ -245,13 +274,13 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     wxString upl_speed, dl_speed;
     gchar *temp, *tempstring;
     int tempspeed;
-    uint16 max_dl_speed, max_up_speed;
-    uint16 actual_dl_speed, actual_up_speed;
+    uint16_t max_dl_speed, max_up_speed;
+    uint16_t actual_dl_speed, actual_up_speed;
     speed_check();
-    actual_up_speed = theApp.glob_prefs->GetMaxUpload();
-    actual_dl_speed = theApp.glob_prefs->GetMaxDownload();
-    max_up_speed = theApp.glob_prefs->GetMaxGraphUploadRate();
-    max_dl_speed = theApp.glob_prefs->GetMaxGraphDownloadRate();
+    actual_up_speed = theApp.dynprefs->Get<long>("limits-upload");
+    actual_dl_speed = theApp.dynprefs->Get<long>("limits-download");
+    max_up_speed = theApp.dynprefs->Get<long>("capacities-upload");
+    max_dl_speed = theApp.dynprefs->Get<long>("capacities-download");
     // What will be shown, very nice!
     if (actual_dl_speed == UNLIMITED || actual_dl_speed == 0)
     {
@@ -283,9 +312,10 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     // Info menu
     info_menu = gtk_menu_new();
     gtk_menu_set_title(GTK_MENU(info_menu), "xMule TrayMenu Info");
-    if (theApp.glob_prefs->GetUserNick() != NULL)
+
+    if (theApp.dynprefs->Get<wxString>("nickname").IsEmpty() != true)
     {
-        info_item = gtk_menu_item_new_with_label(wxString("Nick: ") + theApp.glob_prefs->GetUserNick());
+        info_item = gtk_menu_item_new_with_label(wxT("Nick: ") + theApp.dynprefs->Get<wxString>("nickname"));
     }
     else
     {
@@ -294,9 +324,9 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
     if (theApp.glob_prefs->GetUserHash())
     {
-        CString hash;
+        wxString hash;
         hash = EncodeBase16((const unsigned char *) theApp.glob_prefs->GetUserHash(), 16);
-        info_item = gtk_menu_item_new_with_label(wxString("Hash: ") + hash.GetBuffer());
+        info_item = gtk_menu_item_new_with_label(wxString("Hash: ") + hash.c_str());
     }
     else
     {
@@ -315,27 +345,25 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     tempstring = getIP();
     info_item = gtk_menu_item_new_with_label(wxString("IP: ") + tempstring);
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.glob_prefs->GetPort())
-    {
-        tempstring = g_strdup_printf("%d", theApp.glob_prefs->GetPort());
-        info_item = gtk_menu_item_new_with_label(wxString("TCP Port: ") + tempstring);
-    }
-    else
-    {
-        info_item = gtk_menu_item_new_with_label("TCP Port: Not Ready");
-    }
+
+    tempstring = g_strdup_printf("%d", theApp.dynprefs->Get<long>("tcp-port"));
+    info_item = gtk_menu_item_new_with_label(wxString("TCP Port: ") + tempstring);
+
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.glob_prefs->GetUDPPort())
+
+    long udp_port(theApp.dynprefs->Get<long>("udp-port"));
+    if (udp_port)
     {
-        tempstring = g_strdup_printf("%d", theApp.glob_prefs->GetUDPPort());
+        tempstring = g_strdup_printf("%d", udp_port);
         info_item = gtk_menu_item_new_with_label(wxString("UDP Port: ") + tempstring);
     }
     else
     {
         info_item = gtk_menu_item_new_with_label("UDP Port: Not Ready");
     }
+
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.glob_prefs->IsOnlineSignatureEnabled())
+    if (theApp.dynprefs->Get<bool>("online-signature") == true)
     {
         info_item = gtk_menu_item_new_with_label("Online Signature: Enabled");
     }
@@ -371,7 +399,7 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
         info_item = gtk_menu_item_new_with_label("ServerIP: Not Connected");
         gtk_container_add(GTK_CONTAINER(info_menu), info_item);
     }
-    tempstring = g_strdup_printf("%d", theApp.sharedfiles->listof_SharedFiles->Data);
+//    tempstring = g_strdup_printf("%d", theApp.sharedfiles->listof_SharedFiles->Data);
     info_item = gtk_menu_item_new_with_label(wxString("Shared Files: ") + tempstring);
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
     tempstring = g_strdup_printf("%d", theApp.uploadqueue->GetWaitingUserCount());
@@ -569,8 +597,6 @@ CSysTray::CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
     m_nSpacingWidth = 1;
     m_nNumBars = 1;
     m_nMaxVal = 100;
-    m_pLimits = NULL;
-    m_pColors = NULL;
     parent = _parent;
     desktopMode = _desktopMode;
     if (desktopMode == 3)
@@ -781,19 +807,6 @@ void CSysTray::TraySetIcon(char **data, bool what, int *pVals)
 bool CSysTray::SetColorLevels(int *pLimits, COLORREF *pColors, int nEntries)
 {
 #ifndef __SYSTRAY_DISABLED__
-    // Free allocated memory
-    if (m_pLimits)
-    {
-        delete[] m_pLimits;
-    }
-    if (m_pColors)
-    {
-        delete[] m_pColors;
-    }
-    // Allocate new memory
-    m_pLimits = new int[nEntries];
-    m_pColors = new COLORREF[nEntries];
-    // Copy values
     for (int i = 0 ; i < nEntries ; i++)
     {
         m_pLimits[i] = pLimits[i];
