@@ -5,15 +5,15 @@
 //
 // Copyright (C)2002 Tiku & Patrizio Bassi aka Hetfield <hetfield@email.it>
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either version 2
-//of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either version 2
+// of the License, or (at your option) any later version.
 //
-//This program is distributed in the hope that it will be useful, 
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful, 
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
@@ -22,13 +22,33 @@
 #ifndef SYSTRAY_H
 #define SYSTRAY_H
 
-#include "wintypes.h"                       // Needed for DWORD
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
+#include <gdk/gdkx.h>
+#include <glib.h>
+#include <X11/Xatom.h>
 
-#include <wx/defs.h>                        // Needed for wxChar
-#include <wx/wxchar.h>                      // Needed for wxChar
+#include <locale.h>
+#include <config.h>
+#include <sys/ioctl.h>
+#include <net/if.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <netdb.h>
 
-class wxString;
-class wxWindow;
+#ifdef __WXGTK__
+#	include <unistd.h>
+#endif
+
+#ifdef __WXMAC__
+#	include <sys/types.h>
+#	include <sys/socket.h>
+#endif
+
+#include "eggtrayicon.h"
+#include "wintypes.h"
+#include "wx/window.h"
+#include "wx/string.h"
 
 #define GetRValue(rgb) (((rgb)>>16)&0xff)
 #define GetGValue(rgb) (((rgb)>>8)&0xff)
@@ -73,8 +93,6 @@ private:
 	int m_nSpacingWidth;
 	int m_nNumBars;
 	int m_nMaxVal;
-	int *m_pLimits;
-	COLORREF *m_pColors;
 	int m_nEntries;
 };
 
