@@ -3,77 +3,81 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful, 
+// 
+// This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+
 #ifndef _TRANSFERWND_H
 #define _TRANSFERWND_H
 
+#include <stdint.h>                         // Needed for uint32_t
 #include <wx/panel.h>                       // Needed for wxPanel
 
-class CatMenuHandler;
-class CDownloadListCtrl;
-class CMuleNotebook;
-class CQueueListCtrl;
-class CString;
 class CUploadListCtrl;
+class CDownloadListCtrl;
+class CQueueListCtrl;
+class CMuleNotebook;
 class wxListCtrl;
-class wxMouseEvent;
-class wxNotebookEvent;
 class wxSplitterEvent;
+class wxNotebookEvent;
+class wxCommandEvent;
+class wxMouseEvent;
+class wxEvent;
 
-class CTransferWnd : public wxPanel
+class CTransferWnd : public wxPanel //CResizableDialog
 {
-friend class CatMenuHandler;
+  //DECLARE_DYNAMIC(CTransferWnd)
   DECLARE_DYNAMIC_CLASS(CTransferWnd)
 
 public:
 	CTransferWnd(wxWindow* pParent = NULL);   // standard constructor
 	virtual ~CTransferWnd();
-	void	ShowQueueCount(wxUint32 number);
+	void	ShowQueueCount(uint32_t number);
 	void	SwitchUploadList(wxCommandEvent& evt);
-	void	Localize();
 	bool	OnInitDialog();
 // Dialog Data
-	enum { IDD };
 	CUploadListCtrl*		uploadlistctrl;
 	CDownloadListCtrl*	downloadlistctrl;
 	CQueueListCtrl*		queuelistctrl;
+	//wxToolTip		m_ttip;
 	bool			windowtransferstate;
-	DECLARE_EVENT_TABLE()
-
 protected:
-	void DoResize(int delta);
-	void UpdateSplitterRange();
-	void SetInitLayout();
+	/*
+	virtual bool PreTranslateMessage(MSG* pMsg);
+	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
+	virtual bool OnInitDialog();
+	virtual LRESULT DefWindowProc(UINT message, WPARAM wParam, LPARAM lParam);
+	afx_msg bool OnToolTipNotify(UINT id, NMHDR *pNMH, LRESULT *pResult);
+	*/
 
-	void DoSplitResize(int delta);
-	void UpdateToolTips(void);
-	int GetItemUnderMouse(wxListCtrl* ctrl);
-    void OnSelchangeDltab(wxNotebookEvent& evt);
-    void OnNMRclickDLtab(wxMouseEvent& evt);
+	void OnSelchangeDltab(wxNotebookEvent& evt);
+	void OnNMRclickDLtab(wxMouseEvent& evt);
     void OnSashPositionChanged(wxSplitterEvent& event);
 
-
-	int AddCategorie(CString newtitle, CString newincoming, CString newcomment, bool addTab);
-	void EditCatTabLabel(int index, CString newlabel);
+	int AddCategorie(wxString newtitle, wxString newincoming, wxString newcomment, bool addTab);
+	void EditCatTabLabel(int index, wxString newlabel);
 
 	CMuleNotebook* m_dlTab;
 
+	DECLARE_EVENT_TABLE()
+
+	//DECLARE_MESSAGE_MAP()
+
 private:
+    void HandleCatMenu(wxCommandEvent& event);
 	wxString m_strToolTip;
 	int m_iOldToolTipItemDown;
 	int m_iOldToolTipItemUp;
@@ -81,4 +85,5 @@ private:
 	int rightclickindex;
 	bool CatMenu;
 };
+
 #endif
