@@ -3,50 +3,49 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "UploadListCtrl.h"
+
+#	include "ChatWnd.h"
+#include "ClientCredits.h"                  // CClientCredits
+#	include "ClientDetailDialog.h"
+#	include "FriendList.h"
+#	include "KnownFile.h"
+#	include "muuli_wdr.h"
+#	include "opcodes.h"
+#	include "otherfunctions.h"
+#include "Preferences.h"                    // CPreferences::List Settings
+#	include "SharedFileList.h"
+#	include "TransferWnd.h"
+#include "updownclient.h"                   // Needed for CUpDownClient - audited 5 Nov 2004
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
 #endif
 
-#include "UploadListCtrl.h"                 // Needed for this Interface's Prototype
-
-#include "ChatWnd.h"                        // Needed for CChatWnd
-#include "ClientCredits.h"                  // Needed for CClientCredits
-#include "ClientDetailDialog.h"             // Needed for CClientDetailDialog
-#include "FriendList.h"                     // Needed for CFriendList
-#include "KnownFile.h"                      // Needed for CKnownFile
-#include "muuli_wdr.h"                      // Needed for ID_UPLOADLIST
-#include "otherfunctions.h"                 // Needed for GetResString
-#include "Preferences.h"                    // Needed for CPreferences
-#include "SharedFileList.h"                 // Needed for CSharedFileList
-#include "TransferWnd.h"                    // Needed for CTransferWnd
-#include "updownclient.h"                   // Needed for CUpDownClient
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
-
-#include <wx/dcmemory.h>                    // Needed for wxMemoryDC
-#include <wx/menu.h>                        // Needed for wxMenu
-
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
 
 BEGIN_EVENT_TABLE(CUploadListCtrl, CMuleListCtrl)
-    EVT_RIGHT_DOWN(CUploadListCtrl::OnNMRclick)
-    EVT_LIST_COL_CLICK(ID_UPLOADLIST, CUploadListCtrl::OnColumnClick)
+EVT_RIGHT_DOWN(CUploadListCtrl::OnNMRclick)
+EVT_LIST_COL_CLICK(ID_UPLOADLIST, CUploadListCtrl::OnColumnClick)
 END_EVENT_TABLE()
 
 // images
@@ -61,6 +60,7 @@ END_EVENT_TABLE()
 #include "pixmaps/pluseDonkeyHybrid.ico.xpm"
 #include "pixmaps/thief.ico.xpm"
 
+//IMPLEMENT_DYNAMIC(CUploadListCtrl, CMuleListCtrl)
 CUploadListCtrl::CUploadListCtrl()
 {
 }
@@ -96,16 +96,23 @@ CUploadListCtrl::CUploadListCtrl(wxWindow *&parent, int id, const wxPoint &pos,
 
 void CUploadListCtrl::Init()
 {
+    //,0);:
     InsertColumn(0, GetResString(IDS_QL_USERNAME), wxLIST_FORMAT_LEFT, 150);
+    //,1);:
     InsertColumn(1, GetResString(IDS_FILE), wxLIST_FORMAT_LEFT, 275);
+    //,2);:
     InsertColumn(2, GetResString(IDS_DL_SPEED), wxLIST_FORMAT_LEFT, 60);
+    //,3);:
     InsertColumn(3, GetResString(IDS_DL_TRANSF), wxLIST_FORMAT_LEFT, 65);
+    //,4);:
     InsertColumn(4, GetResString(IDS_WAITED), wxLIST_FORMAT_LEFT, 60);
+    //,6);:
     InsertColumn(5, GetResString(IDS_UPLOADTIME), wxLIST_FORMAT_LEFT, 60);
+    //,5);:
     InsertColumn(6, GetResString(IDS_STATUS), wxLIST_FORMAT_LEFT, 110);
     InsertColumn(7, GetResString(IDS_UPSTATUS), wxLIST_FORMAT_LEFT, 100);
     // not here.. no preferences yet
-    // LoadSettings(CPreferences::tableUpload);
+    //LoadSettings(CPreferences::tableUpload);
 }
 
 void CUploadListCtrl::InitSort()
@@ -160,8 +167,9 @@ void CUploadListCtrl::OnNMRclick(wxMouseEvent &evt)
 
 void CUploadListCtrl::AddClient(CUpDownClient *client)
 {
-    uint32 itemnr = GetItemCount();
+    uint32_t itemnr = GetItemCount();
     char buffer[100];
+    //itemnr = InsertItem(LVIF_TEXT|LVIF_PARAM,itemnr,client->GetUserName(),0,0,1,(LPARAM)client);
     itemnr = InsertItem(itemnr, client->GetUserName());
     SetItemData(itemnr, (long) client);
     wxListItem myitem;
@@ -174,33 +182,41 @@ void CUploadListCtrl::AddClient(CUpDownClient *client)
 
 void CUploadListCtrl::RemoveClient(CUpDownClient *client)
 {
-    sint32 result = FindItem( - 1, (long) client);
+    //LVFINDINFO find;
+    //find.flags = LVFI_PARAM;
+    //find.lParam = (LPARAM)client;
+    //int32_t result = FindItem(&find);
+    int32_t result = FindItem( - 1, (long) client);
     if (result != ( - 1))
     DeleteItem(result);
 }
 
 void CUploadListCtrl::RefreshClient(CUpDownClient *client)
 {
-    if (theApp.nowindow)
-	return;
-    sint32 itemnr = FindItem( - 1, (long) client);
+    //LVFINDINFO find;
+    //find.flags = LVFI_PARAM;
+    //find.lParam = (LPARAM)client;
+    //int32_t itemnr = FindItem(&find);
+    int32_t itemnr = FindItem( - 1, (long) client);
     if (itemnr == ( - 1))
     return;
-    uint8 image;
+    uint8_t image;
     if (client->ExtProtocolAvailable())
     {
-        if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+        if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
         image = 3;
         else
         image = 1;
     }
     else
     {
-        if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+        if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
         image = 2;
         else
         image = 0;
     }
+    // no images yet
+    //SetItem(itemnr,0,LVIF_IMAGE,0,image,0,0,0,0);
     char buffer[100];
     CKnownFile *file = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
     if (file)
@@ -230,7 +246,7 @@ void CUploadListCtrl::RefreshClient(CUpDownClient *client)
     SetItem(itemnr, 7, "Bar is missing :)");
 }
 
-bool CUploadListCtrl::ProcessEvent(wxEvent& evt)
+bool CUploadListCtrl::ProcessEvent(wxEvent &evt)
 {
     if (evt.GetEventType() != wxEVT_COMMAND_MENU_SELECTED)
     return CMuleListCtrl::ProcessEvent(evt);
@@ -251,7 +267,11 @@ bool CUploadListCtrl::ProcessEvent(wxEvent& evt)
             }
         case MP_ADDFRIEND:
             {
+                //      int pos;
+                //      while (pos!=-1) {
                 theApp.friendlist->AddFriend(client);
+                //	pos=GetNextItem(pos,wxLIST_NEXT_ALL,wxLIST_STATE_SELECTED);
+                //      }
                 break;
             }
         case MP_DETAIL:
@@ -268,6 +288,7 @@ bool CUploadListCtrl::ProcessEvent(wxEvent& evt)
     {
     case MP_SWITCHCTRL:
         {
+            //((CTransferWnd*)GetParent())->SwitchUploadList(event);
             theApp.xmuledlg->transferwnd->SwitchUploadList(event);
         }
     }
@@ -276,6 +297,8 @@ bool CUploadListCtrl::ProcessEvent(wxEvent& evt)
 
 void CUploadListCtrl::OnColumnClick(wxListEvent &evt)
 {
+    //NMHDR* pNMHDR, LRESULT* pResult){
+    //NM_LISTVIEW* pNMListView = (NM_LISTVIEW*)pNMHDR;
     // if it's a second click on the same column then reverse the sort order,
     // Barry - Store sort order in preferences
     // Determine ascending based on whether already sorted on this column
@@ -291,6 +314,7 @@ void CUploadListCtrl::OnColumnClick(wxListEvent &evt)
     SetSortArrow(sortItem, sortAscending);
     SortItems(SortProc, sortItem + (sortAscending ? 0: 100));
     // otherwise sort the new column in ascending order.
+    //*pResult = 0;
 }
 
 int CUploadListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
@@ -302,19 +326,19 @@ int CUploadListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
     switch (lParamSort)
     {
     case 0:
-        return CString(item1->GetUserName()) .CmpNoCase(item2->GetUserName());
+        return wxString(item1->GetUserName()) .CmpNoCase(item2->GetUserName());
     case 100:
-        return CString(item2->GetUserName()) .CmpNoCase(item1->GetUserName());
+        return wxString(item2->GetUserName()) .CmpNoCase(item1->GetUserName());
     case 1:
         if ((file1 != NULL) && (file2 != NULL))
-        return CString(file1->GetFileName()) .CmpNoCase(file2->GetFileName());
+        return wxString(file1->GetFileName()) .CmpNoCase(file2->GetFileName());
         else if(file1 == NULL)
         return 1;
         else
         return 0;
     case 101:
         if ((file1 != NULL) && (file2 != NULL))
-        return CString(file2->GetFileName()) .CmpNoCase(file1->GetFileName());
+        return wxString(file2->GetFileName()) .CmpNoCase(file1->GetFileName());
         else if(file1 == NULL)
         return 1;
         else
@@ -393,22 +417,31 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
     dc->DrawRectangle(rectHL);
     dc->SetPen( *wxTRANSPARENT_PEN);
     // then stuff from original xmule
+    //lpDrawItemStruct->itemData;:
     CUpDownClient *client = (CUpDownClient *) GetItemData(item);
+    //CMemDC dc(CDC::FromHandle(lpDrawItemStruct->hDC),&CRect(lpDrawItemStruct->rcItem));
+    //dc.SelectObject(GetFont());
+    //COLORREF crOldTextColor = dc->GetTextColor();
+    //COLORREF crOldBkColor = dc->GetBkColor();
     RECT cur_rec;
+    //memcpy(&cur_rec,&lpDrawItemStruct->rcItem,sizeof(RECT));
     cur_rec.left = rect.x;
     cur_rec.top = rect.y;
     cur_rec.right = rect.x + rect.width;
     cur_rec.bottom = rect.y + rect.height;
     // lagloose
-    CString rbuffer;
+    wxString rbuffer;
     // end lagloose
-    CString Sbuffer;
+    wxString Sbuffer;
     CKnownFile *file = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
+    //CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
+    //pHeaderCtrl->GetItemCount();:
     int iCount = GetColumnCount();
     cur_rec.right = cur_rec.left - 8;
     cur_rec.left += 4;
     for (int iCurrent = 0 ; iCurrent < iCount ; iCurrent++)
     {
+        //pHeaderCtrl->OrderToIndex(iCurrent);:
         int iColumn = iCurrent;
         if (1)
         {
@@ -424,12 +457,12 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
             {
             case 0:
                 {
-                    uint8 image;
+                    uint8_t image;
                     if (client->IsFriend())
                     image = 4;
                     else if(client->ExtProtocolAvailable())
                     {
-                        if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                        if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                         image = 3;
                         else
                         image = 1;
@@ -438,21 +471,21 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
                     {
                         if (client->GetClientSoft() == SO_MLDONKEY)
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 6;
                             else
                             image = 5;
                         }
                         else if(client->GetClientSoft() == SO_EDONKEYHYBRID)
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 8;
                             else
                             image = 7;
                         }
                         else
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 2;
                             else
                             image = 0;
@@ -466,15 +499,17 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
                         cur_rec.left, cur_rec.top + 1
                                         };
                     imagelist.Draw(image, *dc, cur_rec.left, cur_rec.top + 1, wxIMAGELIST_DRAW_TRANSPARENT);
-                    Sbuffer.Format("%s", client->GetUserName());
+                    //imagelist.Draw(dc,image, point, ILD_NORMAL);
+                    Sbuffer.Printf("%s", client->GetUserName());
                     cur_rec.left += 20;
+                    //dc->DrawText(Sbuffer,Sbuffer.GetLength(),&cur_rec,DT_LEFT|DT_SINGLELINE|DT_VCENTER|DT_NOPREFIX|DT_END_ELLIPSIS);
                     dc->DrawText(Sbuffer, cur_rec.left, cur_rec.top + 3);
                     cur_rec.left -= 20;
                     break;
                 }
             case 1:
                 if (file)
-                Sbuffer.Format("%s", file->GetFileName());
+                Sbuffer.Printf("%s", file->GetFileName());
                 else
                 Sbuffer = "?";
                 break;
@@ -483,26 +518,26 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
                 if (client->GetDownloadState() == DS_DOWNLOADING)
                 {
                     Sbuffer = "";
-                    rbuffer.Format("%.1f", (float) client->GetDatarate() /1024);
+                    rbuffer.Printf("%.1f", (float) client->GetDatarate() /1024);
                     Sbuffer.Append(rbuffer);
                     Sbuffer.Append("/");
-                    rbuffer.Format("%.1f %s", (float) client->GetDownloadDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
+                    rbuffer.Printf("%.1f %s", (float) client->GetDownloadDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
                     Sbuffer.Append(rbuffer);
                 }
                 else
                 {
-                    Sbuffer.Format("%.1f %s", (float) client->GetDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
+                    Sbuffer.Printf("%.1f %s", (float) client->GetDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
                 }
                 // end lagloose
                 break;
             case 3:
-                Sbuffer.Format("%s", CastItoXBytes(client->GetSessionUp()) .GetData());
+                Sbuffer.Printf("%s", CastItoXBytes(client->GetSessionUp()) .GetData());
                 break;
             case 4:
-                Sbuffer.Format("%s", CastSecondsToHM((client->GetWaitTime()) /1000) .GetData());
+                Sbuffer.Printf("%s", CastSecondsToHM((client->GetWaitTime()) /1000) .GetData());
                 break;
             case 5:
-                Sbuffer.Format("%s", CastSecondsToHM((client->GetUpStartTimeDelay()) /1000) .GetData());
+                Sbuffer.Printf("%s", CastSecondsToHM((client->GetUpStartTimeDelay()) /1000) .GetData());
                 break;
             case 6:
                 switch (client->GetUploadState())
@@ -521,6 +556,7 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
                     {
                         Sbuffer.Append(" -->");
                     }
+                    // Sbuffer = GetResString(IDS_TRANSFERRING);
                     // end lagloose
                     break;
                 default:
@@ -557,8 +593,10 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
             }
             if (iColumn != 7 &&iColumn != 0)
             {
+                //dc->DrawText(Sbuffer,Sbuffer.GetLength(),&cur_rec,DT_LEFT|DT_SINGLELINE|DT_VCENTER|DT_NOPREFIX|DT_END_ELLIPSIS);
                 dc->DrawText(Sbuffer, cur_rec.left, cur_rec.top + 3);
             }
+            //GetColumnWidth(iColumn);:
             cur_rec.left += cx;
             delete clipper;
         }
