@@ -3,7 +3,7 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -22,7 +22,11 @@
 #ifndef _UPLOADLISTCTRL_H
 #define _UPLOADLISTCTRL_H
 
-#include "MuleListCtrl.h"                   // Needed for CMuleListCtrl
+#include "MuleListCtrl.h"                   // Needed for CMuleListCtrl - audited 5 Nov 2004
+
+#include <stdint.h>                         // Needed for uint32_t
+#include <wx/imaglist.h>
+#include <wx/menu.h>
 
 class CUpDownClient;
 
@@ -31,6 +35,8 @@ class CUpDownClient;
 
 class CUploadListCtrl : public CMuleListCtrl
 {
+  //DECLARE_DYNAMIC(CUploadListCtrl)
+
 public:
 	CUploadListCtrl();
 	CUploadListCtrl(wxWindow*& parent,int id,const wxPoint& pos,wxSize siz,int flags);
@@ -44,7 +50,15 @@ public:
 	void	Hide() {/*ShowWindow(SW_HIDE);*/}
 	void	Visable() {/*ShowWindow(SW_SHOW);*/}
 	void	Localize();
+	//virtual bool OnCommand(WPARAM wParam,LPARAM lParam );
 protected:
+	/*
+	static int CALLBACK SortProc(LPARAM lParam1, LPARAM lParam2, LPARAM lParamSort);
+	afx_msg	void OnColumnClick( NMHDR* pNMHDR, LRESULT* pResult);
+	afx_msg void OnNMRclick(NMHDR *pNMHDR, LRESULT *pResult);
+	DECLARE_MESSAGE_MAP()
+	*/
+	
 	static int SortProc(long lp1,long lp2,long lpSort);
 
 	void OnColumnClick(wxListEvent& evt);
