@@ -20,45 +20,72 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
+    #include "xmule-headers.h"
+#endif
+
+#include "UploadQueue.h"                    // Needed for Module's Protype(s)
+#include "ClientCredits.h"                  // CClientCredits
 #	include "DownloadQueue.h"
 #	include "FriendList.h"
 #	include "ini2.h"
 #	include "KnownFile.h"
 #	include "ListenSocket.h"
 #	include "packets.h"
-#include "Preferences.h"                    // CPreferences::GetQueueSize
+#include "Preferences.h"                    // CPreferences::GetTotalDownloaded
+#include "QueueListCtrl.h"                  // CQueueListCtrl
+#include "server.h"                         // Needed for CServer - audited 5 Nov 2004
+#include "ServerList.h"                     // Needed for CServerList - audited 5 Nov 2004
+#include "ServerListCtrl.h"                 // Needed for CServerListCtrl - audited 5 Nov 2004
 #	include "ServerWnd.h"
 #	include "SharedFileList.h"
+#include "sockets.h"                        // Needed for CServerConnect - audited 5 Nov 2004
 #	include "StatisticsDlg.h"
 #	include "TransferWnd.h"
-#	include "UploadQueue.h"
+#include "updownclient.h"                   // Needed for CUpDownClient - audited 5 Nov 2004
+#include "UploadListCtrl.h"                 // Needed for CUploadListCtrl - audited 5 Nov 2004
 #	include "wintypes.h"
 #	include "xmule.h"
 #	include "xmuleDlg.h"
-#endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
-#include <string.h>
-#include <netinet/in.h>
 #include <arpa/inet.h>
+#include <cstring>
+#include <netinet/in.h>
+#include <wx/timer.h>                       // wxTimer
 
 #define ID_UQTIMER 59742
 
-#ifdef _DEBUG
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
-
-#define new DEBUG_NEW
-#endif
-
 //TODO rewrite the whole networkcode, use overlapped sockets
 
-static uint32 counter, sec, statsave;
+bool operator==(const CFileHash& h1, const CFileHash& h2)
+{
+    return !memcmp(h1.m_hash, h2.m_hash,16);
+}
 
-static uint32 igraph, istats;
+CFileHash::CFileHash()
+{
+    memset(m_hash, 0, 16);
+}
+
+CFileHash::CFileHash(const unsigned char* k)
+{
+    memcpy(m_hash, k, 16);
+}
+
+CFileHash::CFileHash(const CFileHash& s)
+{
+    memcpy(m_hash, s.m_hash,16);
+}
+
+CFileHash::operator const unsigned char*() const
+{
+    return m_hash;
+}
+
+static uint32_t counter, sec, statsave;
+
+static uint32_t igraph, istats;
 
 CUploadQueue::CUploadQueue(CPreferences *in_prefs)
 {
@@ -90,14 +117,14 @@ CUploadQueue::CUploadQueue(CPreferences *in_prefs)
     m_nSumForAvgDataRate = 0;
     statsave = 0;
     for (int i = 0 ; i != 400 ; i++)
-    avarage_dr_list.AddHead((uint32) 0);
+    avarage_dr_list.AddHead((uint32_t) 0);
     h_timer->Start(100);
 }
 
 void CUploadQueue::AddUpNextClient(CUpDownClient *directadd)
 {
     POSITION toadd = 0;
-    uint32 bestscore = 0;
+    uint32_t bestscore = 0;
     CUpDownClient *newclient;
     // select next client or use given client
     if (!directadd)
@@ -253,7 +280,7 @@ void CUploadQueue::AddUpNextClient(CUpDownClient *directadd)
         newclient->ResetSessionUp();
         uploadinglist.AddTail(newclient);
         // statistic
-        CKnownFile *reqfile = theApp.sharedfiles->GetFileByID((uchar *) newclient->GetUploadFileID());
+        CKnownFile *reqfile = theApp.sharedfiles->GetFileByID((unsigned char *) newclient->GetUploadFileID());
         if (reqfile)
         reqfile->statistic.AddAccepted();
         theApp.xmuledlg->transferwnd->uploadlistctrl->AddClient(newclient);
@@ -274,7 +301,7 @@ void CUploadQueue::Process()
     }
     if (!uploadinglist.GetCount())
     return;
-    int16 clientsrdy = 0;
+    int16_t clientsrdy = 0;
     for (POSITION pos = uploadinglist.GetHeadPosition() ; pos != 0 ; uploadinglist.GetNext(pos))
     {
         CUpDownClient *cur_client = uploadinglist.GetAt(pos);
@@ -303,7 +330,7 @@ void CUploadQueue::Process()
             estadatarate = upload_rate * 102;
         }
     }
-    uint32 sendperclient = estadatarate / clientsrdy;
+    uint32_t sendperclient = estadatarate / clientsrdy;
     POSITION pos1, pos2;
     for (pos1 = uploadinglist.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
@@ -324,28 +351,28 @@ bool CUploadQueue::AcceptNewClient()
     return true;
     else if(uploadinglist.GetCount() >= MAX_UP_CLIENTS_ALLOWED)
     return false;
-    uint32 upPerClient = UPLOAD_CLIENT_DATARATE + datarate/50;
+    uint32_t upPerClient = UPLOAD_CLIENT_DATARATE + datarate/50;
     if (upPerClient > 10000)
     upPerClient = 11000;
     //now the final check
     if (theApp.dynprefs->Get<long>("limits-upload") == UNLIMITED)
     {
-        if ((uint32) uploadinglist.GetCount() < ((datarate/upPerClient) + 2))
+        if ((uint32_t) uploadinglist.GetCount() < ((datarate/upPerClient) + 2))
         {
             return true;
         }
     }
     else
     {
-        uint16 nMaxSlots = 0;
+        uint16_t nMaxSlots = 0;
         if (theApp.dynprefs->Get<long>("limits-upload") > 10)
         {
             nMaxSlots += 2;
-            nMaxSlots += (uint16) ceil((float)((theApp.dynprefs->Get<long>("limits-upload") - 10) * 1024) / upPerClient);
+            nMaxSlots += (uint16_t) ceil((float)((theApp.dynprefs->Get<long>("limits-upload") - 10) * 1024) / upPerClient);
         }
         else
         nMaxSlots = MIN_UP_CLIENTS_ALLOWED;
-        if ((uint32) uploadinglist.GetCount() < (datarate/UPLOAD_CHECK_CLIENT_DR) &&uploadinglist.GetCount() <= nMaxSlots)
+        if ((uint32_t) uploadinglist.GetCount() < (datarate/UPLOAD_CHECK_CLIENT_DR) &&uploadinglist.GetCount() <= nMaxSlots)
         return true;
     }
     //nope
@@ -363,7 +390,7 @@ POSITION CUploadQueue::GetWaitingClient(CUpDownClient *client)
     return waitinglist.Find(client);
 }
 
-CUpDownClient *CUploadQueue::GetWaitingClientByIP(uint32 dwIP)
+CUpDownClient *CUploadQueue::GetWaitingClientByIP(uint32_t dwIP)
 {
     for (POSITION pos = waitinglist.GetHeadPosition() ; pos != 0 ; waitinglist.GetNext(pos))
     {
@@ -405,7 +432,7 @@ void CUploadQueue::AddClientToQueue(CUpDownClient *client, bool bIgnoreTimelimit
         return;
     }
     
-    uchar checkid[16];
+    unsigned char checkid[16];
     CKnownFile* knownfile = new CKnownFile();
     char* my_nick = client->GetUserName();
     
@@ -477,7 +504,7 @@ void CUploadQueue::AddClientToQueue(CUpDownClient *client, bool bIgnoreTimelimit
         reqfile->statistic.AddRequest();
     }
     // TODO find better ways to cap the list
-    if ((uint32) waitinglist.GetCount() > (theApp.glob_prefs->GetQueueSize() + bannedcount))
+    if ((uint32_t) waitinglist.GetCount() > (theApp.dynprefs->Get<long>("upload-queue-size") + bannedcount))
     {
         return;
     }
@@ -528,7 +555,7 @@ bool CUploadQueue::RemoveFromUploadQueue(CUpDownClient *client, bool updatewindo
     return false;
 }
 
-uint32 CUploadQueue::GetAverageUpTime()
+uint32_t CUploadQueue::GetAverageUpTime()
 {
     if (successfullupcount)
     {
@@ -591,12 +618,12 @@ void CUploadQueue::DeleteAll()
     uploadinglist.RemoveAll();
 }
 
-uint16 CUploadQueue::GetWaitingPosition(CUpDownClient *client)
+uint16_t CUploadQueue::GetWaitingPosition(CUpDownClient *client)
 {
     if (!IsOnUploadQueue(client))
     return 0;
-    uint16 rank = 1;
-    uint32 myscore = client->GetScore(false);
+    uint16_t rank = 1;
+    uint32_t myscore = client->GetScore(false);
     for (POSITION pos = waitinglist.GetHeadPosition() ; pos != 0 ; waitinglist.GetNext(pos))
     {
         if (waitinglist.GetAt(pos)->GetScore(false) > myscore)
@@ -647,7 +674,7 @@ void TimerProc()
         if (theApp.dynprefs->Get<long>("graph-delay") > 0)
         {
             igraph++;
-            if (igraph >= (uint32)(theApp.dynprefs->Get<long>("graph-delay")))
+            if (igraph >= (uint32_t)(theApp.dynprefs->Get<long>("graph-delay")))
             {
                 igraph = 0;
                 theApp.xmuledlg->statisticswnd->SetCurrentRate((float) theApp.uploadqueue->GetDatarate() /1024, (float) theApp.downloadqueue->GetDatarate() /1024);
@@ -659,7 +686,7 @@ void TimerProc()
             if (theApp.dynprefs->Get<long>("tree-delay") > 0)
             {
                 istats++;
-                if (istats >= (uint32)(theApp.dynprefs->Get<long>("tree-delay")))
+                if (istats >= (uint32_t)(theApp.dynprefs->Get<long>("tree-delay")))
                 {
                     istats = 0;
                     theApp.xmuledlg->ShowStatistics();
@@ -685,11 +712,11 @@ void TimerProc()
         if (statsave >= 60)
         {
             statsave = 0;
-            CString buffer;
+            wxString buffer;
             CIni ini(theApp.dynprefs->Get<wxString>("appdir") + wxT("preferences.ini"), "xMule");
-            buffer.Format("%llu", theApp.stat_sessionReceivedBytes + theApp.glob_prefs->GetTotalDownloaded());
+            buffer.Printf("%llu", theApp.stat_sessionReceivedBytes + theApp.glob_prefs->GetTotalDownloaded());
             ini.WriteString("TotalDownloadedBytes", buffer, "Statistics");
-            buffer.Format("%llu", theApp.stat_sessionSentBytes + theApp.glob_prefs->GetTotalUploaded());
+            buffer.Printf("%llu", theApp.stat_sessionSentBytes + theApp.glob_prefs->GetTotalUploaded());
             ini.WriteString("TotalUploadedBytes", buffer, "Statistics");
         }
     }
@@ -745,7 +772,7 @@ void CUploadQueue::SuspendUpload(const CFileHash &filehash)
 {
     //Append the filehash to the list.
     suspended_uploads_list.Append(filehash);
-    CString base16hash = EncodeBase16(filehash, 16);
+    wxString base16hash = EncodeBase16(filehash, 16);
     POSITION pos = uploadinglist.GetHeadPosition();
     while (pos)
     {
@@ -756,7 +783,7 @@ void CUploadQueue::SuspendUpload(const CFileHash &filehash)
         {
             //remove the unlucky client from the upload queue and add to the waiting queue
             RemoveFromUploadQueue(potential, 1);
-            printf("%s: Removed user '%s'\n", base16hash.GetBuffer(), potential->GetUserName());
+            printf("%s: Removed user '%s'\n", base16hash.c_str(), potential->GetUserName());
             //this code to add to the waitinglist was copied from the end of AddClientToQueue()
             //the function itself is not used as it could prevent the requeuing of the client
             waitinglist.AddTail(potential);
