@@ -3,7 +3,7 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -23,7 +23,7 @@
 #define _UPLOADQUEUE_H
 
 #include "mfc.h"                            // Needed for POSITION
-#include "types.h"                          // Needed for uint16
+#include <stdint.h>                         // Needed for uint32_t
 
 class CPreferences;
 class CUpDownClient;
@@ -31,20 +31,16 @@ class wxTimer;
 
 // Helper class holding a copy of a filehash
 // The CCKey class is similiar but not useable here.
-class CFileHash
-{
+class CFileHash {
 public:
-	CFileHash()			{ memset(m_hash, 0, 16); }
-	CFileHash(const unsigned char* k) { memcpy(m_hash, k, 16); }
-	CFileHash(const CFileHash& s)	{ memcpy(m_hash, s.m_hash,16); }
-
-	friend bool operator==(const CFileHash& h1, const CFileHash& h2)
-			{ return !memcmp(h1.m_hash, h2.m_hash,16); }
-
-	operator const unsigned char*() const { return m_hash; }
+    CFileHash();
+    CFileHash(const unsigned char* k);
+    CFileHash(const CFileHash& s);
+    friend bool operator==(const CFileHash& h1, const CFileHash& h2);
+    operator const unsigned char*() const;
 
 private:
-	unsigned char m_hash[16];
+    unsigned char m_hash[16];
 };
 
 class CUploadQueue
@@ -58,7 +54,7 @@ public:
 	bool	RemoveFromWaitingQueue(CUpDownClient* client,bool updatewindow = true);
 	bool	IsOnUploadQueue(CUpDownClient* client)	{return GetWaitingClient(client);}
 	bool	IsDownloading(CUpDownClient* client)	{return GetDownloadingClient(client);}
-	uint32	GetDatarate()							{return datarate;}
+	uint32_t	GetDatarate()							{return datarate;}
 	bool	CheckForTimeOver(CUpDownClient* client);
 	int		GetWaitingUserCount()					{return waitinglist.GetCount();}
 	int		GetUploadQueueLength()					{return uploadinglist.GetCount();}
@@ -74,46 +70,47 @@ waitinglist.GetHeadPosition();}
  
 
 	void	UpdateBanCount();
-	CUpDownClient*	GetWaitingClientByIP(uint32 dwIP);
+	CUpDownClient*	GetWaitingClientByIP(uint32_t dwIP);
 	CUpDownClient*	GetNextClient(CUpDownClient* update);
 
 	
 	void	DeleteAll();
-	uint16	GetWaitingPosition(CUpDownClient* client);
-	void	SetBanCount(uint32 in_count)			{bannedcount = in_count;}
-	uint32	GetBanCount()							{return bannedcount;}
-	uint32	GetSuccessfullUpCount()					{return successfullupcount;}
-	uint32	GetFailedUpCount()						{return failedupcount;}
-	uint32	GetAverageUpTime();
-	void	FindSourcesForFileById(CTypedPtrList<CPtrList, CUpDownClient*>* srclist, uchar* filehash);
-	void	AddUpDataOverheadSourceExchange(uint32 data)	{ m_nUpDataRateMSOverhead += data;
+	uint16_t	GetWaitingPosition(CUpDownClient* client);
+	void	SetBanCount(uint32_t in_count)			{bannedcount = in_count;}
+	uint32_t	GetBanCount()							{return bannedcount;}
+	uint32_t	GetSuccessfullUpCount()					{return successfullupcount;}
+	uint32_t	GetFailedUpCount()						{return failedupcount;}
+	uint32_t	GetAverageUpTime();
+	void	FindSourcesForFileById(CTypedPtrList<CPtrList, CUpDownClient*>* srclist, unsigned char* filehash);
+	void	AddUpDataOverheadSourceExchange(uint32_t data)	{ m_nUpDataRateMSOverhead += data;
 															  m_nUpDataOverheadSourceExchange += data;
 															  m_nUpDataOverheadSourceExchangePackets++;}
-	void	AddUpDataOverheadFileRequest(uint32 data)		{ m_nUpDataRateMSOverhead += data;
+	void	AddUpDataOverheadFileRequest(uint32_t data)		{ m_nUpDataRateMSOverhead += data;
 															  m_nUpDataOverheadFileRequest += data;
 															  m_nUpDataOverheadFileRequestPackets++;}
-	void	AddUpDataOverheadServer(uint32 data)	{ m_nUpDataRateMSOverhead += data;
+	void	AddUpDataOverheadServer(uint32_t data)	{ m_nUpDataRateMSOverhead += data;
 															  m_nUpDataOverheadServer += data;
 															  m_nUpDataOverheadServerPackets++;}
 
-	void	AddUpDataOverheadOther(uint32 data)				{ m_nUpDataRateMSOverhead += data;
+	void	AddUpDataOverheadOther(uint32_t data)				{ m_nUpDataRateMSOverhead += data;
 															  m_nUpDataOverheadOther += data;
 															  m_nUpDataOverheadOtherPackets++;}
-	uint32	GetUpDatarateOverhead()						{return m_nUpDatarateOverhead;}
-	uint64	GetUpDataOverheadSourceExchange()			{return m_nUpDataOverheadSourceExchange;}
-	uint64	GetUpDataOverheadFileRequest()				{return m_nUpDataOverheadFileRequest;}
-	uint64	GetUpDataOverheadServer()					{return m_nUpDataOverheadServer;}
-	uint64	GetUpDataOverheadOther()					{return m_nUpDataOverheadOther;}
-	uint64	GetUpDataOverheadSourceExchangePackets()	{return m_nUpDataOverheadSourceExchangePackets;}
-	uint64	GetUpDataOverheadFileRequestPackets()		{return m_nUpDataOverheadFileRequestPackets;}
-	uint64	GetUpDataOverheadServerPackets()			{return m_nUpDataOverheadServerPackets;}
-	uint64	GetUpDataOverheadOtherPackets()				{return m_nUpDataOverheadOtherPackets;}
+	uint32_t	GetUpDatarateOverhead()						{return m_nUpDatarateOverhead;}
+	uint64_t	GetUpDataOverheadSourceExchange()			{return m_nUpDataOverheadSourceExchange;}
+	uint64_t	GetUpDataOverheadFileRequest()				{return m_nUpDataOverheadFileRequest;}
+	uint64_t	GetUpDataOverheadServer()					{return m_nUpDataOverheadServer;}
+	uint64_t	GetUpDataOverheadOther()					{return m_nUpDataOverheadOther;}
+	uint64_t	GetUpDataOverheadSourceExchangePackets()	{return m_nUpDataOverheadSourceExchangePackets;}
+	uint64_t	GetUpDataOverheadFileRequestPackets()		{return m_nUpDataOverheadFileRequestPackets;}
+	uint64_t	GetUpDataOverheadServerPackets()			{return m_nUpDataOverheadServerPackets;}
+	uint64_t	GetUpDataOverheadOtherPackets()				{return m_nUpDataOverheadOtherPackets;}
 	void	CompUpDatarateOverhead();
 	void	SuspendUpload( const CFileHash& );
 	void	ResumeUpload( const CFileHash& );
 protected:
 	void	RemoveFromWaitingQueue(POSITION pos, bool updatewindow);
 	POSITION	GetWaitingClient(CUpDownClient* client);
+//	POSITION	GetWaitingClientByID(CUpDownClient* client);
 	POSITION	GetDownloadingClient(CUpDownClient* client);
 	bool		AcceptNewClient();
 	void		AddUpNextClient(CUpDownClient* directadd = 0);
@@ -122,28 +119,28 @@ private:
 	CTypedPtrList<CPtrList, CUpDownClient*> waitinglist;
 	CTypedPtrList<CPtrList, CUpDownClient*> uploadinglist;
 	CList<CFileHash, const CFileHash&> suspended_uploads_list;  //list for suspended uploads
-	uint32	datarate;   //datarate 
-	uint32	dataratems;	// datarate last 100ms
-	uint32	datarateave; //datarage average (since progstart) *unused*
-	sint32	estadatarate; // esta. max datarate	
+	uint32_t	datarate;   //datarate 
+	uint32_t	dataratems;	// datarate last 100ms
+	uint32_t	datarateave; //datarage average (since progstart) *unused*
+	int32_t	estadatarate; // esta. max datarate	
 	CPreferences* app_prefs;
 	wxTimer* h_timer;
-	uint32	bannedcount;
-	uint32	successfullupcount;
-	uint32	failedupcount;
-	uint32	totaluploadtime;
-	uint32	m_nLastStartUpload;
-	uint32	m_nUpDatarateOverhead;
-	uint32	m_nUpDataRateMSOverhead;
-	uint64	m_nUpDataOverheadSourceExchange;
-	uint64	m_nUpDataOverheadFileRequest;
-	uint64	m_nUpDataOverheadServer;
-	uint64	m_nUpDataOverheadOther;
-	uint64	m_nUpDataOverheadSourceExchangePackets;
-	uint64	m_nUpDataOverheadFileRequestPackets;
-	uint64	m_nUpDataOverheadServerPackets;
-	uint64	m_nUpDataOverheadOtherPackets;
-	uint32	m_nSumForAvgDataRate;
+	uint32_t	bannedcount;
+	uint32_t	successfullupcount;
+	uint32_t	failedupcount;
+	uint32_t	totaluploadtime;
+	uint32_t	m_nLastStartUpload;
+	uint32_t	m_nUpDatarateOverhead;
+	uint32_t	m_nUpDataRateMSOverhead;
+	uint64_t	m_nUpDataOverheadSourceExchange;
+	uint64_t	m_nUpDataOverheadFileRequest;
+	uint64_t	m_nUpDataOverheadServer;
+	uint64_t	m_nUpDataOverheadOther;
+	uint64_t	m_nUpDataOverheadSourceExchangePackets;
+	uint64_t	m_nUpDataOverheadFileRequestPackets;
+	uint64_t	m_nUpDataOverheadServerPackets;
+	uint64_t	m_nUpDataOverheadOtherPackets;
+	uint32_t	m_nSumForAvgDataRate;
 	CList<int,int>	m_AvarageUDRO_list;
 
 };
