@@ -27,7 +27,7 @@
 #	include "ClientList.h"
 #endif
 
-bool CClientList::VerifyUpload(uint32 clientip, uint16 port)
+bool CClientList::VerifyUpload(uint32_t clientip, uint16_t port)
 {
     CUpDownClient *tocheck = FindClientByIP(clientip, port);
     if (tocheck && ((tocheck->GetDownloadState() == DS_DOWNLOADING &&tocheck->GetDatarate() > 1000) || (tocheck->GetTransferedDown() > 400000)))
@@ -48,7 +48,7 @@ CUpDownClient *CClientList::VUGetRandomClient()
     }
     if (templist.IsEmpty())
     return 0;
-    uint16 randomness = (uint16) ROUND(((float) rand() /RAND_MAX) * (templist.GetCount() - 1));
+    uint16_t randomness = (uint16_t) ROUND(((float) rand() /RAND_MAX) * (templist.GetCount() - 1));
     return templist.GetAt(templist.FindIndex(randomness));
 }
 
