@@ -20,28 +20,30 @@
 // Wizard.cpp : implementation file
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "muuli_wdr.h"
+#	include "otherfunctions.h"
+#	include "Preferences.h"
+#	include "PreferencesDlg.h"
+#	include "StatisticsDlg.h"
+#	include "wintypes.h"
+#	include "Wizard.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
 #endif
 
-#include "Wizard.h"                         // Needed for this Interface's Prototype
+#include <wx/listctrl.h>
 
-#include "muuli_wdr.h"                      // Needed for connWizDlg
-#include "otherfunctions.h"                 // Needed for GetResString
-#include "PPgConnection.h"                  // Needed for CPPgConnection
-#include "PPgTweaks.h"                      // Needed for CPPgTweaks
-#include "Preferences.h"                    // Needed for CPreferences
-#include "PreferencesDlg.h"                 // Needed for CPreferencesDlg
-#include "resource.h"                       // Needed for IDS_PW_CONNECTION
-#include "StatisticsDlg.h"                  // Needed for CStatisticsDlg
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+// Wizard dialog
 
-#include <wx/listctrl.h>                    // Needed for wxListCtrl
-#include <wx/sizer.h>                       // Needed for wxSizer
-#include <wx/textctrl.h>                    // Needed for wxTextCtrl
+//IMPLEMENT_DYNAMIC(Wizard, CDialog)
+    Wizard::Wizard(wxWindow *pParent /*=NULL*/
 
-Wizard::Wizard(wxWindow* pParent)
-: wxDialog(pParent, Wizard::IDD, _("Wizard"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxSYSTEM_MENU)
+)
+//: CDialog(Wizard::IDD, pParent)
+: wxDialog(pParent, Wizard::IDD, _("Wizard"), wxDefaultPosition, wxDefaultSize,
+wxDEFAULT_DIALOG_STYLE |wxSYSTEM_MENU)
 {
     m_iOS = 0;
     m_iTotalDownload = 0;
@@ -70,7 +72,7 @@ END_EVENT_TABLE()
 #define GetDlgItem(a,b) wxStaticCast(FindWindowById((a)),b)
 #define IsDlgButtonChecked(a) GetDlgItem(a,wxRadioButton)->GetValue()
 
-void Wizard::OnBnClickedApply(wxCommandEvent&evt)
+void Wizard::OnBnClickedApply(wxEvent &evt)
 {
     char buffer[510];
     int upload, download;
@@ -101,7 +103,7 @@ void Wizard::OnBnClickedApply(wxCommandEvent&evt)
     }
     if (upload > 0 &&download > 0)
     {
-        app_prefs->prefs->maxupload = (uint16)(upload *.8);
+        app_prefs->prefs->maxupload = (uint16_t)(upload *.8);
         if (upload < 4 &&download > upload *3)
         {
             app_prefs->prefs->maxdownload = app_prefs->prefs->maxupload *3;
@@ -113,7 +115,7 @@ void Wizard::OnBnClickedApply(wxCommandEvent&evt)
             download = upload *4;
         }
         else
-        app_prefs->prefs->maxdownload = (uint16)(download *.9);
+        app_prefs->prefs->maxdownload = (uint16_t)(download *.9);
         app_prefs->prefs->maxGraphDownloadRate = app_prefs->prefs->maxdownload;
         app_prefs->prefs->maxGraphUploadRate = app_prefs->prefs->maxupload;
         theApp.xmuledlg->statisticswnd->SetARange(false, app_prefs->prefs->maxGraphUploadRate);
@@ -213,43 +215,45 @@ void Wizard::OnBnClickedApply(wxCommandEvent&evt)
     }
     theApp.xmuledlg->preferenceswnd->m_wndConnection->LoadSettings();
     theApp.xmuledlg->preferenceswnd->m_wndTweaks->LoadSettings();
+    printf("TODO: TWEAKS missing \n");
+    //CDialog::OnOK();
     EndModal(0);
 }
 
-void Wizard::OnBnClickedCancel(wxCommandEvent&evt)
+void Wizard::OnBnClickedCancel(wxEvent &evt)
 {
     EndModal(1);
 }
 
-void Wizard::OnBnClickedWizRadioOsNtxp(wxCommandEvent&evt)
+void Wizard::OnBnClickedWizRadioOsNtxp(wxEvent &evt)
 {
     m_iOS = 0;
 }
 
-void Wizard::OnBnClickedWizRadioUs98me(wxCommandEvent&evt)
+void Wizard::OnBnClickedWizRadioUs98me(wxEvent &evt)
 {
     m_iOS = 1;
 }
 
-void Wizard::OnBnClickedWizLowdownloadRadio(wxCommandEvent&evt)
+void Wizard::OnBnClickedWizLowdownloadRadio(wxEvent &evt)
 {
     m_iTotalDownload = 0;
 }
 
-void Wizard::OnBnClickedWizMediumdownloadRadio(wxCommandEvent&evt)
+void Wizard::OnBnClickedWizMediumdownloadRadio(wxEvent &evt)
 {
     m_iTotalDownload = 1;
 }
 
-void Wizard::OnBnClickedWizHighdownloadRadio(wxCommandEvent&evt)
+void Wizard::OnBnClickedWizHighdownloadRadio(wxEvent &evt)
 {
     m_iTotalDownload = 2;
 }
 
-void Wizard::OnBnClickedWizResetButton(wxCommandEvent&evt)
+void Wizard::OnBnClickedWizResetButton(wxEvent &evt)
 {
-    CString strBuffer;
-    strBuffer.Format("%i", 0);
+    wxString strBuffer;
+    strBuffer.Printf("%i", 0);
     GetDlgItem(ID_TRUEDOWNLOAD, wxTextCtrl)->SetValue(strBuffer);
     GetDlgItem(ID_TRUEUPLOAD, wxTextCtrl)->SetValue(strBuffer);
 }
@@ -258,9 +262,14 @@ void Wizard::OnBnClickedWizResetButton(wxCommandEvent&evt)
 
 bool Wizard::OnInitDialog()
 {
-    CString temp;
-    temp.Format("%u", app_prefs->prefs->maxGraphDownloadRate *8);
-    temp.Format("%u", app_prefs->prefs->maxGraphUploadRate *8);
+    //CheckDlgButton(IDC_WIZ_XP_RADIO,1);
+    //CheckDlgButton(ID_LOWDOWN, 1);
+    //CheckDlgButton(ID_KBITS, 1);
+    wxString temp;
+    temp.Printf("%u", app_prefs->prefs->maxGraphDownloadRate *8);
+    //GetDlgItem(ID_TRUEDOWNLOAD, wxTextCtrl)->SetValue(temp);
+    temp.Printf("%u", app_prefs->prefs->maxGraphUploadRate *8);
+    //GetDlgItem(ID_TRUEUPLOAD, wxTextCtrl)->SetValue(temp);
     m_provider->InsertColumn(0, GetResString(IDS_PW_CONNECTION), wxLIST_FORMAT_LEFT, 160);
     m_provider->InsertColumn(1, GetResString(IDS_WIZ_DOWN), wxLIST_FORMAT_LEFT, 90);
     m_provider->InsertColumn(2, GetResString(IDS_WIZ_UP), wxLIST_FORMAT_LEFT, 90);
@@ -333,8 +342,9 @@ void Wizard::SetCustomItemsActivation()
 
 void Wizard::OnNMClickProviders(wxListEvent &evt)
 {
+    //LPNMLISTVIEW pNMLV = reinterpret_cast<LPNMLISTVIEW>(pNMHDR);
     SetCustomItemsActivation();
-    uint16 up, down;
+    uint16_t up, down;
     int cursel = m_provider->GetNextItem( - 1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
     switch (cursel)
     {
@@ -391,8 +401,13 @@ void Wizard::OnNMClickProviders(wxListEvent &evt)
         break;
     default: return;
     }
-    CString temp;
-    temp.Format("%u", down);
-    temp.Format("%u", up);
+    wxString temp;
+    temp.Printf("%u", down);
+    //GetDlgItem(ID_TRUEDOWNLOAD, wxTextCtrl)->SetValue(temp);
+    temp.Printf("%u", up);
+    //GetDlgItem(ID_TRUEUPLOAD, wxTextCtrl)->SetValue(temp);
+    //CheckDlgButton(ID_KBITS, 1);
+    //CheckDlgButton(ID_KBYTES, 0);
+    //*pResult = 0;
 }
 
