@@ -1,7 +1,7 @@
-/* This file is a part of the xMule Project.
+// This file is a part of the xMule Project.
 //
 // Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
-// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -15,7 +15,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.*/
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 /* -------------------------------------------------------------------------
  * Project: GSocket (Generic Socket) for WX
@@ -24,7 +24,7 @@
  *          Guillermo Rodriguez Garcia <guille@iies.es> (maintainer)
  * Purpose: GSocket main Unix file
  * Licence: The wxWindows licence
- * CVSID:   $Id: gsocket.c,v 1.15 2004/08/26 07:23:48 HopeSeekr Exp $
+ * CVSID:   $Id: gsocket.c,v 1.14 2004/10/05 02:09:43 HopeSeekr Exp $
  * -------------------------------------------------------------------------
  */
 
@@ -34,11 +34,7 @@
 
 #include <wx/version.h>                     // Needed for wxCHECK_VERSION
 
-#if defined(__WXUNIVERSAL__)
-#elif wxCHECK_VERSION(2, 5, 0)
-
-#include "gsocket-2.5.c"
-
+#if defined(__WXUNIVERSAL__) || wxCHECK_VERSION(2, 5, 0)
 #else
 
 #ifndef __GSOCKET_STANDALONE__
@@ -1728,4 +1724,4 @@ GSocketError GAddress_UNIX_GetPath(GAddress *address, char *path, size_t sbuf)
 }
 
 #endif  /* wxUSE_SOCKETS || defined(__GSOCKET_STANDALONE__) */
-#endif  /* wxCHECK_VERSION(2, 5, 0) */
+#endif
