@@ -22,12 +22,15 @@
 //////////////////////////////////////////////////////////////////////
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#include "wintypes.h"
+#include "ini2.h"
 #endif
 
-#include "ini2.h"                           // Needed for this Interface's Prototype
-
-#include <wx/config.h>                      // Needed for wxConfigBase
+#include <wx/string.h>
+#include <wx/window.h>
+#include <wx/config.h>
 
 #ifdef _DEBUG
 #undef THIS_FILE
@@ -48,10 +51,42 @@ static char THIS_FILE[] = __FILE__;
 // to avoid storing in the windows-directory
     /*static*/
 
-    void CIni::AddModulPath(wxString &strFileName, BOOL bModulPath /*= TRUE*/
+    void CIni::AddModulPath(wxString &strFileName, bool bModulPath /*= TRUE*/
 
 )
 {
+#if 0
+    char drive[_MAX_DRIVE];
+    char dir[_MAX_DIR];
+    char fname[_MAX_FNAME];
+    char ext[_MAX_EXT];
+    _splitpath(strFileName, drive, dir, fname, ext);
+    if (! drive[0])
+    {
+        //PathCanonicalize(..) doesn't work with for all Plattforms !
+        wxString strModule;
+        if (bModulPath)
+        {
+            GetModuleFileName(NULL, strModule.GetBuffer(MAX_INI_BUFFER), MAX_INI_BUFFER);
+            strModule.ReleaseBuffer();
+        }
+        else
+        {
+            GetCurrentDirectory(MAX_INI_BUFFER, strModule.GetBuffer(MAX_INI_BUFFER));
+            strModule.ReleaseBuffer();
+            // fix by "cpp@world-online.no"
+            strModule.TrimRight('\\');
+            strModule.TrimRight('/');
+            strModule += "\\";
+        }
+        strModule.ReleaseBuffer();
+        _splitpath(strModule, drive, dir, fname, ext);
+        strModule = drive;
+        strModule += dir;
+        strModule += strFileName;
+        strFileName = strModule;
+    }
+#endif
 }
 
     /*static*/
@@ -64,10 +99,41 @@ wxString CIni::GetDefaultSection()
 
     /*static*/
 
-    wxString CIni::GetDefaultIniFile(BOOL bModulPath /*= TRUE*/
+    wxString CIni::GetDefaultIniFile(bool bModulPath /*= TRUE*/
 
 )
 {
+#if 0
+    char drive[_MAX_DRIVE];
+    char dir[_MAX_DIR];
+    char fname[_MAX_FNAME];
+    char ext[_MAX_EXT];
+    wxString strTemp;
+    wxString strApplName;
+    GetModuleFileName(NULL, strTemp.GetBuffer(MAX_INI_BUFFER), MAX_INI_BUFFER);
+    strTemp.ReleaseBuffer();
+    _splitpath(strTemp, drive, dir, fname, ext);
+    //"ApplName":
+    strTemp = fname;
+    //"ApplName.ini":
+    strTemp += ".ini";
+    if (bModulPath)
+    {
+        strApplName = drive;
+        strApplName += dir;
+        strApplName += strTemp;
+    }
+    else
+    {
+        GetCurrentDirectory(MAX_INI_BUFFER, strApplName.GetBuffer(MAX_INI_BUFFER));
+        strApplName.ReleaseBuffer();
+        strApplName.TrimRight('\\');
+        strApplName.TrimRight('/');
+        strApplName += "\\";
+        strApplName += strTemp;
+    }
+    return strApplName;
+#endif
     return "perse";
 }
 
@@ -75,19 +141,22 @@ wxString CIni::GetDefaultSection()
 // Konstruktion/Destruktion
 //////////////////////////////////////////////////////////////////////
 // Creates/Use file : "Drive:\ApplPath\ApplName.ini"
-CIni::CIni(BOOL bModulPath)
+    CIni::CIni(bool bModulPath /*= TRUE*/
+
+):
+m_bModulPath(bModulPath)
 {
-    m_bModulPath = bModulPath;
     m_strFileName = GetDefaultIniFile(m_bModulPath);
     m_strSection = GetDefaultSection();
 }
 
-CIni::CIni(CIni const &Ini, BOOL bModulPath)
+    CIni::CIni(CIni const &Ini, bool bModulPath /*= TRUE*/
+
+):
+m_strFileName(Ini.m_strFileName),
+m_strSection(Ini.m_strSection),
+m_bModulPath(Ini.m_bModulPath)
 {
-    m_strSection = Ini.m_strSection;
-    m_strFileName = Ini.m_strFileName;
-    m_bModulPath = Ini.m_bModulPath;
-   
     if (m_strFileName.IsEmpty())
     m_strFileName = GetDefaultIniFile(m_bModulPath);
     AddModulPath(m_strFileName, m_bModulPath);
@@ -95,7 +164,7 @@ CIni::CIni(CIni const &Ini, BOOL bModulPath)
     m_strSection = GetDefaultSection();
 }
 
-    CIni::CIni(wxString const &strFileName, BOOL bModulPath /*= TRUE*/
+    CIni::CIni(wxString const &strFileName, bool bModulPath /*= TRUE*/
 
 ):
 m_strFileName(strFileName),
@@ -107,7 +176,7 @@ m_bModulPath(bModulPath)
     m_strSection = GetDefaultSection();
 }
 
-    CIni::CIni(wxString const &strFileName, wxString const &strSection, BOOL bModulPath /*= TRUE*/
+    CIni::CIni(wxString const &strFileName, wxString const &strSection, bool bModulPath /*= TRUE*/
 
 ):
 m_strFileName(strFileName),
@@ -182,7 +251,7 @@ wxString const &CIni::GetSection() const
 )
 {
     wxString strDefault;
-    //strDefault.Format("%g",fDefault);
+    //strDefault.Printf("%g",fDefault);
     strDefault = wxString::Format("%g", fDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return atof(m_chBuffer);
@@ -195,7 +264,7 @@ wxString const &CIni::GetSection() const
 )
 {
     wxString strDefault;
-    //strDefault.Format("%g",fDefault);
+    //strDefault.Printf("%g",fDefault);
     strDefault = wxString::Format("%g", fDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(float) atof(m_chBuffer);
@@ -208,7 +277,7 @@ wxString const &CIni::GetSection() const
 )
 {
     wxString strDefault;
-    //strDefault.Format("%d",nDefault);
+    //strDefault.Printf("%d",nDefault);
     strDefault = wxString::Format("%d", nDefault);
     GetLPCSTR(strEntry, strSection, strDefault.GetData());
     return atoi(m_chBuffer);
@@ -221,20 +290,20 @@ wxString const &CIni::GetSection() const
 )
 {
     wxString strDefault;
-    //strDefault.Format("%u",nDefault);
+    //strDefault.Printf("%u",nDefault);
     strDefault = wxString::Format("%u", nDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(WORD) atoi(m_chBuffer);
 }
 
-    BOOL CIni::GetBool(wxString strEntry, BOOL bDefault/* = FALSE*/
+    bool CIni::GetBool(wxString strEntry, bool bDefault/* = FALSE*/
 
     , LPCSTR strSection/* = NULL*/
 
 )
 {
     wxString strDefault;
-    //strDefault.Format("%d",bDefault);
+    //strDefault.Printf("%d",bDefault);
     strDefault = wxString::Format("%d", bDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(atoi(m_chBuffer) != 0);
@@ -245,7 +314,7 @@ wxPoint CIni::GetPoint(wxString strEntry, wxPoint ptDefault, LPCSTR strSection)
     wxPoint ptReturn = ptDefault;
     wxString strDefault;
     strDefault = wxString::Format("(%d,%d)", ptDefault.x, ptDefault.y);
-    //strDefault.Format("(%d,%d)",ptDefault.x, ptDefault.y);
+    //strDefault.Printf("(%d,%d)",ptDefault.x, ptDefault.y);
     wxString strPoint = GetString(strEntry, (char *) strDefault.GetData());
     sscanf(strPoint, "(%d,%d)", &ptReturn.x, &ptReturn.y);
     return ptReturn;
@@ -253,6 +322,20 @@ wxPoint CIni::GetPoint(wxString strEntry, wxPoint ptDefault, LPCSTR strSection)
 
 wxRect CIni::GetRect(wxString strEntry, wxRect rectDefault, LPCSTR strSection)
 {
+#if 0
+    wxRect rectReturn = rectDefault;
+    wxString strDefault;
+    //old version :strDefault.Printf("(%d,%d,%d,%d)",rectDefault.top,rectDefault.left,rectDefault.bottom,rectDefault.right);
+    strDefault.Printf("%d,%d,%d,%d", rectDefault.left, rectDefault.top, rectDefault.right, rectDefault.bottom);
+    wxString strRect = GetString(strEntry, strDefault);
+    int nRead = 0;
+    //new Version found
+    if (4 == sscanf(strRect, "%d,%d,%d,%d", &rectDefault.left, &rectDefault.top, &rectDefault.right, &rectDefault.bottom))
+    return rectReturn;
+    //old Version found
+    sscanf(strRect, "(%d,%d,%d,%d)", &rectReturn.top, &rectReturn.left, &rectReturn.bottom, &rectReturn.right);
+    return rectReturn;
+#endif
     return wxRect(0, 0, 0, 0);
 }
 
@@ -333,7 +416,7 @@ void WritePrivateProfileString(const char *sec, const char *entry, const char *j
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni::WriteBool(wxString strEntry, BOOL b, LPCSTR strSection/* = NULL*/
+    void CIni::WriteBool(wxString strEntry, bool b, LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -358,7 +441,7 @@ void CIni::WriteRect(wxString strEntry, wxRect rect, LPCSTR strSection)
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    //strBuffer.Format("(%d,%d,%d,%d)",rect.top,rect.left,rect.bottom,rect.right);
+    //strBuffer.Printf("(%d,%d,%d,%d)",rect.top,rect.left,rect.bottom,rect.right);
     Write(m_strFileName, m_strSection, strEntry, strBuffer);
 }
 
@@ -382,9 +465,21 @@ wxChar *CIni::GetLPCSTR(wxString strEntry, const wxChar *strSection, const wxCha
     cb->Flush();
     memcpy(m_chBuffer, stringu.GetData(), stringu.Length() + 1);
     return m_chBuffer;
+#if 0
+    // evtl Section neu setzen
+    if (strSection != NULL)
+    m_strSection = strSection;
+    wxString temp;
+    if (strDefault == NULL)
+    temp = Read(m_strFileName, m_strSection, strEntry, wxString());
+    else
+    temp = Read(m_strFileName, m_strSection, strEntry, strDefault);
+    // '+1' damit die Null am Ende mit kopiert wird:
+    return(wxChar *) memcpy(m_chBuffer, (LPCTSTR) temp.GetData(), temp.Length() + 1);
+#endif
 }
 
-void CIni::SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strSection, LPCSTR strDefault)
+void CIni::SerGetString(bool bGet, wxString &str, wxString strEntry, LPCSTR strSection, LPCSTR strDefault)
 {
     if (bGet)
     str = GetString(strEntry, strDefault/*=NULL*/
@@ -395,7 +490,7 @@ void CIni::SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-    void CIni::SerGetDouble(BOOL bGet, double &f, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetDouble(bool bGet, double &f, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , double fDefault/* = 0.0*/
 
@@ -410,7 +505,7 @@ void CIni::SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-    void CIni::SerGetFloat(BOOL bGet, float &f, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetFloat(bool bGet, float &f, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , float fDefault/* = 0.0*/
 
@@ -425,7 +520,7 @@ void CIni::SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-    void CIni::SerGetInt(BOOL bGet, int &n, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetInt(bool bGet, int &n, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , int nDefault/* = 0*/
 
@@ -440,7 +535,7 @@ void CIni::SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-    void CIni::SerGetDWORD(BOOL bGet, DWORD &n, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetDWORD(bool bGet, DWORD &n, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , DWORD nDefault/* = 0*/
 
@@ -455,9 +550,9 @@ void CIni::SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-    void CIni::SerGetBool(BOOL bGet, BOOL &b, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetBool(bool bGet, bool &b, wxString strEntry, LPCSTR strSection/* = NULL*/
 
-    , BOOL bDefault/* = FALSE*/
+    , bool bDefault/* = FALSE*/
 
 )
 {
@@ -470,7 +565,7 @@ void CIni::SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-void CIni::SerGetPoint(BOOL bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection, wxPoint ptDefault)
+void CIni::SerGetPoint(bool bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection, wxPoint ptDefault)
 {
     if (bGet)
     pt = GetPoint(strEntry, ptDefault, strSection);
@@ -478,7 +573,7 @@ void CIni::SerGetPoint(BOOL bGet, wxPoint &pt, wxString strEntry, LPCSTR strSect
     WritePoint(strEntry, pt, strSection);
 }
 
-void CIni::SerGetRect(BOOL bGet, wxRect &rect, wxString strEntry, LPCSTR strSection, wxRect rectDefault)
+void CIni::SerGetRect(bool bGet, wxRect &rect, wxString strEntry, LPCSTR strSection, wxRect rectDefault)
 {
     if (bGet)
     rect = GetRect(strEntry, rectDefault, strSection);
@@ -486,7 +581,7 @@ void CIni::SerGetRect(BOOL bGet, wxRect &rect, wxString strEntry, LPCSTR strSect
     WriteRect(strEntry, rect, strSection);
 }
 
-void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSection, COLORREF crDefault)
+void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSection, COLORREF crDefault)
 {
     if (bGet)
     cr = GetColRef(strEntry, crDefault, strSection);
@@ -496,7 +591,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
 
 // berladene Methoden //////////////////////////////////////////////////////////////////////////////////////////////////77
 // Einfache Typen /////////////////////////////////////////////////////////////////////////////////////////////////////////
-    void CIni::SerGet(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, wxString &str, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , LPCSTR strDefault/*= NULL*/
 
@@ -505,7 +600,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetString(bGet, str, strEntry, strSection, strDefault);
 }
 
-    void CIni::SerGet(BOOL bGet, double &f, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, double &f, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , double fDefault/* = 0.0*/
 
@@ -514,7 +609,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetDouble(bGet, f, strEntry, strSection, fDefault);
 }
 
-    void CIni::SerGet(BOOL bGet, float &f, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, float &f, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , float fDefault/* = 0.0*/
 
@@ -523,7 +618,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetFloat(bGet, f, strEntry, strSection, fDefault);
 }
 
-    void CIni::SerGet(BOOL bGet, int &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, int &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , int nDefault/* = 0*/
 
@@ -532,7 +627,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetInt(bGet, n, strEntry, strSection, nDefault);
 }
 
-    void CIni::SerGet(BOOL bGet, short &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, short &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , int nDefault/* = 0*/
 
@@ -543,7 +638,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     n = nTemp;
 }
 
-    void CIni::SerGet(BOOL bGet, DWORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, DWORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , DWORD nDefault/* = 0*/
 
@@ -552,7 +647,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetDWORD(bGet, n, strEntry, strSection, nDefault);
 }
 
-    void CIni::SerGet(BOOL bGet, WORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, WORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , DWORD nDefault/* = 0*/
 
@@ -563,8 +658,8 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     n = dwTemp;
 }
 
-//	void		SerGet(	BOOL bGet,BOOL		& b,	wxString strEntry,	LPCSTR strSection = NULL,	BOOL bDefault = FALSE);
-    void CIni::SerGet(BOOL bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection/*= NULL*/
+//	void		SerGet(	bool bGet,bool		& b,	wxString strEntry,	LPCSTR strSection = NULL,	bool bDefault = FALSE);
+    void CIni::SerGet(bool bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , wxPoint ptDefault/* = wxPoint(0,0)*/
 
@@ -573,7 +668,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetPoint(bGet, pt, strEntry, strSection, ptDefault);
 }
 
-    void CIni::SerGet(BOOL bGet, wxRect &rect, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, wxRect &rect, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , wxRect rectDefault/* = wxRect(0,0,0,0)*/
 
@@ -582,12 +677,12 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetRect(bGet, rect, strEntry, strSection, rectDefault);
 }
 
-//	void		SerGet(	BOOL bGet,COLORREF	& cr,	wxString strEntry,	LPCSTR strSection = NULL,	COLORREF crDefault = RGB(128,128,128));
+//	void		SerGet(	bool bGet,COLORREF	& cr,	wxString strEntry,	LPCSTR strSection = NULL,	COLORREF crDefault = RGB(128,128,128));
 
 // berladene Methoden ////////////////////////////////////////////////////////////////////////////////////////////
 // ARRAYS /////////////////////////////////////////////////////////////////////////////////////////////////////////
 // Entries werden durch Unterstrich + Index ergenzt////////////////////////////////////////////////////////////////
-    void CIni::SerGet(BOOL bGet, wxString *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, wxString *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , LPCSTR Default/*=NULL*/
 
@@ -621,7 +716,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(BOOL bGet, double *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, double *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , double Default/* = 0.0*/
 
@@ -660,7 +755,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(BOOL bGet, float *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, float *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , float Default/* = 0.0*/
 
@@ -699,7 +794,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(BOOL bGet, int *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, int *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , int Default/* = 0*/
 
@@ -738,7 +833,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(BOOL bGet, unsigned char *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, unsigned char *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , unsigned char Default/* = 0*/
 
@@ -777,7 +872,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(BOOL bGet, short *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, short *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , int Default/* = 0*/
 
@@ -816,7 +911,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(BOOL bGet, DWORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, DWORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , DWORD Default/* = 0*/
 
@@ -855,7 +950,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(BOOL bGet, WORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, WORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , DWORD Default/* = 0*/
 
@@ -894,7 +989,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(BOOL bGet, wxPoint *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, wxPoint *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , wxPoint Default/* = wxPoint(0,0)*/
 
@@ -909,7 +1004,7 @@ void CIni::SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(BOOL bGet, wxRect *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, wxRect *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , wxRect Default/* = wxRect(0,0,0,0)*/
 
