@@ -18,12 +18,10 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "mfc.h"
 #endif
 
-#include "mfc.h"                            // Needed for this Interface's Prototype
-
-#include <wx/listimpl.cpp>                  // Needed for WX_DEFINE_LIST
-
-WX_DEFINE_LIST(stringList)
+//WX_DEFINE_LIST(stringList);
 
