@@ -23,6 +23,11 @@
 #ifndef _OPCODES_H
 #define _OPCODES_H
 
+static const short int MAJOR_VERSION = 1;
+static const short int MINOR_VERSION = 10;
+static const short int RELEASE_VERSION = 0;
+static const short int REVISION_VERSION = 0;
+
 static const short int ET_MOD_VERSION = 0x55;
 // MOD Note: Do not change this part - Merkur
 static const short int CURRENT_VERSION_SHORT = 0x30;
@@ -41,13 +46,13 @@ static const short int MAX_CLIENTCONNECTIONTRY = 2;
 static const long int CONNECTION_TIMEOUT = 40000;       // set his lower if you want less connections at once, set it higher if you have enough sockets (edonkey has its own timout too, so a very high value won't effect this)
 static const long int FILEREASKTIME = 1300000;          // **
 static const long int SERVERREASKTIME = 800000;         // don't set this too low, it wont speed up anything, but it could kill xmule or your internetconnection
-static const long int UDPSERVERREASKTIME = 1300000;     // ***
+static const unsigned long int UDPSERVERREASKTIME = 1300000;     // ***
 static const long int SOURCECLIENTREASK = 600000;
 static const short int MINCOMMONPENALTY = 9;
-static const int UDPSERVERSTATTIME = 5000;
+static const unsigned int UDPSERVERSTATTIME = 5000;
 static const long int UDPSERVSTATREASKTIME = 14400000;
 static const int UDPSERVERPORT = 4665;                  // default udp port
-static const short int MIN_UP_CLIENTS_ALLOWED = 3;      // min. clients allowed to download regardless UPLOAD_CLIENT_DATARATE or any other factors. Don't set this too high
+static const short int MIN_UP_CLIENTS_ALLOWED = 4;      // min. clients allowed to download regardless UPLOAD_CLIENT_DATARATE or any other factors. Don't set this too high
 // MOD Note: end
 
 static const short int MAXCONPER5SEC = 20;
@@ -56,7 +61,7 @@ static const int UPLOAD_CHECK_CLIENT_DR = 1000;
 static const int UPLOAD_LOW_CLIENT_DR = 2400;           // uploadspeed per client in bytes - you may want to adjust this if you have a slow connection or T1-T3 ;)
 static const int UPLOAD_CLIENT_DATARATE = 2048;
 static const short int MAX_UP_CLIENTS_ALLOWED = 100;    // max. clients allowed regardless UPLOAD_CLIENT_DATARATE or any other factors. Don't set this too low, use DATARATE to adjust uploadspeed per client
-static const long int DOWNLOADTIMEOUT = 100000;
+static const unsigned long int DOWNLOADTIMEOUT = 100000;
 static const int CONSERVTIMEOUT = 25000;                // agelimit for pending connection attempts
 static const short int RARE_FILE = 25;
 static const short int BADCLIENTBAN = 3;
@@ -68,8 +73,8 @@ static const int MINWAIT_BEFORE_DLDISPLAY_WINDOWUPDATE = 1000;
 static const int MAXAVERAGETIME = 40000;                //milliseconds
 
 // you shouldn't change anything here if you are not really sure, or xmule will probaly not work
-static const int MAXFRAGSIZE = 1300;
-static const long int PARTSIZE = 9728000;
+static const unsigned int MAXFRAGSIZE = 1300;
+static const unsigned long int PARTSIZE = 9728000;
 static const long int GAPBLOCKSIZE = 184320;
 static const short int OP_EDONKEYPROT = 0xE3;
 static const short int OP_PACKEDPROT = 0xD4;
@@ -77,7 +82,7 @@ static const short int OP_EMULEPROT = 0xC5;
 static const short int OP_MLDONKEYPROT = 0x00;
 static const short int MET_HEADER = 0x0E;
 
-static const long int UNLIMITED = 0xFFFF;
+static const long int UNLIMITED = 0;
 
 // client <-> server
 static const short int OP_LOGINREQUEST = 0x01;          //<HASH 16><ID 4><PORT 2><1 Tag_set>
@@ -232,17 +237,25 @@ static const short int CT_EMULE_VERSION = 0xfb;
 
 enum
 {
-    MP_MESSAGE = 50000,
+// Download enums
+    MP_CANCEL = 50000,
+    MP_STOP,
+    MP_RESUME,
+    MP_RESUME_NEXT,
+    MP_PAUSE,
+    MP_PRIOVERYLOW,
+    MP_PRIOLOW,
+    MP_PRIONORMAL,
+    MP_PRIOHIGH,
+    MP_PRIOVERYHIGH,
+    MP_PRIOAUTO,
+
+    MP_MESSAGE,
     MP_DETAIL,
     MP_ADDFRIEND,
     MP_REMOVEFRIEND,
     MP_SHOWLIST,
     MP_FRIENDSLOT,
-    MP_CANCEL,
-    MP_STOP,
-    MP_RESUME,
-    MP_RESUME_NEXT,
-    MP_PAUSE,
     MP_CLEARCOMPLETED,
     MP_OPEN,
     MP_PREVIEW,
@@ -250,12 +263,6 @@ enum
     MP_CMT,
     MP_SWITCHCTRL,
 
-    MP_PRIOVERYLOW,
-    MP_PRIOLOW,
-    MP_PRIONORMAL,
-    MP_PRIOHIGH,
-    MP_PRIOVERYHIGH,
-    MP_PRIOAUTO,
     MP_GETED2KLINK,
     MP_GETHTMLED2KLINK,
     MP_GETSOURCEED2KLINK,
@@ -274,10 +281,6 @@ enum
     MP_VIEWFILECOMMENTS,
     MP_VERSIONCHECK,
     MP_WEBURL,
-    MP_CAT_ADD,
-    MP_CAT_EDIT,
-    MP_CAT_REMOVE,
-
 // reserve some for weburls!
 
     Irc_Op,
@@ -295,11 +298,9 @@ enum
     Irc_SendLink,
     Irc_SetSendLink,
 
-    MP_ASSIGNCAT,
 // reserve some for categories!
-    MP_SCHACTIONS,
+    MP_SCHACTIONS
 // reserve some for schedules
-    MP_CAT_SET0
 };
 // reserve some for change all-cats (about 20)
 	
@@ -391,7 +392,6 @@ enum
     MP_LISTCOL_14,
     MP_LISTCOL_15,
 
-
   /* Razor 1a - Modif by MikaelB
      Opcodes for :
       - Drop No Needed Sources now
@@ -408,8 +408,14 @@ enum
     MP_CLEAN_UP_SOURCES,
     MP_SWAP_A4AF_TO_THIS,
     MP_SWAP_A4AF_TO_THIS_AUTO,
-    MP_SWAP_A4AF_TO_ANY_OTHER
+    MP_SWAP_A4AF_TO_ANY_OTHER,
+    MP_ASSIGNCAT
 };
   /* End Modif */
   
+enum
+{
+    ID_XMULEDLG
+};
+
 #endif
