@@ -3,35 +3,40 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "otherfunctions.h"
+#	include "PartFile.h"
+#	include "Preferences.h"                 // CPreferences::GetAllinCat
+#	include "resource.h"
+#	include "wintypes.h"                    // BYTE DWORD UINT WORD
+#	include "xmule.h"
 #endif
 
-#include "otherfunctions.h"                 // Needed for this Interface's Prototype
-
-#include "PartFile.h"                       // Needed for CPartFile
-#include "Preferences.h"                    // Needed for CPreferences
-#include "xmule.h"                          // Needed for theApp
-
 #include <map>                              // Needed for std::map
+#include <stdint.h>                         // uint32_t
+#include <wx/utils.h>
 #include <wx/file.h>                        // Needed for wxFile
 
+#include "strings.en"
+
 #define itemsof(x) (sizeof(x)/sizeof(x[0]))
 
 wxString GetResString(unsigned int uStringID)
@@ -51,41 +56,112 @@ wxString GetResString(unsigned int uStringID)
 }
 
 // Base chars for encode an decode functions
-static wxByte base16Chars[17] = "0123456789ABCDEF";
+static BYTE base16Chars[17] = "0123456789ABCDEF";
 
-static wxByte base32Chars[33] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ234567";
+static BYTE base32Chars[33] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ234567";
 
 #define BASE16_LOOKUP_MAX 23
-static wxByte base16Lookup[BASE16_LOOKUP_MAX][2] =
+static BYTE base16Lookup[BASE16_LOOKUP_MAX][2] =
 {
-    { '0', 0x0 },
-    { '1', 0x1 },
-    { '2', 0x2 },
-    { '3', 0x3 },
-    { '4', 0x4 },
-    { '5', 0x5 },
-    { '6', 0x6 },
-    { '7', 0x7 },
-    { '8', 0x8 },
-    { '9', 0x9 },
-    { ':', 0x9 },
-    { ';', 0x9 },
-    { '<', 0x9 },
-    { '=', 0x9 },
-    { '>', 0x9 },
-    { '?', 0x9 },
-    { '@', 0x9 },
-    { 'A', 0xA },
-    { 'B', 0xB },
-    { 'C', 0xC },
-    { 'D', 0xD },
-    { 'E', 0xE },
-    { 'F', 0xF }
-};
+    {
+        '0', 0x0
+    }
+    ,
+    {
+        '1', 0x1
+    }
+    ,
+    {
+        '2', 0x2
+    }
+    ,
+    {
+        '3', 0x3
+    }
+    ,
+    {
+        '4', 0x4
+    }
+    ,
+    {
+        '5', 0x5
+    }
+    ,
+    {
+        '6', 0x6
+    }
+    ,
+    {
+        '7', 0x7
+    }
+    ,
+    {
+        '8', 0x8
+    }
+    ,
+    {
+        '9', 0x9
+    }
+    ,
+    {
+        ':', 0x9
+    }
+    ,
+    {
+        ';', 0x9
+    }
+    ,
+    {
+        '<', 0x9
+    }
+    ,
+    {
+        '=', 0x9
+    }
+    ,
+    {
+        '>', 0x9
+    }
+    ,
+    {
+        '?', 0x9
+    }
+    ,
+    {
+        '@', 0x9
+    }
+    ,
+    {
+        'A', 0xA
+    }
+    ,
+    {
+        'B', 0xB
+    }
+    ,
+    {
+        'C', 0xC
+    }
+    ,
+    {
+        'D', 0xD
+    }
+    ,
+    {
+        'E', 0xE
+    }
+    ,
+    {
+        'F', 0xF
+    }
+}
 
-wxString CastItoXBytes(wxUint64 count)
+;
+
+wxString CastItoXBytes(uint64_t count)
 {
     wxString buffer;
+
     if (count < 1024)
     {
         buffer.Printf("%.0f %s", (float) count, GetResString(IDS_BYTES) .GetData());
@@ -98,7 +174,7 @@ wxString CastItoXBytes(wxUint64 count)
     {
         buffer.Printf("%.2f %s", (float) count/1048576, GetResString(IDS_MBYTES) .GetData());
     }
-    else if (count < 1099511627776LL)
+    else if(count < 1099511627776LL)
     {
         buffer.Printf("%.2f %s", (float) count/1073741824, GetResString(IDS_GBYTES) .GetData());
     }
@@ -106,38 +182,42 @@ wxString CastItoXBytes(wxUint64 count)
     {
         buffer.Printf("%.3f %s", (float) count/1099511627776LL, GetResString(IDS_TBYTES) .GetData());
     }
+
     return buffer;
 }
 
-wxString CastItoIShort(wxUint64 count)
+wxString CastItoIShort(uint64_t count)
 {
     wxString output;
+
     if (count < 1000)
     {
         output.Printf("%i", count);
     }
     else if(count < 1000000)
     {
-        output.Printf("%.0f%s", (float) count/1000, GetResString(IDS_KILO) .GetData());
+        output.Printf("%.0f" + GetResString(IDS_KILO), static_cast<float>(count / 1000));
     }
     else if(count < 1000000000)
     {
-        output.Printf("%.2f%s", (float) count/1000000, GetResString(IDS_MEGA) .GetData());
+        output.Printf("%.2f" + GetResString(IDS_MEGA), static_cast<float>(count / 1000000));
     }
     else if(count < 1000000000000LL)
     {
-        output.Printf("%.2f%s", (float) count/1000000000LL, GetResString(IDS_GIGA) .GetData());
+        output.Printf("%.2f" + GetResString(IDS_GIGA), static_cast<float>(count / 1000000000LL));
     }
     else if(count < 1000000000000000LL)
     {
-        output.Printf("%.2f%s", (float) count/1000000000000LL, GetResString(IDS_TERRA) .GetData());
+        output.Printf("%.2f" + GetResString(IDS_TERRA), static_cast<float>(count / 1000000000000LL));
     }
+
     return output;
 }
 
-wxString CastSecondsToHM(wxInt32 count)
+wxString CastSecondsToHM(int32_t count)
 {
     wxString buffer;
+
     if (count < 0)
     {
         buffer = "?";
@@ -148,20 +228,21 @@ wxString CastSecondsToHM(wxInt32 count)
     }
     else if(count < 3600)
     {
-        buffer.Printf("%i:%s %s", count/60, LeadingZero(count - (count/60) *60) .GetData(), GetResString(IDS_MINS) .GetData());
+        buffer.Printf("%i:%s %s", count / 60, LeadingZero(count - (count/60) *60) .GetData(), GetResString(IDS_MINS) .GetData());
     }
     else if(count < 86400)
     {
-        buffer.Printf("%i:%s %s", count/3600, LeadingZero((count - (count/3600) *3600) /60) .GetData(), GetResString(IDS_HOURS) .GetData());
+        buffer.Printf("%i:%s %s", count  /3600, LeadingZero((count - (count/3600) *3600) /60) .GetData(), GetResString(IDS_HOURS) .GetData());
     }
     else
     {
-        buffer.Printf("%i %s %i %s", count/86400, GetResString(IDS_DAYS) .GetData(), (count - (count/86400) *86400) /3600, GetResString(IDS_HOURS) .GetData());
+        buffer.Printf("%i %s %i %s", count / 86400, GetResString(IDS_DAYS) .GetData(), (count - (count/86400) *86400) /3600, GetResString(IDS_HOURS) .GetData());
     }
+
     return buffer;
 }
 
-wxString LeadingZero(wxUint32 units)
+wxString LeadingZero(uint32_t units)
 {
     wxString temp;
     if (units < 10)
@@ -172,6 +253,7 @@ wxString LeadingZero(wxUint32 units)
     {
         temp.Printf("%i", units);
     }
+
     return temp;
 }
 
@@ -227,7 +309,7 @@ void URLDecode(wxString &result, const char *buff)
         if (buff[x] == '%' &&x + 2 < buflen &&IsHexDigit(buff[x + 1]) &&IsHexDigit(buff[x + 2]))
         {
             char hexstr[3];
-            // Copy the two wxBytes following the %
+            // Copy the two BYTEs following the %
             strncpy(hexstr, &buff[x + 1], 2);
             // Skip over the hex
             x = x + 2;
@@ -248,14 +330,14 @@ wxString URLEncode(wxString sIn)
 {
     wxString sOut;
     const int nLen = sIn.Length() + 1;
-    register wxByte* pOutTmp = NULL;
-    wxByte* pOutBuf = NULL;
-    register wxByte* pInTmp = NULL;
+    register LPBYTE pOutTmp = NULL;
+    LPBYTE pOutBuf = NULL;
+    register LPBYTE pInTmp = NULL;
     //GetData(); //GetBuffer(nLen);:
-    wxByte* pInBuf = (wxByte*) sIn.GetWriteBuf(nLen);
+    LPBYTE pInBuf = (LPBYTE) sIn.GetWriteBuf(nLen);
     //alloc out buffer
-    //GetData(); //GetBuffer(nLen  * 3 - 2);//new wxByte [nLen  * 3];:
-    pOutBuf = (wxByte*) sOut.GetWriteBuf(nLen *3 - 2);
+    //GetData(); //GetBuffer(nLen  * 3 - 2);//new BYTE [nLen  * 3];:
+    pOutBuf = (LPBYTE) sOut.GetWriteBuf(nLen *3 - 2);
     if (pOutBuf)
     {
         pInTmp = pInBuf;
@@ -287,6 +369,11 @@ wxString URLEncode(wxString sIn)
     return sOut;
 }
 
+inline unsigned char toHex(const unsigned char& x)
+{
+    return x > 9 ? x + 55: x + 48;
+}
+
 int GetFTIDbyName(wxString infile)
 {
     int i;
@@ -350,6 +437,10 @@ int GetFTIDbyName(wxString infile)
 wxString GetFiletypeByName(wxString infile)
 {
     wxString ext;
+    // For what was this ???  PLK
+#if 0
+    if (infile.ReverseFind('.') == - 1) return GetResString(IDS_SEARCH_ANY);
+#endif
     // For what is this ??? PLK
     if (infile.Find('.', TRUE) == - 1) return GetResString(IDS_SEARCH_ANY);
     // ext == extension of the filename (Search Result) PLK
@@ -390,16 +481,106 @@ wxString GetFiletypeByName(wxString infile)
 
 wxString MakeStringEscaped(wxString in)
 {
-    in.Replace("&", "&&");
+    in.Replace(wxT("&"), wxT("&&"));
     return in;
 }
 
 bool Ask4RegFix(bool checkOnly)
 {
-    return true;
+#if 0
+    // check registry if ed2k links is assigned to xmule
+    CRegKey regkey;
+    regkey.Create(HKEY_CLASSES_ROOT, "ed2k\\shell\\open\\command");
+    ULONG maxsize = 500;
+    TCHAR rbuffer[500];
+    char modbuffer[490];
+    char regbuffer[520];
+    regkey.QueryStringValue(0, rbuffer, &maxsize);
+    ::GetModuleFileName(0, modbuffer, 490);
+    sprintf(regbuffer, "\"%s\" \"%%1\"", modbuffer);
+    if (strcmp(rbuffer, regbuffer))
+    {
+        if (checkOnly) return true;
+        if (MessageBox(0, GetResString(IDS_ASSIGNED2K), GetResString(IDS_ED2KLINKFIX), MB_ICONQUESTION |MB_YESNO) == IDYES)
+        {
+            regkey.SetStringValue(0, regbuffer);
+            // Added Shrink:
+            regkey.Create(HKEY_CLASSES_ROOT, "ed2k\\DefaultIcon");
+            regkey.SetStringValue(0, modbuffer);
+            regkey.Create(HKEY_CLASSES_ROOT, "ed2k");
+            regkey.SetStringValue(0, "URL: ed2k Protocol");
+            regkey.SetStringValue("URL Protocol", "");
+        }
+    }
+    regkey.Close();
+    return false;
+#endif
 }
 
-wxString GetRateString(wxUint16 rate)
+int GetMaxConnections()
+{
+#if 0
+    OSVERSIONINFOEX osvi;
+    ZeroMemory( &osvi, sizeof(OSVERSIONINFOEX));
+    osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
+    if (!GetVersionEx((OSVERSIONINFO *) &osvi))
+    {
+        //if OSVERSIONINFOEX doesn't work, try OSVERSIONINFO
+        osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
+        if (!GetVersionEx((OSVERSIONINFO *) &osvi))
+        //shouldn't ever happen:
+        return - 1;
+    }
+    // Windows NT product family:
+    if (osvi.dwPlatformId == VER_PLATFORM_WIN32_NT)
+    //no limits:
+    return - 1;
+    if (osvi.dwPlatformId == VER_PLATFORM_WIN32_WINDOWS)
+    {
+        // Windows 95 product family
+        if (osvi.dwMajorVersion == 4 &&osvi.dwMinorVersion == 0)
+        {
+            //old school 95
+            HKEY hKey;
+            DWORD dwValue;
+            DWORD dwLength = sizeof(dwValue);
+            LONG lResult;
+            RegOpenKeyEx(HKEY_LOCAL_MACHINE, "System\\CurrentControlSet\\Services\\VxD\\MSTCP",
+            0, KEY_QUERY_VALUE, &hKey);
+            lResult = RegQueryValueEx(hKey, TEXT("MaxConnections"), NULL, NULL,
+            (LPBYTE) &dwValue, &dwLength);
+            RegCloseKey(hKey);
+            if (lResult != ERROR_SUCCESS || lResult < 1)
+            //the default for 95 is 100:
+            return 100;
+            return dwValue;
+        }
+        else
+        {
+            //98 or ME
+            HKEY hKey;
+            TCHAR szValue[32];
+            DWORD dwLength = sizeof(szValue);
+            LONG lResult;
+            RegOpenKeyEx(HKEY_LOCAL_MACHINE, "System\\CurrentControlSet\\Services\\VxD\\MSTCP",
+            0, KEY_QUERY_VALUE, &hKey);
+            lResult = RegQueryValueEx(hKey, TEXT("MaxConnections"), NULL, NULL,
+            (LPBYTE) szValue, &dwLength);
+            RegCloseKey(hKey);
+            LONG lMaxConnections;
+            if (lResult != ERROR_SUCCESS || (lMaxConnections = atoi(szValue)) < 1)
+            //the default for 98/ME is 100:
+            return 100;
+            return lMaxConnections;
+        }
+    }
+    //give the user the benefit of the doubt, most use NT+ anyway:
+    return - 1;
+#endif
+    return - 1;
+}
+
+wxString GetRateString(uint16_t rate)
 {
     switch (rate)
     {
@@ -425,29 +606,34 @@ wxString GetRateString(wxUint16 rate)
     return GetResString(IDS_CMT_NOTRATED);
 }
 
-// Returns a BASE32 encoded wxByte array
+// Returns a BASE32 encoded BYTE array
 //
 // [In]
-//   buffer: Pointer to wxByte array
+//   buffer: Pointer to BYTE array
 //   bufLen: Lenght of buffer array
 //
 // [Return]
-//   wxString object with BASE32 encoded wxByte array
+//   wxString object with BASE32 encoded BYTE array
 wxString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
 {
     wxString Base32Buff;
     unsigned int i, index;
     unsigned char word;
+
     for (i = 0, index = 0 ; i < bufLen ;)
     {
-        // Is the current word going to span a wxByte boundary?
+        // Is the current word going to span a BYTE boundary?
         if (index > 3)
         {
             word = (buffer[i] & (0xFF >> index));
             index = (index + 5) % 8;
             word <<= index;
+
             if (i < bufLen - 1)
-            word |= buffer[i + 1] >> (8 - index);
+            {
+                word |= buffer[i + 1] >> (8 - index);
+            }
+
             i++;
         }
         else
@@ -455,48 +641,54 @@ wxString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
             word = (buffer[i] >> (8 - (index + 5))) &0x1F;
             index = (index + 5) % 8;
             if (index == 0)
-            i++;
+            {
+                i++;
+            }
         }
-        Base32Buff += (char) base32Chars[word];
+
+        Base32Buff += (char)base32Chars[word];
     }
+
     return Base32Buff;
 }
 
-// Returns a BASE16 encoded wxByte array
+// Returns a BASE16 encoded BYTE array
 //
 // [In]
-//   buffer: Pointer to wxByte array
+//   buffer: Pointer to BYTE array
 //   bufLen: Lenght of buffer array
 //
 // [Return]
-//   wxString object with BASE16 encoded wxByte array
+//   wxString object with BASE16 encoded BYTE array
 wxString EncodeBase16(const unsigned char *buffer, unsigned int bufLen)
 {
     wxString Base16Buff;
-    for (unsigned int i = 0 ; i < bufLen ; i++)
+
+    for (unsigned int i = 0; i < bufLen; ++i)
     {
         Base16Buff += base16Chars[buffer[i] >> 4];
         Base16Buff += base16Chars[buffer[i] &0xf];
     }
+
     return Base16Buff;
 }
 
-// Decodes a BASE16 string into a wxByte array
+// Decodes a BASE16 string into a BYTE array
 //
 // [In]
 //   base16Buffer: String containing BASE16
 //   base16BufLen: Lenght BASE16 coded string's length
 //
 // [Out]
-//   buffer: wxByte array containing decoded string
-void DecodeBase16(const char *base16Buffer, unsigned int base16BufLen, wxByte *buffer)
+//   buffer: BYTE array containing decoded string
+void DecodeBase16(const char *base16Buffer, unsigned int base16BufLen, BYTE *buffer)
 {
     memset(buffer, 0, DecodeLengthBase16(base16BufLen));
     for (unsigned int i = 0 ; i < base16BufLen ; i++)
     {
         int lookup = toupper(base16Buffer[i]) - '0';
         // Check to make sure that the given word falls inside a valid range
-        wxByte word = 0;
+        BYTE word = 0;
         if (lookup < 0 || lookup >= BASE16_LOOKUP_MAX)
         word = 0xFF;
         else
@@ -518,33 +710,69 @@ void DecodeBase16(const char *base16Buffer, unsigned int base16BufLen, wxByte *b
 //   base16Length: Actual length of BASE16 string
 //
 // [Return]
-//   New length of wxByte array decoded
+//   New length of BYTE array decoded
 int DecodeLengthBase16(int base16Length)
 {
     return base16Length / 2;
 }
 
+#if 0
+void UpdateURLMenu(CMenu &menu, int &counter)
+{
+    counter = 0;
+    theApp.webservices.RemoveAll();
+    wxString name, url, sbuffer;
+    char buffer[1024];
+    int lenBuf = 1024;
+    FILE *readFile = fopen(wxString(theApp.glob_prefs->GetAppDir()) + "webservices.dat", "r");
+    if (readFile != NULL)
+    {
+        while (!feof(readFile))
+        {
+            if (fgets(buffer, lenBuf, readFile) == 0) break;
+            sbuffer = buffer;
+            // ignore comments & too short lines
+            if (sbuffer.GetAt(0) == '#' || sbuffer.GetAt(0) == '/' || sbuffer.GetLength() < 5)
+            continue;
+            int pos = sbuffer.Find(',');
+            if (pos > 0)
+            {
+                counter++;
+                menu.AppendMenu(MF_STRING, MP_WEBURL + (counter - 1), sbuffer.Left(pos) .Trim());
+                theApp.webservices.Add(sbuffer.Right(sbuffer.GetLength() - pos - 1) .Trim());
+            }
+        }
+        fclose(readFile);
+    }
+}
+
+#endif
+
+void RunURL(CAbstractFile *file, wxString urlpattern)
+{
+}
+
 wxString GetCatTitle(int catid)
 {
     switch (catid)
     {
-    case 0: return GetResString(IDS_ALL);
-    case 1: return GetResString(IDS_ALLOTHERS);
-    case 2: return GetResString(IDS_STATUS_NOTCOMPLETED);
-    case 3: return GetResString(IDS_DL_TRANSFCOMPL);
-    case 4: return GetResString(IDS_WAITING);
-    case 5: return GetResString(IDS_DOWNLOADING);
-    case 6: return GetResString(IDS_ERRORLIKE);
-    case 7: return GetResString(IDS_PAUSED);
-    case 8: return GetResString(IDS_STOPPED);
-    case 9: return GetResString(IDS_VIDEO);
-    case 10: return GetResString(IDS_AUDIO);
-    case 11: return GetResString(IDS_SEARCH_ARC);
-    case 12: return GetResString(IDS_SEARCH_CDIMG);
-    case 13: return GetResString(IDS_SEARCH_PICS);
-    case 14: return GetResString(IDS_TEXT);
+        case 0: return GetResString(IDS_ALL);
+        case 1: return GetResString(IDS_ALLOTHERS);
+        case 2: return GetResString(IDS_STATUS_NOTCOMPLETED);
+        case 3: return GetResString(IDS_DL_TRANSFCOMPL);
+        case 4: return GetResString(IDS_WAITING);
+        case 5: return GetResString(IDS_DOWNLOADING);
+        case 6: return GetResString(IDS_ERRORLIKE);
+        case 7: return GetResString(IDS_PAUSED);
+        case 8: return GetResString(IDS_STOPPED);
+        case 9: return GetResString(IDS_VIDEO);
+        case 10: return GetResString(IDS_AUDIO);
+        case 11: return GetResString(IDS_SEARCH_ARC);
+        case 12: return GetResString(IDS_SEARCH_CDIMG);
+        case 13: return GetResString(IDS_SEARCH_PICS);
+        case 14: return GetResString(IDS_TEXT);
     }
-    return wxString("?");
+    return "?";
 }
 
 bool CheckShowItemInGivenCat(CPartFile *file, int inCategory)
@@ -630,24 +858,39 @@ bool CheckShowItemInGivenCat(CPartFile *file, int inCategory)
     return(IsNotFiltered &&IsInCat);
 }
 
-void MakeFoldername(char *path)
+#ifdef __FreeBSD__
+long long atoll(char *s)
 {
-    wxString string(path);
-    if (string.Length() > 0) if(string.Right(1) == '\\') string = string.Left(string.Length() - 1);
-    sprintf(path, "%s", string.GetData());
+    return strtoll(s, (char **) NULL, 10);
+}
+
+#endif /* __FreeBSD__ */
+
+void MakeFoldername(wxString& path)
+{
+    int length = path.length();
+    if (length <= 0)
+    {
+        return;
+    }
+    
+    if (path.Right(1) == '/')
+    {
+        path = path.Left(length - 1);
+    }
 }
 
 void HexDump(const void *buffer, unsigned long buflen)
 {
 #if defined(__DEBUG__)
-    const wxUint8 *cbuf = (const wxUint8 *) buffer;
+    const uint8_t *cbuf = (const uint8_t *) buffer;
     for (unsigned long ofs = 0 ; ofs < buflen ; /* no increment here */
     )
     {
         printf("%08lx", ofs);
         for (unsigned long i = 0 ; (i < 8) && (ofs < buflen) ; i++, ofs++)
         {
-            printf(" %02x", (int)cbuf[ofs]);
+            printf(" %02x", (int) cbuf[ofs]);
         }
         printf("\n");
     }
@@ -678,16 +921,13 @@ bool BackupFile(const wxString &filename, const wxString &appendix)
 bool SafeCopyFile(const wxString &file1, const wxString &file2)
 {
     wxFile fileIn(file1, wxFile::read);
-
     if (!fileIn.IsOpened())
     {
-        // for copying it the file could be open too!!
-        return FALSE;
+        //		return FALSE;// for copying it the file could be open too!!
     }
     wxFile fileOut(file2, wxFile::write);
     char buf[4096];
     size_t count;
-
     while (true)
     {
         count = fileIn.Read(buf, WXSIZEOF(buf));
@@ -704,12 +944,10 @@ bool SafeCopyFile(const wxString &file1, const wxString &file2)
             return FALSE;
         }
     }
-
     if (!fileIn.Close() || !fileOut.Close())
     {
         return FALSE;
     }
-
     return TRUE;
 }
 
