@@ -22,13 +22,15 @@
 #ifndef PACKETS_H
 #define PACKETS_H
 
-#include "types.h"
-#include "opcodes.h"
-#include "otherstructs.h"
-#include "CFile.h"
+#include "opcodes.h"                        // OP_EDONKEYPROT - audited 5 Nov 2004
+#include "wintypes.h"                       // UINT - audited 4 Nov 2004
 
-#include <exception>
+#include <cstdio>                           // FILE
+#include <exception>                        // std::exception
+#include <stdint.h>                         // uint32_t
 
+class CFile;
+class CMemFile;
 struct Packet_int;
 
 //          CLIENT TO SERVER
@@ -37,30 +39,31 @@ struct Packet_int;
 class Packet
 {
 public:
-    Packet(const uint8 protocol = OP_EDONKEYPROT);
+    Packet(const uint8_t protocol = OP_EDONKEYPROT);
     Packet(const char* header); // only used for receiving packets
-    Packet(const char* type, const char* pPacketPart, const uint32 nSize, const bool bLast, const bool bFromPF = true);//only used for spl. packets!
-    Packet(const char* type, const int8 in_opcode, const int32 in_size, const uint8 protocol = OP_EDONKEYPROT, const bool bFromPF = true);
-    Packet(const char* pPacketPart, const uint32 nSize, const bool bLast); // only used for splitted packets!
-    Packet(const int8 in_opcode, const int32 in_size, const uint8 protocol, const unsigned char* buffer);
-    Packet(const int8 in_opcode, const int32 in_size, const uint8 protocol = OP_EDONKEYPROT);
-    Packet(CMemFile* datafile, const uint8 protocol = OP_EDONKEYPROT);
-    //Packet(int8 in_opcode,CMemFile* datafile,uint8 protocol = OP_EDONKEYPROT);
+    Packet(const char* type, const char* pPacketPart, const uint32_t nSize, const bool bLast, const bool bFromPF = true);//only used for spl. packets!
+    Packet(const char* type, const int8_t in_opcode, const uint32_t in_size, const uint8_t protocol = OP_EDONKEYPROT, const bool bFromPF = true);
+    Packet(const char* pPacketPart, const uint32_t nSize, const bool bLast); // only used for splitted packets!
+
+    Packet(const int8_t in_opcode, const uint32_t in_size, const uint8_t protocol, const unsigned char* buffer);
+    Packet(const int8_t in_opcode, const uint32_t in_size, const uint8_t protocol = OP_EDONKEYPROT);
+    Packet(CMemFile* datafile, const uint8_t protocol = OP_EDONKEYPROT);
+    //Packet(int8_t in_opcode,CMemFile* datafile,uint8_t protocol = OP_EDONKEYPROT);
 
     ~Packet();
     char* GetHeader();
     char* GetUDPHeader();
     char* GetPacket();
     char* DetachPacket();
-    uint32  GetRealPacketSize()     {return size+6;}
+    uint32_t  GetRealPacketSize()     {return size+6;}
     bool IsSplitted() const;
     bool IsLastSplitted() const;
     void    PackPacket();
     bool    UnPackPacket(UINT uMaxDecompressedSize = 50000);
     char*   pBuffer;
-    uint32  size;
-    uint8   opcode;
-    uint8   prot;
+    uint32_t  size;
+    uint8_t   opcode;
+    uint8_t   prot;
     // -khaos--+++> Returns either -1, 0 or 1.  -1 is unset, 0 is from complete file, 1 is from part file
     
     bool IsFromPF() const;
@@ -71,11 +74,11 @@ private:
 };
 
 struct Tag_Struct{
-    int8    type;
+    int8_t    type;
     char*   tagname;
     char*   stringvalue;
-    uint32  intvalue;
-    int8    specialtag;
+    uint32_t  intvalue;
+    int8_t    specialtag;
 
 };
 
@@ -106,10 +109,10 @@ enum TTagType
 
 class CTag {
 public:
-    CTag(char* name,uint32 intvalue);
-    CTag(int8 special, uint32 intvalue);
+    CTag(char* name,uint32_t intvalue);
+    CTag(int8_t special, uint32_t intvalue);
     CTag(char* name,char* strvalue);
-    CTag(int8 special, char* strvalue);
+    CTag(int8_t special, char* strvalue);
     CTag(Tag_Struct* in_tag);
     CTag(CFile* in_data);
     CTag(CMemFile* in_data);
