@@ -3,56 +3,61 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "ListenSocket.h"
+#	include "opcodes.h"
+#include "packets.h"                        // Packet
+#include "Preferences.h"                    // CPreferences::GetUseHash
+#	include "SearchDlg.h"
+#	include "SearchList.h"
+#include "ServerList.h"                     // CServerList
+#include "ServerListCtrl.h"                 // CServerListCtrl - audited 5 Nov 2004
+#	include "ServerSocket.h"
+#	include "ServerWnd.h"
+#	include "SharedFileList.h"
+#	include "sockets.h"
+#	include "SysTray.h"
+#	include "UDPSocket.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
 #endif
 
-#include "sockets.h"                        // Needed for this Interface's Prototype
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
-#include "CMemFile.h"                       // Needed for CMemFile
-#include "ListenSocket.h"                   // Needed for CListenSocket
-#include "otherfunctions.h"                 // Needed for GetResString
-#include "packets.h"                        // Needed for Packet
-#include "Preferences.h"                    // Needed for CPreferences
-#include "SearchDlg.h"                      // Needed for CSearchDlg
-#include "server.h"                         // Needed for CServer
-#include "ServerList.h"                     // Needed for CServerList
-#include "ServerListCtrl.h"                 // Needed for CServerListCtrl
-#include "ServerSocket.h"                   // Needed for CServerSocket
-#include "ServerWnd.h"                      // Needed for CServerWnd
-#include "SharedFileList.h"                 // Needed for CSharedFileList
-#include "SysTray.h"                        // Needed for TBN_IMPORTANTEVENT
-#include "UDPSocket.h"                      // Needed for CUDPSocket
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+#include <ctime>
+#include <iostream>                         // Needed for std::cout std::endl
 
-#include <net/if.h>                         // Needed for ifreq
-#include <sys/ioctl.h>                      // Needed for SIOCGIFADDR
+using std::cout;
+using std::endl;
+using std::map;
 
 void CServerConnect::TryAnotherConnectionrequest()
 {
-    if (connectionattemps.GetCount() < ((app_prefs->IsSafeServerConnectEnabled()) ? 1: 2))
+    if (connectionattempts.size() < (theApp.dynprefs->Get<bool>("use-safe-connect") ? 1 : 2))
     {
-        CServer *next_server = used_list->GetNextServer();
-        if (!next_server)
+        CServer* next_server = used_list->GetNextServer();
+
+        if (next_server == NULL)
         {
-            if (connectionattemps.GetCount() == 0)
+            if (connectionattempts.empty() == true)
             {
                 theApp.xmuledlg->AddLogLine(true, GetResString(IDS_OUTOFSERVERS));
                 ConnectToAnyServer(lastStartAt);
@@ -61,7 +66,7 @@ void CServerConnect::TryAnotherConnectionrequest()
         else
         {
             // Barry - Only auto-connect to static server option
-            if (theApp.glob_prefs->AutoConnectStaticOnly())
+            if (theApp.dynprefs->Get<bool>("auto-static") == true)
             {
                 if (next_server->IsStaticMember())
                 {
@@ -76,7 +81,7 @@ void CServerConnect::TryAnotherConnectionrequest()
     }
 }
 
-void CServerConnect::ConnectToAnyServer(wxUint32 startAt, bool prioSort, bool isAuto)
+void CServerConnect::ConnectToAnyServer(uint32_t startAt, bool prioSort, bool isAuto)
 {
     lastStartAt = startAt;
     StopConnectionTry();
@@ -85,7 +90,7 @@ void CServerConnect::ConnectToAnyServer(wxUint32 startAt, bool prioSort, bool is
     connecting = true;
     singleconnecting = false;
     // Barry - Only auto-connect to static server option
-    if (theApp.glob_prefs->AutoConnectStaticOnly() &&isAuto)
+    if ((theApp.dynprefs->Get<bool>("auto-static") == true) && isAuto)
     {
         bool anystatic = false;
         CServer *next_server;
@@ -106,7 +111,10 @@ void CServerConnect::ConnectToAnyServer(wxUint32 startAt, bool prioSort, bool is
         }
     }
     used_list->SetServerPosition(startAt);
-    if (theApp.glob_prefs->Score() &&prioSort) used_list->Sort();
+    if ((theApp.dynprefs->Get<bool>("priority-system") == true) && prioSort)
+    {
+        used_list->Sort();
+    }
     if (used_list->GetServerCount() == 0)
     {
         connecting = false;
@@ -126,17 +134,16 @@ void CServerConnect::ConnectToServer(CServer *server, bool multiconnect)
     }
     connecting = true;
     singleconnecting =!multiconnect;
-    CServerSocket *newsocket = new CServerSocket(this);
+    CServerSocket* newsocket = new CServerSocket(this);
     m_lstOpenSockets.AddTail((void *&) newsocket);
     //newsocket->Create(0,SOCK_STREAM,FD_READ|FD_WRITE|FD_CLOSE|FD_CONNECT,NULL);
     newsocket->ConnectToServer(server);
-    unsigned long x = GetTickCount();
-    connectionattemps.SetAt(x, newsocket);
+    connectionattempts[GetTickCount()] = newsocket;
 }
 
 void CServerConnect::StopConnectionTry()
 {
-    connectionattemps.RemoveAll();
+    connectionattempts.clear();
     connecting = false;
     singleconnecting = false;
     if (m_idRetryTimer.IsRunning())
@@ -174,17 +181,17 @@ void CServerConnect::ConnectionEstablished(CServerSocket *sender)
         }
         CMemFile *data = new CMemFile();
         data->Write(theApp.glob_prefs->GetUserHash(), 16);
-        wxUint32 clientid = GetClientID();
+        uint32_t clientid = GetClientID();
         data->Write( &clientid, 4);
-        wxUint16 port = app_prefs->GetPort();
+        uint16_t port = static_cast<uint16_t>(theApp.dynprefs->Get<long>("tcp-port"));
         data->Write( &port, 2);
-        wxUint32 tagcount = 4;
+        uint32_t tagcount = 4;
         data->Write( &tagcount, 4);
-        CTag tagName(CT_NAME, app_prefs->GetUserNick());
+        CTag tagName(CT_NAME, const_cast<char *>(theApp.dynprefs->Get<wxString>("nickname").c_str()));
         tagName.WriteTagToFile(data);
         CTag tagVersion(CT_VERSION, EDONKEYVERSION);
         tagVersion.WriteTagToFile(data);
-        CTag tagPort(CT_PORT, app_prefs->GetPort());
+        CTag tagPort(CT_PORT, static_cast<uint16_t>(theApp.dynprefs->Get<long>("tcp-port")));
         tagPort.WriteTagToFile(data);
         // I am zlib aware! :-):
         CTag tagFlags(0x20, 0x00000001);
@@ -192,8 +199,9 @@ void CServerConnect::ConnectionEstablished(CServerSocket *sender)
         Packet *packet = new Packet(data);
         packet->opcode = OP_LOGINREQUEST;
         SendPacket(packet, true, sender);
+        delete data;
     }
-    else if(sender->GetConnectionState() == CS_CONNECTED)
+    else if (sender->GetConnectionState() == CS_CONNECTED)
     {
         theApp.stat_reconnects++;
         theApp.stat_serverConnectTime = GetTickCount();
@@ -205,7 +213,7 @@ void CServerConnect::ConnectionEstablished(CServerSocket *sender)
         theApp.sharedfiles->SendListToServer();
         theApp.xmuledlg->serverwnd->serverlistctrl->RemoveDeadServer();
         // tecxx 1609 2002 - serverlist update
-        if (theApp.glob_prefs->AddServersFromServer())
+        if (theApp.dynprefs->Get<bool>("add-server-server"))
         {
             Packet *packet = new Packet(OP_GETSERVERLIST, 0);
             SendPacket(packet, true);
@@ -215,7 +223,6 @@ void CServerConnect::ConnectionEstablished(CServerSocket *sender)
 
 bool CServerConnect::SendPacket(Packet *packet, bool delpacket, CServerSocket *to)
 {
-//pckfilter(packet->opcode,packet,packet->size);
     if (!to)
     {
         if (connected)
@@ -234,7 +241,6 @@ bool CServerConnect::SendPacket(Packet *packet, bool delpacket, CServerSocket *t
 
 bool CServerConnect::SendUDPPacket(Packet *packet, CServer *host, bool delpacket)
 {
-//pckfilter(packet->opcode,packet,packet->size);
     //printf("CServerConnect::SendUDPPacket opcode=0x%02x size=%u\n", packet->opcode, packet->size);
     if (connected)
     {
@@ -285,9 +291,9 @@ void CServerConnect::ConnectionFailed(CServerSocket *sender)
         {
         case CS_FATALERROR:
             {
-                bool autoretry =!singleconnecting;
+                bool autoretry = !singleconnecting;
                 StopConnectionTry();
-                if ((app_prefs->Reconnect()) && (autoretry) && (!m_idRetryTimer.IsRunning()))
+                if ((theApp.dynprefs->Get<bool>("reconnect-on-loss") == true) && (autoretry) && (!m_idRetryTimer.IsRunning()))
                 {
                     theApp.xmuledlg->AddLogLine(false, GetResString(IDS_RECONNECT), CS_RETRYCONNECTTIME);
                     //m_idRetryTimer= SetTimer(NULL, 0, 1000*CS_RETRYCONNECTTIME, (TIMERPROC)RetryConnectCallback);
@@ -306,7 +312,7 @@ void CServerConnect::ConnectionFailed(CServerSocket *sender)
                 wxCommandEvent evt;
                 theApp.xmuledlg->searchwnd->ButtonCancel(evt);
                 //			printf("Reconn %d conn %d\n",app_prefs->Reconnect(),connecting);
-                if (app_prefs->Reconnect() && !connecting)
+                if (theApp.dynprefs->Get<bool>("reconnect-on-loss") && !connecting)
                 {
                     ConnectToAnyServer();
                 }
@@ -334,18 +340,25 @@ void CServerConnect::ConnectionFailed(CServerSocket *sender)
                     StopConnectionTry();
                     break;
                 }
-                DWORD tmpkey;
-                CServerSocket *tmpsock;
-                POSITION pos = connectionattemps.GetStartPosition();
-                while (pos)
+
+                CServerSocket* tmpsock;
+
+                map<uint32_t, CServerSocket *>::iterator it;
+                it = connectionattempts.begin();
+
+                while (it != connectionattempts.end())
                 {
-                    connectionattemps.GetNextAssoc(pos, tmpkey, tmpsock);
+                    tmpsock = it->second;
+
                     if (tmpsock == sender)
                     {
-                        connectionattemps.RemoveKey(tmpkey);
+                        connectionattempts.erase(it->first);
+                        delete tmpsock;
                         break;
                     }
+                    ++it;
                 }
+
                 TryAnotherConnectionrequest();
             }
         }
@@ -357,24 +370,32 @@ void CServerConnect::CheckForTimeout()
 {
     DWORD maxage = GetTickCount() - CONSERVTIMEOUT;
     DWORD tmpkey;
-    CServerSocket *tmpsock;
-    POSITION pos = connectionattemps.GetStartPosition();
-    while (pos)
+    CServerSocket* tmpsock;
+
+    map<uint32_t, CServerSocket *>::iterator it;
+    it = connectionattempts.begin();
+
+    while (it != connectionattempts.end())
     {
-        connectionattemps.GetNextAssoc(pos, tmpkey, tmpsock);
+        tmpkey = it->first;
+        tmpsock = it->second;
+
         if (!tmpsock)
         {
             theApp.xmuledlg->AddLogLine(false, "Error: Socket invalid at timeoutcheck");
-            connectionattemps.RemoveKey(tmpkey);
-            return;
+            connectionattempts.erase(it++);
+            continue;
         }
-        if (tmpkey <= maxage)
+        else if (tmpkey <= maxage)
         {
             theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_CONTIMEOUT), tmpsock->info.GetData(), tmpsock->cur_server->GetFullIP(), tmpsock->cur_server->GetPort());
-            connectionattemps.RemoveKey(tmpkey);
+            connectionattempts.erase(it++);
             TryAnotherConnectionrequest();
             DestroySocket(tmpsock);
+            continue;
         }
+
+        ++it;
     }
 }
 
@@ -387,6 +408,7 @@ bool CServerConnect::Disconnect()
         connected = false;
         theApp.xmuledlg->ShowConnectionState(false, "");
         theApp.stat_serverConnectTime = 0;
+        //theApp.xmuledlg->serverwnd->servermsgbox.AppendText(wxString("\n\n\n\n"));
         return true;
     }
     else
@@ -398,16 +420,17 @@ CServerConnect::CServerConnect(CServerList *in_serverlist, CPreferences *in_pref
     connectedsocket = NULL;
     app_prefs = in_prefs;
     used_list = in_serverlist;
-    max_simcons = (app_prefs->IsSafeServerConnectEnabled()) ? 1: 2;
+    max_simcons = (theApp.dynprefs->Get<bool>("use-safe-connect")) ? 1 : 2;
     connecting = false;
     connected = false;
     clientid = 0;
     singleconnecting = false;
     wxIPV4address tmp;
     tmp.AnyAddress();
-    tmp.Service(theApp.glob_prefs->GetPort() + 10);
+    tmp.Service(static_cast<uint16_t>(theApp.dynprefs->Get<long>("tcp-port")) + 10);
     // initalize socket for udp packets:
     udpsocket = new CUDPSocket(this, tmp);
+    //udpsocket->Create();
     m_idRetryTimer.SetOwner(theApp.xmuledlg, 4333);
     lastStartAt = 0;
     InitLocalIP();
@@ -417,6 +440,15 @@ CServerConnect::CServerConnect(CServerList *in_serverlist, CPreferences *in_pref
 
 CServerConnect::~CServerConnect()
 {
+/*  K...I have *no* idea how this got here or what I was thinking...it causes crashes, so it's gone.
+    for (POSITION pos = m_lstOpenSockets.GetHeadPosition() ; pos != NULL ;)
+    {
+        CServerSocket* tmp((CServerSocket *)m_lstOpenSockets.GetNext(pos));
+        m_lstOpenSockets.RemoveAt(pos);
+        tmp->Destroy();
+        delete tmp;
+    }
+*/
     m_idRetryTimer.Stop();
     StopConnectionTry();
     DestroySocket(connectedsocket);
@@ -436,7 +468,7 @@ CServer *CServerConnect::GetCurrentServer()
     }
 }
 
-void CServerConnect::SetClientID(wxUint32 newid)
+void CServerConnect::SetClientID(uint32_t newid)
 {
     clientid = newid;
     theApp.xmuledlg->ShowConnectionState(IsConnected(), GetCurrentServer()->GetListName());
@@ -456,6 +488,8 @@ void CServerConnect::DestroySocket(CServerSocket *pSck)
             }
         }
         pSck->Destroy();
+        delete pSck;
+        pSck = NULL;
     }
 }
 
@@ -473,6 +507,7 @@ void CServerConnect::InitLocalIP()
         {
             memcpy( &sin, &ifr.ifr_addr, sizeof(struct sockaddr));
             m_nLocalIP = sin.sin_addr.s_addr;
+            cout << "Local IP: " << m_nLocalIP << endl;
         }
         else
         {
@@ -493,7 +528,7 @@ void CServerConnect::InitLocalIP()
     }
 }
 
-bool CServerConnect::IsLocalServer(wxUint32 dwIP, wxUint16 nPort)
+bool CServerConnect::IsLocalServer(uint32_t dwIP, uint16_t nPort)
 {
     if (IsConnected())
     {
