@@ -3,7 +3,7 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -24,8 +24,8 @@
 #ifndef _SOCKETS_H
 #define _SOCKETS_H
 
-#include "mfc.h"                            // Needed for CTypedPtrList
-
+#include <map>                              // Needed for std::map
+#include <stdint.h>                         // Needed for uint32_t
 #include <wx/timer.h>                       // Needed for wxTimer
 
 #define CS_FATALERROR	-5
@@ -39,15 +39,14 @@
 #define	CS_WAITFORLOGIN	3
 #define CS_RETRYCONNECTTIME  30 // seconds
 
-class CUDPSocket;
-class Packet;
 class CPreferences;
 class CServer;
 class CServerList;
 class CServerSocket;
+class CUDPSocket;
+class Packet;
 
-class CServerConnect
-{
+class CServerConnect{
 public:
 	CServerConnect(CServerList* in_serverlist, CPreferences* in_prefs);
 	~CServerConnect();
@@ -55,9 +54,10 @@ public:
 	void	ConnectionEstablished(CServerSocket* sender);
 	
 	void	ConnectToAnyServer() {ConnectToAnyServer(0,true,true);}
-	void	ConnectToAnyServer(wxUint32 startAt,bool prioSort=false,bool isAuto=true);
+	void	ConnectToAnyServer(uint32_t startAt,bool prioSort=false,bool isAuto=true);
 	void	ConnectToServer(CServer* toconnect, bool multiconnect=false);
 	void	StopConnectionTry();
+	//static  VOID CALLBACK RetryConnectCallback(HWND hWnd, UINT nMsg, UINT nId, DWORD dwTime);
 
 	void	CheckForTimeout();
 	void	DestroySocket(CServerSocket* pSck);	// safe socket closure and destruction
@@ -68,11 +68,11 @@ public:
 	bool	IsConnected()	{return connected;}
 	wxUint32	GetClientID()		{return clientid;}
 	CServer*	GetCurrentServer();
-	wxUint32	clientid;
-	wxUint8	pendingConnects;
+	uint32_t	clientid;
+	uint8_t	pendingConnects;
 	bool	IsLowID()		{return (clientid < 16777216);}
-	void	SetClientID(wxUint32 newid);
-	bool	IsLocalServer(wxUint32 dwIP, wxUint16 nPort);
+	void	SetClientID(uint32_t newid);
+	bool	IsLocalServer(uint32_t dwIP, uint16_t nPort);
 	void	TryAnotherConnectionrequest();
 	bool	IsSingleConnect()	{return singleconnecting;}
 	void	InitLocalIP();
@@ -82,17 +82,18 @@ private:
 	bool	connecting;
 	bool	singleconnecting;
 	bool	connected;
-	wxInt8	max_simcons;
-	wxUint32 lastStartAt;
+	int8_t	max_simcons;
+	uint32_t lastStartAt;
 	CPreferences*	app_prefs;
 	CServerSocket*	connectedsocket;
 	CServerList*	used_list;
 	CUDPSocket*		udpsocket;
 	CTypedPtrList<CPtrList,void*>		m_lstOpenSockets;	// list of currently opened sockets
+	//UINT			m_idRetryTimer;
 	wxTimer m_idRetryTimer;
 	wxUint32 	m_nLocalIP;
 
-	CMap<unsigned long, unsigned long&, CServerSocket*, CServerSocket*> connectionattemps;
+	std::map<uint32_t, CServerSocket *> connectionattempts;
 // Added by sivka [Tarod: Tries after a LowID connection]
 public: 
 	void	ResetLowIDTries() {m_lowid_tries = 0;}
