@@ -20,18 +20,15 @@
 #ifndef _WINTYPES_H
 #define _WINTYPES_H
 
-#include <stdint.h>                         // Needed for uint64_t
-
 typedef unsigned int UINT;
 typedef UINT* UINT_PTR;
 
 typedef char* LPCSTR;
 typedef unsigned char BYTE;
 typedef unsigned long DWORD;
-typedef unsigned long BOOL;
 typedef signed long LONG;
 typedef unsigned long ULONG;
-typedef uint64_t ULONGLONG;
+typedef unsigned long long ULONGLONG;
 typedef BYTE* LPBYTE;
 typedef int INT;
 typedef unsigned short WORD;
