@@ -25,7 +25,6 @@
 
 #include "xmule.h"                          // Needed for this Interface's Prototype
 
-#include "CFile.h"                          // Needed for CFile
 #include "ChatWnd.h"                        // Needed for CChatWnd
 #include "ClientCredits.h"                  // Needed for CClientCredits
 #include "ClientList.h"                     // Needed for CClientList
@@ -44,7 +43,7 @@
 #include "NewFunctions.h"                   // Needed for MAP
 #include "NewSockets.h"                     // Needed for NewSocket_Start
 #include "otherfunctions.h"                 // Needed for CastItoXBytes
-#include "Preferences.h"                    // Needed for CPreferences
+#include "Preferences.h"                    // CPreferences::List Settings
 #include "PreferencesDlg.h"                 // Needed for CPreferencesDlg
 #include "QueueListCtrl.h"                  // Needed for CQueueListCtrl
 #include "server.h"                         // Needed for CServer
@@ -62,7 +61,8 @@
 #include "UploadQueue.h"                    // Needed for CUploadQueue
 #include "xmuleDlg.h"                       // Needed for CxmuleDlg
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefsCtrl.h>          // Needed for wxEVT_PREFS_CHANGED
 
 #include <iostream>                         // Needed for std::cout
 #include <gtk/gtk.h>                        // Needed for GTK_WINDOW_TOPLEVEL
@@ -74,6 +74,8 @@
 
 #include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
 
+#include <unistd.h>                         // Needed for close
+
 using std::cout;
 using std::endl;
 
@@ -91,6 +93,8 @@ void InitSplashXRC();
 # define RLIMIT_RESOURCE int
 #endif
 
+//MAP* listof_sourcesKF;
+
 static void UnlimitResource(RLIMIT_RESOURCE resType)
 {
 #if defined(HAVE_GETRLIMIT) && defined(HAVE_SETRLIMIT)
@@ -122,6 +126,7 @@ CxmuleApp::~ CxmuleApp()
 
 int CxmuleApp::OnExit()
 {
+    delete uploadqueue;
     cout << "xMule shutdown completed." << endl;
     return wxApp::OnExit();
 }
@@ -131,22 +136,21 @@ extern void InitXmlResource();
 bool CxmuleApp::OnInit()
 {
 //    mtrace();
+    daemon = nowindow = false;
     for (int i = 1 ; i < argc ; i++)
     {
         if (strncmp(argv[i], "--version", 7) == 0)
         {
             printf("%s version %s\n", PACKAGE_NAME, PACKAGE_VERSION);
-            sleep(1);
             exit(0);
         }
-        else if (!(strncmp(argv[i], "--nowindow", 10)))
+        else if (strncmp(argv[i], "--daemon", 8) == 0)
         {
             printf ("Starting without windows\n");
             daemon = true;
-            nowindow = true;
         }
     }
-
+//    MapData_Init(listof_sourcesKF);
     wxHandleFatalExceptions(true);
     SetResourceLimits();
     // for resources
@@ -199,12 +203,14 @@ bool CxmuleApp::OnInit()
     }
     // Delete old log file.
     wxRemoveFile(wxString::Format("%s/.xMule/logfile", getenv("HOME")));
-    glob_prefs = new CPreferences();
     dynprefs = new DynamicPreferences;
-    xmuledlg->flowchartwnd = new CFlowChart(xmuledlg);
+    glob_prefs = new CPreferences();
+    xmuledlg->flowchartwnd = new CFlowChart(xmuledlg, dynprefs);
     xmuledlg->flowchartwnd->Show(false);
     LoadCompatiblePrefs();
     xmuledlg->preferenceswnd->SetPrefs(glob_prefs);
+
+    dynprefs->Add("daemon", daemon);
 /*
 -----BEGIN PGP MESSAGE-----
 Charset: UTF-8
@@ -223,12 +229,14 @@ hu+JvF+Z2knW4lRM7VrainKZOdpEvT3EKEBI
 =BUaZ
 -----END PGP MESSAGE-----
 */
-    if (daemon == false)
+    if (dynprefs->Get<bool>("daemon") == false)
     {
         xmuledlg->createSystray(wxString::Format(wxT("%s v%s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION)));
     }
 
-    if (daemon == false && theApp.glob_prefs->UseSplashScreen() && !theApp.glob_prefs->GetStartMinimized())
+    if (dynprefs->Get<bool>("daemon") == false &&
+/*->*/  theApp.dynprefs->Get<bool>("show-splashscreen") && 
+/*->*/  theApp.dynprefs->Get<bool>("start-minimized") == false)
     {
         InitSplashXRC();
         wxImage::AddHandler(new wxJPEGHandler);
@@ -237,20 +245,23 @@ hu+JvF+Z2knW4lRM7VrainKZOdpEvT3EKEBI
         wxSplashScreen* splsh = new wxSplashScreen(wxImage(*f->GetStream(), wxBITMAP_TYPE_JPEG), wxSPLASH_CENTRE_ON_SCREEN | wxSPLASH_TIMEOUT, 5000, NULL, - 1, wxDefaultPosition, wxDefaultSize, wxSIMPLE_BORDER | wxSTAY_ON_TOP);
     }
 
-    if (daemon)
+    if (dynprefs->Get<bool>("command-line") == true)
+    {
+        lda = new CLDaemon;
         lda->Init();
+    }
 
     clientlist = new CClientList();
     friendlist = new CFriendList();
-    knownfiles = new CKnownFileList(glob_prefs->GetAppDir());
+    knownfiles = new CKnownFileList(const_cast<char *>(dynprefs->Get<wxString>("app-directory").c_str()));
     serverlist = new CServerList(glob_prefs);
     serverconnect = new CServerConnect(serverlist, theApp.glob_prefs);
     sharedfiles = new CSharedFileList(glob_prefs, serverconnect, knownfiles);
-    printf("*** TCP socket at %d\n", glob_prefs->GetPort());
+//    printf("*** TCP socket at %d\n", theApp.dynprefs->Get<long>("tcp-port"));
     wxIPV4address myaddr;
     myaddr.AnyAddress();
-    myaddr.Service(glob_prefs->GetPort());
-    NewSocket_Start(1, 0, glob_prefs->GetUDPPort());
+    myaddr.Service(theApp.dynprefs->Get<long>("tcp-port"));
+    NewSocket_Start(1, 0, theApp.dynprefs->Get<long>("udp-port"));
 
     // bugfix - do this before creating the uploadqueue:
     downloadqueue = new CDownloadQueue(glob_prefs, sharedfiles);
@@ -300,17 +311,18 @@ hu+JvF+Z2knW4lRM7VrainKZOdpEvT3EKEBI
         webserver->ReloadTemplates();
         webserver->StartServer();
     }*/
-    myaddr.Service(glob_prefs->GetPort());
+
     listensocket = new CListenSocket(glob_prefs, myaddr);
     if (!listensocket->Ok())
     {
-        xmuledlg->AddLogLine(false, (_("Port %d is not available. You will be LOWID")), glob_prefs->GetPort());
-        CString str;
-        str.Format(_("Port %d is not available !!\n\nThis will mean that you will be LOWID.\n\nUse netstat to determine when port becomes available\nand try starting xmule again."), glob_prefs->GetPort());
+        xmuledlg->AddLogLine(false, (_("Port %d is not available. You will be LOWID")), theApp.dynprefs->Get<long>("tcp-port"));
+        wxString str;
+        str.Printf(_("Port %d is not available !!\n\nThis will mean that you will be LOWID.\n\nUse netstat to determine when port becomes available\nand try starting xmule again."), theApp.dynprefs->Get<long>("tcp-port"));
         wxMessageBox(str, _("Error"), wxCENTRE | wxOK | wxICON_ERROR);
     }
+
     // pretty much ready now. start autoconnect if
-    if (theApp.glob_prefs->DoAutoConnect())
+    if (theApp.dynprefs->Get<bool>("autoconnect") == true)
     {
         wxCommandEvent event;
         theApp.xmuledlg->OnBnConnect(event);
@@ -320,7 +332,7 @@ hu+JvF+Z2knW4lRM7VrainKZOdpEvT3EKEBI
 
 void CxmuleApp::ProcessCommand()
 {
-    uint32 num,i;
+    uint32_t num,i;
     wxString St1;
     bool notunderstood=true;
 
@@ -433,13 +445,13 @@ void CxmuleApp::RefreshFiles()
     }
 }
 
-void CxmuleApp::UpdateReceivedBytes(int32 bytesToAdd)
+void CxmuleApp::UpdateReceivedBytes(int32_t bytesToAdd)
 {
     SetTimeOnTransfer();
     stat_sessionReceivedBytes += bytesToAdd;
 }
 
-void CxmuleApp::UpdateSentBytes(int32 bytesToAdd)
+void CxmuleApp::UpdateSentBytes(int32_t bytesToAdd)
 {
     SetTimeOnTransfer();
     stat_sessionSentBytes += bytesToAdd;
@@ -485,7 +497,7 @@ wxString CxmuleApp::CreateED2kLink(CAbstractFile * f)
 {
     wxString strLink;
     // spaces to dots:
-    strLink = strLink.Format("ed2k://|file|%s|%d|%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x|/", StripInvalidFilenameChars(f->GetFileName(), true) .GetData(),
+    strLink.Printf("ed2k://|file|%s|%d|%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x|/", StripInvalidFilenameChars(f->GetFileName(), true) .GetData(),
     f->GetFileSize(), f->GetFileHash() [0], f->GetFileHash() [1], f->GetFileHash() [2], f->GetFileHash() [3], f->GetFileHash() [4], f->GetFileHash() [5], f->GetFileHash() [6], f->GetFileHash() [7], f->GetFileHash() [8], f->GetFileHash() [9], f->GetFileHash() [10], f->GetFileHash() [11], f->GetFileHash() [12], f->GetFileHash() [13], f->GetFileHash() [14], f->GetFileHash() [15]);
     return strLink.GetData();
 }
@@ -495,13 +507,13 @@ wxString CxmuleApp::CreateED2kSourceLink(CAbstractFile * f)
     if (!serverconnect->IsConnected() || serverconnect->IsLowID())
     {
         xmuledlg->AddLogLine(true, GetResString(IDS_SOURCELINKFAILED));
-        return CString("");
+        return wxString("");
     }
-    uint32 dwID = serverconnect->GetClientID();
+    uint32_t dwID = serverconnect->GetClientID();
     wxString strLink;
     // spaces to dots:
     strLink.Printf("ed2k://|file|%s|%u|%s|/|sources,%i.%i.%i.%i:%i|/", StripInvalidFilenameChars(f->GetFileName(), false) .GetData(),
-    f->GetFileSize(), EncodeBase16(f->GetFileHash(), 16) .GetData(), (uint8) dwID, (uint8)(dwID >> 8), (uint8)(dwID >> 16), (uint8)(dwID >> 24), glob_prefs->GetPort());
+    f->GetFileSize(), EncodeBase16(f->GetFileHash(), 16) .GetData(), (uint8_t) dwID, (uint8_t)(dwID >> 8), (uint8_t)(dwID >> 16), (uint8_t)(dwID >> 24), theApp.dynprefs->Get<long>("tcp-port"));
     return strLink;
 }
 
@@ -521,32 +533,25 @@ bool CxmuleApp::CopyTextToClipboard(wxString strText)
     }
 }
 
- /* Original implementation by Bouc7 of the eMule Project.
+/* Original implementation by Bouc7 of the eMule Project.
  xMule Signature idea was designed by BigBob and implemented
  by Un-Thesis, with design inputs and suggestions from bothie.
-    */
+*/
 
-    void CxmuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */
-
-)
+void CxmuleApp::OnlineSig(bool zero)
 {
     // Do not do anything if online signature is disabled in Preferences
-    if (!theApp.glob_prefs->IsOnlineSignatureEnabled())
+    if (theApp.dynprefs->Get<bool>("online-signature") == false)
     {
         return;
     }
-    // Build the filenames for the two files
-    char * emulesig_path = new char[strlen(glob_prefs->GetAppDir()) + 14];
-    char * xmulesig_path = new char[strlen(glob_prefs->GetAppDir()) + 13];
-    sprintf(emulesig_path, "%sonlinesig.dat", glob_prefs->GetAppDir());
-    sprintf(xmulesig_path, "%sxmulesig.dat", glob_prefs->GetAppDir());
     // Open both files for writing
-    CFile xmulesig_out, emulesig_out;
-    if (!emulesig_out.Open(emulesig_path, CFile::write))
+    wxFile xmulesig_out, emulesig_out;
+    if (!emulesig_out.Open(dynprefs->Get<wxString>("app-directory") + wxT("onlinesig.dat"), wxFile::write))
     {
         theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERROR_SAVEFILE) + wxString(" OnlineSig File"));
     }
-    if (!xmulesig_out.Open(xmulesig_path, CFile::write))
+    if (!xmulesig_out.Open(dynprefs->Get<wxString>("app-directory") + wxT("xmulesig.dat"), wxFile::write))
     {
         theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERROR_SAVEFILE) + wxString(" xMule OnlineSig File"));
     }
@@ -615,13 +620,13 @@ bool CxmuleApp::CopyTextToClipboard(wxString strText)
         xmulesig_out.Write(buffer, strlen(buffer));
         xmulesig_out.Write("\n", 1);
         // Number of shared files
-        sprintf(buffer, "%d", theApp.sharedfiles->listof_SharedFiles->Data);
+        sprintf(buffer, "%d", theApp.sharedfiles->GetCount());
         xmulesig_out.Write(buffer, strlen(buffer));
         xmulesig_out.Write("\n", 1);
     }
     /* if (!zero) */
     // Nick on the network
-    sprintf(buffer, "%s", theApp.glob_prefs->GetUserNick());
+    sprintf(buffer, "%s", const_cast<char *>(dynprefs->Get<wxString>("nickname").c_str()));
     xmulesig_out.Write(buffer, strlen(buffer));
     xmulesig_out.Write("\n", 1);
     // Total received in GB
@@ -639,8 +644,6 @@ bool CxmuleApp::CopyTextToClipboard(wxString strText)
     // Close the files
     emulesig_out.Close();
     xmulesig_out.Close();
-    delete[] emulesig_path;
-    delete[] xmulesig_path;
     //End Added By Bouc7:
 }
 
@@ -821,134 +824,12 @@ wxColour GetColour(wxSystemColour what)
 
 void CxmuleApp::LoadCompatiblePrefs()
 {
-    Preferences_Struct* oldprefs = theApp.glob_prefs->prefs;
-// General Settings
-    dynprefs->Add("nickname", wxString(oldprefs->nick, *wxConvCurrent));
-    dynprefs->Add("progress-bar-style", (long)oldprefs->depth3D);
-    dynprefs->Add("beep-on-errors", (bool)oldprefs->beepOnError);
-    dynprefs->Add("bring-to-front", (bool)oldprefs->bringtoforeground);
-    dynprefs->Add("download-doubleclick", (bool)oldprefs->transferDoubleclick);
-    dynprefs->Add("mimimize-to-tray", (bool)oldprefs->mintotray);
-    dynprefs->Add("online-signature", (bool)oldprefs->onlineSig);
-    dynprefs->Add("prompt-on-exit", (bool)oldprefs->confirmExit);
-    // * As a temp hack, we subtract 1 from desktopMode because of irregularities in eMule code 
-    dynprefs->Add("systray-integration", (long)(oldprefs->desktopMode - 1));
-    dynprefs->Add("show-splashscreen", (bool)oldprefs->splashscreen);
-    dynprefs->Add("start-minimized", (bool)oldprefs->startMinimized);
-
-// Connection Settings
-    dynprefs->Add("limits-download", (long)(oldprefs->maxdownload == 65535 ? 0 : oldprefs->maxdownload));
-    dynprefs->Add("limits-upload", (long)(oldprefs->maxupload == 65535 ? 0 : oldprefs->maxupload));
-    dynprefs->Add("capacities-download", (long)(oldprefs->maxGraphDownloadRate == 65535 ? 0 : oldprefs->maxGraphDownloadRate));
-    dynprefs->Add("capacities-upload", (long)(oldprefs->maxGraphUploadRate == 65535 ? 0 : oldprefs->maxGraphUploadRate));
-    dynprefs->Add("tcp-port", (long)oldprefs->port);
-    dynprefs->Add("enable-udp", (bool)(oldprefs->udpport == 0 ? false : true));
-    dynprefs->Add("udp-port", (long)oldprefs->udpport);
-    dynprefs->Add("max-sources", (long)oldprefs->maxsourceperfile);
-    dynprefs->Add("autoconnect", (bool)oldprefs->autoconnect);
-    dynprefs->Add("reconnect-on-loss", (bool)oldprefs->reconnect);
-    dynprefs->Add("show-overhead", (bool)oldprefs->m_bshowoverhead);
-
-// Server Settings
-    dynprefs->Add("remove-dead-server", (bool)oldprefs->deadserver);
-    dynprefs->Add("server-connect-tries", (long)oldprefs->deadserverretries);
-    dynprefs->Add("filter-bad-ip", (bool)oldprefs->filterBadIP);
-    dynprefs->Add("autoupdate-server", (bool)oldprefs->autoserverlist);
-    dynprefs->Add("add-server-server", (bool)oldprefs->addserversfromserver);
-    dynprefs->Add("add-server-client", (bool)oldprefs->addserversfromclient);
-    dynprefs->Add("priority-system", (bool)oldprefs->scorsystem);
-    dynprefs->Add("smart-lowid-check", (bool)oldprefs->smartidcheck);
-    dynprefs->Add("use-safe-connect", (bool)oldprefs->safeServerConnect);
-    dynprefs->Add("auto-static", (bool)oldprefs->autoconnectstaticonly);
-    dynprefs->Add("add-server-high", (bool)oldprefs->m_bmanualhighprio);
-
-// Files Settings
-    dynprefs->Add("see-share", (long)oldprefs->m_iSeeShares);
-    dynprefs->Add("last-chunk-first", (bool)oldprefs->m_bpreviewprio);
-    dynprefs->Add("start-next-file", (bool)oldprefs->m_bstartnextfile);
-    dynprefs->Add("transfer-full-chunks", (bool)oldprefs->m_btransferfullchunks);
-    dynprefs->Add("add-paused", (bool)oldprefs->addnewfilespaused);
-    dynprefs->Add("enable-ich", (bool)oldprefs->ICH);
-    dynprefs->Add("auto-priority-share", (bool)oldprefs->m_bUAP);
-
-// Directories Settings
-    dynprefs->Add("incoming-directory", wxString(oldprefs->incomingdir, *wxConvCurrent));
-    dynprefs->Add("temp-directory", wxString(oldprefs->tempdir, *wxConvCurrent));
-#warning FIXME: -NEED- support for sharing other folders
-
-// Statistics Settings
-    dynprefs->Add("graph-delay", (long)oldprefs->trafficOMeterInterval);
-    dynprefs->Add("graph-average", (long)oldprefs->statsAverageMinutes);
-    dynprefs->Add("tree-delay", (long)oldprefs->statsInterval);
-
 // Send newprefs event
     wxNotifyEvent event(wxEVT_PREFS_CHANGED);
-    xmuledlg->flowchartwnd->dynprefs->AddPendingEvent(event);
+    xmuledlg->flowchartwnd->AddPendingEvent(event);
 }
 
 void CxmuleApp::SetCompatiblePrefs()
 {
-    Preferences_Struct* oldprefs = theApp.glob_prefs->prefs;
-// General Settings
-    strcpy(oldprefs->nick, dynprefs->Get<wxString>("nickname").c_str());
-    oldprefs->depth3D = dynprefs->Get<long>("progress-bar-style");
-    oldprefs->beepOnError = dynprefs->Get<bool>("beep-on-errors");
-    oldprefs->bringtoforeground = dynprefs->Get<bool>("bring-to-front");
-    oldprefs->transferDoubleclick = dynprefs->Get<bool>("download-doubleclick");
-    oldprefs->mintotray = dynprefs->Get<bool>("mimimize-to-tray");
-    oldprefs->onlineSig = dynprefs->Get<bool>("online-signature");
-    oldprefs->confirmExit = dynprefs->Get<bool>("prompt-on-exit");
-    // * As a temp hack, we subtract 1 from desktopMode because of irregularities in eMule code 
-    oldprefs->desktopMode = dynprefs->Get<long>("systray-integration") + 1;
-    oldprefs->splashscreen = dynprefs->Get<bool>("show-splashscreen");
-    oldprefs->startMinimized = dynprefs->Get<bool>("start-minimized");
-
-// Connection Settings
-    long temp;
-    temp = dynprefs->Get<long>("capacities-download");
-    oldprefs->maxGraphDownloadRate = (temp == 0 ? 65535 : temp);
-    temp = dynprefs->Get<long>("capacities-upload");
-    oldprefs->maxGraphUploadRate = (temp == 0 ? 65535 : temp);
-    temp = dynprefs->Get<long>("limits-upload");
-    oldprefs->maxupload = (temp == 0 ? 65535 : temp);
-    temp = dynprefs->Get<long>("limits-download");
-    oldprefs->maxdownload = (temp == 0 ? 65535 : temp);
-    oldprefs->port = dynprefs->Get<long>("tcp-port");
-    oldprefs->udpport = dynprefs->Get<long>("udp-port");
-    oldprefs->maxsourceperfile = dynprefs->Get<long>("max-sources");
-    oldprefs->autoconnect = dynprefs->Get<bool>("autoconnect");
-    oldprefs->reconnect = dynprefs->Get<bool>("reconnect-on-loss");
-    oldprefs->m_bshowoverhead = dynprefs->Get<bool>("show-overhead");
-
-// Server Settings
-    oldprefs->deadserver = dynprefs->Get<bool>("remove-dead-server");
-    oldprefs->deadserverretries = dynprefs->Get<long>("server-connect-tries");
-    oldprefs->filterBadIP = dynprefs->Get<bool>("filter-bad-ip");
-    oldprefs->autoserverlist = dynprefs->Get<bool>("autoupdate-server");
-    oldprefs->addserversfromserver = dynprefs->Get<bool>("add-server-server");
-    oldprefs->addserversfromclient = dynprefs->Get<bool>("add-server-client");
-    oldprefs->scorsystem = dynprefs->Get<bool>("priority-system");
-    oldprefs->smartidcheck = dynprefs->Get<bool>("smart-lowid-check");
-    oldprefs->safeServerConnect = dynprefs->Get<bool>("use-safe-connect");
-    oldprefs->autoconnectstaticonly = dynprefs->Get<bool>("auto-static");
-    oldprefs->m_bmanualhighprio = dynprefs->Get<bool>("add-server-high");
-
-// Files Settings
-    oldprefs->m_iSeeShares = dynprefs->Get<long>("see-share");
-    oldprefs->m_bpreviewprio = dynprefs->Get<bool>("last-chunk-first");
-    oldprefs->m_bstartnextfile = dynprefs->Get<bool>("start-next-file");
-    oldprefs->m_btransferfullchunks = dynprefs->Get<bool>("transfer-full-chunks");
-    oldprefs->addnewfilespaused = dynprefs->Get<bool>("add-paused");
-    oldprefs->ICH = dynprefs->Get<bool>("enable-ich");
-    oldprefs->m_bUAP = dynprefs->Get<bool>("auto-priority-share");
-
-// Directories Settings
-    strcpy(oldprefs->incomingdir, dynprefs->Get<wxString>("incoming-directory").c_str());
-    strcpy(oldprefs->tempdir, dynprefs->Get<wxString>("temp-directory").c_str());
-
-// Statistics Settings
-    theApp.glob_prefs->SetTrafficOMeterInterval(dynprefs->Get<long>("graph-delay"));
-    theApp.glob_prefs->SetStatsAverageMinutes(dynprefs->Get<long>("graph-average"));
-    theApp.glob_prefs->SetStatsInterval(dynprefs->Get<long>("tree-delay"));
     theApp.xmuledlg->statisticswnd->ShowInterval();
 }
