@@ -22,9 +22,9 @@
 #ifndef XMULE_H
 #define XMULE_H
 
-#include "types.h"                          // Needed for uint64
-#include "wintypes.h"                       // Needed for DWORD
+#include "wintypes.h"                       // Needed for DWORD - audited 4 Nov 2004
 
+#include <stdint.h>                         // uint32_t
 #include <wx/app.h>                         // Needed for wxApp
 #include <wx/intl.h>                        // Needed for wxLocale
 #include <wx/settings.h>                    // Needed for wxSystemColour
@@ -72,19 +72,19 @@ public:
     CClientCreditsList *clientcredits;
     CFriendList *friendlist;
 //    CWebServer *webserver;
-    //virtual BOOL		InitInstance();
+    //virtual bool		InitInstance();
     virtual bool OnInit();
     wxString *pendinglink;
     //tagCOPYDATASTRUCT  sendstruct; //added by Cax2 28/10/02
     CIPFilter *ipfilter;
-    uint64 stat_sessionReceivedBytes;
-    uint64 stat_sessionSentBytes;
-    uint16 stat_reconnects;
+    uint64_t stat_sessionReceivedBytes;
+    uint64_t stat_sessionSentBytes;
+    uint16_t stat_reconnects;
     DWORD stat_transferStarttime;
     DWORD stat_serverConnectTime;
-    uint16 stat_filteredclients;
+    uint16_t stat_filteredclients;
     DWORD Start_time;
-    bool daemon,nowindow;
+    bool daemon, nowindow;
     CLDaemon* lda;
     // Implementierung
     // ed2k link functions
@@ -94,8 +94,8 @@ public:
     wxString CreateED2kSourceLink(CAbstractFile *f);
     bool CopyTextToClipboard(wxString strText);
     void OnlineSig(bool zero = false);
-    void UpdateReceivedBytes(int32 bytesToAdd);
-    void UpdateSentBytes(int32 bytesToAdd);
+    void UpdateReceivedBytes(int32_t bytesToAdd);
+    void UpdateSentBytes(int32_t bytesToAdd);
     void ProcessCommand ();
     void RefreshFiles ();
     
