@@ -39,6 +39,7 @@
 #include "ListenSocket.h"                   // Needed for CListenSocket
 #include "muuli_wdr.h"                      // Needed for ID_BUTTONCONNECT
 #include "NewSockets.h"                     // Needed for NewSocket_Stop
+#include "opcodes.h"                        // Needed for ID_XMULEDLG
 #include "PartFile.h"                       // Needed for CPartFile
 #include "Preferences.h"                    // Needed for CPreferences
 #include "PreferencesDlg.h"                 // Needed for CPreferencesDlg
@@ -61,7 +62,7 @@
 #include "UploadQueue.h"                    // Needed for CUploadQueue
 #include "xmule.h"                          // Needed for theApp
 
-#include "DynPrefs/DynPrefs.h"              // Needed for theApp.dynprefs
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <cerrno>                           // Needed for errno
 #include <cmath>                            // Needed for ceil
@@ -82,15 +83,15 @@
 #include "pixmaps/mule_Tr_grey.ico.xpm"
 
 #if wxMINOR_VERSION > 4
-#	define CLOSEBOX wxCLOSE_BOX
+    #define CLOSEBOX wxCLOSE_BOX
 #else
-#	define CLOSEBOX 0
+    #define CLOSEBOX 0
 #endif
 
 #define ID_UQTIMER 59742
 #define TM_DNSDONE 17851
 
-extern wxRadioButton * radiobutton[4];
+extern wxRadioButton* radiobutton[4];
 
 BEGIN_EVENT_TABLE(CxmuleDlg, wxFrame)
     EVT_SOCKET(ID_SOKETTI, CxmuleDlg::socketHandler)
@@ -133,9 +134,9 @@ void CxmuleDlg::OnFinishedHashing(wxCommandEvent & evt)
     }
     else
     {
-        if (theApp.sharedfiles->kfilelist->SafeAddKFile(0, result))
+        if (theApp.sharedfiles->filelist->SafeAddKFile(result))
         {
-            theApp.sharedfiles->SafeAddKFile(0, result);
+            theApp.sharedfiles->SafeAddKFile(result);
         }
         else
         {
@@ -160,17 +161,22 @@ void muleDefaultToolbar(wxToolBar * parent)
     //    parent->AddCheckTool( ID_BUTTONIRC, _("IRC"),xmuleDlgImages( 19 ), wxNullBitmap, _("Internet Relay Chat"));
     parent->AddCheckTool(ID_BUTTONSTATISTICS, _("Statistics"), xmuleDlgImages(4), wxNullBitmap, _("Show current statistics"));
     parent->AddSeparator();
-    parent->AddTool(ID_BUTTONPREFERENCES, _("Preferences"), xmuleDlgImages(5), _("Modify preferences"));
+    parent->AddTool(ID_BUTTONFLOWCHART, _("Main Prefs"), xmuleDlgImages(5), _("Most setings"));
+    parent->AddTool(ID_BUTTONPREFERENCES, _("Minor Prefs"), xmuleDlgImages(6), _("Modify preferences"));
     parent->AddSeparator();
-    parent->AddTool(ID_BUTTONFLOWCHART, _("FlowChart"), xmuleDlgImages(6), _("FlowChart - Debuging & Docs"));
     parent->Realize();
 }
 
 // CxmuleDlg Dialog
 
 CxmuleDlg::CxmuleDlg(wxWindow * pParent, wxString title)
-: wxFrame(pParent, -1, title, wxDefaultPosition, wxSize(800, 520),
+: wxFrame(pParent, ID_XMULEDLG, title, wxDefaultPosition, wxSize(800, 520),
 wxCAPTION | wxRESIZE_BORDER | wxSYSTEM_MENU | wxDIALOG_NO_PARENT | wxTHICK_FRAME | wxMINIMIZE_BOX | wxMAXIMIZE_BOX | CLOSEBOX)
+{
+    OnInit();
+}
+
+void CxmuleDlg::OnInit()
 {
     theApp.xmuledlg = this;
     m_app_state = APP_STATE_STARTING;
@@ -249,60 +255,60 @@ wxCAPTION | wxRESIZE_BORDER | wxSYSTEM_MENU | wxDIALOG_NO_PARENT | wxTHICK_FRAME
 
 class QueryDlg: public wxDialog
 {
-    public:
-    QueryDlg(wxWindow * parent): wxDialog(parent, 21373, _("Desktop integration"), wxDefaultPosition,
-    wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxSYSTEM_MENU)
+public:
+    QueryDlg(wxWindow* parent): wxDialog(parent, 21373, _("Desktop integration"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxSYSTEM_MENU)
     {
-        wxSizer * content = desktopDlg(this, TRUE);
+        wxSizer* content = desktopDlg(this, TRUE);
         content->Show(this, TRUE);
         Centre();
-        };
-    protected:
+    }
+protected:
     void OnOk(wxCommandEvent& evt)
     {
+        long mode = 0;
+
+        if (radiobutton[0]->GetValue())
+        {
+            mode = 1;
+        }
+        else if (radiobutton[1]->GetValue())
+        {
+            mode = 2;
+        }
+        else if (radiobutton[2]->GetValue())
+        {
+            mode = 3;
+        }
+        else
+        {
+            mode = 4;
+        }
+
+        theApp.dynprefs->Add("systray-integration", mode);
         EndModal(0);
-        };
+    }
     DECLARE_EVENT_TABLE()
 };
 
 BEGIN_EVENT_TABLE(QueryDlg, wxDialog)
-EVT_BUTTON(ID_OK, QueryDlg::OnOk)
+    EVT_BUTTON(ID_OK, QueryDlg::OnOk)
 END_EVENT_TABLE()
 
 void CxmuleDlg::changeDesktopMode()
 {
     QueryDlg query(this);
-    query.ShowModal();
-    // then determine what choice is selected
-    int mode = 0;
-    if (radiobutton[0]->GetValue())
-    {
-        mode = 1;
-    }
-    else if(radiobutton[1]->GetValue())
-    {
-        mode = 2;
-    }
-    else if(radiobutton[2]->GetValue())
-    {
-        mode = 3;
-    }
-    else
-    {
-        mode = 4;
-    }
-    theApp.glob_prefs->SetDesktopMode(mode);
 }
 
 void CxmuleDlg::createSystray(const wxString & title)
 {
     // create the docklet (at this point we already have preferences!)
-    if (theApp.glob_prefs->GetDesktopMode() == 0)
+    if (theApp.dynprefs->Get<long>("systray-integration") == 0)
     {
         // ok, it's not set yet.
         changeDesktopMode();
     }
-    m_wndTaskbarNotifier = new CSysTray(this, theApp.glob_prefs->GetDesktopMode(), title);
+
+    m_wndTaskbarNotifier = new CSysTray(this, theApp.dynprefs->Get<long>("systray-integration"), title);
 }
 
 extern void TimerProc();
@@ -371,168 +377,9 @@ void CxmuleDlg::btnPreferences(wxCommandEvent& ev)
     preferenceswnd->ShowModal();
 }
 
-void CxmuleDlg::socketHandler(wxSocketEvent & event)
+void CxmuleDlg::socketHandler(wxSocketEvent& event)
 {
-    if (event.GetSocket())
-    {
-        if (IsRunning())
-        {
- /*
- #if defined(__DEBUG__)
- printf("socketHandler:  %lu ", (wxUint32) event.GetSocket());
- switch (event.GetSocketEvent())
- {
- case wxSOCKET_CONNECTION:
- printf(" type=%ld (CONNECTION) ", event.GetSocketEvent());
- break;
- case wxSOCKET_LOST:
- printf(" type=%ld (LOST)       ", event.GetSocketEvent());
- break;
- case wxSOCKET_INPUT:
- if(theApp.dynprefs->Get<bool>("enable-serverless") == false) {
- printf(" type=%ld (INPUT)      ", event.GetSocketEvent());
- }
- break;
- case wxSOCKET_OUTPUT:
- printf(" type=%ld (OUTPUT)     ", event.GetSocketEvent());
- break;
- default:
- printf(" type=%ld (wxUNKNOWN)           ", event.GetSocketEvent());
- break;
- }
- #endif
-    */
-            wxSocketBase * soc = event.GetSocket();
-            wxIPV4address addr1;
-            (void) soc->GetPeer(addr1);
-            if (inet_addr(addr1.IPAddress()) != 1)
-            {
- /*
- #if defined(__DEBUG__)
- printf(" peer(ip:port)=%s:%d ",
- (const char *) addr1.IPAddress(), addr1.Service());
- #endif
-    */
-                switch (event.GetSocketEvent())
-                {
-                case wxSOCKET_CONNECTION:
-                    break;
-                case wxSOCKET_LOST:
-                    break;
-                case wxSOCKET_INPUT:
-                    break;
-                case wxSOCKET_OUTPUT:
-                    break;
-                default:
-                    break;
-                }
- /*
- #if defined(__DEBUG__)
- printf(" class=%s\n", event.GetSocket()->GetClassInfo()->GetClassName());
- #endif
-    */
-                if (event.GetSocket()->IsKindOf(CLASSINFO(CListenSocket)))
-                {
-                    CListenSocket * soc = (CListenSocket *) event.GetSocket();
-                    switch (event.GetSocketEvent())
-                    {
-                    case wxSOCKET_CONNECTION:
-                        soc->OnAccept(0);
-                        break;
-                    default:
-                        // shouldn't get other than connection events...
-                        break;
-                    }
-                    return;
-                }
-                if (event.GetSocket()->IsKindOf(CLASSINFO(CClientReqSocket)))
-                {
-                    CClientReqSocket * soc = (CClientReqSocket *) event.GetSocket();
-                    switch (event.GetSocketEvent())
-                    {
-                    case wxSOCKET_LOST:
-                        soc->OnLost(errno);
-                        break;
-                    case wxSOCKET_INPUT:
-                        if (theApp.dynprefs->Get<bool>("enable-serverless") == false)
-                        {
-                            soc->OnInput(0);
-                        }
-                        break;
-                    case wxSOCKET_OUTPUT:
-                        soc->OnOutput(0);
-                        break;
-                    default:
-                        // connection requests should not arrive here..
-                        break;
-                    }
-                    return;
-                }
-                if (event.GetSocket()->IsKindOf(CLASSINFO(CUDPSocket)))
-                {
-                    CUDPSocket * soc = (CUDPSocket *) event.GetSocket();
-                    switch (event.GetSocketEvent())
-                    {
-                    case wxSOCKET_INPUT:
-                        if (theApp.dynprefs->Get<bool>("enable-serverless") == false)
-                        {
-                            soc->OnReceive(0);
-                        }
-                        break;
-                    default:
-                        break;
-                    }
-                    return;
-                }
-                if (event.GetSocket()->IsKindOf(CLASSINFO(CServerSocket)))
-                {
-                    CServerSocket * soc = (CServerSocket *) event.GetSocket();
-                    switch (event.GetSocketEvent())
-                    {
-                    case wxSOCKET_CONNECTION:
-                        soc->OnConnect(0);
-                        break;
-                    case wxSOCKET_LOST:
-                        soc->OnLost(errno);
-                        break;
-                    case wxSOCKET_INPUT:
-                        if (theApp.dynprefs->Get<bool>("enable-serverless") == false)
-                        {
-                            soc->OnInput(0);
-                        }
-                        break;
-                    case wxSOCKET_OUTPUT:
-                        soc->OnSend(0);
-                        break;
-                    default:
-                        break;
-                    }
-                    return;
-                }
-                if (event.GetSocket()->IsKindOf(CLASSINFO(CClientUDPSocket)))
-                {
-                    CClientUDPSocket * soc = (CClientUDPSocket *) event.GetSocket();
-                    switch (event.GetSocketEvent())
-                    {
-                    case wxSOCKET_INPUT:
-                        if (theApp.dynprefs->Get<bool>("enable-serverless") == false)
-                        {
-                            soc->OnReceive(0);
-                        }
-                        break;
-                    case wxSOCKET_OUTPUT:
-                        soc->OnSend(0);
-                        break;
-                    default:
-                        break;
-                    }
-                    return;
-                }
-                printf("*** SHOULD NOT END UP HERE\n");
-                printf("** class is %s\n", event.GetSocket()->GetClassInfo()->GetClassName());
-            }
-        }
-    }
+    cout << "CxmuleDlg::socketHandler() should have *not* been called! :o" << endl;
 }
 
 CxmuleDlg::~ CxmuleDlg()
@@ -593,6 +440,8 @@ void CxmuleDlg::ShutDown()
     theApp.glob_prefs = NULL;
     delete theApp.serverconnect;
     theApp.serverconnect = NULL;
+    delete m_wndTaskbarNotifier;
+    m_wndTaskbarNotifier = NULL;
 }
 
 // CxmuleDlg eventhandler
@@ -669,7 +518,7 @@ void CxmuleDlg::AddLogLine(bool addtostatusbar, const wxChar * line, ...)
     }
     // Write into log file
     wxString filename;
-    filename = filename.Format("%s/.xMule/logfile", getenv("HOME"));
+    filename =  wxString(getenv("HOME"), *wxConvCurrent) + wxT("/.xMule/logfile");
     wxFile file(filename, wxFile::write_append);
     if (file.IsOpened())
     {
@@ -693,7 +542,7 @@ void CxmuleDlg::AddServerMessageLine(char * line, ...)
         cv->AppendText(wxString(bufferline) + wxString("\n"));
         cv->ShowPosition(cv->GetValue() .Length() - 1);
     }
-    //serverwnd.servermsgbox.AppendText(CString(bufferline)+CString("\n"));
+    //serverwnd.servermsgbox.AppendText(wxString(bufferline)+wxString("\n"));
 }
 
 void CxmuleDlg::ShowConnectionState(bool connected)
@@ -749,7 +598,7 @@ void CxmuleDlg::ShowConnectionState(bool connected, wxString server, bool iconOn
  else
  statusbar.SetIcon(3,connicons[2]);
     */
-        //statusbar.SetText(GetResString(IDS_MAIN_CONNECTEDTO) +CString(server),0,0);
+        //statusbar.SetText(GetResString(IDS_MAIN_CONNECTEDTO) +wxString(server),0,0);
         wxStaticText * tx = (wxStaticText *) FindWindow("infoLabel");
         tx->SetLabel(GetResString(IDS_MAIN_CONNECTEDTO) + wxString(server));
         ((wxStaticText *) FindWindow("connLabel"))->SetLabel(server);
@@ -815,9 +664,9 @@ void CxmuleDlg::ShowConnectionState(bool connected, wxString server, bool iconOn
     }
 }
 
-void CxmuleDlg::ShowUserCount(uint32 user_toshow, uint32 file_toshow)
+void CxmuleDlg::ShowUserCount(uint32_t user_toshow, uint32_t file_toshow)
 {
-    uint32 totaluser, totalfile;
+    uint32_t totaluser, totalfile;
     totaluser = totalfile = 0;
     if (user_toshow || file_toshow)
     theApp.serverlist->GetUserFileStatus(totaluser, totalfile);
@@ -828,7 +677,7 @@ void CxmuleDlg::ShowUserCount(uint32 user_toshow, uint32 file_toshow)
     //statusbar.SetText(buffer,1,0);
 }
 
-void CxmuleDlg::ShowMessageState(uint8 iconnr)
+void CxmuleDlg::ShowMessageState(uint8_t iconnr)
 {
     //statusbar.SetIcon(4,imicons[iconnr]);
 }
@@ -846,7 +695,7 @@ void CxmuleDlg::ShowTransferRate(bool foreceAll)
     int lastuprateoverhead = theApp.uploadqueue->GetUpDatarateOverhead();
     int lastdownrateoverhead = theApp.downloadqueue->GetDownDatarateOverhead();
 
-    if (theApp.glob_prefs->ShowOverhead())
+    if (theApp.dynprefs->Get<bool>("show-overhead"))
     {
         sprintf(buffer, GetResString(IDS_UPDOWN), (float) lastuprate/ 1024, (float) lastuprateoverhead/ 1024, (float) lastdownrate/ 1024, (float) lastdownrateoverhead/ 1024);
     }
@@ -875,10 +724,10 @@ void CxmuleDlg::ShowTransferRate(bool foreceAll)
         ConnState = GetResString(IDS_DISCONNECTED);
     }
 
-    if (!theApp.daemon)
+    if (theApp.dynprefs->Get<bool>("daemon") == false)
     {
         // set trayicon-icon
-        int DownRateProcent = (int) ceil((lastdownrate/10.24) / theApp.glob_prefs->GetMaxGraphDownloadRate());
+        int DownRateProcent = (int)ceil((lastdownrate / 10.24) / theApp.dynprefs->Get<long>("capacities-download"));
         if (DownRateProcent > 100) DownRateProcent = 100;
         UpdateTrayIcon(DownRateProcent);
 
@@ -905,26 +754,26 @@ void CxmuleDlg::ShowTransferRate(bool foreceAll)
     }
 
     //PLK Show-Rates on title
-    if (theApp.glob_prefs->ShowRatesOnTitle())
+    if (theApp.dynprefs->Get<bool>("xfer-on-title") == true)
     {
-        if (theApp.daemon)
+        if (theApp.dynprefs->Get<bool>("command-line") == true)
         {
             theApp.lda->Print(wxString::Format(wxT("%s v%s --- %s --- %s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION), buffer,ConnState.GetData()),LD_STATUS,true);
         }
 
-        if (!theApp.nowindow)
+        if (theApp.dynprefs->Get<bool>("daemon") == false)
         {
             theApp.xmuledlg->SetTitle(wxString::Format(wxT("%s v%s --- %s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION), buffer));
         }
     }
     else
     {
-        if (theApp.daemon)
+        if (theApp.dynprefs->Get<bool>("command-line") == true)
         {
-            theApp.lda->Print (wxString::Format(wxT("%s v%s --- %s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION),ConnState.GetData()),LD_STATUS,true);
+            theApp.lda->Print(wxString::Format(wxT("%s v%s --- %s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION),ConnState.GetData()),LD_STATUS,true);
         }
         
-        if (!theApp.nowindow)
+        if (theApp.dynprefs->Get<bool>("daemon") == false)
         {
               theApp.xmuledlg->SetTitle(wxString::Format(wxT("%s v%s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION)));
         }
@@ -957,7 +806,7 @@ void CxmuleDlg::OnHashingShutdown(wxCommandEvent &)
 
 void CxmuleDlg::OnClose(wxCloseEvent & evt)
 {
-    if (evt.CanVeto() && theApp.glob_prefs->IsConfirmExitEnabled())
+    if (evt.CanVeto() && theApp.dynprefs->Get<bool>("prompt-on-exit") == true)
     if (wxNO == wxMessageBox(GetResString(IDS_MAIN_EXIT), GetResString(IDS_MAIN_EXITTITLE), wxYES_NO))
     {
         evt.Veto();
@@ -1107,7 +956,7 @@ void CxmuleDlg::OnQLTimer(wxTimerEvent & evt)
 
 void CxmuleDlg::MinimizeDlg(wxIconizeEvent& event)
 {
-    if ((theApp.glob_prefs->DoMinToTray() == true) && (theApp.glob_prefs->GetDesktopMode() != 4) && (event.Iconized() == true))
+    if ((theApp.dynprefs->Get<bool>("mimimize-to-tray") == true) && (theApp.dynprefs->Get<long>("systray-integration") != 3) && (event.Iconized() == true))
     {
         theApp.xmuledlg->Show(false);
     }
